/* Generated by Cython 0.28.1 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [], 
        "include_dirs": [
            "/opt/nec/ve/veos/include"
        ], 
        "libraries": [
            "veosinfo"
        ], 
        "library_dirs": [
            "/opt/nec/ve/veos/lib64"
        ], 
        "name": "veosinfo", 
        "sources": [
            "veosinfo.pyx"
        ]
    }, 
    "module_name": "veosinfo"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_28_1"
#define CYTHON_FUTURE_DIVISION 0
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (0 && PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0; // PyThread_create_key reports success always
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif // TSS (Thread Specific Storage) API
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : (Py_INCREF(func), func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__veosinfo
#define __PYX_HAVE_API__veosinfo
/* Early includes */
#include <sys/types.h>
#include <signal.h>
#include <sys/time.h>
#include <sys/resource.h>
#include <stdint.h>
#include <string.h>
#include <sched.h>
#include <sys/param.h>
#include <veosinfo/veosinfo.h>
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "veosinfo.pyx",
  "stringsource",
};

/* "veosinfo.pyx":40
 * import time
 * 
 * ctypedef int pid_t             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "<sched.h>":
 */
typedef int __pyx_t_8veosinfo_pid_t;

/*--- Type declarations ---*/
struct __pyx_obj___Pyx_EnumMeta;

/* "veosinfo.pyx":429
 * # VE register IDs usable to retrieve registers with ve_get_regvals()
 * #
 * cpdef enum VERegIds:             # <<<<<<<<<<<<<<
 *     USRCC = 0,
 *     PMC00, PMC01, PMC02, PMC03, PMC04, PMC05, PMC06,
 */
enum __pyx_t_8veosinfo_VERegIds {
  __pyx_e_8veosinfo_USRCC = 0,
  __pyx_e_8veosinfo_PMC00,
  __pyx_e_8veosinfo_PMC01,
  __pyx_e_8veosinfo_PMC02,
  __pyx_e_8veosinfo_PMC03,
  __pyx_e_8veosinfo_PMC04,
  __pyx_e_8veosinfo_PMC05,
  __pyx_e_8veosinfo_PMC06,
  __pyx_e_8veosinfo_PMC07,
  __pyx_e_8veosinfo_PMC08,
  __pyx_e_8veosinfo_PMC09,
  __pyx_e_8veosinfo_PMC10,
  __pyx_e_8veosinfo_PMC11,
  __pyx_e_8veosinfo_PMC12,
  __pyx_e_8veosinfo_PMC13,
  __pyx_e_8veosinfo_PMC14,
  __pyx_e_8veosinfo_PMC15,
  __pyx_e_8veosinfo_PSW,
  __pyx_e_8veosinfo_EXS,
  __pyx_e_8veosinfo_IC,
  __pyx_e_8veosinfo_ICE,
  __pyx_e_8veosinfo_VIXR,
  __pyx_e_8veosinfo_VL,
  __pyx_e_8veosinfo_SAR,
  __pyx_e_8veosinfo_PMMR,
  __pyx_e_8veosinfo_PMCR00,
  __pyx_e_8veosinfo_PMCR01,
  __pyx_e_8veosinfo_PMCR02,
  __pyx_e_8veosinfo_PMCR03,
  __pyx_e_8veosinfo_PMCR04,
  __pyx_e_8veosinfo_SR00,
  __pyx_e_8veosinfo_SR01,
  __pyx_e_8veosinfo_SR02,
  __pyx_e_8veosinfo_SR03,
  __pyx_e_8veosinfo_SR04,
  __pyx_e_8veosinfo_SR05,
  __pyx_e_8veosinfo_SR06,
  __pyx_e_8veosinfo_SR07,
  __pyx_e_8veosinfo_SR08,
  __pyx_e_8veosinfo_SR09,
  __pyx_e_8veosinfo_SR10,
  __pyx_e_8veosinfo_SR11,
  __pyx_e_8veosinfo_SR12,
  __pyx_e_8veosinfo_SR13,
  __pyx_e_8veosinfo_SR14,
  __pyx_e_8veosinfo_SR15,
  __pyx_e_8veosinfo_SR16,
  __pyx_e_8veosinfo_SR17,
  __pyx_e_8veosinfo_SR18,
  __pyx_e_8veosinfo_SR19,
  __pyx_e_8veosinfo_SR20,
  __pyx_e_8veosinfo_SR21,
  __pyx_e_8veosinfo_SR22,
  __pyx_e_8veosinfo_SR23,
  __pyx_e_8veosinfo_SR24,
  __pyx_e_8veosinfo_SR25,
  __pyx_e_8veosinfo_SR26,
  __pyx_e_8veosinfo_SR27,
  __pyx_e_8veosinfo_SR28,
  __pyx_e_8veosinfo_SR29,
  __pyx_e_8veosinfo_SR30,
  __pyx_e_8veosinfo_SR31,
  __pyx_e_8veosinfo_SR32,
  __pyx_e_8veosinfo_SR33,
  __pyx_e_8veosinfo_SR34,
  __pyx_e_8veosinfo_SR35,
  __pyx_e_8veosinfo_SR36,
  __pyx_e_8veosinfo_SR37,
  __pyx_e_8veosinfo_SR38,
  __pyx_e_8veosinfo_SR39,
  __pyx_e_8veosinfo_SR40,
  __pyx_e_8veosinfo_SR41,
  __pyx_e_8veosinfo_SR42,
  __pyx_e_8veosinfo_SR43,
  __pyx_e_8veosinfo_SR44,
  __pyx_e_8veosinfo_SR45,
  __pyx_e_8veosinfo_SR46,
  __pyx_e_8veosinfo_SR47,
  __pyx_e_8veosinfo_SR48,
  __pyx_e_8veosinfo_SR49,
  __pyx_e_8veosinfo_SR50,
  __pyx_e_8veosinfo_SR51,
  __pyx_e_8veosinfo_SR52,
  __pyx_e_8veosinfo_SR53,
  __pyx_e_8veosinfo_SR54,
  __pyx_e_8veosinfo_SR55,
  __pyx_e_8veosinfo_SR56,
  __pyx_e_8veosinfo_SR57,
  __pyx_e_8veosinfo_SR58,
  __pyx_e_8veosinfo_SR59,
  __pyx_e_8veosinfo_SR60,
  __pyx_e_8veosinfo_SR61,
  __pyx_e_8veosinfo_SR62,
  __pyx_e_8veosinfo_SR63
};

/* "EnumBase":15
 * 
 * @cython.internal
 * cdef class __Pyx_EnumMeta(type):             # <<<<<<<<<<<<<<
 *     def __init__(cls, name, parents, dct):
 *         type.__init__(cls, name, parents, dct)
 */
struct __pyx_obj___Pyx_EnumMeta {
  PyHeapTypeObject __pyx_base;
};


/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* GetModuleGlobalName.proto */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return __Pyx_PyObject_GetAttrStr(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#else
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AndObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_AndObjC(op1, op2, intval, inplace)\
    (inplace ? PyNumber_InPlaceAnd(op1, op2) : PyNumber_And(op1, op2))
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractCObj(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_SubtractCObj(op1, op2, intval, inplace)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddCObj(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_AddCObj(op1, op2, intval, inplace)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunction.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, globals, code)\
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, globals, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(enum __pyx_t_8veosinfo_VERegIds value);

static PyObject* __pyx_convert__to_py_struct__ve_archinfo(struct ve_archinfo s);
/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

static PyObject* __pyx_convert__to_py_struct__ve_cpuinfo(struct ve_cpuinfo s);
/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_long(unsigned long value);

static PyObject* __pyx_convert__to_py_struct__ve_loadavg(struct ve_loadavg s);
static PyObject* __pyx_convert__to_py_struct__ve_meminfo(struct ve_meminfo s);
static PyObject* __pyx_convert__to_py_struct__ve_nodeinfo(struct ve_nodeinfo s);
/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_char(char value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_int(unsigned int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_PY_LONG_LONG(unsigned PY_LONG_LONG value);

static PyObject* __pyx_convert__to_py_struct__ve_pidstat(struct ve_pidstat s);
static PyObject* __pyx_convert__to_py_struct__ve_pwr_fan(struct ve_pwr_fan s);
static PyObject* __pyx_convert__to_py_struct__ve_pwr_temp(struct ve_pwr_temp s);
static PyObject* __pyx_convert__to_py_struct__ve_pwr_voltage(struct ve_pwr_voltage s);
static PyObject* __pyx_convert__to_py_struct__ve_statinfo(struct ve_statinfo s);
static PyObject* __pyx_convert__to_py_struct__ve_vmstat(struct ve_vmstat s);
/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_uint64_t(uint64_t value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'posix.types' */

/* Module declarations from 'posix.signal' */

/* Module declarations from 'posix.time' */

/* Module declarations from 'posix.resource' */

/* Module declarations from 'libc.stdint' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'veosinfo' */
static PyTypeObject *__pyx_ptype___Pyx_EnumMeta = 0;
static PyObject *__Pyx_OrderedDict = 0;
static PyObject *__Pyx_EnumBase = 0;
static PyObject *__Pyx_globals = 0;
__PYX_EXTERN_C DL_IMPORT(int) ve_sysfs_path_info(int, char *); /*proto*/
static int __pyx_f_8veosinfo_check_pid(int, int, int __pyx_skip_dispatch); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_py_char___5b_VE_BUF_LEN_5d_(char (*)[VE_BUF_LEN], Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_char___5b_VE_BUF_LEN_5d_(char (*)[VE_BUF_LEN], Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_py_int(int *, Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_int(int *, Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_(char (*)[MAX_DEVICE_LEN], Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_char___5b_MAX_DEVICE_LEN_5d_(char (*)[MAX_DEVICE_LEN], Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_py_double(double *, Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_double(double *, Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_py_unsigned_PY_LONG_LONG(unsigned PY_LONG_LONG *, Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_unsigned_PY_LONG_LONG(unsigned PY_LONG_LONG *, Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_py_unsigned_long(unsigned long *, Py_ssize_t); /*proto*/
static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_unsigned_long(unsigned long *, Py_ssize_t); /*proto*/
static PyObject *__pyx_unpickle___Pyx_EnumMeta__set_state(struct __pyx_obj___Pyx_EnumMeta *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "veosinfo"
extern int __pyx_module_is_main_veosinfo;
int __pyx_module_is_main_veosinfo = 0;

/* Implementation of 'veosinfo' */
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_xrange;
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_range;
static const char __pyx_k_T[] = "T";
static const char __pyx_k_d[] = "d";
static const char __pyx_k_f[] = "f";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_l[] = "l";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_s[] = "s";
static const char __pyx_k_t[] = "t";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_EX[] = "EX";
static const char __pyx_k_IC[] = "IC";
static const char __pyx_k_VE[] = "VE";
static const char __pyx_k_VL[] = "VL";
static const char __pyx_k_VX[] = "VX";
static const char __pyx_k_ai[] = "ai";
static const char __pyx_k_ci[] = "ci";
static const char __pyx_k_la[] = "la";
static const char __pyx_k_mi[] = "mi";
static const char __pyx_k_ni[] = "ni";
static const char __pyx_k_os[] = "os";
static const char __pyx_k_si[] = "si";
static const char __pyx_k_up[] = "up";
static const char __pyx_k_EXS[] = "EXS";
static const char __pyx_k_ICE[] = "ICE";
static const char __pyx_k_PSW[] = "PSW";
static const char __pyx_k_SAR[] = "SAR";
static const char __pyx_k_UEC[] = "UEC";
static const char __pyx_k_UXC[] = "UXC";
static const char __pyx_k_VE2[] = "VE2";
static const char __pyx_k__21[] = " ";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_cmd[] = "cmd";
static const char __pyx_k_dct[] = "dct";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_mhz[] = "mhz";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_pid[] = "pid";
static const char __pyx_k_res[] = "res";
static const char __pyx_k_rid[] = "rid";
static const char __pyx_k_rss[] = "rss";
static const char __pyx_k_s_s[] = "%s.%s";
static const char __pyx_k_str[] = "__str__";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_vni[] = "vni";
static const char __pyx_k_BPFC[] = "BPFC";
static const char __pyx_k_BREC[] = "BREC";
static const char __pyx_k_FPEC[] = "FPEC";
static const char __pyx_k_L2AC[] = "L2AC";
static const char __pyx_k_L2MC[] = "L2MC";
static const char __pyx_k_LTRC[] = "LTRC";
static const char __pyx_k_PCCC[] = "PCCC";
static const char __pyx_k_PMMR[] = "PMMR";
static const char __pyx_k_PTCC[] = "PTCC";
static const char __pyx_k_SR00[] = "SR00";
static const char __pyx_k_SR01[] = "SR01";
static const char __pyx_k_SR02[] = "SR02";
static const char __pyx_k_SR03[] = "SR03";
static const char __pyx_k_SR04[] = "SR04";
static const char __pyx_k_SR05[] = "SR05";
static const char __pyx_k_SR06[] = "SR06";
static const char __pyx_k_SR07[] = "SR07";
static const char __pyx_k_SR08[] = "SR08";
static const char __pyx_k_SR09[] = "SR09";
static const char __pyx_k_SR10[] = "SR10";
static const char __pyx_k_SR11[] = "SR11";
static const char __pyx_k_SR12[] = "SR12";
static const char __pyx_k_SR13[] = "SR13";
static const char __pyx_k_SR14[] = "SR14";
static const char __pyx_k_SR15[] = "SR15";
static const char __pyx_k_SR16[] = "SR16";
static const char __pyx_k_SR17[] = "SR17";
static const char __pyx_k_SR18[] = "SR18";
static const char __pyx_k_SR19[] = "SR19";
static const char __pyx_k_SR20[] = "SR20";
static const char __pyx_k_SR21[] = "SR21";
static const char __pyx_k_SR22[] = "SR22";
static const char __pyx_k_SR23[] = "SR23";
static const char __pyx_k_SR24[] = "SR24";
static const char __pyx_k_SR25[] = "SR25";
static const char __pyx_k_SR26[] = "SR26";
static const char __pyx_k_SR27[] = "SR27";
static const char __pyx_k_SR28[] = "SR28";
static const char __pyx_k_SR29[] = "SR29";
static const char __pyx_k_SR30[] = "SR30";
static const char __pyx_k_SR31[] = "SR31";
static const char __pyx_k_SR32[] = "SR32";
static const char __pyx_k_SR33[] = "SR33";
static const char __pyx_k_SR34[] = "SR34";
static const char __pyx_k_SR35[] = "SR35";
static const char __pyx_k_SR36[] = "SR36";
static const char __pyx_k_SR37[] = "SR37";
static const char __pyx_k_SR38[] = "SR38";
static const char __pyx_k_SR39[] = "SR39";
static const char __pyx_k_SR40[] = "SR40";
static const char __pyx_k_SR41[] = "SR41";
static const char __pyx_k_SR42[] = "SR42";
static const char __pyx_k_SR43[] = "SR43";
static const char __pyx_k_SR44[] = "SR44";
static const char __pyx_k_SR45[] = "SR45";
static const char __pyx_k_SR46[] = "SR46";
static const char __pyx_k_SR47[] = "SR47";
static const char __pyx_k_SR48[] = "SR48";
static const char __pyx_k_SR49[] = "SR49";
static const char __pyx_k_SR50[] = "SR50";
static const char __pyx_k_SR51[] = "SR51";
static const char __pyx_k_SR52[] = "SR52";
static const char __pyx_k_SR53[] = "SR53";
static const char __pyx_k_SR54[] = "SR54";
static const char __pyx_k_SR55[] = "SR55";
static const char __pyx_k_SR56[] = "SR56";
static const char __pyx_k_SR57[] = "SR57";
static const char __pyx_k_SR58[] = "SR58";
static const char __pyx_k_SR59[] = "SR59";
static const char __pyx_k_SR60[] = "SR60";
static const char __pyx_k_SR61[] = "SR61";
static const char __pyx_k_SR62[] = "SR62";
static const char __pyx_k_SR63[] = "SR63";
static const char __pyx_k_STRC[] = "STRC";
static const char __pyx_k_TTCC[] = "TTCC";
static const char __pyx_k_VECC[] = "VECC";
static const char __pyx_k_VIXR[] = "VIXR";
static const char __pyx_k_VLEC[] = "VLEC";
static const char __pyx_k_VLXC[] = "VLXC";
static const char __pyx_k_acct[] = "acct";
static const char __pyx_k_av_1[] = "av_1";
static const char __pyx_k_av_5[] = "av_5";
static const char __pyx_k_ctxt[] = "ctxt";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_enum[] = "enum";
static const char __pyx_k_exit[] = "__exit__";
static const char __pyx_k_flag[] = "flag";
static const char __pyx_k_freq[] = "freq";
static const char __pyx_k_idle[] = "idle";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_intr[] = "intr";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_line[] = "line";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_mode[] = "mode";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_nice[] = "nice";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_path[] = "path";
static const char __pyx_k_pids[] = "pids";
static const char __pyx_k_pmmr[] = "pmmr";
static const char __pyx_k_ppid[] = "ppid";
static const char __pyx_k_repr[] = "__repr__";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_time[] = "time";
static const char __pyx_k_user[] = "user";
static const char __pyx_k_FMAEC[] = "FMAEC";
static const char __pyx_k_FMAXC[] = "FMAXC";
static const char __pyx_k_IPHCC[] = "IPHCC";
static const char __pyx_k_L1IAC[] = "L1IAC";
static const char __pyx_k_L1IMC[] = "L1IMC";
static const char __pyx_k_L1MCC[] = "L1MCC";
static const char __pyx_k_L1OAC[] = "L1OAC";
static const char __pyx_k_L1OMC[] = "L1OMC";
static const char __pyx_k_L2MCC[] = "L2MCC";
static const char __pyx_k_PMC00[] = "PMC00";
static const char __pyx_k_PMC01[] = "PMC01";
static const char __pyx_k_PMC02[] = "PMC02";
static const char __pyx_k_PMC03[] = "PMC03";
static const char __pyx_k_PMC04[] = "PMC04";
static const char __pyx_k_PMC05[] = "PMC05";
static const char __pyx_k_PMC06[] = "PMC06";
static const char __pyx_k_PMC07[] = "PMC07";
static const char __pyx_k_PMC08[] = "PMC08";
static const char __pyx_k_PMC09[] = "PMC09";
static const char __pyx_k_PMC10[] = "PMC10";
static const char __pyx_k_PMC11[] = "PMC11";
static const char __pyx_k_PMC12[] = "PMC12";
static const char __pyx_k_PMC13[] = "PMC13";
static const char __pyx_k_PMC14[] = "PMC14";
static const char __pyx_k_PMC15[] = "PMC15";
static const char __pyx_k_SARCC[] = "SARCC";
static const char __pyx_k_USRCC[] = "USRCC";
static const char __pyx_k_VAREC[] = "VAREC";
static const char __pyx_k_VLCME[] = "VLCME";
static const char __pyx_k_VLCMX[] = "VLCMX";
static const char __pyx_k_VLDCC[] = "VLDCC";
static const char __pyx_k_VLDEC[] = "VLDEC";
static const char __pyx_k_av_15[] = "av_15";
static const char __pyx_k_blkio[] = "blkio";
static const char __pyx_k_btime[] = "btime";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_cores[] = "cores";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_enter[] = "__enter__";
static const char __pyx_k_flags[] = "flags";
static const char __pyx_k_guest[] = "guest";
static const char __pyx_k_model[] = "model";
static const char __pyx_k_nswap[] = "nswap";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_regid[] = "regid";
static const char __pyx_k_s_s_d[] = "<%s.%s: %d>";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_steal[] = "steal";
static const char __pyx_k_stime[] = "stime";
static const char __pyx_k_utime[] = "utime";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_vsize[] = "vsize";
static const char __pyx_k_wchan[] = "wchan";
static const char __pyx_k_whole[] = "whole";
static const char __pyx_k_L1IMCC[] = "L1IMCC";
static const char __pyx_k_L1OMCC[] = "L1OMCC";
static const char __pyx_k_PMCR00[] = "PMCR00";
static const char __pyx_k_PMCR01[] = "PMCR01";
static const char __pyx_k_PMCR02[] = "PMCR02";
static const char __pyx_k_PMCR03[] = "PMCR03";
static const char __pyx_k_PMCR04[] = "PMCR04";
static const char __pyx_k_VEREGS[] = "VEREGS";
static const char __pyx_k_VLCME2[] = "VLCME2";
static const char __pyx_k_VLCMX2[] = "VLCMX2";
static const char __pyx_k_cnswap[] = "cnswap";
static const char __pyx_k_cstime[] = "cstime";
static const char __pyx_k_cutime[] = "cutime";
static const char __pyx_k_family[] = "family";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_iowait[] = "iowait";
static const char __pyx_k_ksteip[] = "ksteip";
static const char __pyx_k_kstesp[] = "kstesp";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_nnodes[] = "nnodes";
static const char __pyx_k_nodeid[] = "nodeid";
static const char __pyx_k_pgfree[] = "pgfree";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_policy[] = "policy";
static const char __pyx_k_pswpin[] = "pswpin";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_regval[] = "regval";
static const char __pyx_k_rsslim[] = "rsslim";
static const char __pyx_k_rstrip[] = "rstrip";
static const char __pyx_k_socket[] = "socket";
static const char __pyx_k_status[] = "status";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_vendor[] = "vendor";
static const char __pyx_k_xrange[] = "xrange";
static const char __pyx_k_IntEnum[] = "IntEnum";
static const char __pyx_k_blocked[] = "blocked";
static const char __pyx_k_endcode[] = "endcode";
static const char __pyx_k_fan_max[] = "fan_max";
static const char __pyx_k_fan_min[] = "fan_min";
static const char __pyx_k_hardirq[] = "hardirq";
static const char __pyx_k_linesep[] = "linesep";
static const char __pyx_k_machine[] = "machine";
static const char __pyx_k_maj_flt[] = "maj_flt";
static const char __pyx_k_members[] = "__members__";
static const char __pyx_k_min_flt[] = "min_flt";
static const char __pyx_k_op_mode[] = "op_mode";
static const char __pyx_k_os_path[] = "os.path";
static const char __pyx_k_parents[] = "parents";
static const char __pyx_k_pgfault[] = "pgfault";
static const char __pyx_k_pgsteal[] = "pgsteal";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_pswpout[] = "pswpout";
static const char __pyx_k_regname[] = "regname";
static const char __pyx_k_running[] = "running";
static const char __pyx_k_softirq[] = "softirq";
static const char __pyx_k_ve_pids[] = "ve_pids";
static const char __pyx_k_ve_temp[] = "ve_temp";
static const char __pyx_k_EnumBase[] = "EnumBase";
static const char __pyx_k_EnumType[] = "EnumType";
static const char __pyx_k_PMC_NAME[] = "PMC_NAME";
static const char __pyx_k_VERegIds[] = "VERegIds";
static const char __pyx_k_bogomips[] = "bogomips";
static const char __pyx_k_cmaj_flt[] = "cmaj_flt";
static const char __pyx_k_cmin_flt[] = "cmin_flt";
static const char __pyx_k_cpu_info[] = "cpu_info";
static const char __pyx_k_cpu_volt[] = "cpu_volt";
static const char __pyx_k_filename[] = "filename";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_kb_dirty[] = "kb_dirty";
static const char __pyx_k_mem_info[] = "mem_info";
static const char __pyx_k_priority[] = "priority";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_read_fan[] = "read_fan";
static const char __pyx_k_runnable[] = "runnable";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_stepping[] = "stepping";
static const char __pyx_k_temp_max[] = "temp_max";
static const char __pyx_k_temp_min[] = "temp_min";
static const char __pyx_k_ve_regid[] = "ve_regid";
static const char __pyx_k_veosinfo[] = "veosinfo";
static const char __pyx_k_volt_max[] = "volt_max";
static const char __pyx_k_volt_min[] = "volt_min";
static const char __pyx_k_arch_info[] = "arch_info";
static const char __pyx_k_core_info[] = "core_info";
static const char __pyx_k_fan_speed[] = "fan_speed";
static const char __pyx_k_kb_active[] = "kb_active";
static const char __pyx_k_maj_delta[] = "maj_delta";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_min_delta[] = "min_delta";
static const char __pyx_k_modelname[] = "modelname";
static const char __pyx_k_node_info[] = "node_info";
static const char __pyx_k_processes[] = "processes";
static const char __pyx_k_processor[] = "processor";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_read_temp[] = "read_temp";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_startcode[] = "startcode";
static const char __pyx_k_stat_info[] = "stat_info";
static const char __pyx_k_ve_regval[] = "ve_regval";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_cache_name[] = "cache_name";
static const char __pyx_k_cache_size[] = "cache_size";
static const char __pyx_k_guest_nice[] = "guest_nice";
static const char __pyx_k_guest_time[] = "guest_time";
static const char __pyx_k_pgmajfault[] = "pgmajfault";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_start_time[] = "start_time";
static const char __pyx_k_startstack[] = "startstack";
static const char __pyx_k_sysfs_path[] = "sysfs_path";
static const char __pyx_k_total_proc[] = "total_proc";
static const char __pyx_k_OrderedDict[] = "OrderedDict";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_cguest_time[] = "cguest_time";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_device_name[] = "device_name";
static const char __pyx_k_get_regvals[] = "get_regvals";
static const char __pyx_k_hw_platform[] = "hw_platform";
static const char __pyx_k_itrealvalue[] = "itrealvalue";
static const char __pyx_k_kb_inactive[] = "kb_inactive";
static const char __pyx_k_kb_low_free[] = "kb_low_free";
static const char __pyx_k_rt_priority[] = "rt_priority";
static const char __pyx_k_task_id_all[] = "task_id_all";
static const char __pyx_k_uptime_info[] = "uptime_info";
static const char __pyx_k_ve_pid_perf[] = "ve_pid_perf";
static const char __pyx_k_vmstat_info[] = "vmstat_info";
static const char __pyx_k_Pyx_EnumBase[] = "__Pyx_EnumBase";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_cpufreq_info[] = "cpufreq_info";
static const char __pyx_k_kb_high_free[] = "kb_high_free";
static const char __pyx_k_kb_low_total[] = "kb_low_total";
static const char __pyx_k_kb_main_free[] = "kb_main_free";
static const char __pyx_k_kb_main_used[] = "kb_main_used";
static const char __pyx_k_kb_swap_free[] = "kb_swap_free";
static const char __pyx_k_loadavg_info[] = "loadavg_info";
static const char __pyx_k_pidstat_info[] = "pidstat_info";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_read_voltage[] = "read_voltage";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_veosinfo_pyx[] = "veosinfo.pyx";
static const char __pyx_k_hugepage_free[] = "hugepage_free";
static const char __pyx_k_kb_high_total[] = "kb_high_total";
static const char __pyx_k_kb_main_total[] = "kb_main_total";
static const char __pyx_k_kb_swap_total[] = "kb_swap_total";
static const char __pyx_k_pgscan_direct[] = "pgscan_direct";
static const char __pyx_k_pgscan_kswapd[] = "pgscan_kswapd";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_ve_sysfs_path[] = "ve_sysfs_path";
static const char __pyx_k_create_process[] = "create_process";
static const char __pyx_k_hugepage_total[] = "hugepage_total";
static const char __pyx_k_kb_main_cached[] = "kb_main_cached";
static const char __pyx_k_kb_main_shared[] = "kb_main_shared";
static const char __pyx_k_kb_swap_cached[] = "kb_swap_cached";
static const char __pyx_k_ve_acct_failed[] = "ve_acct failed";
static const char __pyx_k_core_per_socket[] = "core_per_socket";
static const char __pyx_k_kb_committed_as[] = "kb_committed_as";
static const char __pyx_k_kb_main_buffers[] = "kb_main_buffers";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_thread_per_core[] = "thread_per_core";
static const char __pyx_k_kb_hugepage_used[] = "kb_hugepage_used";
static const char __pyx_k_total_node_count[] = "total_node_count";
static const char __pyx_k_Pyx_EnumBase___new[] = "__Pyx_EnumBase.__new__";
static const char __pyx_k_Pyx_EnumBase___str[] = "__Pyx_EnumBase.__str__";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_ve_cpu_info_failed[] = "ve_cpu_info failed";
static const char __pyx_k_ve_mem_info_failed[] = "ve_mem_info failed";
static const char __pyx_k_ve_read_fan_failed[] = "ve_read_fan failed";
static const char __pyx_k_Pyx_EnumBase___repr[] = "__Pyx_EnumBase.__repr__";
static const char __pyx_k_ve_arch_info_failed[] = "ve_arch_info failed";
static const char __pyx_k_ve_core_info_failed[] = "ve_core_info failed";
static const char __pyx_k_ve_node_info_failed[] = "ve_node_info failed";
static const char __pyx_k_ve_read_temp_failed[] = "ve_read_temp failed";
static const char __pyx_k_ve_stat_info_failed[] = "ve_stat_info failed";
static const char __pyx_k_Unknown_enum_value_s[] = "Unknown enum value: '%s'";
static const char __pyx_k_ve_get_regvals_failed[] = "ve_get_regvals failed";
static const char __pyx_k_ve_uptime_info_failed[] = "ve_uptime_info failed";
static const char __pyx_k_ve_vmstat_info_failed[] = "ve_vmstat_info failed";
static const char __pyx_k_ve_cpufreq_info_failed[] = "ve_cpufreq_info failed";
static const char __pyx_k_ve_loadavg_info_failed[] = "ve_loadavg_info failed";
static const char __pyx_k_ve_pidstat_info_failed[] = "ve_pidstat_info failed";
static const char __pyx_k_ve_read_voltage_failed[] = "ve_read_voltage failed";
static const char __pyx_k_ve_check_pid_d_failed_d[] = "ve_check_pid (%d) failed: %d";
static const char __pyx_k_ve_create_process_failed[] = "ve_create_process failed";
static const char __pyx_k_ve_sysfs_path_info_failed[] = "ve_sysfs_path_info failed";
static const char __pyx_k_pyx_unpickle___Pyx_EnumMeta[] = "__pyx_unpickle___Pyx_EnumMeta";
static const char __pyx_k_Illegal_mode_in_PMMR_PMC_d_mode[] = "Illegal mode in PMMR: PMC%d mode=%d";
static const char __pyx_k_Incompatible_checksums_s_vs_0xd4[] = "Incompatible checksums (%s vs 0xd41d8cd = ())";
static const char __pyx_k_Wrong_node_ID_d_Only_d_node_onli[] = "Wrong node ID: %d. Only %d node online.";
static PyObject *__pyx_n_s_BPFC;
static PyObject *__pyx_n_s_BREC;
static PyObject *__pyx_n_s_EX;
static PyObject *__pyx_n_s_EXS;
static PyObject *__pyx_n_s_EnumBase;
static PyObject *__pyx_n_s_EnumType;
static PyObject *__pyx_n_s_FMAEC;
static PyObject *__pyx_n_s_FMAXC;
static PyObject *__pyx_n_s_FPEC;
static PyObject *__pyx_n_s_IC;
static PyObject *__pyx_n_s_ICE;
static PyObject *__pyx_n_s_IPHCC;
static PyObject *__pyx_kp_s_Illegal_mode_in_PMMR_PMC_d_mode;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xd4;
static PyObject *__pyx_n_s_IntEnum;
static PyObject *__pyx_n_s_L1IAC;
static PyObject *__pyx_n_s_L1IMC;
static PyObject *__pyx_n_s_L1IMCC;
static PyObject *__pyx_n_s_L1MCC;
static PyObject *__pyx_n_s_L1OAC;
static PyObject *__pyx_n_s_L1OMC;
static PyObject *__pyx_n_s_L1OMCC;
static PyObject *__pyx_n_s_L2AC;
static PyObject *__pyx_n_s_L2MC;
static PyObject *__pyx_n_s_L2MCC;
static PyObject *__pyx_n_s_LTRC;
static PyObject *__pyx_n_s_OrderedDict;
static PyObject *__pyx_n_s_PCCC;
static PyObject *__pyx_n_s_PMC00;
static PyObject *__pyx_n_s_PMC01;
static PyObject *__pyx_n_s_PMC02;
static PyObject *__pyx_n_s_PMC03;
static PyObject *__pyx_n_s_PMC04;
static PyObject *__pyx_n_s_PMC05;
static PyObject *__pyx_n_s_PMC06;
static PyObject *__pyx_n_s_PMC07;
static PyObject *__pyx_n_s_PMC08;
static PyObject *__pyx_n_s_PMC09;
static PyObject *__pyx_n_s_PMC10;
static PyObject *__pyx_n_s_PMC11;
static PyObject *__pyx_n_s_PMC12;
static PyObject *__pyx_n_s_PMC13;
static PyObject *__pyx_n_s_PMC14;
static PyObject *__pyx_n_s_PMC15;
static PyObject *__pyx_n_s_PMCR00;
static PyObject *__pyx_n_s_PMCR01;
static PyObject *__pyx_n_s_PMCR02;
static PyObject *__pyx_n_s_PMCR03;
static PyObject *__pyx_n_s_PMCR04;
static PyObject *__pyx_n_s_PMC_NAME;
static PyObject *__pyx_n_s_PMMR;
static PyObject *__pyx_n_s_PSW;
static PyObject *__pyx_n_s_PTCC;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_n_s_Pyx_EnumBase;
static PyObject *__pyx_n_s_Pyx_EnumBase___new;
static PyObject *__pyx_n_s_Pyx_EnumBase___repr;
static PyObject *__pyx_n_s_Pyx_EnumBase___str;
static PyObject *__pyx_n_s_RuntimeError;
static PyObject *__pyx_n_s_SAR;
static PyObject *__pyx_n_s_SARCC;
static PyObject *__pyx_n_s_SR00;
static PyObject *__pyx_n_s_SR01;
static PyObject *__pyx_n_s_SR02;
static PyObject *__pyx_n_s_SR03;
static PyObject *__pyx_n_s_SR04;
static PyObject *__pyx_n_s_SR05;
static PyObject *__pyx_n_s_SR06;
static PyObject *__pyx_n_s_SR07;
static PyObject *__pyx_n_s_SR08;
static PyObject *__pyx_n_s_SR09;
static PyObject *__pyx_n_s_SR10;
static PyObject *__pyx_n_s_SR11;
static PyObject *__pyx_n_s_SR12;
static PyObject *__pyx_n_s_SR13;
static PyObject *__pyx_n_s_SR14;
static PyObject *__pyx_n_s_SR15;
static PyObject *__pyx_n_s_SR16;
static PyObject *__pyx_n_s_SR17;
static PyObject *__pyx_n_s_SR18;
static PyObject *__pyx_n_s_SR19;
static PyObject *__pyx_n_s_SR20;
static PyObject *__pyx_n_s_SR21;
static PyObject *__pyx_n_s_SR22;
static PyObject *__pyx_n_s_SR23;
static PyObject *__pyx_n_s_SR24;
static PyObject *__pyx_n_s_SR25;
static PyObject *__pyx_n_s_SR26;
static PyObject *__pyx_n_s_SR27;
static PyObject *__pyx_n_s_SR28;
static PyObject *__pyx_n_s_SR29;
static PyObject *__pyx_n_s_SR30;
static PyObject *__pyx_n_s_SR31;
static PyObject *__pyx_n_s_SR32;
static PyObject *__pyx_n_s_SR33;
static PyObject *__pyx_n_s_SR34;
static PyObject *__pyx_n_s_SR35;
static PyObject *__pyx_n_s_SR36;
static PyObject *__pyx_n_s_SR37;
static PyObject *__pyx_n_s_SR38;
static PyObject *__pyx_n_s_SR39;
static PyObject *__pyx_n_s_SR40;
static PyObject *__pyx_n_s_SR41;
static PyObject *__pyx_n_s_SR42;
static PyObject *__pyx_n_s_SR43;
static PyObject *__pyx_n_s_SR44;
static PyObject *__pyx_n_s_SR45;
static PyObject *__pyx_n_s_SR46;
static PyObject *__pyx_n_s_SR47;
static PyObject *__pyx_n_s_SR48;
static PyObject *__pyx_n_s_SR49;
static PyObject *__pyx_n_s_SR50;
static PyObject *__pyx_n_s_SR51;
static PyObject *__pyx_n_s_SR52;
static PyObject *__pyx_n_s_SR53;
static PyObject *__pyx_n_s_SR54;
static PyObject *__pyx_n_s_SR55;
static PyObject *__pyx_n_s_SR56;
static PyObject *__pyx_n_s_SR57;
static PyObject *__pyx_n_s_SR58;
static PyObject *__pyx_n_s_SR59;
static PyObject *__pyx_n_s_SR60;
static PyObject *__pyx_n_s_SR61;
static PyObject *__pyx_n_s_SR62;
static PyObject *__pyx_n_s_SR63;
static PyObject *__pyx_n_s_STRC;
static PyObject *__pyx_n_s_T;
static PyObject *__pyx_n_s_TTCC;
static PyObject *__pyx_n_s_UEC;
static PyObject *__pyx_n_s_USRCC;
static PyObject *__pyx_n_s_UXC;
static PyObject *__pyx_kp_s_Unknown_enum_value_s;
static PyObject *__pyx_n_s_VAREC;
static PyObject *__pyx_n_s_VE;
static PyObject *__pyx_n_s_VE2;
static PyObject *__pyx_n_s_VECC;
static PyObject *__pyx_n_s_VEREGS;
static PyObject *__pyx_n_s_VERegIds;
static PyObject *__pyx_n_s_VIXR;
static PyObject *__pyx_n_s_VL;
static PyObject *__pyx_n_s_VLCME;
static PyObject *__pyx_n_s_VLCME2;
static PyObject *__pyx_n_s_VLCMX;
static PyObject *__pyx_n_s_VLCMX2;
static PyObject *__pyx_n_s_VLDCC;
static PyObject *__pyx_n_s_VLDEC;
static PyObject *__pyx_n_s_VLEC;
static PyObject *__pyx_n_s_VLXC;
static PyObject *__pyx_n_s_VX;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_kp_s_Wrong_node_ID_d_Only_d_node_onli;
static PyObject *__pyx_kp_s__21;
static PyObject *__pyx_n_s_acct;
static PyObject *__pyx_n_s_ai;
static PyObject *__pyx_n_s_arch_info;
static PyObject *__pyx_n_s_av_1;
static PyObject *__pyx_n_s_av_15;
static PyObject *__pyx_n_s_av_5;
static PyObject *__pyx_n_s_blkio;
static PyObject *__pyx_n_s_blocked;
static PyObject *__pyx_n_s_bogomips;
static PyObject *__pyx_n_s_btime;
static PyObject *__pyx_n_s_cache_name;
static PyObject *__pyx_n_s_cache_size;
static PyObject *__pyx_n_s_cguest_time;
static PyObject *__pyx_n_s_ci;
static PyObject *__pyx_n_s_class;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_cls;
static PyObject *__pyx_n_s_cmaj_flt;
static PyObject *__pyx_n_s_cmd;
static PyObject *__pyx_n_s_cmin_flt;
static PyObject *__pyx_n_s_cnswap;
static PyObject *__pyx_n_s_collections;
static PyObject *__pyx_n_s_core_info;
static PyObject *__pyx_n_s_core_per_socket;
static PyObject *__pyx_n_s_cores;
static PyObject *__pyx_n_s_count;
static PyObject *__pyx_n_s_cpu_info;
static PyObject *__pyx_n_s_cpu_volt;
static PyObject *__pyx_n_s_cpufreq_info;
static PyObject *__pyx_n_s_create_process;
static PyObject *__pyx_n_s_cstime;
static PyObject *__pyx_n_s_ctxt;
static PyObject *__pyx_n_s_cutime;
static PyObject *__pyx_n_s_d;
static PyObject *__pyx_n_s_dct;
static PyObject *__pyx_n_s_device_name;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_s_endcode;
static PyObject *__pyx_n_s_enter;
static PyObject *__pyx_n_s_enum;
static PyObject *__pyx_n_s_exit;
static PyObject *__pyx_n_s_f;
static PyObject *__pyx_n_s_family;
static PyObject *__pyx_n_s_fan_max;
static PyObject *__pyx_n_s_fan_min;
static PyObject *__pyx_n_s_fan_speed;
static PyObject *__pyx_n_s_filename;
static PyObject *__pyx_n_s_flag;
static PyObject *__pyx_n_s_flags;
static PyObject *__pyx_n_s_freq;
static PyObject *__pyx_n_s_get_regvals;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_guest;
static PyObject *__pyx_n_s_guest_nice;
static PyObject *__pyx_n_s_guest_time;
static PyObject *__pyx_n_s_hardirq;
static PyObject *__pyx_n_s_hugepage_free;
static PyObject *__pyx_n_s_hugepage_total;
static PyObject *__pyx_n_s_hw_platform;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_s_idle;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_intr;
static PyObject *__pyx_n_s_iowait;
static PyObject *__pyx_n_s_itrealvalue;
static PyObject *__pyx_n_s_join;
static PyObject *__pyx_n_s_kb_active;
static PyObject *__pyx_n_s_kb_committed_as;
static PyObject *__pyx_n_s_kb_dirty;
static PyObject *__pyx_n_s_kb_high_free;
static PyObject *__pyx_n_s_kb_high_total;
static PyObject *__pyx_n_s_kb_hugepage_used;
static PyObject *__pyx_n_s_kb_inactive;
static PyObject *__pyx_n_s_kb_low_free;
static PyObject *__pyx_n_s_kb_low_total;
static PyObject *__pyx_n_s_kb_main_buffers;
static PyObject *__pyx_n_s_kb_main_cached;
static PyObject *__pyx_n_s_kb_main_free;
static PyObject *__pyx_n_s_kb_main_shared;
static PyObject *__pyx_n_s_kb_main_total;
static PyObject *__pyx_n_s_kb_main_used;
static PyObject *__pyx_n_s_kb_swap_cached;
static PyObject *__pyx_n_s_kb_swap_free;
static PyObject *__pyx_n_s_kb_swap_total;
static PyObject *__pyx_n_s_key;
static PyObject *__pyx_n_s_ksteip;
static PyObject *__pyx_n_s_kstesp;
static PyObject *__pyx_n_s_l;
static PyObject *__pyx_n_s_la;
static PyObject *__pyx_n_s_line;
static PyObject *__pyx_n_s_linesep;
static PyObject *__pyx_n_s_loadavg_info;
static PyObject *__pyx_n_s_machine;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_maj_delta;
static PyObject *__pyx_n_s_maj_flt;
static PyObject *__pyx_n_s_mem_info;
static PyObject *__pyx_n_s_members;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_s_mhz;
static PyObject *__pyx_n_s_mi;
static PyObject *__pyx_n_s_min_delta;
static PyObject *__pyx_n_s_min_flt;
static PyObject *__pyx_n_s_mode;
static PyObject *__pyx_n_s_model;
static PyObject *__pyx_n_s_modelname;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_ni;
static PyObject *__pyx_n_s_nice;
static PyObject *__pyx_n_s_nnodes;
static PyObject *__pyx_n_s_node_info;
static PyObject *__pyx_n_s_nodeid;
static PyObject *__pyx_n_s_nswap;
static PyObject *__pyx_n_s_op_mode;
static PyObject *__pyx_n_s_open;
static PyObject *__pyx_n_s_os;
static PyObject *__pyx_n_s_os_path;
static PyObject *__pyx_n_s_p;
static PyObject *__pyx_n_s_parents;
static PyObject *__pyx_n_s_path;
static PyObject *__pyx_n_s_pgfault;
static PyObject *__pyx_n_s_pgfree;
static PyObject *__pyx_n_s_pgmajfault;
static PyObject *__pyx_n_s_pgscan_direct;
static PyObject *__pyx_n_s_pgscan_kswapd;
static PyObject *__pyx_n_s_pgsteal;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_pid;
static PyObject *__pyx_n_s_pids;
static PyObject *__pyx_n_s_pidstat_info;
static PyObject *__pyx_n_s_pmmr;
static PyObject *__pyx_n_s_policy;
static PyObject *__pyx_n_s_ppid;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_priority;
static PyObject *__pyx_n_s_processes;
static PyObject *__pyx_n_s_processor;
static PyObject *__pyx_n_s_pswpin;
static PyObject *__pyx_n_s_pswpout;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle___Pyx_EnumMeta;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_s_r;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_read_fan;
static PyObject *__pyx_n_s_read_temp;
static PyObject *__pyx_n_s_read_voltage;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_regid;
static PyObject *__pyx_n_s_regname;
static PyObject *__pyx_n_s_regval;
static PyObject *__pyx_n_s_repr;
static PyObject *__pyx_n_s_res;
static PyObject *__pyx_n_s_rid;
static PyObject *__pyx_n_s_rss;
static PyObject *__pyx_n_s_rsslim;
static PyObject *__pyx_n_s_rstrip;
static PyObject *__pyx_n_s_rt_priority;
static PyObject *__pyx_n_s_runnable;
static PyObject *__pyx_n_s_running;
static PyObject *__pyx_n_s_s;
static PyObject *__pyx_kp_s_s_s;
static PyObject *__pyx_kp_s_s_s_d;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_si;
static PyObject *__pyx_n_s_socket;
static PyObject *__pyx_n_s_softirq;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_n_s_start_time;
static PyObject *__pyx_n_s_startcode;
static PyObject *__pyx_n_s_startstack;
static PyObject *__pyx_n_s_stat_info;
static PyObject *__pyx_n_s_state;
static PyObject *__pyx_n_s_status;
static PyObject *__pyx_n_s_steal;
static PyObject *__pyx_n_s_stepping;
static PyObject *__pyx_n_s_stime;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_sysfs_path;
static PyObject *__pyx_n_s_t;
static PyObject *__pyx_n_s_task_id_all;
static PyObject *__pyx_n_s_temp_max;
static PyObject *__pyx_n_s_temp_min;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_thread_per_core;
static PyObject *__pyx_n_s_time;
static PyObject *__pyx_n_s_total_node_count;
static PyObject *__pyx_n_s_total_proc;
static PyObject *__pyx_n_s_up;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_uptime_info;
static PyObject *__pyx_n_s_user;
static PyObject *__pyx_n_s_utime;
static PyObject *__pyx_n_s_v;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_s_values;
static PyObject *__pyx_kp_s_ve_acct_failed;
static PyObject *__pyx_kp_s_ve_arch_info_failed;
static PyObject *__pyx_kp_s_ve_check_pid_d_failed_d;
static PyObject *__pyx_kp_s_ve_core_info_failed;
static PyObject *__pyx_kp_s_ve_cpu_info_failed;
static PyObject *__pyx_kp_s_ve_cpufreq_info_failed;
static PyObject *__pyx_kp_s_ve_create_process_failed;
static PyObject *__pyx_kp_s_ve_get_regvals_failed;
static PyObject *__pyx_kp_s_ve_loadavg_info_failed;
static PyObject *__pyx_kp_s_ve_mem_info_failed;
static PyObject *__pyx_kp_s_ve_node_info_failed;
static PyObject *__pyx_n_s_ve_pid_perf;
static PyObject *__pyx_n_s_ve_pids;
static PyObject *__pyx_kp_s_ve_pidstat_info_failed;
static PyObject *__pyx_kp_s_ve_read_fan_failed;
static PyObject *__pyx_kp_s_ve_read_temp_failed;
static PyObject *__pyx_kp_s_ve_read_voltage_failed;
static PyObject *__pyx_n_s_ve_regid;
static PyObject *__pyx_n_s_ve_regval;
static PyObject *__pyx_kp_s_ve_stat_info_failed;
static PyObject *__pyx_n_s_ve_sysfs_path;
static PyObject *__pyx_kp_s_ve_sysfs_path_info_failed;
static PyObject *__pyx_n_s_ve_temp;
static PyObject *__pyx_kp_s_ve_uptime_info_failed;
static PyObject *__pyx_kp_s_ve_vmstat_info_failed;
static PyObject *__pyx_n_s_vendor;
static PyObject *__pyx_n_s_veosinfo;
static PyObject *__pyx_kp_s_veosinfo_pyx;
static PyObject *__pyx_n_s_vmstat_info;
static PyObject *__pyx_n_s_vni;
static PyObject *__pyx_n_s_volt_max;
static PyObject *__pyx_n_s_volt_min;
static PyObject *__pyx_n_s_vsize;
static PyObject *__pyx_n_s_wchan;
static PyObject *__pyx_n_s_whole;
static PyObject *__pyx_n_s_xrange;
static PyObject *__pyx_pf_8veosinfo_acct(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, char *__pyx_v_filename); /* proto */
static PyObject *__pyx_pf_8veosinfo_2arch_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_4check_pid(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, int __pyx_v_pid); /* proto */
static PyObject *__pyx_pf_8veosinfo_6core_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_8cpu_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_10cpufreq_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_12create_process(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, int __pyx_v_pid, int __pyx_v_flag); /* proto */
static PyObject *__pyx_pf_8veosinfo_14loadavg_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_16mem_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_18node_info(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_8veosinfo_20pidstat_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, __pyx_t_8veosinfo_pid_t __pyx_v_pid); /* proto */
static PyObject *__pyx_pf_8veosinfo_22read_fan(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_24read_temp(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_26read_voltage(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_28stat_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_30uptime_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_32vmstat_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_34get_regvals(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, __pyx_t_8veosinfo_pid_t __pyx_v_pid, PyObject *__pyx_v_regid); /* proto */
static PyObject *__pyx_pf_8veosinfo_36ve_sysfs_path(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_38ve_pids(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid); /* proto */
static PyObject *__pyx_pf_8veosinfo_40ve_pid_perf(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, int __pyx_v_pid); /* proto */
static int __pyx_pf_8EnumBase_14__Pyx_EnumMeta___init__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name, PyObject *__pyx_v_parents, PyObject *__pyx_v_dct); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_2__iter__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_4__getitem__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_6__reduce_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_8__setstate_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_value, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8EnumBase___pyx_unpickle___Pyx_EnumMeta(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new___Pyx_EnumMeta(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_60;
static PyObject *__pyx_int_222419149;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__28;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__38;
static PyObject *__pyx_tuple__40;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__56;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__60;
static PyObject *__pyx_tuple__62;
static PyObject *__pyx_tuple__64;
static PyObject *__pyx_tuple__66;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_codeobj__25;
static PyObject *__pyx_codeobj__27;
static PyObject *__pyx_codeobj__29;
static PyObject *__pyx_codeobj__31;
static PyObject *__pyx_codeobj__33;
static PyObject *__pyx_codeobj__35;
static PyObject *__pyx_codeobj__37;
static PyObject *__pyx_codeobj__39;
static PyObject *__pyx_codeobj__41;
static PyObject *__pyx_codeobj__43;
static PyObject *__pyx_codeobj__45;
static PyObject *__pyx_codeobj__47;
static PyObject *__pyx_codeobj__49;
static PyObject *__pyx_codeobj__51;
static PyObject *__pyx_codeobj__53;
static PyObject *__pyx_codeobj__55;
static PyObject *__pyx_codeobj__57;
static PyObject *__pyx_codeobj__59;
static PyObject *__pyx_codeobj__61;
static PyObject *__pyx_codeobj__63;
static PyObject *__pyx_codeobj__65;
static PyObject *__pyx_codeobj__68;
static PyObject *__pyx_codeobj__70;
static PyObject *__pyx_codeobj__72;
/* Late includes */

/* "veosinfo.pyx":311
 * 
 * 
 * def acct(int nodeid, char *filename):             # <<<<<<<<<<<<<<
 *     if ve_acct(nodeid, filename):
 *         raise RuntimeError("ve_acct failed")
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_1acct(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_1acct = {"acct", (PyCFunction)__pyx_pw_8veosinfo_1acct, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8veosinfo_1acct(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_nodeid;
  char *__pyx_v_filename;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("acct (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nodeid,&__pyx_n_s_filename,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nodeid)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_filename)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("acct", 1, 2, 2, 1); __PYX_ERR(0, 311, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "acct") < 0)) __PYX_ERR(0, 311, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_nodeid = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 311, __pyx_L3_error)
    __pyx_v_filename = __Pyx_PyObject_AsWritableString(values[1]); if (unlikely((!__pyx_v_filename) && PyErr_Occurred())) __PYX_ERR(0, 311, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("acct", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 311, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.acct", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_acct(__pyx_self, __pyx_v_nodeid, __pyx_v_filename);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_acct(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, char *__pyx_v_filename) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("acct", 0);

  /* "veosinfo.pyx":312
 * 
 * def acct(int nodeid, char *filename):
 *     if ve_acct(nodeid, filename):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_acct failed")
 * 
 */
  __pyx_t_1 = (ve_acct(__pyx_v_nodeid, __pyx_v_filename) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":313
 * def acct(int nodeid, char *filename):
 *     if ve_acct(nodeid, filename):
 *         raise RuntimeError("ve_acct failed")             # <<<<<<<<<<<<<<
 * 
 * def arch_info(int nodeid):
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 313, __pyx_L1_error)

    /* "veosinfo.pyx":312
 * 
 * def acct(int nodeid, char *filename):
 *     if ve_acct(nodeid, filename):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_acct failed")
 * 
 */
  }

  /* "veosinfo.pyx":311
 * 
 * 
 * def acct(int nodeid, char *filename):             # <<<<<<<<<<<<<<
 *     if ve_acct(nodeid, filename):
 *         raise RuntimeError("ve_acct failed")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.acct", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":315
 *         raise RuntimeError("ve_acct failed")
 * 
 * def arch_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_archinfo ai
 *     if ve_arch_info(nodeid, &ai):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_3arch_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_3arch_info = {"arch_info", (PyCFunction)__pyx_pw_8veosinfo_3arch_info, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_3arch_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arch_info (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 315, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.arch_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_2arch_info(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_2arch_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  struct ve_archinfo __pyx_v_ai;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("arch_info", 0);

  /* "veosinfo.pyx":317
 * def arch_info(int nodeid):
 *     cdef ve_archinfo ai
 *     if ve_arch_info(nodeid, &ai):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_arch_info failed")
 *     return ai
 */
  __pyx_t_1 = (ve_arch_info(__pyx_v_nodeid, (&__pyx_v_ai)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":318
 *     cdef ve_archinfo ai
 *     if ve_arch_info(nodeid, &ai):
 *         raise RuntimeError("ve_arch_info failed")             # <<<<<<<<<<<<<<
 *     return ai
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 318, __pyx_L1_error)

    /* "veosinfo.pyx":317
 * def arch_info(int nodeid):
 *     cdef ve_archinfo ai
 *     if ve_arch_info(nodeid, &ai):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_arch_info failed")
 *     return ai
 */
  }

  /* "veosinfo.pyx":319
 *     if ve_arch_info(nodeid, &ai):
 *         raise RuntimeError("ve_arch_info failed")
 *     return ai             # <<<<<<<<<<<<<<
 * 
 * cpdef bint check_pid(int nodeid, int pid) except -1:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_archinfo(__pyx_v_ai); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":315
 *         raise RuntimeError("ve_acct failed")
 * 
 * def arch_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_archinfo ai
 *     if ve_arch_info(nodeid, &ai):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.arch_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":321
 *     return ai
 * 
 * cpdef bint check_pid(int nodeid, int pid) except -1:             # <<<<<<<<<<<<<<
 *     cdef int rc
 *     cdef bint res = False
 */

static PyObject *__pyx_pw_8veosinfo_5check_pid(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_f_8veosinfo_check_pid(int __pyx_v_nodeid, int __pyx_v_pid, CYTHON_UNUSED int __pyx_skip_dispatch) {
  int __pyx_v_rc;
  int __pyx_v_res;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("check_pid", 0);

  /* "veosinfo.pyx":323
 * cpdef bint check_pid(int nodeid, int pid) except -1:
 *     cdef int rc
 *     cdef bint res = False             # <<<<<<<<<<<<<<
 *     rc = ve_check_pid(nodeid, pid)
 *     if rc < 0:
 */
  __pyx_v_res = 0;

  /* "veosinfo.pyx":324
 *     cdef int rc
 *     cdef bint res = False
 *     rc = ve_check_pid(nodeid, pid)             # <<<<<<<<<<<<<<
 *     if rc < 0:
 *         raise RuntimeError("ve_check_pid (%d) failed: %d" % (pid, rc))
 */
  __pyx_v_rc = ve_check_pid(__pyx_v_nodeid, __pyx_v_pid);

  /* "veosinfo.pyx":325
 *     cdef bint res = False
 *     rc = ve_check_pid(nodeid, pid)
 *     if rc < 0:             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_check_pid (%d) failed: %d" % (pid, rc))
 *     elif rc == 0:
 */
  __pyx_t_1 = ((__pyx_v_rc < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":326
 *     rc = ve_check_pid(nodeid, pid)
 *     if rc < 0:
 *         raise RuntimeError("ve_check_pid (%d) failed: %d" % (pid, rc))             # <<<<<<<<<<<<<<
 *     elif rc == 0:
 *         res = True
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_pid); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_rc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_ve_check_pid_d_failed_d, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 326, __pyx_L1_error)

    /* "veosinfo.pyx":325
 *     cdef bint res = False
 *     rc = ve_check_pid(nodeid, pid)
 *     if rc < 0:             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_check_pid (%d) failed: %d" % (pid, rc))
 *     elif rc == 0:
 */
  }

  /* "veosinfo.pyx":327
 *     if rc < 0:
 *         raise RuntimeError("ve_check_pid (%d) failed: %d" % (pid, rc))
 *     elif rc == 0:             # <<<<<<<<<<<<<<
 *         res = True
 *     return res
 */
  __pyx_t_1 = ((__pyx_v_rc == 0) != 0);
  if (__pyx_t_1) {

    /* "veosinfo.pyx":328
 *         raise RuntimeError("ve_check_pid (%d) failed: %d" % (pid, rc))
 *     elif rc == 0:
 *         res = True             # <<<<<<<<<<<<<<
 *     return res
 * 
 */
    __pyx_v_res = 1;

    /* "veosinfo.pyx":327
 *     if rc < 0:
 *         raise RuntimeError("ve_check_pid (%d) failed: %d" % (pid, rc))
 *     elif rc == 0:             # <<<<<<<<<<<<<<
 *         res = True
 *     return res
 */
  }

  /* "veosinfo.pyx":329
 *     elif rc == 0:
 *         res = True
 *     return res             # <<<<<<<<<<<<<<
 * 
 * def core_info(int nodeid):
 */
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "veosinfo.pyx":321
 *     return ai
 * 
 * cpdef bint check_pid(int nodeid, int pid) except -1:             # <<<<<<<<<<<<<<
 *     cdef int rc
 *     cdef bint res = False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("veosinfo.check_pid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_5check_pid(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8veosinfo_5check_pid(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_nodeid;
  int __pyx_v_pid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_pid (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nodeid,&__pyx_n_s_pid,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nodeid)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("check_pid", 1, 2, 2, 1); __PYX_ERR(0, 321, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "check_pid") < 0)) __PYX_ERR(0, 321, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_nodeid = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 321, __pyx_L3_error)
    __pyx_v_pid = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_pid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 321, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("check_pid", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 321, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.check_pid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_4check_pid(__pyx_self, __pyx_v_nodeid, __pyx_v_pid);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_4check_pid(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, int __pyx_v_pid) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("check_pid", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8veosinfo_check_pid(__pyx_v_nodeid, __pyx_v_pid, 0); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 321, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.check_pid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":331
 *     return res
 * 
 * def core_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef int cores
 *     if ve_core_info(nodeid, &cores):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_7core_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_7core_info = {"core_info", (PyCFunction)__pyx_pw_8veosinfo_7core_info, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_7core_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("core_info (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 331, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.core_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_6core_info(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_6core_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  int __pyx_v_cores;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("core_info", 0);

  /* "veosinfo.pyx":333
 * def core_info(int nodeid):
 *     cdef int cores
 *     if ve_core_info(nodeid, &cores):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_core_info failed")
 *     return cores
 */
  __pyx_t_1 = (ve_core_info(__pyx_v_nodeid, (&__pyx_v_cores)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":334
 *     cdef int cores
 *     if ve_core_info(nodeid, &cores):
 *         raise RuntimeError("ve_core_info failed")             # <<<<<<<<<<<<<<
 *     return cores
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 334, __pyx_L1_error)

    /* "veosinfo.pyx":333
 * def core_info(int nodeid):
 *     cdef int cores
 *     if ve_core_info(nodeid, &cores):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_core_info failed")
 *     return cores
 */
  }

  /* "veosinfo.pyx":335
 *     if ve_core_info(nodeid, &cores):
 *         raise RuntimeError("ve_core_info failed")
 *     return cores             # <<<<<<<<<<<<<<
 * 
 * def cpu_info(int nodeid):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_cores); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":331
 *     return res
 * 
 * def core_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef int cores
 *     if ve_core_info(nodeid, &cores):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.core_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":337
 *     return cores
 * 
 * def cpu_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_cpuinfo ci
 *     if ve_cpu_info(nodeid, &ci):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_9cpu_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_9cpu_info = {"cpu_info", (PyCFunction)__pyx_pw_8veosinfo_9cpu_info, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_9cpu_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cpu_info (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 337, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.cpu_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_8cpu_info(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_8cpu_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  struct ve_cpuinfo __pyx_v_ci;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("cpu_info", 0);

  /* "veosinfo.pyx":339
 * def cpu_info(int nodeid):
 *     cdef ve_cpuinfo ci
 *     if ve_cpu_info(nodeid, &ci):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_cpu_info failed")
 *     return ci
 */
  __pyx_t_1 = (ve_cpu_info(__pyx_v_nodeid, (&__pyx_v_ci)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":340
 *     cdef ve_cpuinfo ci
 *     if ve_cpu_info(nodeid, &ci):
 *         raise RuntimeError("ve_cpu_info failed")             # <<<<<<<<<<<<<<
 *     return ci
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 340, __pyx_L1_error)

    /* "veosinfo.pyx":339
 * def cpu_info(int nodeid):
 *     cdef ve_cpuinfo ci
 *     if ve_cpu_info(nodeid, &ci):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_cpu_info failed")
 *     return ci
 */
  }

  /* "veosinfo.pyx":341
 *     if ve_cpu_info(nodeid, &ci):
 *         raise RuntimeError("ve_cpu_info failed")
 *     return ci             # <<<<<<<<<<<<<<
 * 
 * def cpufreq_info(int nodeid):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_cpuinfo(__pyx_v_ci); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":337
 *     return cores
 * 
 * def cpu_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_cpuinfo ci
 *     if ve_cpu_info(nodeid, &ci):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.cpu_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":343
 *     return ci
 * 
 * def cpufreq_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef unsigned long freq
 *     if ve_cpufreq_info(nodeid, &freq):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_11cpufreq_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_11cpufreq_info = {"cpufreq_info", (PyCFunction)__pyx_pw_8veosinfo_11cpufreq_info, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_11cpufreq_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cpufreq_info (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 343, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.cpufreq_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_10cpufreq_info(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_10cpufreq_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  unsigned long __pyx_v_freq;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("cpufreq_info", 0);

  /* "veosinfo.pyx":345
 * def cpufreq_info(int nodeid):
 *     cdef unsigned long freq
 *     if ve_cpufreq_info(nodeid, &freq):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_cpufreq_info failed")
 *     return freq
 */
  __pyx_t_1 = (ve_cpufreq_info(__pyx_v_nodeid, (&__pyx_v_freq)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":346
 *     cdef unsigned long freq
 *     if ve_cpufreq_info(nodeid, &freq):
 *         raise RuntimeError("ve_cpufreq_info failed")             # <<<<<<<<<<<<<<
 *     return freq
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 346, __pyx_L1_error)

    /* "veosinfo.pyx":345
 * def cpufreq_info(int nodeid):
 *     cdef unsigned long freq
 *     if ve_cpufreq_info(nodeid, &freq):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_cpufreq_info failed")
 *     return freq
 */
  }

  /* "veosinfo.pyx":347
 *     if ve_cpufreq_info(nodeid, &freq):
 *         raise RuntimeError("ve_cpufreq_info failed")
 *     return freq             # <<<<<<<<<<<<<<
 * 
 * def create_process(int nodeid, int pid, int flag):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_unsigned_long(__pyx_v_freq); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":343
 *     return ci
 * 
 * def cpufreq_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef unsigned long freq
 *     if ve_cpufreq_info(nodeid, &freq):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.cpufreq_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":349
 *     return freq
 * 
 * def create_process(int nodeid, int pid, int flag):             # <<<<<<<<<<<<<<
 *     if ve_create_process(nodeid, pid, flag):
 *         raise RuntimeError("ve_create_process failed")
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_13create_process(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_13create_process = {"create_process", (PyCFunction)__pyx_pw_8veosinfo_13create_process, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8veosinfo_13create_process(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_nodeid;
  int __pyx_v_pid;
  int __pyx_v_flag;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_process (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nodeid,&__pyx_n_s_pid,&__pyx_n_s_flag,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nodeid)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("create_process", 1, 3, 3, 1); __PYX_ERR(0, 349, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_flag)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("create_process", 1, 3, 3, 2); __PYX_ERR(0, 349, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create_process") < 0)) __PYX_ERR(0, 349, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_nodeid = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 349, __pyx_L3_error)
    __pyx_v_pid = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_pid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 349, __pyx_L3_error)
    __pyx_v_flag = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_flag == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 349, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_process", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 349, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.create_process", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_12create_process(__pyx_self, __pyx_v_nodeid, __pyx_v_pid, __pyx_v_flag);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_12create_process(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, int __pyx_v_pid, int __pyx_v_flag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("create_process", 0);

  /* "veosinfo.pyx":350
 * 
 * def create_process(int nodeid, int pid, int flag):
 *     if ve_create_process(nodeid, pid, flag):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_create_process failed")
 *     return True
 */
  __pyx_t_1 = (ve_create_process(__pyx_v_nodeid, __pyx_v_pid, __pyx_v_flag) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":351
 * def create_process(int nodeid, int pid, int flag):
 *     if ve_create_process(nodeid, pid, flag):
 *         raise RuntimeError("ve_create_process failed")             # <<<<<<<<<<<<<<
 *     return True
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 351, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 351, __pyx_L1_error)

    /* "veosinfo.pyx":350
 * 
 * def create_process(int nodeid, int pid, int flag):
 *     if ve_create_process(nodeid, pid, flag):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_create_process failed")
 *     return True
 */
  }

  /* "veosinfo.pyx":352
 *     if ve_create_process(nodeid, pid, flag):
 *         raise RuntimeError("ve_create_process failed")
 *     return True             # <<<<<<<<<<<<<<
 * 
 * def loadavg_info(int nodeid):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "veosinfo.pyx":349
 *     return freq
 * 
 * def create_process(int nodeid, int pid, int flag):             # <<<<<<<<<<<<<<
 *     if ve_create_process(nodeid, pid, flag):
 *         raise RuntimeError("ve_create_process failed")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.create_process", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":354
 *     return True
 * 
 * def loadavg_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_loadavg la
 *     if ve_loadavg_info(nodeid, &la):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_15loadavg_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_15loadavg_info = {"loadavg_info", (PyCFunction)__pyx_pw_8veosinfo_15loadavg_info, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_15loadavg_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("loadavg_info (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 354, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.loadavg_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_14loadavg_info(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_14loadavg_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  struct ve_loadavg __pyx_v_la;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("loadavg_info", 0);

  /* "veosinfo.pyx":356
 * def loadavg_info(int nodeid):
 *     cdef ve_loadavg la
 *     if ve_loadavg_info(nodeid, &la):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_loadavg_info failed")
 *     return la
 */
  __pyx_t_1 = (ve_loadavg_info(__pyx_v_nodeid, (&__pyx_v_la)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":357
 *     cdef ve_loadavg la
 *     if ve_loadavg_info(nodeid, &la):
 *         raise RuntimeError("ve_loadavg_info failed")             # <<<<<<<<<<<<<<
 *     return la
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 357, __pyx_L1_error)

    /* "veosinfo.pyx":356
 * def loadavg_info(int nodeid):
 *     cdef ve_loadavg la
 *     if ve_loadavg_info(nodeid, &la):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_loadavg_info failed")
 *     return la
 */
  }

  /* "veosinfo.pyx":358
 *     if ve_loadavg_info(nodeid, &la):
 *         raise RuntimeError("ve_loadavg_info failed")
 *     return la             # <<<<<<<<<<<<<<
 * 
 * def mem_info(int nodeid):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_loadavg(__pyx_v_la); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":354
 *     return True
 * 
 * def loadavg_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_loadavg la
 *     if ve_loadavg_info(nodeid, &la):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.loadavg_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":360
 *     return la
 * 
 * def mem_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_meminfo mi
 *     if ve_mem_info(nodeid, &mi):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_17mem_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_17mem_info = {"mem_info", (PyCFunction)__pyx_pw_8veosinfo_17mem_info, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_17mem_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mem_info (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 360, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.mem_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_16mem_info(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_16mem_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  struct ve_meminfo __pyx_v_mi;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("mem_info", 0);

  /* "veosinfo.pyx":362
 * def mem_info(int nodeid):
 *     cdef ve_meminfo mi
 *     if ve_mem_info(nodeid, &mi):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_mem_info failed")
 *     return mi
 */
  __pyx_t_1 = (ve_mem_info(__pyx_v_nodeid, (&__pyx_v_mi)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":363
 *     cdef ve_meminfo mi
 *     if ve_mem_info(nodeid, &mi):
 *         raise RuntimeError("ve_mem_info failed")             # <<<<<<<<<<<<<<
 *     return mi
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 363, __pyx_L1_error)

    /* "veosinfo.pyx":362
 * def mem_info(int nodeid):
 *     cdef ve_meminfo mi
 *     if ve_mem_info(nodeid, &mi):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_mem_info failed")
 *     return mi
 */
  }

  /* "veosinfo.pyx":364
 *     if ve_mem_info(nodeid, &mi):
 *         raise RuntimeError("ve_mem_info failed")
 *     return mi             # <<<<<<<<<<<<<<
 * 
 * def node_info():
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_meminfo(__pyx_v_mi); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":360
 *     return la
 * 
 * def mem_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_meminfo mi
 *     if ve_mem_info(nodeid, &mi):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.mem_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":366
 *     return mi
 * 
 * def node_info():             # <<<<<<<<<<<<<<
 *     cdef ve_nodeinfo vni
 *     if ve_node_info(&vni):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_19node_info(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_19node_info = {"node_info", (PyCFunction)__pyx_pw_8veosinfo_19node_info, METH_NOARGS, 0};
static PyObject *__pyx_pw_8veosinfo_19node_info(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("node_info (wrapper)", 0);
  __pyx_r = __pyx_pf_8veosinfo_18node_info(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_18node_info(CYTHON_UNUSED PyObject *__pyx_self) {
  struct ve_nodeinfo __pyx_v_vni;
  PyObject *__pyx_v_d = 0;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("node_info", 0);

  /* "veosinfo.pyx":368
 * def node_info():
 *     cdef ve_nodeinfo vni
 *     if ve_node_info(&vni):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_node_info failed")
 *     cdef object d = vni
 */
  __pyx_t_1 = (ve_node_info((&__pyx_v_vni)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":369
 *     cdef ve_nodeinfo vni
 *     if ve_node_info(&vni):
 *         raise RuntimeError("ve_node_info failed")             # <<<<<<<<<<<<<<
 *     cdef object d = vni
 *     for key in ("nodeid", "status", "cores"):
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 369, __pyx_L1_error)

    /* "veosinfo.pyx":368
 * def node_info():
 *     cdef ve_nodeinfo vni
 *     if ve_node_info(&vni):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_node_info failed")
 *     cdef object d = vni
 */
  }

  /* "veosinfo.pyx":370
 *     if ve_node_info(&vni):
 *         raise RuntimeError("ve_node_info failed")
 *     cdef object d = vni             # <<<<<<<<<<<<<<
 *     for key in ("nodeid", "status", "cores"):
 *         d[key] = d[key][:d["total_node_count"]]
 */
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_nodeinfo(__pyx_v_vni); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_d = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "veosinfo.pyx":371
 *         raise RuntimeError("ve_node_info failed")
 *     cdef object d = vni
 *     for key in ("nodeid", "status", "cores"):             # <<<<<<<<<<<<<<
 *         d[key] = d[key][:d["total_node_count"]]
 *     return d
 */
  __pyx_t_2 = __pyx_tuple__10; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
  for (;;) {
    if (__pyx_t_3 >= 3) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 371, __pyx_L1_error)
    #else
    __pyx_t_4 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 371, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "veosinfo.pyx":372
 *     cdef object d = vni
 *     for key in ("nodeid", "status", "cores"):
 *         d[key] = d[key][:d["total_node_count"]]             # <<<<<<<<<<<<<<
 *     return d
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_d, __pyx_v_key); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 372, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_d, __pyx_n_s_total_node_count); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 372, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 0, NULL, &__pyx_t_5, NULL, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 372, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(PyObject_SetItem(__pyx_v_d, __pyx_v_key, __pyx_t_6) < 0)) __PYX_ERR(0, 372, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "veosinfo.pyx":371
 *         raise RuntimeError("ve_node_info failed")
 *     cdef object d = vni
 *     for key in ("nodeid", "status", "cores"):             # <<<<<<<<<<<<<<
 *         d[key] = d[key][:d["total_node_count"]]
 *     return d
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "veosinfo.pyx":373
 *     for key in ("nodeid", "status", "cores"):
 *         d[key] = d[key][:d["total_node_count"]]
 *     return d             # <<<<<<<<<<<<<<
 * 
 * def pidstat_info(int nodeid, pid_t pid):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_d);
  __pyx_r = __pyx_v_d;
  goto __pyx_L0;

  /* "veosinfo.pyx":366
 *     return mi
 * 
 * def node_info():             # <<<<<<<<<<<<<<
 *     cdef ve_nodeinfo vni
 *     if ve_node_info(&vni):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("veosinfo.node_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":375
 *     return d
 * 
 * def pidstat_info(int nodeid, pid_t pid):             # <<<<<<<<<<<<<<
 *     cdef ve_pidstat p
 *     if ve_pidstat_info(nodeid, pid, &p):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_21pidstat_info(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_21pidstat_info = {"pidstat_info", (PyCFunction)__pyx_pw_8veosinfo_21pidstat_info, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8veosinfo_21pidstat_info(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_nodeid;
  __pyx_t_8veosinfo_pid_t __pyx_v_pid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pidstat_info (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nodeid,&__pyx_n_s_pid,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nodeid)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pidstat_info", 1, 2, 2, 1); __PYX_ERR(0, 375, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pidstat_info") < 0)) __PYX_ERR(0, 375, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_nodeid = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 375, __pyx_L3_error)
    __pyx_v_pid = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_pid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 375, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pidstat_info", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 375, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.pidstat_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_20pidstat_info(__pyx_self, __pyx_v_nodeid, __pyx_v_pid);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_20pidstat_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, __pyx_t_8veosinfo_pid_t __pyx_v_pid) {
  struct ve_pidstat __pyx_v_p;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("pidstat_info", 0);

  /* "veosinfo.pyx":377
 * def pidstat_info(int nodeid, pid_t pid):
 *     cdef ve_pidstat p
 *     if ve_pidstat_info(nodeid, pid, &p):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_pidstat_info failed")
 *     return p
 */
  __pyx_t_1 = (ve_pidstat_info(__pyx_v_nodeid, __pyx_v_pid, (&__pyx_v_p)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":378
 *     cdef ve_pidstat p
 *     if ve_pidstat_info(nodeid, pid, &p):
 *         raise RuntimeError("ve_pidstat_info failed")             # <<<<<<<<<<<<<<
 *     return p
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 378, __pyx_L1_error)

    /* "veosinfo.pyx":377
 * def pidstat_info(int nodeid, pid_t pid):
 *     cdef ve_pidstat p
 *     if ve_pidstat_info(nodeid, pid, &p):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_pidstat_info failed")
 *     return p
 */
  }

  /* "veosinfo.pyx":379
 *     if ve_pidstat_info(nodeid, pid, &p):
 *         raise RuntimeError("ve_pidstat_info failed")
 *     return p             # <<<<<<<<<<<<<<
 * 
 * def read_fan(int nodeid):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_pidstat(__pyx_v_p); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":375
 *     return d
 * 
 * def pidstat_info(int nodeid, pid_t pid):             # <<<<<<<<<<<<<<
 *     cdef ve_pidstat p
 *     if ve_pidstat_info(nodeid, pid, &p):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.pidstat_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":381
 *     return p
 * 
 * def read_fan(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_fan f
 *     if ve_read_fan(nodeid, &f):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_23read_fan(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_23read_fan = {"read_fan", (PyCFunction)__pyx_pw_8veosinfo_23read_fan, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_23read_fan(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read_fan (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 381, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.read_fan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_22read_fan(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_22read_fan(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  struct ve_pwr_fan __pyx_v_f;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("read_fan", 0);

  /* "veosinfo.pyx":383
 * def read_fan(int nodeid):
 *     cdef ve_pwr_fan f
 *     if ve_read_fan(nodeid, &f):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_read_fan failed")
 *     return f
 */
  __pyx_t_1 = (ve_read_fan(__pyx_v_nodeid, (&__pyx_v_f)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":384
 *     cdef ve_pwr_fan f
 *     if ve_read_fan(nodeid, &f):
 *         raise RuntimeError("ve_read_fan failed")             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 384, __pyx_L1_error)

    /* "veosinfo.pyx":383
 * def read_fan(int nodeid):
 *     cdef ve_pwr_fan f
 *     if ve_read_fan(nodeid, &f):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_read_fan failed")
 *     return f
 */
  }

  /* "veosinfo.pyx":385
 *     if ve_read_fan(nodeid, &f):
 *         raise RuntimeError("ve_read_fan failed")
 *     return f             # <<<<<<<<<<<<<<
 * 
 * def read_temp(int nodeid):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_pwr_fan(__pyx_v_f); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":381
 *     return p
 * 
 * def read_fan(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_fan f
 *     if ve_read_fan(nodeid, &f):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.read_fan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":387
 *     return f
 * 
 * def read_temp(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_temp t
 *     if ve_read_temp(nodeid, &t):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_25read_temp(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_25read_temp = {"read_temp", (PyCFunction)__pyx_pw_8veosinfo_25read_temp, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_25read_temp(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read_temp (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 387, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.read_temp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_24read_temp(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_24read_temp(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  struct ve_pwr_temp __pyx_v_t;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("read_temp", 0);

  /* "veosinfo.pyx":389
 * def read_temp(int nodeid):
 *     cdef ve_pwr_temp t
 *     if ve_read_temp(nodeid, &t):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_read_temp failed")
 *     return t
 */
  __pyx_t_1 = (ve_read_temp(__pyx_v_nodeid, (&__pyx_v_t)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":390
 *     cdef ve_pwr_temp t
 *     if ve_read_temp(nodeid, &t):
 *         raise RuntimeError("ve_read_temp failed")             # <<<<<<<<<<<<<<
 *     return t
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 390, __pyx_L1_error)

    /* "veosinfo.pyx":389
 * def read_temp(int nodeid):
 *     cdef ve_pwr_temp t
 *     if ve_read_temp(nodeid, &t):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_read_temp failed")
 *     return t
 */
  }

  /* "veosinfo.pyx":391
 *     if ve_read_temp(nodeid, &t):
 *         raise RuntimeError("ve_read_temp failed")
 *     return t             # <<<<<<<<<<<<<<
 * 
 * def read_voltage(int nodeid):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_pwr_temp(__pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":387
 *     return f
 * 
 * def read_temp(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_temp t
 *     if ve_read_temp(nodeid, &t):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.read_temp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":393
 *     return t
 * 
 * def read_voltage(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_voltage v
 *     if ve_read_voltage(nodeid, &v):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_27read_voltage(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_27read_voltage = {"read_voltage", (PyCFunction)__pyx_pw_8veosinfo_27read_voltage, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_27read_voltage(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read_voltage (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 393, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.read_voltage", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_26read_voltage(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_26read_voltage(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  struct ve_pwr_voltage __pyx_v_v;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("read_voltage", 0);

  /* "veosinfo.pyx":395
 * def read_voltage(int nodeid):
 *     cdef ve_pwr_voltage v
 *     if ve_read_voltage(nodeid, &v):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_read_voltage failed")
 *     return v
 */
  __pyx_t_1 = (ve_read_voltage(__pyx_v_nodeid, (&__pyx_v_v)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":396
 *     cdef ve_pwr_voltage v
 *     if ve_read_voltage(nodeid, &v):
 *         raise RuntimeError("ve_read_voltage failed")             # <<<<<<<<<<<<<<
 *     return v
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 396, __pyx_L1_error)

    /* "veosinfo.pyx":395
 * def read_voltage(int nodeid):
 *     cdef ve_pwr_voltage v
 *     if ve_read_voltage(nodeid, &v):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_read_voltage failed")
 *     return v
 */
  }

  /* "veosinfo.pyx":397
 *     if ve_read_voltage(nodeid, &v):
 *         raise RuntimeError("ve_read_voltage failed")
 *     return v             # <<<<<<<<<<<<<<
 * 
 * def stat_info(int nodeid):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_pwr_voltage(__pyx_v_v); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":393
 *     return t
 * 
 * def read_voltage(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_voltage v
 *     if ve_read_voltage(nodeid, &v):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.read_voltage", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":399
 *     return v
 * 
 * def stat_info(int nodeid):             # <<<<<<<<<<<<<<
 *     ni = node_info()
 *     if nodeid >= ni["total_node_count"]:
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_29stat_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_29stat_info = {"stat_info", (PyCFunction)__pyx_pw_8veosinfo_29stat_info, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_29stat_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stat_info (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 399, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.stat_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_28stat_info(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_28stat_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  PyObject *__pyx_v_ni = NULL;
  PyObject *__pyx_v_cores = NULL;
  struct ve_statinfo __pyx_v_si;
  PyObject *__pyx_v_d = 0;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  __Pyx_RefNannySetupContext("stat_info", 0);

  /* "veosinfo.pyx":400
 * 
 * def stat_info(int nodeid):
 *     ni = node_info()             # <<<<<<<<<<<<<<
 *     if nodeid >= ni["total_node_count"]:
 *         raise ValueError("Wrong node ID: %d. Only %d node online." %
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_node_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 400, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 400, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_ni = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "veosinfo.pyx":401
 * def stat_info(int nodeid):
 *     ni = node_info()
 *     if nodeid >= ni["total_node_count"]:             # <<<<<<<<<<<<<<
 *         raise ValueError("Wrong node ID: %d. Only %d node online." %
 *                          (nodeid, ni["total_node_count"]))
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_nodeid); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_ni, __pyx_n_s_total_node_count); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(__pyx_t_4)) {

    /* "veosinfo.pyx":403
 *     if nodeid >= ni["total_node_count"]:
 *         raise ValueError("Wrong node ID: %d. Only %d node online." %
 *                          (nodeid, ni["total_node_count"]))             # <<<<<<<<<<<<<<
 *     cores = ni["cores"][nodeid]
 *     cdef ve_statinfo si
 */
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_nodeid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_ni, __pyx_n_s_total_node_count); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_2 = 0;

    /* "veosinfo.pyx":402
 *     ni = node_info()
 *     if nodeid >= ni["total_node_count"]:
 *         raise ValueError("Wrong node ID: %d. Only %d node online." %             # <<<<<<<<<<<<<<
 *                          (nodeid, ni["total_node_count"]))
 *     cores = ni["cores"][nodeid]
 */
    __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_Wrong_node_ID_d_Only_d_node_onli, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 402, __pyx_L1_error)

    /* "veosinfo.pyx":401
 * def stat_info(int nodeid):
 *     ni = node_info()
 *     if nodeid >= ni["total_node_count"]:             # <<<<<<<<<<<<<<
 *         raise ValueError("Wrong node ID: %d. Only %d node online." %
 *                          (nodeid, ni["total_node_count"]))
 */
  }

  /* "veosinfo.pyx":404
 *         raise ValueError("Wrong node ID: %d. Only %d node online." %
 *                          (nodeid, ni["total_node_count"]))
 *     cores = ni["cores"][nodeid]             # <<<<<<<<<<<<<<
 *     cdef ve_statinfo si
 *     if ve_stat_info(nodeid, &si):
 */
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_ni, __pyx_n_s_cores); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, __pyx_v_nodeid, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cores = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "veosinfo.pyx":406
 *     cores = ni["cores"][nodeid]
 *     cdef ve_statinfo si
 *     if ve_stat_info(nodeid, &si):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_stat_info failed")
 *     cdef object d = si
 */
  __pyx_t_4 = (ve_stat_info(__pyx_v_nodeid, (&__pyx_v_si)) != 0);
  if (unlikely(__pyx_t_4)) {

    /* "veosinfo.pyx":407
 *     cdef ve_statinfo si
 *     if ve_stat_info(nodeid, &si):
 *         raise RuntimeError("ve_stat_info failed")             # <<<<<<<<<<<<<<
 *     cdef object d = si
 *     for key in ("user", "nice", "idle", "iowait", "sys", "hardirq",
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 407, __pyx_L1_error)

    /* "veosinfo.pyx":406
 *     cores = ni["cores"][nodeid]
 *     cdef ve_statinfo si
 *     if ve_stat_info(nodeid, &si):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_stat_info failed")
 *     cdef object d = si
 */
  }

  /* "veosinfo.pyx":408
 *     if ve_stat_info(nodeid, &si):
 *         raise RuntimeError("ve_stat_info failed")
 *     cdef object d = si             # <<<<<<<<<<<<<<
 *     for key in ("user", "nice", "idle", "iowait", "sys", "hardirq",
 *                 "softirq", "steal", "guest", "guest_nice"):
 */
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_statinfo(__pyx_v_si); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_d = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "veosinfo.pyx":409
 *         raise RuntimeError("ve_stat_info failed")
 *     cdef object d = si
 *     for key in ("user", "nice", "idle", "iowait", "sys", "hardirq",             # <<<<<<<<<<<<<<
 *                 "softirq", "steal", "guest", "guest_nice"):
 *         d[key] = d[key][:cores]
 */
  __pyx_t_2 = __pyx_tuple__16; __Pyx_INCREF(__pyx_t_2); __pyx_t_5 = 0;
  for (;;) {
    if (__pyx_t_5 >= 10) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 409, __pyx_L1_error)
    #else
    __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "veosinfo.pyx":411
 *     for key in ("user", "nice", "idle", "iowait", "sys", "hardirq",
 *                 "softirq", "steal", "guest", "guest_nice"):
 *         d[key] = d[key][:cores]             # <<<<<<<<<<<<<<
 *     return d
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_d, __pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, 0, NULL, &__pyx_v_cores, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(PyObject_SetItem(__pyx_v_d, __pyx_v_key, __pyx_t_3) < 0)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "veosinfo.pyx":409
 *         raise RuntimeError("ve_stat_info failed")
 *     cdef object d = si
 *     for key in ("user", "nice", "idle", "iowait", "sys", "hardirq",             # <<<<<<<<<<<<<<
 *                 "softirq", "steal", "guest", "guest_nice"):
 *         d[key] = d[key][:cores]
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "veosinfo.pyx":412
 *                 "softirq", "steal", "guest", "guest_nice"):
 *         d[key] = d[key][:cores]
 *     return d             # <<<<<<<<<<<<<<
 * 
 * def uptime_info(int nodeid):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_d);
  __pyx_r = __pyx_v_d;
  goto __pyx_L0;

  /* "veosinfo.pyx":399
 *     return v
 * 
 * def stat_info(int nodeid):             # <<<<<<<<<<<<<<
 *     ni = node_info()
 *     if nodeid >= ni["total_node_count"]:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("veosinfo.stat_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ni);
  __Pyx_XDECREF(__pyx_v_cores);
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":414
 *     return d
 * 
 * def uptime_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef double up
 *     if ve_uptime_info(nodeid, &up):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_31uptime_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_31uptime_info = {"uptime_info", (PyCFunction)__pyx_pw_8veosinfo_31uptime_info, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_31uptime_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("uptime_info (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 414, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.uptime_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_30uptime_info(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_30uptime_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  double __pyx_v_up;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("uptime_info", 0);

  /* "veosinfo.pyx":416
 * def uptime_info(int nodeid):
 *     cdef double up
 *     if ve_uptime_info(nodeid, &up):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_uptime_info failed")
 *     return up
 */
  __pyx_t_1 = (ve_uptime_info(__pyx_v_nodeid, (&__pyx_v_up)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":417
 *     cdef double up
 *     if ve_uptime_info(nodeid, &up):
 *         raise RuntimeError("ve_uptime_info failed")             # <<<<<<<<<<<<<<
 *     return up
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 417, __pyx_L1_error)

    /* "veosinfo.pyx":416
 * def uptime_info(int nodeid):
 *     cdef double up
 *     if ve_uptime_info(nodeid, &up):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_uptime_info failed")
 *     return up
 */
  }

  /* "veosinfo.pyx":418
 *     if ve_uptime_info(nodeid, &up):
 *         raise RuntimeError("ve_uptime_info failed")
 *     return up             # <<<<<<<<<<<<<<
 * 
 * def vmstat_info(int nodeid):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_up); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":414
 *     return d
 * 
 * def uptime_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef double up
 *     if ve_uptime_info(nodeid, &up):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.uptime_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":420
 *     return up
 * 
 * def vmstat_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_vmstat s
 *     if ve_vmstat_info(nodeid, &s):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_33vmstat_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_33vmstat_info = {"vmstat_info", (PyCFunction)__pyx_pw_8veosinfo_33vmstat_info, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_33vmstat_info(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vmstat_info (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 420, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.vmstat_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_32vmstat_info(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_32vmstat_info(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  struct ve_vmstat __pyx_v_s;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("vmstat_info", 0);

  /* "veosinfo.pyx":422
 * def vmstat_info(int nodeid):
 *     cdef ve_vmstat s
 *     if ve_vmstat_info(nodeid, &s):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_vmstat_info failed")
 *     return s
 */
  __pyx_t_1 = (ve_vmstat_info(__pyx_v_nodeid, (&__pyx_v_s)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":423
 *     cdef ve_vmstat s
 *     if ve_vmstat_info(nodeid, &s):
 *         raise RuntimeError("ve_vmstat_info failed")             # <<<<<<<<<<<<<<
 *     return s
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 423, __pyx_L1_error)

    /* "veosinfo.pyx":422
 * def vmstat_info(int nodeid):
 *     cdef ve_vmstat s
 *     if ve_vmstat_info(nodeid, &s):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_vmstat_info failed")
 *     return s
 */
  }

  /* "veosinfo.pyx":424
 *     if ve_vmstat_info(nodeid, &s):
 *         raise RuntimeError("ve_vmstat_info failed")
 *     return s             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_convert__to_py_struct__ve_vmstat(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":420
 *     return up
 * 
 * def vmstat_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_vmstat s
 *     if ve_vmstat_info(nodeid, &s):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.vmstat_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":445
 *     SR56, SR57, SR58, SR59, SR60, SR61, SR62, SR63
 * 
 * def get_regvals(int nodeid, pid_t pid, list regid):             # <<<<<<<<<<<<<<
 *     cdef uint64_t ve_regval[VE_MAX_REGVALS]
 *     cdef int ve_regid[VE_MAX_REGVALS], i = 0
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_35get_regvals(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_35get_regvals = {"get_regvals", (PyCFunction)__pyx_pw_8veosinfo_35get_regvals, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8veosinfo_35get_regvals(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_nodeid;
  __pyx_t_8veosinfo_pid_t __pyx_v_pid;
  PyObject *__pyx_v_regid = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_regvals (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nodeid,&__pyx_n_s_pid,&__pyx_n_s_regid,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nodeid)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_regvals", 1, 3, 3, 1); __PYX_ERR(0, 445, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_regid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_regvals", 1, 3, 3, 2); __PYX_ERR(0, 445, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_regvals") < 0)) __PYX_ERR(0, 445, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_nodeid = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 445, __pyx_L3_error)
    __pyx_v_pid = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_pid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 445, __pyx_L3_error)
    __pyx_v_regid = ((PyObject*)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_regvals", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 445, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.get_regvals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_regid), (&PyList_Type), 1, "regid", 1))) __PYX_ERR(0, 445, __pyx_L1_error)
  __pyx_r = __pyx_pf_8veosinfo_34get_regvals(__pyx_self, __pyx_v_nodeid, __pyx_v_pid, __pyx_v_regid);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_34get_regvals(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, __pyx_t_8veosinfo_pid_t __pyx_v_pid, PyObject *__pyx_v_regid) {
  uint64_t __pyx_v_ve_regval[VE_MAX_REGVALS];
  int __pyx_v_ve_regid[VE_MAX_REGVALS];
  int __pyx_v_i;
  CYTHON_UNUSED PyObject *__pyx_v_rid = NULL;
  PyObject *__pyx_v_regval = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("get_regvals", 0);
  __Pyx_INCREF(__pyx_v_regid);

  /* "veosinfo.pyx":447
 * def get_regvals(int nodeid, pid_t pid, list regid):
 *     cdef uint64_t ve_regval[VE_MAX_REGVALS]
 *     cdef int ve_regid[VE_MAX_REGVALS], i = 0             # <<<<<<<<<<<<<<
 *     regid = regid[:VE_MAX_REGVALS]
 *     for rid in regid:
 */
  __pyx_v_i = 0;

  /* "veosinfo.pyx":448
 *     cdef uint64_t ve_regval[VE_MAX_REGVALS]
 *     cdef int ve_regid[VE_MAX_REGVALS], i = 0
 *     regid = regid[:VE_MAX_REGVALS]             # <<<<<<<<<<<<<<
 *     for rid in regid:
 *         ve_regid[i] = regid[i]
 */
  if (unlikely(__pyx_v_regid == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 448, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_GetSlice(__pyx_v_regid, 0, VE_MAX_REGVALS); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_regid, ((PyObject*)__pyx_t_1));
  __pyx_t_1 = 0;

  /* "veosinfo.pyx":449
 *     cdef int ve_regid[VE_MAX_REGVALS], i = 0
 *     regid = regid[:VE_MAX_REGVALS]
 *     for rid in regid:             # <<<<<<<<<<<<<<
 *         ve_regid[i] = regid[i]
 *         i += 1
 */
  __pyx_t_1 = __pyx_v_regid; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 449, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_rid, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "veosinfo.pyx":450
 *     regid = regid[:VE_MAX_REGVALS]
 *     for rid in regid:
 *         ve_regid[i] = regid[i]             # <<<<<<<<<<<<<<
 *         i += 1
 *     if ve_get_regvals(nodeid, pid, len(regid), ve_regid, &ve_regval[0]):
 */
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_regid, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 450, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    (__pyx_v_ve_regid[__pyx_v_i]) = __pyx_t_4;

    /* "veosinfo.pyx":451
 *     for rid in regid:
 *         ve_regid[i] = regid[i]
 *         i += 1             # <<<<<<<<<<<<<<
 *     if ve_get_regvals(nodeid, pid, len(regid), ve_regid, &ve_regval[0]):
 *         raise RuntimeError("ve_get_regvals failed")
 */
    __pyx_v_i = (__pyx_v_i + 1);

    /* "veosinfo.pyx":449
 *     cdef int ve_regid[VE_MAX_REGVALS], i = 0
 *     regid = regid[:VE_MAX_REGVALS]
 *     for rid in regid:             # <<<<<<<<<<<<<<
 *         ve_regid[i] = regid[i]
 *         i += 1
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":452
 *         ve_regid[i] = regid[i]
 *         i += 1
 *     if ve_get_regvals(nodeid, pid, len(regid), ve_regid, &ve_regval[0]):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_get_regvals failed")
 *     cdef list regval = list()
 */
  __pyx_t_2 = PyList_GET_SIZE(__pyx_v_regid); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 452, __pyx_L1_error)
  __pyx_t_5 = (ve_get_regvals(__pyx_v_nodeid, __pyx_v_pid, __pyx_t_2, __pyx_v_ve_regid, (&(__pyx_v_ve_regval[0]))) != 0);
  if (unlikely(__pyx_t_5)) {

    /* "veosinfo.pyx":453
 *         i += 1
 *     if ve_get_regvals(nodeid, pid, len(regid), ve_regid, &ve_regval[0]):
 *         raise RuntimeError("ve_get_regvals failed")             # <<<<<<<<<<<<<<
 *     cdef list regval = list()
 *     for i in xrange(len(regid)):
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 453, __pyx_L1_error)

    /* "veosinfo.pyx":452
 *         ve_regid[i] = regid[i]
 *         i += 1
 *     if ve_get_regvals(nodeid, pid, len(regid), ve_regid, &ve_regval[0]):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_get_regvals failed")
 *     cdef list regval = list()
 */
  }

  /* "veosinfo.pyx":454
 *     if ve_get_regvals(nodeid, pid, len(regid), ve_regid, &ve_regval[0]):
 *         raise RuntimeError("ve_get_regvals failed")
 *     cdef list regval = list()             # <<<<<<<<<<<<<<
 *     for i in xrange(len(regid)):
 *         regval.append(ve_regval[i])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_regval = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "veosinfo.pyx":455
 *         raise RuntimeError("ve_get_regvals failed")
 *     cdef list regval = list()
 *     for i in xrange(len(regid)):             # <<<<<<<<<<<<<<
 *         regval.append(ve_regval[i])
 *     return regval
 */
  __pyx_t_2 = PyList_GET_SIZE(__pyx_v_regid); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 455, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_6; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "veosinfo.pyx":456
 *     cdef list regval = list()
 *     for i in xrange(len(regid)):
 *         regval.append(ve_regval[i])             # <<<<<<<<<<<<<<
 *     return regval
 * 
 */
    __pyx_t_1 = __Pyx_PyInt_From_uint64_t((__pyx_v_ve_regval[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_regval, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 456, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "veosinfo.pyx":457
 *     for i in xrange(len(regid)):
 *         regval.append(ve_regval[i])
 *     return regval             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_regval);
  __pyx_r = __pyx_v_regval;
  goto __pyx_L0;

  /* "veosinfo.pyx":445
 *     SR56, SR57, SR58, SR59, SR60, SR61, SR62, SR63
 * 
 * def get_regvals(int nodeid, pid_t pid, list regid):             # <<<<<<<<<<<<<<
 *     cdef uint64_t ve_regval[VE_MAX_REGVALS]
 *     cdef int ve_regid[VE_MAX_REGVALS], i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("veosinfo.get_regvals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_rid);
  __Pyx_XDECREF(__pyx_v_regval);
  __Pyx_XDECREF(__pyx_v_regid);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":462
 * # Return VE sysfs path corresponding to a certain nodeid
 * #
 * def ve_sysfs_path(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef char sysfs_path[PATH_MAX]
 *     memset(sysfs_path, 0, PATH_MAX)
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_37ve_sysfs_path(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_37ve_sysfs_path = {"ve_sysfs_path", (PyCFunction)__pyx_pw_8veosinfo_37ve_sysfs_path, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_37ve_sysfs_path(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ve_sysfs_path (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 462, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.ve_sysfs_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_36ve_sysfs_path(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_36ve_sysfs_path(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  char __pyx_v_sysfs_path[PATH_MAX];
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("ve_sysfs_path", 0);

  /* "veosinfo.pyx":464
 * def ve_sysfs_path(int nodeid):
 *     cdef char sysfs_path[PATH_MAX]
 *     memset(sysfs_path, 0, PATH_MAX)             # <<<<<<<<<<<<<<
 *     if ve_sysfs_path_info(nodeid, &sysfs_path[0]):
 *         raise RuntimeError("ve_sysfs_path_info failed")
 */
  (void)(memset(__pyx_v_sysfs_path, 0, PATH_MAX));

  /* "veosinfo.pyx":465
 *     cdef char sysfs_path[PATH_MAX]
 *     memset(sysfs_path, 0, PATH_MAX)
 *     if ve_sysfs_path_info(nodeid, &sysfs_path[0]):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_sysfs_path_info failed")
 *     return sysfs_path
 */
  __pyx_t_1 = (ve_sysfs_path_info(__pyx_v_nodeid, (&(__pyx_v_sysfs_path[0]))) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "veosinfo.pyx":466
 *     memset(sysfs_path, 0, PATH_MAX)
 *     if ve_sysfs_path_info(nodeid, &sysfs_path[0]):
 *         raise RuntimeError("ve_sysfs_path_info failed")             # <<<<<<<<<<<<<<
 *     return sysfs_path
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 466, __pyx_L1_error)

    /* "veosinfo.pyx":465
 *     cdef char sysfs_path[PATH_MAX]
 *     memset(sysfs_path, 0, PATH_MAX)
 *     if ve_sysfs_path_info(nodeid, &sysfs_path[0]):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("ve_sysfs_path_info failed")
 *     return sysfs_path
 */
  }

  /* "veosinfo.pyx":467
 *     if ve_sysfs_path_info(nodeid, &sysfs_path[0]):
 *         raise RuntimeError("ve_sysfs_path_info failed")
 *     return sysfs_path             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_FromString(__pyx_v_sysfs_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "veosinfo.pyx":462
 * # Return VE sysfs path corresponding to a certain nodeid
 * #
 * def ve_sysfs_path(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef char sysfs_path[PATH_MAX]
 *     memset(sysfs_path, 0, PATH_MAX)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("veosinfo.ve_sysfs_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":472
 * # List of task IDs running on a certain VE node.
 * #
 * def ve_pids(int nodeid):             # <<<<<<<<<<<<<<
 *     sysfs_path = ve_sysfs_path(nodeid)
 *     pids = list()
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_39ve_pids(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid); /*proto*/
static PyMethodDef __pyx_mdef_8veosinfo_39ve_pids = {"ve_pids", (PyCFunction)__pyx_pw_8veosinfo_39ve_pids, METH_O, 0};
static PyObject *__pyx_pw_8veosinfo_39ve_pids(PyObject *__pyx_self, PyObject *__pyx_arg_nodeid) {
  int __pyx_v_nodeid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ve_pids (wrapper)", 0);
  assert(__pyx_arg_nodeid); {
    __pyx_v_nodeid = __Pyx_PyInt_As_int(__pyx_arg_nodeid); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 472, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.ve_pids", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_38ve_pids(__pyx_self, ((int)__pyx_v_nodeid));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_38ve_pids(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid) {
  PyObject *__pyx_v_sysfs_path = NULL;
  PyObject *__pyx_v_pids = NULL;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_v_line = NULL;
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  PyObject *(*__pyx_t_15)(PyObject *);
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  int __pyx_t_19;
  int __pyx_t_20;
  int __pyx_t_21;
  __Pyx_RefNannySetupContext("ve_pids", 0);

  /* "veosinfo.pyx":473
 * #
 * def ve_pids(int nodeid):
 *     sysfs_path = ve_sysfs_path(nodeid)             # <<<<<<<<<<<<<<
 *     pids = list()
 *     with open(os.path.join(sysfs_path, "task_id_all"), "r") as f:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ve_sysfs_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_nodeid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 473, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 473, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 473, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 473, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 473, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_sysfs_path = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "veosinfo.pyx":474
 * def ve_pids(int nodeid):
 *     sysfs_path = ve_sysfs_path(nodeid)
 *     pids = list()             # <<<<<<<<<<<<<<
 *     with open(os.path.join(sysfs_path, "task_id_all"), "r") as f:
 *         for line in f:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pids = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "veosinfo.pyx":475
 *     sysfs_path = ve_sysfs_path(nodeid)
 *     pids = list()
 *     with open(os.path.join(sysfs_path, "task_id_all"), "r") as f:             # <<<<<<<<<<<<<<
 *         for line in f:
 *             line = line.rstrip(os.linesep)
 */
  /*with:*/ {
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_join); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_sysfs_path, __pyx_n_s_task_id_all};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_sysfs_path, __pyx_n_s_task_id_all};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_3 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 475, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_sysfs_path);
      __Pyx_GIVEREF(__pyx_v_sysfs_path);
      PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_6, __pyx_v_sysfs_path);
      __Pyx_INCREF(__pyx_n_s_task_id_all);
      __Pyx_GIVEREF(__pyx_n_s_task_id_all);
      PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_6, __pyx_n_s_task_id_all);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_r);
    __Pyx_GIVEREF(__pyx_n_s_r);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_r);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_open, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_exit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_n_s_enter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 475, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 475, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 475, __pyx_L3_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __pyx_t_2;
    __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        /*try:*/ {
          __pyx_v_f = __pyx_t_3;
          __pyx_t_3 = 0;

          /* "veosinfo.pyx":476
 *     pids = list()
 *     with open(os.path.join(sysfs_path, "task_id_all"), "r") as f:
 *         for line in f:             # <<<<<<<<<<<<<<
 *             line = line.rstrip(os.linesep)
 *             for l in line.split(" "):
 */
          if (likely(PyList_CheckExact(__pyx_v_f)) || PyTuple_CheckExact(__pyx_v_f)) {
            __pyx_t_3 = __pyx_v_f; __Pyx_INCREF(__pyx_t_3); __pyx_t_11 = 0;
            __pyx_t_12 = NULL;
          } else {
            __pyx_t_11 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_f); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 476, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_12 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 476, __pyx_L7_error)
          }
          for (;;) {
            if (likely(!__pyx_t_12)) {
              if (likely(PyList_CheckExact(__pyx_t_3))) {
                if (__pyx_t_11 >= PyList_GET_SIZE(__pyx_t_3)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_11); __Pyx_INCREF(__pyx_t_1); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 476, __pyx_L7_error)
                #else
                __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 476, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_1);
                #endif
              } else {
                if (__pyx_t_11 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_11); __Pyx_INCREF(__pyx_t_1); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 476, __pyx_L7_error)
                #else
                __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 476, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_1);
                #endif
              }
            } else {
              __pyx_t_1 = __pyx_t_12(__pyx_t_3);
              if (unlikely(!__pyx_t_1)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 476, __pyx_L7_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_1);
            }
            __Pyx_XDECREF_SET(__pyx_v_line, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "veosinfo.pyx":477
 *     with open(os.path.join(sysfs_path, "task_id_all"), "r") as f:
 *         for line in f:
 *             line = line.rstrip(os.linesep)             # <<<<<<<<<<<<<<
 *             for l in line.split(" "):
 *                 try:
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_line, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 477, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 477, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_linesep); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 477, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_5 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
              if (likely(__pyx_t_5)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_2, function);
              }
            }
            if (!__pyx_t_5) {
              __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 477, __pyx_L7_error)
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_GOTREF(__pyx_t_1);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_2)) {
                PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
                __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 477, __pyx_L7_error)
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
                PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
                __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 477, __pyx_L7_error)
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              } else
              #endif
              {
                __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 477, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_13);
                __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_5); __pyx_t_5 = NULL;
                __Pyx_GIVEREF(__pyx_t_4);
                PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_4);
                __pyx_t_4 = 0;
                __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 477, __pyx_L7_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF_SET(__pyx_v_line, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "veosinfo.pyx":478
 *         for line in f:
 *             line = line.rstrip(os.linesep)
 *             for l in line.split(" "):             # <<<<<<<<<<<<<<
 *                 try:
 *                     pids.append(int(l))
 */
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_line, __pyx_n_s_split); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 478, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 478, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
              __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_14 = 0;
              __pyx_t_15 = NULL;
            } else {
              __pyx_t_14 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 478, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_15 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 478, __pyx_L7_error)
            }
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            for (;;) {
              if (likely(!__pyx_t_15)) {
                if (likely(PyList_CheckExact(__pyx_t_1))) {
                  if (__pyx_t_14 >= PyList_GET_SIZE(__pyx_t_1)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_14); __Pyx_INCREF(__pyx_t_2); __pyx_t_14++; if (unlikely(0 < 0)) __PYX_ERR(0, 478, __pyx_L7_error)
                  #else
                  __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 478, __pyx_L7_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  #endif
                } else {
                  if (__pyx_t_14 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_14); __Pyx_INCREF(__pyx_t_2); __pyx_t_14++; if (unlikely(0 < 0)) __PYX_ERR(0, 478, __pyx_L7_error)
                  #else
                  __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 478, __pyx_L7_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  #endif
                }
              } else {
                __pyx_t_2 = __pyx_t_15(__pyx_t_1);
                if (unlikely(!__pyx_t_2)) {
                  PyObject* exc_type = PyErr_Occurred();
                  if (exc_type) {
                    if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                    else __PYX_ERR(0, 478, __pyx_L7_error)
                  }
                  break;
                }
                __Pyx_GOTREF(__pyx_t_2);
              }
              __Pyx_XDECREF_SET(__pyx_v_l, __pyx_t_2);
              __pyx_t_2 = 0;

              /* "veosinfo.pyx":479
 *             line = line.rstrip(os.linesep)
 *             for l in line.split(" "):
 *                 try:             # <<<<<<<<<<<<<<
 *                     pids.append(int(l))
 *                 except:
 */
              {
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __Pyx_ExceptionSave(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
                __Pyx_XGOTREF(__pyx_t_16);
                __Pyx_XGOTREF(__pyx_t_17);
                __Pyx_XGOTREF(__pyx_t_18);
                /*try:*/ {

                  /* "veosinfo.pyx":480
 *             for l in line.split(" "):
 *                 try:
 *                     pids.append(int(l))             # <<<<<<<<<<<<<<
 *                 except:
 *                     pass
 */
                  __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_v_l); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 480, __pyx_L17_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __pyx_t_19 = __Pyx_PyList_Append(__pyx_v_pids, __pyx_t_2); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(0, 480, __pyx_L17_error)
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                  /* "veosinfo.pyx":479
 *             line = line.rstrip(os.linesep)
 *             for l in line.split(" "):
 *                 try:             # <<<<<<<<<<<<<<
 *                     pids.append(int(l))
 *                 except:
 */
                }
                __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                goto __pyx_L24_try_end;
                __pyx_L17_error:;
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

                /* "veosinfo.pyx":481
 *                 try:
 *                     pids.append(int(l))
 *                 except:             # <<<<<<<<<<<<<<
 *                     pass
 *     return pids
 */
                /*except:*/ {
                  __Pyx_ErrRestore(0,0,0);
                  goto __pyx_L18_exception_handled;
                }
                __pyx_L18_exception_handled:;
                __Pyx_XGIVEREF(__pyx_t_16);
                __Pyx_XGIVEREF(__pyx_t_17);
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
                __pyx_L24_try_end:;
              }

              /* "veosinfo.pyx":478
 *         for line in f:
 *             line = line.rstrip(os.linesep)
 *             for l in line.split(" "):             # <<<<<<<<<<<<<<
 *                 try:
 *                     pids.append(int(l))
 */
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "veosinfo.pyx":476
 *     pids = list()
 *     with open(os.path.join(sysfs_path, "task_id_all"), "r") as f:
 *         for line in f:             # <<<<<<<<<<<<<<
 *             line = line.rstrip(os.linesep)
 *             for l in line.split(" "):
 */
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "veosinfo.pyx":475
 *     sysfs_path = ve_sysfs_path(nodeid)
 *     pids = list()
 *     with open(os.path.join(sysfs_path, "task_id_all"), "r") as f:             # <<<<<<<<<<<<<<
 *         for line in f:
 *             line = line.rstrip(os.linesep)
 */
        }
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L12_try_end;
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("veosinfo.ve_pids", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 475, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_13 = PyTuple_Pack(3, __pyx_t_3, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 475, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_18 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_13, NULL);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 475, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_20 = __Pyx_PyObject_IsTrue(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (__pyx_t_20 < 0) __PYX_ERR(0, 475, __pyx_L9_except_error)
          __pyx_t_21 = ((!(__pyx_t_20 != 0)) != 0);
          if (__pyx_t_21) {
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_GIVEREF(__pyx_t_1);
            __Pyx_XGIVEREF(__pyx_t_2);
            __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_1, __pyx_t_2);
            __pyx_t_3 = 0; __pyx_t_1 = 0; __pyx_t_2 = 0; 
            __PYX_ERR(0, 475, __pyx_L9_except_error)
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        goto __pyx_L1_error;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        __pyx_L12_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_7) {
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__23, NULL);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 475, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L6:;
    }
    goto __pyx_L28;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L1_error;
    __pyx_L28:;
  }

  /* "veosinfo.pyx":483
 *                 except:
 *                     pass
 *     return pids             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pids);
  __pyx_r = __pyx_v_pids;
  goto __pyx_L0;

  /* "veosinfo.pyx":472
 * # List of task IDs running on a certain VE node.
 * #
 * def ve_pids(int nodeid):             # <<<<<<<<<<<<<<
 *     sysfs_path = ve_sysfs_path(nodeid)
 *     pids = list()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("veosinfo.ve_pids", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sysfs_path);
  __Pyx_XDECREF(__pyx_v_pids);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "veosinfo.pyx":508
 * 
 * 
 * def ve_pid_perf(int nodeid, int pid):             # <<<<<<<<<<<<<<
 *     """
 *     Create a dict with performance counter values for
 */

/* Python wrapper */
static PyObject *__pyx_pw_8veosinfo_41ve_pid_perf(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8veosinfo_40ve_pid_perf[] = "\n    Create a dict with performance counter values for\n    a certain pid on a VE node.\n    ";
static PyMethodDef __pyx_mdef_8veosinfo_41ve_pid_perf = {"ve_pid_perf", (PyCFunction)__pyx_pw_8veosinfo_41ve_pid_perf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8veosinfo_40ve_pid_perf};
static PyObject *__pyx_pw_8veosinfo_41ve_pid_perf(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_nodeid;
  int __pyx_v_pid;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ve_pid_perf (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nodeid,&__pyx_n_s_pid,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nodeid)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ve_pid_perf", 1, 2, 2, 1); __PYX_ERR(0, 508, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ve_pid_perf") < 0)) __PYX_ERR(0, 508, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_nodeid = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_nodeid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 508, __pyx_L3_error)
    __pyx_v_pid = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_pid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 508, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ve_pid_perf", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 508, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("veosinfo.ve_pid_perf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8veosinfo_40ve_pid_perf(__pyx_self, __pyx_v_nodeid, __pyx_v_pid);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8veosinfo_40ve_pid_perf(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_nodeid, int __pyx_v_pid) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_regval = NULL;
  PyObject *__pyx_v_pmmr = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_mode = NULL;
  PyObject *__pyx_v_regname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  long __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  __Pyx_RefNannySetupContext("ve_pid_perf", 0);

  /* "veosinfo.pyx":513
 *     a certain pid on a VE node.
 *     """
 *     res = dict()             # <<<<<<<<<<<<<<
 *     regval = get_regvals(nodeid, pid, VEREGS)
 *     res["T"] = time.time()
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_res = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "veosinfo.pyx":514
 *     """
 *     res = dict()
 *     regval = get_regvals(nodeid, pid, VEREGS)             # <<<<<<<<<<<<<<
 *     res["T"] = time.time()
 *     res["USRCC"] = regval[0]
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_get_regvals); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_nodeid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_pid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_VEREGS); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_3, __pyx_t_4, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_3, __pyx_t_4, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_7, __pyx_t_5);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_regval = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "veosinfo.pyx":515
 *     res = dict()
 *     regval = get_regvals(nodeid, pid, VEREGS)
 *     res["T"] = time.time()             # <<<<<<<<<<<<<<
 *     res["USRCC"] = regval[0]
 *     pmmr = regval[1]
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 515, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 515, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(PyDict_SetItem(__pyx_v_res, __pyx_n_s_T, __pyx_t_1) < 0)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":516
 *     regval = get_regvals(nodeid, pid, VEREGS)
 *     res["T"] = time.time()
 *     res["USRCC"] = regval[0]             # <<<<<<<<<<<<<<
 *     pmmr = regval[1]
 *     for i in xrange(16):
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_regval, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(PyDict_SetItem(__pyx_v_res, __pyx_n_s_USRCC, __pyx_t_1) < 0)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":517
 *     res["T"] = time.time()
 *     res["USRCC"] = regval[0]
 *     pmmr = regval[1]             # <<<<<<<<<<<<<<
 *     for i in xrange(16):
 *         mode = (pmmr >> (60 - (i * 4))) & 3
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_regval, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pmmr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "veosinfo.pyx":518
 *     res["USRCC"] = regval[0]
 *     pmmr = regval[1]
 *     for i in xrange(16):             # <<<<<<<<<<<<<<
 *         mode = (pmmr >> (60 - (i * 4))) & 3
 *         if mode in PMC_NAME[i]:
 */
  for (__pyx_t_9 = 0; __pyx_t_9 < 16; __pyx_t_9+=1) {
    __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "veosinfo.pyx":519
 *     pmmr = regval[1]
 *     for i in xrange(16):
 *         mode = (pmmr >> (60 - (i * 4))) & 3             # <<<<<<<<<<<<<<
 *         if mode in PMC_NAME[i]:
 *             regname = PMC_NAME[i][mode]
 */
    __pyx_t_1 = PyNumber_Multiply(__pyx_v_i, __pyx_int_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyInt_SubtractCObj(__pyx_int_60, __pyx_t_1, 60, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Rshift(__pyx_v_pmmr, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyInt_AndObjC(__pyx_t_1, __pyx_int_3, 3, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_mode, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "veosinfo.pyx":520
 *     for i in xrange(16):
 *         mode = (pmmr >> (60 - (i * 4))) & 3
 *         if mode in PMC_NAME[i]:             # <<<<<<<<<<<<<<
 *             regname = PMC_NAME[i][mode]
 *         else:
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_PMC_NAME); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_v_mode, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 520, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_11 = (__pyx_t_10 != 0);
    if (likely(__pyx_t_11)) {

      /* "veosinfo.pyx":521
 *         mode = (pmmr >> (60 - (i * 4))) & 3
 *         if mode in PMC_NAME[i]:
 *             regname = PMC_NAME[i][mode]             # <<<<<<<<<<<<<<
 *         else:
 *             raise RuntimeError("Illegal mode in PMMR: PMC%d mode=%d" % i, mode)
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_PMC_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 521, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_i); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 521, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_v_mode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 521, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF_SET(__pyx_v_regname, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "veosinfo.pyx":520
 *     for i in xrange(16):
 *         mode = (pmmr >> (60 - (i * 4))) & 3
 *         if mode in PMC_NAME[i]:             # <<<<<<<<<<<<<<
 *             regname = PMC_NAME[i][mode]
 *         else:
 */
      goto __pyx_L5;
    }

    /* "veosinfo.pyx":523
 *             regname = PMC_NAME[i][mode]
 *         else:
 *             raise RuntimeError("Illegal mode in PMMR: PMC%d mode=%d" % i, mode)             # <<<<<<<<<<<<<<
 *         res[regname] = regval[2 + i]
 *     return res
 */
    /*else*/ {
      __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Illegal_mode_in_PMMR_PMC_d_mode, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_1);
      __Pyx_INCREF(__pyx_v_mode);
      __Pyx_GIVEREF(__pyx_v_mode);
      PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_mode);
      __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 523, __pyx_L1_error)
    }
    __pyx_L5:;

    /* "veosinfo.pyx":524
 *         else:
 *             raise RuntimeError("Illegal mode in PMMR: PMC%d mode=%d" % i, mode)
 *         res[regname] = regval[2 + i]             # <<<<<<<<<<<<<<
 *     return res
 * 
 */
    __pyx_t_1 = __Pyx_PyInt_AddCObj(__pyx_int_2, __pyx_v_i, 2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 524, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_regval, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 524, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(PyDict_SetItem(__pyx_v_res, __pyx_v_regname, __pyx_t_8) < 0)) __PYX_ERR(0, 524, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }

  /* "veosinfo.pyx":525
 *             raise RuntimeError("Illegal mode in PMMR: PMC%d mode=%d" % i, mode)
 *         res[regname] = regval[2 + i]
 *     return res             # <<<<<<<<<<<<<<
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "veosinfo.pyx":508
 * 
 * 
 * def ve_pid_perf(int nodeid, int pid):             # <<<<<<<<<<<<<<
 *     """
 *     Create a dict with performance counter values for
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("veosinfo.ve_pid_perf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_regval);
  __Pyx_XDECREF(__pyx_v_pmmr);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_mode);
  __Pyx_XDECREF(__pyx_v_regname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_char___5b_VE_BUF_LEN_5d_")
 * cdef inline list __Pyx_carray_to_py_char___5b_VE_BUF_LEN_5d_(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_py_char___5b_VE_BUF_LEN_5d_(char (*__pyx_v_v)[VE_BUF_LEN], Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_py_char___5b_VE_BUF_LEN_5d_", 0);

  /* "carray.to_py":115
 *     cdef size_t i
 *     cdef object value
 *     l = PyList_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyList_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_l = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":116
 *     cdef object value
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":117
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 */
    __pyx_t_1 = __Pyx_PyObject_FromString((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":118
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(l, i, value)
 *     return l
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":119
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)             # <<<<<<<<<<<<<<
 *     return l
 * 
 */
    PyList_SET_ITEM(__pyx_v_l, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":120
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 *     return l             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_l);
  __pyx_r = __pyx_v_l;
  goto __pyx_L0;

  /* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_char___5b_VE_BUF_LEN_5d_")
 * cdef inline list __Pyx_carray_to_py_char___5b_VE_BUF_LEN_5d_(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_py_char___5b_VE_BUF_LEN_5d_", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_char___5b_VE_BUF_LEN_5d_")
 * cdef inline tuple __Pyx_carray_to_tuple_char___5b_VE_BUF_LEN_5d_(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_char___5b_VE_BUF_LEN_5d_(char (*__pyx_v_v)[VE_BUF_LEN], Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_tuple_char___5b_VE_BUF_LEN_5d_", 0);

  /* "carray.to_py":127
 *     cdef size_t i
 *     cdef object value
 *     t = PyTuple_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyTuple_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_t = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":128
 *     cdef object value
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":129
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 */
    __pyx_t_1 = __Pyx_PyObject_FromString((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":130
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":131
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)             # <<<<<<<<<<<<<<
 *     return t
 */
    PyTuple_SET_ITEM(__pyx_v_t, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":132
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_t);
  __pyx_r = __pyx_v_t;
  goto __pyx_L0;

  /* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_char___5b_VE_BUF_LEN_5d_")
 * cdef inline tuple __Pyx_carray_to_tuple_char___5b_VE_BUF_LEN_5d_(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_tuple_char___5b_VE_BUF_LEN_5d_", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_int")
 * cdef inline list __Pyx_carray_to_py_int(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_py_int(int *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_py_int", 0);

  /* "carray.to_py":115
 *     cdef size_t i
 *     cdef object value
 *     l = PyList_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyList_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_l = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":116
 *     cdef object value
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":117
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 */
    __pyx_t_1 = __Pyx_PyInt_From_int((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":118
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(l, i, value)
 *     return l
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":119
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)             # <<<<<<<<<<<<<<
 *     return l
 * 
 */
    PyList_SET_ITEM(__pyx_v_l, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":120
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 *     return l             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_l);
  __pyx_r = __pyx_v_l;
  goto __pyx_L0;

  /* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_int")
 * cdef inline list __Pyx_carray_to_py_int(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_py_int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_int")
 * cdef inline tuple __Pyx_carray_to_tuple_int(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_int(int *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_tuple_int", 0);

  /* "carray.to_py":127
 *     cdef size_t i
 *     cdef object value
 *     t = PyTuple_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyTuple_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_t = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":128
 *     cdef object value
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":129
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 */
    __pyx_t_1 = __Pyx_PyInt_From_int((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":130
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":131
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)             # <<<<<<<<<<<<<<
 *     return t
 */
    PyTuple_SET_ITEM(__pyx_v_t, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":132
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_t);
  __pyx_r = __pyx_v_t;
  goto __pyx_L0;

  /* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_int")
 * cdef inline tuple __Pyx_carray_to_tuple_int(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_tuple_int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_")
 * cdef inline list __Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_(char (*__pyx_v_v)[MAX_DEVICE_LEN], Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_", 0);

  /* "carray.to_py":115
 *     cdef size_t i
 *     cdef object value
 *     l = PyList_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyList_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_l = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":116
 *     cdef object value
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":117
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 */
    __pyx_t_1 = __Pyx_PyObject_FromString((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":118
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(l, i, value)
 *     return l
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":119
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)             # <<<<<<<<<<<<<<
 *     return l
 * 
 */
    PyList_SET_ITEM(__pyx_v_l, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":120
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 *     return l             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_l);
  __pyx_r = __pyx_v_l;
  goto __pyx_L0;

  /* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_")
 * cdef inline list __Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_char___5b_MAX_DEVICE_LEN_5d_")
 * cdef inline tuple __Pyx_carray_to_tuple_char___5b_MAX_DEVICE_LEN_5d_(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_char___5b_MAX_DEVICE_LEN_5d_(char (*__pyx_v_v)[MAX_DEVICE_LEN], Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_tuple_char___5b_MAX_DEVICE_LEN_5d_", 0);

  /* "carray.to_py":127
 *     cdef size_t i
 *     cdef object value
 *     t = PyTuple_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyTuple_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_t = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":128
 *     cdef object value
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":129
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 */
    __pyx_t_1 = __Pyx_PyObject_FromString((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":130
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":131
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)             # <<<<<<<<<<<<<<
 *     return t
 */
    PyTuple_SET_ITEM(__pyx_v_t, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":132
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_t);
  __pyx_r = __pyx_v_t;
  goto __pyx_L0;

  /* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_char___5b_MAX_DEVICE_LEN_5d_")
 * cdef inline tuple __Pyx_carray_to_tuple_char___5b_MAX_DEVICE_LEN_5d_(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_tuple_char___5b_MAX_DEVICE_LEN_5d_", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_double")
 * cdef inline list __Pyx_carray_to_py_double(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_py_double(double *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_py_double", 0);

  /* "carray.to_py":115
 *     cdef size_t i
 *     cdef object value
 *     l = PyList_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyList_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_l = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":116
 *     cdef object value
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":117
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 */
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":118
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(l, i, value)
 *     return l
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":119
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)             # <<<<<<<<<<<<<<
 *     return l
 * 
 */
    PyList_SET_ITEM(__pyx_v_l, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":120
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 *     return l             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_l);
  __pyx_r = __pyx_v_l;
  goto __pyx_L0;

  /* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_double")
 * cdef inline list __Pyx_carray_to_py_double(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_py_double", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_double")
 * cdef inline tuple __Pyx_carray_to_tuple_double(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_double(double *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_tuple_double", 0);

  /* "carray.to_py":127
 *     cdef size_t i
 *     cdef object value
 *     t = PyTuple_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyTuple_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_t = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":128
 *     cdef object value
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":129
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 */
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":130
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":131
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)             # <<<<<<<<<<<<<<
 *     return t
 */
    PyTuple_SET_ITEM(__pyx_v_t, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":132
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_t);
  __pyx_r = __pyx_v_t;
  goto __pyx_L0;

  /* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_double")
 * cdef inline tuple __Pyx_carray_to_tuple_double(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_tuple_double", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_unsigned_PY_LONG_LONG")
 * cdef inline list __Pyx_carray_to_py_unsigned_PY_LONG_LONG(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_py_unsigned_PY_LONG_LONG(unsigned PY_LONG_LONG *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_py_unsigned_PY_LONG_LONG", 0);

  /* "carray.to_py":115
 *     cdef size_t i
 *     cdef object value
 *     l = PyList_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyList_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_l = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":116
 *     cdef object value
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":117
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 */
    __pyx_t_1 = __Pyx_PyInt_From_unsigned_PY_LONG_LONG((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":118
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(l, i, value)
 *     return l
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":119
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)             # <<<<<<<<<<<<<<
 *     return l
 * 
 */
    PyList_SET_ITEM(__pyx_v_l, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":120
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 *     return l             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_l);
  __pyx_r = __pyx_v_l;
  goto __pyx_L0;

  /* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_unsigned_PY_LONG_LONG")
 * cdef inline list __Pyx_carray_to_py_unsigned_PY_LONG_LONG(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_py_unsigned_PY_LONG_LONG", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_unsigned_PY_LONG_LONG")
 * cdef inline tuple __Pyx_carray_to_tuple_unsigned_PY_LONG_LONG(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_unsigned_PY_LONG_LONG(unsigned PY_LONG_LONG *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_tuple_unsigned_PY_LONG_LONG", 0);

  /* "carray.to_py":127
 *     cdef size_t i
 *     cdef object value
 *     t = PyTuple_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyTuple_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_t = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":128
 *     cdef object value
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":129
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 */
    __pyx_t_1 = __Pyx_PyInt_From_unsigned_PY_LONG_LONG((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":130
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":131
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)             # <<<<<<<<<<<<<<
 *     return t
 */
    PyTuple_SET_ITEM(__pyx_v_t, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":132
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_t);
  __pyx_r = __pyx_v_t;
  goto __pyx_L0;

  /* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_unsigned_PY_LONG_LONG")
 * cdef inline tuple __Pyx_carray_to_tuple_unsigned_PY_LONG_LONG(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_tuple_unsigned_PY_LONG_LONG", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_unsigned_long")
 * cdef inline list __Pyx_carray_to_py_unsigned_long(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_py_unsigned_long(unsigned long *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_py_unsigned_long", 0);

  /* "carray.to_py":115
 *     cdef size_t i
 *     cdef object value
 *     l = PyList_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyList_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_l = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":116
 *     cdef object value
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":117
 *     l = PyList_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 */
    __pyx_t_1 = __Pyx_PyInt_From_unsigned_long((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":118
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(l, i, value)
 *     return l
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":119
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)             # <<<<<<<<<<<<<<
 *     return l
 * 
 */
    PyList_SET_ITEM(__pyx_v_l, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":120
 *         Py_INCREF(value)
 *         PyList_SET_ITEM(l, i, value)
 *     return l             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_l);
  __pyx_r = __pyx_v_l;
  goto __pyx_L0;

  /* "carray.to_py":112
 * 
 * @cname("__Pyx_carray_to_py_unsigned_long")
 * cdef inline list __Pyx_carray_to_py_unsigned_long(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_py_unsigned_long", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_unsigned_long")
 * cdef inline tuple __Pyx_carray_to_tuple_unsigned_long(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

static CYTHON_INLINE PyObject *__Pyx_carray_to_tuple_unsigned_long(unsigned long *__pyx_v_v, Py_ssize_t __pyx_v_length) {
  size_t __pyx_v_i;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  size_t __pyx_t_3;
  size_t __pyx_t_4;
  __Pyx_RefNannySetupContext("__Pyx_carray_to_tuple_unsigned_long", 0);

  /* "carray.to_py":127
 *     cdef size_t i
 *     cdef object value
 *     t = PyTuple_New(length)             # <<<<<<<<<<<<<<
 *     for i in range(<size_t>length):
 *         value = v[i]
 */
  __pyx_t_1 = PyTuple_New(__pyx_v_length); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_t = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "carray.to_py":128
 *     cdef object value
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):             # <<<<<<<<<<<<<<
 *         value = v[i]
 *         Py_INCREF(value)
 */
  __pyx_t_2 = ((size_t)__pyx_v_length);
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "carray.to_py":129
 *     t = PyTuple_New(length)
 *     for i in range(<size_t>length):
 *         value = v[i]             # <<<<<<<<<<<<<<
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 */
    __pyx_t_1 = __Pyx_PyInt_From_unsigned_long((__pyx_v_v[__pyx_v_i])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "carray.to_py":130
 *     for i in range(<size_t>length):
 *         value = v[i]
 *         Py_INCREF(value)             # <<<<<<<<<<<<<<
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t
 */
    Py_INCREF(__pyx_v_value);

    /* "carray.to_py":131
 *         value = v[i]
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)             # <<<<<<<<<<<<<<
 *     return t
 */
    PyTuple_SET_ITEM(__pyx_v_t, __pyx_v_i, __pyx_v_value);
  }

  /* "carray.to_py":132
 *         Py_INCREF(value)
 *         PyTuple_SET_ITEM(t, i, value)
 *     return t             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_t);
  __pyx_r = __pyx_v_t;
  goto __pyx_L0;

  /* "carray.to_py":124
 * 
 * @cname("__Pyx_carray_to_tuple_unsigned_long")
 * cdef inline tuple __Pyx_carray_to_tuple_unsigned_long(base_type *v, Py_ssize_t length):             # <<<<<<<<<<<<<<
 *     cdef size_t i
 *     cdef object value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("carray.to_py.__Pyx_carray_to_tuple_unsigned_long", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":16
 * @cython.internal
 * cdef class __Pyx_EnumMeta(type):
 *     def __init__(cls, name, parents, dct):             # <<<<<<<<<<<<<<
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 */

/* Python wrapper */
static int __pyx_pw_8EnumBase_14__Pyx_EnumMeta_1__init__(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8EnumBase_14__Pyx_EnumMeta_1__init__(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_parents = 0;
  PyObject *__pyx_v_dct = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_parents,&__pyx_n_s_dct,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parents)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(1, 16, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dct)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(1, 16, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_name = values[0];
    __pyx_v_parents = values[1];
    __pyx_v_dct = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 16, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta___init__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_cls), __pyx_v_name, __pyx_v_parents, __pyx_v_dct);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8EnumBase_14__Pyx_EnumMeta___init__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name, PyObject *__pyx_v_parents, PyObject *__pyx_v_dct) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "EnumBase":17
 * cdef class __Pyx_EnumMeta(type):
 *     def __init__(cls, name, parents, dct):
 *         type.__init__(cls, name, parents, dct)             # <<<<<<<<<<<<<<
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)(&PyType_Type)), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_3, ((PyObject *)__pyx_v_cls), __pyx_v_name, __pyx_v_parents, __pyx_v_dct};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_3, ((PyObject *)__pyx_v_cls), __pyx_v_name, __pyx_v_parents, __pyx_v_dct};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(4+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(((PyObject *)__pyx_v_cls));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_cls));
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, ((PyObject *)__pyx_v_cls));
    __Pyx_INCREF(__pyx_v_name);
    __Pyx_GIVEREF(__pyx_v_name);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_name);
    __Pyx_INCREF(__pyx_v_parents);
    __Pyx_GIVEREF(__pyx_v_parents);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_4, __pyx_v_parents);
    __Pyx_INCREF(__pyx_v_dct);
    __Pyx_GIVEREF(__pyx_v_dct);
    PyTuple_SET_ITEM(__pyx_t_5, 3+__pyx_t_4, __pyx_v_dct);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":18
 *     def __init__(cls, name, parents, dct):
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()             # <<<<<<<<<<<<<<
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())
 */
  __Pyx_INCREF(__Pyx_OrderedDict);
  __pyx_t_2 = __Pyx_OrderedDict; __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 18, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 18, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_members, __pyx_t_1) < 0) __PYX_ERR(1, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":16
 * @cython.internal
 * cdef class __Pyx_EnumMeta(type):
 *     def __init__(cls, name, parents, dct):             # <<<<<<<<<<<<<<
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":19
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):             # <<<<<<<<<<<<<<
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_3__iter__(PyObject *__pyx_v_cls); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_3__iter__(PyObject *__pyx_v_cls) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_2__iter__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_cls));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_2__iter__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__iter__", 0);

  /* "EnumBase":20
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())             # <<<<<<<<<<<<<<
 *     def __getitem__(cls, name):
 *         return cls.__members__[name]
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_members); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_values); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 20, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 20, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "EnumBase":19
 *         type.__init__(cls, name, parents, dct)
 *         cls.__members__ = __Pyx_OrderedDict()
 *     def __iter__(cls):             # <<<<<<<<<<<<<<
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":21
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):             # <<<<<<<<<<<<<<
 *         return cls.__members__[name]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_5__getitem__(PyObject *__pyx_v_cls, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_5__getitem__(PyObject *__pyx_v_cls, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_4__getitem__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_cls), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_4__getitem__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_cls, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "EnumBase":22
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):
 *         return cls.__members__[name]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_members); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "EnumBase":21
 *     def __iter__(cls):
 *         return iter(cls.__members__.values())
 *     def __getitem__(cls, name):             # <<<<<<<<<<<<<<
 *         return cls.__members__[name]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = ()
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_6__reduce_cython__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_6__reduce_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self) {
  int __pyx_v_use_setstate;
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_v__dict = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __Pyx_INCREF(__pyx_empty_tuple);
  __pyx_v_state = __pyx_empty_tuple;

  /* "(tree fragment)":4
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":5
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":6
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":7
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":5
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":9
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 */
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":10
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":11
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyx_unpickle___Pyx_EnumMeta); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_222419149);
    __Pyx_GIVEREF(__pyx_int_222419149);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_222419149);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":10
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 *     else:
 */
  }

  /* "(tree fragment)":13
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, None), state
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyx_unpickle___Pyx_EnumMeta); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_222419149);
    __Pyx_GIVEREF(__pyx_int_222419149);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_222419149);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = ()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumMeta_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumMeta_8__setstate_cython__(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumMeta_8__setstate_cython__(struct __pyx_obj___Pyx_EnumMeta *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":15
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 15, __pyx_L1_error)
  __pyx_t_1 = __pyx_unpickle___Pyx_EnumMeta__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle___Pyx_EnumMeta, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle___Pyx_EnumMeta__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumMeta.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_1__new__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_14__Pyx_EnumBase_1__new__ = {"__new__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumBase_1__new__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_1__new__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__new__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_value,&__pyx_n_s_name,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cls)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__new__", 0, 2, 3, 1); __PYX_ERR(1, 28, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__new__") < 0)) __PYX_ERR(1, 28, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cls = values[0];
    __pyx_v_value = values[1];
    __pyx_v_name = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__new__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 28, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumBase___new__(__pyx_self, __pyx_v_cls, __pyx_v_value, __pyx_v_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_value, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("__new__", 0);

  /* "EnumBase":29
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 *         for v in cls:             # <<<<<<<<<<<<<<
 *             if v == value:
 *                 return v
 */
  if (likely(PyList_CheckExact(__pyx_v_cls)) || PyTuple_CheckExact(__pyx_v_cls)) {
    __pyx_t_1 = __pyx_v_cls; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_cls); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 29, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 29, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(1, 29, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 29, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(1, 29, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 29, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(1, 29, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "EnumBase":30
 *     def __new__(cls, value, name=None):
 *         for v in cls:
 *             if v == value:             # <<<<<<<<<<<<<<
 *                 return v
 *         if name is None:
 */
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_v, __pyx_v_value, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 30, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(1, 30, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {

      /* "EnumBase":31
 *         for v in cls:
 *             if v == value:
 *                 return v             # <<<<<<<<<<<<<<
 *         if name is None:
 *             raise ValueError("Unknown enum value: '%s'" % value)
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_v);
      __pyx_r = __pyx_v_v;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "EnumBase":30
 *     def __new__(cls, value, name=None):
 *         for v in cls:
 *             if v == value:             # <<<<<<<<<<<<<<
 *                 return v
 *         if name is None:
 */
    }

    /* "EnumBase":29
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 *         for v in cls:             # <<<<<<<<<<<<<<
 *             if v == value:
 *                 return v
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "EnumBase":32
 *             if v == value:
 *                 return v
 *         if name is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)
 */
  __pyx_t_5 = (__pyx_v_name == Py_None);
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (unlikely(__pyx_t_6)) {

    /* "EnumBase":33
 *                 return v
 *         if name is None:
 *             raise ValueError("Unknown enum value: '%s'" % value)             # <<<<<<<<<<<<<<
 *         res = int.__new__(cls, value)
 *         res.name = name
 */
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Unknown_enum_value_s, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(1, 33, __pyx_L1_error)

    /* "EnumBase":32
 *             if v == value:
 *                 return v
 *         if name is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)
 */
  }

  /* "EnumBase":34
 *         if name is None:
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)             # <<<<<<<<<<<<<<
 *         res.name = name
 *         setattr(cls, name, res)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)(&PyInt_Type)), __pyx_n_s_new); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_cls, __pyx_v_value};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_cls, __pyx_v_value};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cls);
    __Pyx_GIVEREF(__pyx_v_cls);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_cls);
    __Pyx_INCREF(__pyx_v_value);
    __Pyx_GIVEREF(__pyx_v_value);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_v_value);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "EnumBase":35
 *             raise ValueError("Unknown enum value: '%s'" % value)
 *         res = int.__new__(cls, value)
 *         res.name = name             # <<<<<<<<<<<<<<
 *         setattr(cls, name, res)
 *         cls.__members__[name] = res
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_res, __pyx_n_s_name, __pyx_v_name) < 0) __PYX_ERR(1, 35, __pyx_L1_error)

  /* "EnumBase":36
 *         res = int.__new__(cls, value)
 *         res.name = name
 *         setattr(cls, name, res)             # <<<<<<<<<<<<<<
 *         cls.__members__[name] = res
 *         return res
 */
  __pyx_t_10 = PyObject_SetAttr(__pyx_v_cls, __pyx_v_name, __pyx_v_res); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(1, 36, __pyx_L1_error)

  /* "EnumBase":37
 *         res.name = name
 *         setattr(cls, name, res)
 *         cls.__members__[name] = res             # <<<<<<<<<<<<<<
 *         return res
 *     def __repr__(self):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_members); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely(PyObject_SetItem(__pyx_t_4, __pyx_v_name, __pyx_v_res) < 0)) __PYX_ERR(1, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "EnumBase":38
 *         setattr(cls, name, res)
 *         cls.__members__[name] = res
 *         return res             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_14__Pyx_EnumBase_3__repr__ = {"__repr__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumBase_3__repr__, METH_O, 0};
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumBase_2__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "EnumBase":40
 *         return res
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)             # <<<<<<<<<<<<<<
 *     def __str__(self):
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_s_s_d, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_14__Pyx_EnumBase_5__str__ = {"__str__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumBase_5__str__, METH_O, 0};
static PyObject *__pyx_pw_8EnumBase_14__Pyx_EnumBase_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8EnumBase_14__Pyx_EnumBase_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase_14__Pyx_EnumBase_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "EnumBase":42
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 *         return "%s.%s" % (self.__class__.__name__, self.name)             # <<<<<<<<<<<<<<
 * 
 * if PY_VERSION_HEX >= 0x03040000:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_s_s, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("EnumBase.__Pyx_EnumBase.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError
 */

/* Python wrapper */
static PyObject *__pyx_pw_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta = {"__pyx_unpickle___Pyx_EnumMeta", (PyCFunction)__pyx_pw_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle___Pyx_EnumMeta (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle___Pyx_EnumMeta", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle___Pyx_EnumMeta", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle___Pyx_EnumMeta") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle___Pyx_EnumMeta", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("EnumBase.__pyx_unpickle___Pyx_EnumMeta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8EnumBase___pyx_unpickle___Pyx_EnumMeta(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8EnumBase___pyx_unpickle___Pyx_EnumMeta(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = NULL;
  PyObject *__pyx_v___pyx_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("__pyx_unpickle___Pyx_EnumMeta", 0);

  /* "(tree fragment)":2
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0xd41d8cd:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xd41d8cd) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":3
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":4
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 4, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xd4, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 4, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 4, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 4, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 4, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 4, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 4, __pyx_L1_error)

    /* "(tree fragment)":2
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0xd41d8cd:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":5
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype___Pyx_EnumMeta), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v___pyx_type};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v___pyx_type};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 5, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v___pyx_type);
      __Pyx_GIVEREF(__pyx_v___pyx_type);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v___pyx_type);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "(tree fragment)":7
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 7, __pyx_L1_error)
    __pyx_t_3 = __pyx_unpickle___Pyx_EnumMeta__set_state(((struct __pyx_obj___Pyx_EnumMeta *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = __Pyx_EnumMeta.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":8
 *     if __pyx_state is not None:
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("EnumBase.__pyx_unpickle___Pyx_EnumMeta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":9
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

static PyObject *__pyx_unpickle___Pyx_EnumMeta__set_state(struct __pyx_obj___Pyx_EnumMeta *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("__pyx_unpickle___Pyx_EnumMeta__set_state", 0);

  /* "(tree fragment)":10
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 10, __pyx_L1_error)
  }
  __pyx_t_2 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(1, 10, __pyx_L1_error)
  __pyx_t_3 = ((__pyx_t_2 > 0) != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 10, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "(tree fragment)":11
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 11, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 11, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 11, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 11, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 11, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 11, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "(tree fragment)":10
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  }

  /* "(tree fragment)":9
 *         __pyx_unpickle___Pyx_EnumMeta__set_state(<__Pyx_EnumMeta> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle___Pyx_EnumMeta__set_state(__Pyx_EnumMeta __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("EnumBase.__pyx_unpickle___Pyx_EnumMeta__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new___Pyx_EnumMeta(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = (&PyType_Type)->tp_new(t, a, k);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc___Pyx_EnumMeta(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  PyObject_GC_Track(o);
  (&PyType_Type)->tp_dealloc(o);
}

static int __pyx_tp_traverse___Pyx_EnumMeta(PyObject *o, visitproc v, void *a) {
  int e;
  if (!(&PyType_Type)->tp_traverse); else { e = (&PyType_Type)->tp_traverse(o,v,a); if (e) return e; }
  return 0;
}

static int __pyx_tp_clear___Pyx_EnumMeta(PyObject *o) {
  if (!(&PyType_Type)->tp_clear); else (&PyType_Type)->tp_clear(o);
  return 0;
}
static PyObject *__pyx_sq_item___Pyx_EnumMeta(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyMethodDef __pyx_methods___Pyx_EnumMeta[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumMeta_7__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_8EnumBase_14__Pyx_EnumMeta_9__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence___Pyx_EnumMeta = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item___Pyx_EnumMeta, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping___Pyx_EnumMeta = {
  0, /*mp_length*/
  __pyx_pw_8EnumBase_14__Pyx_EnumMeta_5__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __Pyx_EnumMeta = {
  PyVarObject_HEAD_INIT(0, 0)
  "veosinfo.__Pyx_EnumMeta", /*tp_name*/
  sizeof(struct __pyx_obj___Pyx_EnumMeta), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc___Pyx_EnumMeta, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence___Pyx_EnumMeta, /*tp_as_sequence*/
  &__pyx_tp_as_mapping___Pyx_EnumMeta, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse___Pyx_EnumMeta, /*tp_traverse*/
  __pyx_tp_clear___Pyx_EnumMeta, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_8EnumBase_14__Pyx_EnumMeta_3__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods___Pyx_EnumMeta, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_8EnumBase_14__Pyx_EnumMeta_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new___Pyx_EnumMeta, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {"check_pid", (PyCFunction)__pyx_pw_8veosinfo_5check_pid, METH_VARARGS|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_veosinfo(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_veosinfo},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "veosinfo",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s_BPFC, __pyx_k_BPFC, sizeof(__pyx_k_BPFC), 0, 0, 1, 1},
  {&__pyx_n_s_BREC, __pyx_k_BREC, sizeof(__pyx_k_BREC), 0, 0, 1, 1},
  {&__pyx_n_s_EX, __pyx_k_EX, sizeof(__pyx_k_EX), 0, 0, 1, 1},
  {&__pyx_n_s_EXS, __pyx_k_EXS, sizeof(__pyx_k_EXS), 0, 0, 1, 1},
  {&__pyx_n_s_EnumBase, __pyx_k_EnumBase, sizeof(__pyx_k_EnumBase), 0, 0, 1, 1},
  {&__pyx_n_s_EnumType, __pyx_k_EnumType, sizeof(__pyx_k_EnumType), 0, 0, 1, 1},
  {&__pyx_n_s_FMAEC, __pyx_k_FMAEC, sizeof(__pyx_k_FMAEC), 0, 0, 1, 1},
  {&__pyx_n_s_FMAXC, __pyx_k_FMAXC, sizeof(__pyx_k_FMAXC), 0, 0, 1, 1},
  {&__pyx_n_s_FPEC, __pyx_k_FPEC, sizeof(__pyx_k_FPEC), 0, 0, 1, 1},
  {&__pyx_n_s_IC, __pyx_k_IC, sizeof(__pyx_k_IC), 0, 0, 1, 1},
  {&__pyx_n_s_ICE, __pyx_k_ICE, sizeof(__pyx_k_ICE), 0, 0, 1, 1},
  {&__pyx_n_s_IPHCC, __pyx_k_IPHCC, sizeof(__pyx_k_IPHCC), 0, 0, 1, 1},
  {&__pyx_kp_s_Illegal_mode_in_PMMR_PMC_d_mode, __pyx_k_Illegal_mode_in_PMMR_PMC_d_mode, sizeof(__pyx_k_Illegal_mode_in_PMMR_PMC_d_mode), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xd4, __pyx_k_Incompatible_checksums_s_vs_0xd4, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xd4), 0, 0, 1, 0},
  {&__pyx_n_s_IntEnum, __pyx_k_IntEnum, sizeof(__pyx_k_IntEnum), 0, 0, 1, 1},
  {&__pyx_n_s_L1IAC, __pyx_k_L1IAC, sizeof(__pyx_k_L1IAC), 0, 0, 1, 1},
  {&__pyx_n_s_L1IMC, __pyx_k_L1IMC, sizeof(__pyx_k_L1IMC), 0, 0, 1, 1},
  {&__pyx_n_s_L1IMCC, __pyx_k_L1IMCC, sizeof(__pyx_k_L1IMCC), 0, 0, 1, 1},
  {&__pyx_n_s_L1MCC, __pyx_k_L1MCC, sizeof(__pyx_k_L1MCC), 0, 0, 1, 1},
  {&__pyx_n_s_L1OAC, __pyx_k_L1OAC, sizeof(__pyx_k_L1OAC), 0, 0, 1, 1},
  {&__pyx_n_s_L1OMC, __pyx_k_L1OMC, sizeof(__pyx_k_L1OMC), 0, 0, 1, 1},
  {&__pyx_n_s_L1OMCC, __pyx_k_L1OMCC, sizeof(__pyx_k_L1OMCC), 0, 0, 1, 1},
  {&__pyx_n_s_L2AC, __pyx_k_L2AC, sizeof(__pyx_k_L2AC), 0, 0, 1, 1},
  {&__pyx_n_s_L2MC, __pyx_k_L2MC, sizeof(__pyx_k_L2MC), 0, 0, 1, 1},
  {&__pyx_n_s_L2MCC, __pyx_k_L2MCC, sizeof(__pyx_k_L2MCC), 0, 0, 1, 1},
  {&__pyx_n_s_LTRC, __pyx_k_LTRC, sizeof(__pyx_k_LTRC), 0, 0, 1, 1},
  {&__pyx_n_s_OrderedDict, __pyx_k_OrderedDict, sizeof(__pyx_k_OrderedDict), 0, 0, 1, 1},
  {&__pyx_n_s_PCCC, __pyx_k_PCCC, sizeof(__pyx_k_PCCC), 0, 0, 1, 1},
  {&__pyx_n_s_PMC00, __pyx_k_PMC00, sizeof(__pyx_k_PMC00), 0, 0, 1, 1},
  {&__pyx_n_s_PMC01, __pyx_k_PMC01, sizeof(__pyx_k_PMC01), 0, 0, 1, 1},
  {&__pyx_n_s_PMC02, __pyx_k_PMC02, sizeof(__pyx_k_PMC02), 0, 0, 1, 1},
  {&__pyx_n_s_PMC03, __pyx_k_PMC03, sizeof(__pyx_k_PMC03), 0, 0, 1, 1},
  {&__pyx_n_s_PMC04, __pyx_k_PMC04, sizeof(__pyx_k_PMC04), 0, 0, 1, 1},
  {&__pyx_n_s_PMC05, __pyx_k_PMC05, sizeof(__pyx_k_PMC05), 0, 0, 1, 1},
  {&__pyx_n_s_PMC06, __pyx_k_PMC06, sizeof(__pyx_k_PMC06), 0, 0, 1, 1},
  {&__pyx_n_s_PMC07, __pyx_k_PMC07, sizeof(__pyx_k_PMC07), 0, 0, 1, 1},
  {&__pyx_n_s_PMC08, __pyx_k_PMC08, sizeof(__pyx_k_PMC08), 0, 0, 1, 1},
  {&__pyx_n_s_PMC09, __pyx_k_PMC09, sizeof(__pyx_k_PMC09), 0, 0, 1, 1},
  {&__pyx_n_s_PMC10, __pyx_k_PMC10, sizeof(__pyx_k_PMC10), 0, 0, 1, 1},
  {&__pyx_n_s_PMC11, __pyx_k_PMC11, sizeof(__pyx_k_PMC11), 0, 0, 1, 1},
  {&__pyx_n_s_PMC12, __pyx_k_PMC12, sizeof(__pyx_k_PMC12), 0, 0, 1, 1},
  {&__pyx_n_s_PMC13, __pyx_k_PMC13, sizeof(__pyx_k_PMC13), 0, 0, 1, 1},
  {&__pyx_n_s_PMC14, __pyx_k_PMC14, sizeof(__pyx_k_PMC14), 0, 0, 1, 1},
  {&__pyx_n_s_PMC15, __pyx_k_PMC15, sizeof(__pyx_k_PMC15), 0, 0, 1, 1},
  {&__pyx_n_s_PMCR00, __pyx_k_PMCR00, sizeof(__pyx_k_PMCR00), 0, 0, 1, 1},
  {&__pyx_n_s_PMCR01, __pyx_k_PMCR01, sizeof(__pyx_k_PMCR01), 0, 0, 1, 1},
  {&__pyx_n_s_PMCR02, __pyx_k_PMCR02, sizeof(__pyx_k_PMCR02), 0, 0, 1, 1},
  {&__pyx_n_s_PMCR03, __pyx_k_PMCR03, sizeof(__pyx_k_PMCR03), 0, 0, 1, 1},
  {&__pyx_n_s_PMCR04, __pyx_k_PMCR04, sizeof(__pyx_k_PMCR04), 0, 0, 1, 1},
  {&__pyx_n_s_PMC_NAME, __pyx_k_PMC_NAME, sizeof(__pyx_k_PMC_NAME), 0, 0, 1, 1},
  {&__pyx_n_s_PMMR, __pyx_k_PMMR, sizeof(__pyx_k_PMMR), 0, 0, 1, 1},
  {&__pyx_n_s_PSW, __pyx_k_PSW, sizeof(__pyx_k_PSW), 0, 0, 1, 1},
  {&__pyx_n_s_PTCC, __pyx_k_PTCC, sizeof(__pyx_k_PTCC), 0, 0, 1, 1},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase, __pyx_k_Pyx_EnumBase, sizeof(__pyx_k_Pyx_EnumBase), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase___new, __pyx_k_Pyx_EnumBase___new, sizeof(__pyx_k_Pyx_EnumBase___new), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase___repr, __pyx_k_Pyx_EnumBase___repr, sizeof(__pyx_k_Pyx_EnumBase___repr), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_EnumBase___str, __pyx_k_Pyx_EnumBase___str, sizeof(__pyx_k_Pyx_EnumBase___str), 0, 0, 1, 1},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_n_s_SAR, __pyx_k_SAR, sizeof(__pyx_k_SAR), 0, 0, 1, 1},
  {&__pyx_n_s_SARCC, __pyx_k_SARCC, sizeof(__pyx_k_SARCC), 0, 0, 1, 1},
  {&__pyx_n_s_SR00, __pyx_k_SR00, sizeof(__pyx_k_SR00), 0, 0, 1, 1},
  {&__pyx_n_s_SR01, __pyx_k_SR01, sizeof(__pyx_k_SR01), 0, 0, 1, 1},
  {&__pyx_n_s_SR02, __pyx_k_SR02, sizeof(__pyx_k_SR02), 0, 0, 1, 1},
  {&__pyx_n_s_SR03, __pyx_k_SR03, sizeof(__pyx_k_SR03), 0, 0, 1, 1},
  {&__pyx_n_s_SR04, __pyx_k_SR04, sizeof(__pyx_k_SR04), 0, 0, 1, 1},
  {&__pyx_n_s_SR05, __pyx_k_SR05, sizeof(__pyx_k_SR05), 0, 0, 1, 1},
  {&__pyx_n_s_SR06, __pyx_k_SR06, sizeof(__pyx_k_SR06), 0, 0, 1, 1},
  {&__pyx_n_s_SR07, __pyx_k_SR07, sizeof(__pyx_k_SR07), 0, 0, 1, 1},
  {&__pyx_n_s_SR08, __pyx_k_SR08, sizeof(__pyx_k_SR08), 0, 0, 1, 1},
  {&__pyx_n_s_SR09, __pyx_k_SR09, sizeof(__pyx_k_SR09), 0, 0, 1, 1},
  {&__pyx_n_s_SR10, __pyx_k_SR10, sizeof(__pyx_k_SR10), 0, 0, 1, 1},
  {&__pyx_n_s_SR11, __pyx_k_SR11, sizeof(__pyx_k_SR11), 0, 0, 1, 1},
  {&__pyx_n_s_SR12, __pyx_k_SR12, sizeof(__pyx_k_SR12), 0, 0, 1, 1},
  {&__pyx_n_s_SR13, __pyx_k_SR13, sizeof(__pyx_k_SR13), 0, 0, 1, 1},
  {&__pyx_n_s_SR14, __pyx_k_SR14, sizeof(__pyx_k_SR14), 0, 0, 1, 1},
  {&__pyx_n_s_SR15, __pyx_k_SR15, sizeof(__pyx_k_SR15), 0, 0, 1, 1},
  {&__pyx_n_s_SR16, __pyx_k_SR16, sizeof(__pyx_k_SR16), 0, 0, 1, 1},
  {&__pyx_n_s_SR17, __pyx_k_SR17, sizeof(__pyx_k_SR17), 0, 0, 1, 1},
  {&__pyx_n_s_SR18, __pyx_k_SR18, sizeof(__pyx_k_SR18), 0, 0, 1, 1},
  {&__pyx_n_s_SR19, __pyx_k_SR19, sizeof(__pyx_k_SR19), 0, 0, 1, 1},
  {&__pyx_n_s_SR20, __pyx_k_SR20, sizeof(__pyx_k_SR20), 0, 0, 1, 1},
  {&__pyx_n_s_SR21, __pyx_k_SR21, sizeof(__pyx_k_SR21), 0, 0, 1, 1},
  {&__pyx_n_s_SR22, __pyx_k_SR22, sizeof(__pyx_k_SR22), 0, 0, 1, 1},
  {&__pyx_n_s_SR23, __pyx_k_SR23, sizeof(__pyx_k_SR23), 0, 0, 1, 1},
  {&__pyx_n_s_SR24, __pyx_k_SR24, sizeof(__pyx_k_SR24), 0, 0, 1, 1},
  {&__pyx_n_s_SR25, __pyx_k_SR25, sizeof(__pyx_k_SR25), 0, 0, 1, 1},
  {&__pyx_n_s_SR26, __pyx_k_SR26, sizeof(__pyx_k_SR26), 0, 0, 1, 1},
  {&__pyx_n_s_SR27, __pyx_k_SR27, sizeof(__pyx_k_SR27), 0, 0, 1, 1},
  {&__pyx_n_s_SR28, __pyx_k_SR28, sizeof(__pyx_k_SR28), 0, 0, 1, 1},
  {&__pyx_n_s_SR29, __pyx_k_SR29, sizeof(__pyx_k_SR29), 0, 0, 1, 1},
  {&__pyx_n_s_SR30, __pyx_k_SR30, sizeof(__pyx_k_SR30), 0, 0, 1, 1},
  {&__pyx_n_s_SR31, __pyx_k_SR31, sizeof(__pyx_k_SR31), 0, 0, 1, 1},
  {&__pyx_n_s_SR32, __pyx_k_SR32, sizeof(__pyx_k_SR32), 0, 0, 1, 1},
  {&__pyx_n_s_SR33, __pyx_k_SR33, sizeof(__pyx_k_SR33), 0, 0, 1, 1},
  {&__pyx_n_s_SR34, __pyx_k_SR34, sizeof(__pyx_k_SR34), 0, 0, 1, 1},
  {&__pyx_n_s_SR35, __pyx_k_SR35, sizeof(__pyx_k_SR35), 0, 0, 1, 1},
  {&__pyx_n_s_SR36, __pyx_k_SR36, sizeof(__pyx_k_SR36), 0, 0, 1, 1},
  {&__pyx_n_s_SR37, __pyx_k_SR37, sizeof(__pyx_k_SR37), 0, 0, 1, 1},
  {&__pyx_n_s_SR38, __pyx_k_SR38, sizeof(__pyx_k_SR38), 0, 0, 1, 1},
  {&__pyx_n_s_SR39, __pyx_k_SR39, sizeof(__pyx_k_SR39), 0, 0, 1, 1},
  {&__pyx_n_s_SR40, __pyx_k_SR40, sizeof(__pyx_k_SR40), 0, 0, 1, 1},
  {&__pyx_n_s_SR41, __pyx_k_SR41, sizeof(__pyx_k_SR41), 0, 0, 1, 1},
  {&__pyx_n_s_SR42, __pyx_k_SR42, sizeof(__pyx_k_SR42), 0, 0, 1, 1},
  {&__pyx_n_s_SR43, __pyx_k_SR43, sizeof(__pyx_k_SR43), 0, 0, 1, 1},
  {&__pyx_n_s_SR44, __pyx_k_SR44, sizeof(__pyx_k_SR44), 0, 0, 1, 1},
  {&__pyx_n_s_SR45, __pyx_k_SR45, sizeof(__pyx_k_SR45), 0, 0, 1, 1},
  {&__pyx_n_s_SR46, __pyx_k_SR46, sizeof(__pyx_k_SR46), 0, 0, 1, 1},
  {&__pyx_n_s_SR47, __pyx_k_SR47, sizeof(__pyx_k_SR47), 0, 0, 1, 1},
  {&__pyx_n_s_SR48, __pyx_k_SR48, sizeof(__pyx_k_SR48), 0, 0, 1, 1},
  {&__pyx_n_s_SR49, __pyx_k_SR49, sizeof(__pyx_k_SR49), 0, 0, 1, 1},
  {&__pyx_n_s_SR50, __pyx_k_SR50, sizeof(__pyx_k_SR50), 0, 0, 1, 1},
  {&__pyx_n_s_SR51, __pyx_k_SR51, sizeof(__pyx_k_SR51), 0, 0, 1, 1},
  {&__pyx_n_s_SR52, __pyx_k_SR52, sizeof(__pyx_k_SR52), 0, 0, 1, 1},
  {&__pyx_n_s_SR53, __pyx_k_SR53, sizeof(__pyx_k_SR53), 0, 0, 1, 1},
  {&__pyx_n_s_SR54, __pyx_k_SR54, sizeof(__pyx_k_SR54), 0, 0, 1, 1},
  {&__pyx_n_s_SR55, __pyx_k_SR55, sizeof(__pyx_k_SR55), 0, 0, 1, 1},
  {&__pyx_n_s_SR56, __pyx_k_SR56, sizeof(__pyx_k_SR56), 0, 0, 1, 1},
  {&__pyx_n_s_SR57, __pyx_k_SR57, sizeof(__pyx_k_SR57), 0, 0, 1, 1},
  {&__pyx_n_s_SR58, __pyx_k_SR58, sizeof(__pyx_k_SR58), 0, 0, 1, 1},
  {&__pyx_n_s_SR59, __pyx_k_SR59, sizeof(__pyx_k_SR59), 0, 0, 1, 1},
  {&__pyx_n_s_SR60, __pyx_k_SR60, sizeof(__pyx_k_SR60), 0, 0, 1, 1},
  {&__pyx_n_s_SR61, __pyx_k_SR61, sizeof(__pyx_k_SR61), 0, 0, 1, 1},
  {&__pyx_n_s_SR62, __pyx_k_SR62, sizeof(__pyx_k_SR62), 0, 0, 1, 1},
  {&__pyx_n_s_SR63, __pyx_k_SR63, sizeof(__pyx_k_SR63), 0, 0, 1, 1},
  {&__pyx_n_s_STRC, __pyx_k_STRC, sizeof(__pyx_k_STRC), 0, 0, 1, 1},
  {&__pyx_n_s_T, __pyx_k_T, sizeof(__pyx_k_T), 0, 0, 1, 1},
  {&__pyx_n_s_TTCC, __pyx_k_TTCC, sizeof(__pyx_k_TTCC), 0, 0, 1, 1},
  {&__pyx_n_s_UEC, __pyx_k_UEC, sizeof(__pyx_k_UEC), 0, 0, 1, 1},
  {&__pyx_n_s_USRCC, __pyx_k_USRCC, sizeof(__pyx_k_USRCC), 0, 0, 1, 1},
  {&__pyx_n_s_UXC, __pyx_k_UXC, sizeof(__pyx_k_UXC), 0, 0, 1, 1},
  {&__pyx_kp_s_Unknown_enum_value_s, __pyx_k_Unknown_enum_value_s, sizeof(__pyx_k_Unknown_enum_value_s), 0, 0, 1, 0},
  {&__pyx_n_s_VAREC, __pyx_k_VAREC, sizeof(__pyx_k_VAREC), 0, 0, 1, 1},
  {&__pyx_n_s_VE, __pyx_k_VE, sizeof(__pyx_k_VE), 0, 0, 1, 1},
  {&__pyx_n_s_VE2, __pyx_k_VE2, sizeof(__pyx_k_VE2), 0, 0, 1, 1},
  {&__pyx_n_s_VECC, __pyx_k_VECC, sizeof(__pyx_k_VECC), 0, 0, 1, 1},
  {&__pyx_n_s_VEREGS, __pyx_k_VEREGS, sizeof(__pyx_k_VEREGS), 0, 0, 1, 1},
  {&__pyx_n_s_VERegIds, __pyx_k_VERegIds, sizeof(__pyx_k_VERegIds), 0, 0, 1, 1},
  {&__pyx_n_s_VIXR, __pyx_k_VIXR, sizeof(__pyx_k_VIXR), 0, 0, 1, 1},
  {&__pyx_n_s_VL, __pyx_k_VL, sizeof(__pyx_k_VL), 0, 0, 1, 1},
  {&__pyx_n_s_VLCME, __pyx_k_VLCME, sizeof(__pyx_k_VLCME), 0, 0, 1, 1},
  {&__pyx_n_s_VLCME2, __pyx_k_VLCME2, sizeof(__pyx_k_VLCME2), 0, 0, 1, 1},
  {&__pyx_n_s_VLCMX, __pyx_k_VLCMX, sizeof(__pyx_k_VLCMX), 0, 0, 1, 1},
  {&__pyx_n_s_VLCMX2, __pyx_k_VLCMX2, sizeof(__pyx_k_VLCMX2), 0, 0, 1, 1},
  {&__pyx_n_s_VLDCC, __pyx_k_VLDCC, sizeof(__pyx_k_VLDCC), 0, 0, 1, 1},
  {&__pyx_n_s_VLDEC, __pyx_k_VLDEC, sizeof(__pyx_k_VLDEC), 0, 0, 1, 1},
  {&__pyx_n_s_VLEC, __pyx_k_VLEC, sizeof(__pyx_k_VLEC), 0, 0, 1, 1},
  {&__pyx_n_s_VLXC, __pyx_k_VLXC, sizeof(__pyx_k_VLXC), 0, 0, 1, 1},
  {&__pyx_n_s_VX, __pyx_k_VX, sizeof(__pyx_k_VX), 0, 0, 1, 1},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_kp_s_Wrong_node_ID_d_Only_d_node_onli, __pyx_k_Wrong_node_ID_d_Only_d_node_onli, sizeof(__pyx_k_Wrong_node_ID_d_Only_d_node_onli), 0, 0, 1, 0},
  {&__pyx_kp_s__21, __pyx_k__21, sizeof(__pyx_k__21), 0, 0, 1, 0},
  {&__pyx_n_s_acct, __pyx_k_acct, sizeof(__pyx_k_acct), 0, 0, 1, 1},
  {&__pyx_n_s_ai, __pyx_k_ai, sizeof(__pyx_k_ai), 0, 0, 1, 1},
  {&__pyx_n_s_arch_info, __pyx_k_arch_info, sizeof(__pyx_k_arch_info), 0, 0, 1, 1},
  {&__pyx_n_s_av_1, __pyx_k_av_1, sizeof(__pyx_k_av_1), 0, 0, 1, 1},
  {&__pyx_n_s_av_15, __pyx_k_av_15, sizeof(__pyx_k_av_15), 0, 0, 1, 1},
  {&__pyx_n_s_av_5, __pyx_k_av_5, sizeof(__pyx_k_av_5), 0, 0, 1, 1},
  {&__pyx_n_s_blkio, __pyx_k_blkio, sizeof(__pyx_k_blkio), 0, 0, 1, 1},
  {&__pyx_n_s_blocked, __pyx_k_blocked, sizeof(__pyx_k_blocked), 0, 0, 1, 1},
  {&__pyx_n_s_bogomips, __pyx_k_bogomips, sizeof(__pyx_k_bogomips), 0, 0, 1, 1},
  {&__pyx_n_s_btime, __pyx_k_btime, sizeof(__pyx_k_btime), 0, 0, 1, 1},
  {&__pyx_n_s_cache_name, __pyx_k_cache_name, sizeof(__pyx_k_cache_name), 0, 0, 1, 1},
  {&__pyx_n_s_cache_size, __pyx_k_cache_size, sizeof(__pyx_k_cache_size), 0, 0, 1, 1},
  {&__pyx_n_s_cguest_time, __pyx_k_cguest_time, sizeof(__pyx_k_cguest_time), 0, 0, 1, 1},
  {&__pyx_n_s_ci, __pyx_k_ci, sizeof(__pyx_k_ci), 0, 0, 1, 1},
  {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
  {&__pyx_n_s_cmaj_flt, __pyx_k_cmaj_flt, sizeof(__pyx_k_cmaj_flt), 0, 0, 1, 1},
  {&__pyx_n_s_cmd, __pyx_k_cmd, sizeof(__pyx_k_cmd), 0, 0, 1, 1},
  {&__pyx_n_s_cmin_flt, __pyx_k_cmin_flt, sizeof(__pyx_k_cmin_flt), 0, 0, 1, 1},
  {&__pyx_n_s_cnswap, __pyx_k_cnswap, sizeof(__pyx_k_cnswap), 0, 0, 1, 1},
  {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
  {&__pyx_n_s_core_info, __pyx_k_core_info, sizeof(__pyx_k_core_info), 0, 0, 1, 1},
  {&__pyx_n_s_core_per_socket, __pyx_k_core_per_socket, sizeof(__pyx_k_core_per_socket), 0, 0, 1, 1},
  {&__pyx_n_s_cores, __pyx_k_cores, sizeof(__pyx_k_cores), 0, 0, 1, 1},
  {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
  {&__pyx_n_s_cpu_info, __pyx_k_cpu_info, sizeof(__pyx_k_cpu_info), 0, 0, 1, 1},
  {&__pyx_n_s_cpu_volt, __pyx_k_cpu_volt, sizeof(__pyx_k_cpu_volt), 0, 0, 1, 1},
  {&__pyx_n_s_cpufreq_info, __pyx_k_cpufreq_info, sizeof(__pyx_k_cpufreq_info), 0, 0, 1, 1},
  {&__pyx_n_s_create_process, __pyx_k_create_process, sizeof(__pyx_k_create_process), 0, 0, 1, 1},
  {&__pyx_n_s_cstime, __pyx_k_cstime, sizeof(__pyx_k_cstime), 0, 0, 1, 1},
  {&__pyx_n_s_ctxt, __pyx_k_ctxt, sizeof(__pyx_k_ctxt), 0, 0, 1, 1},
  {&__pyx_n_s_cutime, __pyx_k_cutime, sizeof(__pyx_k_cutime), 0, 0, 1, 1},
  {&__pyx_n_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 1},
  {&__pyx_n_s_dct, __pyx_k_dct, sizeof(__pyx_k_dct), 0, 0, 1, 1},
  {&__pyx_n_s_device_name, __pyx_k_device_name, sizeof(__pyx_k_device_name), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_s_endcode, __pyx_k_endcode, sizeof(__pyx_k_endcode), 0, 0, 1, 1},
  {&__pyx_n_s_enter, __pyx_k_enter, sizeof(__pyx_k_enter), 0, 0, 1, 1},
  {&__pyx_n_s_enum, __pyx_k_enum, sizeof(__pyx_k_enum), 0, 0, 1, 1},
  {&__pyx_n_s_exit, __pyx_k_exit, sizeof(__pyx_k_exit), 0, 0, 1, 1},
  {&__pyx_n_s_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 0, 1, 1},
  {&__pyx_n_s_family, __pyx_k_family, sizeof(__pyx_k_family), 0, 0, 1, 1},
  {&__pyx_n_s_fan_max, __pyx_k_fan_max, sizeof(__pyx_k_fan_max), 0, 0, 1, 1},
  {&__pyx_n_s_fan_min, __pyx_k_fan_min, sizeof(__pyx_k_fan_min), 0, 0, 1, 1},
  {&__pyx_n_s_fan_speed, __pyx_k_fan_speed, sizeof(__pyx_k_fan_speed), 0, 0, 1, 1},
  {&__pyx_n_s_filename, __pyx_k_filename, sizeof(__pyx_k_filename), 0, 0, 1, 1},
  {&__pyx_n_s_flag, __pyx_k_flag, sizeof(__pyx_k_flag), 0, 0, 1, 1},
  {&__pyx_n_s_flags, __pyx_k_flags, sizeof(__pyx_k_flags), 0, 0, 1, 1},
  {&__pyx_n_s_freq, __pyx_k_freq, sizeof(__pyx_k_freq), 0, 0, 1, 1},
  {&__pyx_n_s_get_regvals, __pyx_k_get_regvals, sizeof(__pyx_k_get_regvals), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_guest, __pyx_k_guest, sizeof(__pyx_k_guest), 0, 0, 1, 1},
  {&__pyx_n_s_guest_nice, __pyx_k_guest_nice, sizeof(__pyx_k_guest_nice), 0, 0, 1, 1},
  {&__pyx_n_s_guest_time, __pyx_k_guest_time, sizeof(__pyx_k_guest_time), 0, 0, 1, 1},
  {&__pyx_n_s_hardirq, __pyx_k_hardirq, sizeof(__pyx_k_hardirq), 0, 0, 1, 1},
  {&__pyx_n_s_hugepage_free, __pyx_k_hugepage_free, sizeof(__pyx_k_hugepage_free), 0, 0, 1, 1},
  {&__pyx_n_s_hugepage_total, __pyx_k_hugepage_total, sizeof(__pyx_k_hugepage_total), 0, 0, 1, 1},
  {&__pyx_n_s_hw_platform, __pyx_k_hw_platform, sizeof(__pyx_k_hw_platform), 0, 0, 1, 1},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_s_idle, __pyx_k_idle, sizeof(__pyx_k_idle), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_intr, __pyx_k_intr, sizeof(__pyx_k_intr), 0, 0, 1, 1},
  {&__pyx_n_s_iowait, __pyx_k_iowait, sizeof(__pyx_k_iowait), 0, 0, 1, 1},
  {&__pyx_n_s_itrealvalue, __pyx_k_itrealvalue, sizeof(__pyx_k_itrealvalue), 0, 0, 1, 1},
  {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
  {&__pyx_n_s_kb_active, __pyx_k_kb_active, sizeof(__pyx_k_kb_active), 0, 0, 1, 1},
  {&__pyx_n_s_kb_committed_as, __pyx_k_kb_committed_as, sizeof(__pyx_k_kb_committed_as), 0, 0, 1, 1},
  {&__pyx_n_s_kb_dirty, __pyx_k_kb_dirty, sizeof(__pyx_k_kb_dirty), 0, 0, 1, 1},
  {&__pyx_n_s_kb_high_free, __pyx_k_kb_high_free, sizeof(__pyx_k_kb_high_free), 0, 0, 1, 1},
  {&__pyx_n_s_kb_high_total, __pyx_k_kb_high_total, sizeof(__pyx_k_kb_high_total), 0, 0, 1, 1},
  {&__pyx_n_s_kb_hugepage_used, __pyx_k_kb_hugepage_used, sizeof(__pyx_k_kb_hugepage_used), 0, 0, 1, 1},
  {&__pyx_n_s_kb_inactive, __pyx_k_kb_inactive, sizeof(__pyx_k_kb_inactive), 0, 0, 1, 1},
  {&__pyx_n_s_kb_low_free, __pyx_k_kb_low_free, sizeof(__pyx_k_kb_low_free), 0, 0, 1, 1},
  {&__pyx_n_s_kb_low_total, __pyx_k_kb_low_total, sizeof(__pyx_k_kb_low_total), 0, 0, 1, 1},
  {&__pyx_n_s_kb_main_buffers, __pyx_k_kb_main_buffers, sizeof(__pyx_k_kb_main_buffers), 0, 0, 1, 1},
  {&__pyx_n_s_kb_main_cached, __pyx_k_kb_main_cached, sizeof(__pyx_k_kb_main_cached), 0, 0, 1, 1},
  {&__pyx_n_s_kb_main_free, __pyx_k_kb_main_free, sizeof(__pyx_k_kb_main_free), 0, 0, 1, 1},
  {&__pyx_n_s_kb_main_shared, __pyx_k_kb_main_shared, sizeof(__pyx_k_kb_main_shared), 0, 0, 1, 1},
  {&__pyx_n_s_kb_main_total, __pyx_k_kb_main_total, sizeof(__pyx_k_kb_main_total), 0, 0, 1, 1},
  {&__pyx_n_s_kb_main_used, __pyx_k_kb_main_used, sizeof(__pyx_k_kb_main_used), 0, 0, 1, 1},
  {&__pyx_n_s_kb_swap_cached, __pyx_k_kb_swap_cached, sizeof(__pyx_k_kb_swap_cached), 0, 0, 1, 1},
  {&__pyx_n_s_kb_swap_free, __pyx_k_kb_swap_free, sizeof(__pyx_k_kb_swap_free), 0, 0, 1, 1},
  {&__pyx_n_s_kb_swap_total, __pyx_k_kb_swap_total, sizeof(__pyx_k_kb_swap_total), 0, 0, 1, 1},
  {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
  {&__pyx_n_s_ksteip, __pyx_k_ksteip, sizeof(__pyx_k_ksteip), 0, 0, 1, 1},
  {&__pyx_n_s_kstesp, __pyx_k_kstesp, sizeof(__pyx_k_kstesp), 0, 0, 1, 1},
  {&__pyx_n_s_l, __pyx_k_l, sizeof(__pyx_k_l), 0, 0, 1, 1},
  {&__pyx_n_s_la, __pyx_k_la, sizeof(__pyx_k_la), 0, 0, 1, 1},
  {&__pyx_n_s_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 0, 1, 1},
  {&__pyx_n_s_linesep, __pyx_k_linesep, sizeof(__pyx_k_linesep), 0, 0, 1, 1},
  {&__pyx_n_s_loadavg_info, __pyx_k_loadavg_info, sizeof(__pyx_k_loadavg_info), 0, 0, 1, 1},
  {&__pyx_n_s_machine, __pyx_k_machine, sizeof(__pyx_k_machine), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_maj_delta, __pyx_k_maj_delta, sizeof(__pyx_k_maj_delta), 0, 0, 1, 1},
  {&__pyx_n_s_maj_flt, __pyx_k_maj_flt, sizeof(__pyx_k_maj_flt), 0, 0, 1, 1},
  {&__pyx_n_s_mem_info, __pyx_k_mem_info, sizeof(__pyx_k_mem_info), 0, 0, 1, 1},
  {&__pyx_n_s_members, __pyx_k_members, sizeof(__pyx_k_members), 0, 0, 1, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_s_mhz, __pyx_k_mhz, sizeof(__pyx_k_mhz), 0, 0, 1, 1},
  {&__pyx_n_s_mi, __pyx_k_mi, sizeof(__pyx_k_mi), 0, 0, 1, 1},
  {&__pyx_n_s_min_delta, __pyx_k_min_delta, sizeof(__pyx_k_min_delta), 0, 0, 1, 1},
  {&__pyx_n_s_min_flt, __pyx_k_min_flt, sizeof(__pyx_k_min_flt), 0, 0, 1, 1},
  {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
  {&__pyx_n_s_model, __pyx_k_model, sizeof(__pyx_k_model), 0, 0, 1, 1},
  {&__pyx_n_s_modelname, __pyx_k_modelname, sizeof(__pyx_k_modelname), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_ni, __pyx_k_ni, sizeof(__pyx_k_ni), 0, 0, 1, 1},
  {&__pyx_n_s_nice, __pyx_k_nice, sizeof(__pyx_k_nice), 0, 0, 1, 1},
  {&__pyx_n_s_nnodes, __pyx_k_nnodes, sizeof(__pyx_k_nnodes), 0, 0, 1, 1},
  {&__pyx_n_s_node_info, __pyx_k_node_info, sizeof(__pyx_k_node_info), 0, 0, 1, 1},
  {&__pyx_n_s_nodeid, __pyx_k_nodeid, sizeof(__pyx_k_nodeid), 0, 0, 1, 1},
  {&__pyx_n_s_nswap, __pyx_k_nswap, sizeof(__pyx_k_nswap), 0, 0, 1, 1},
  {&__pyx_n_s_op_mode, __pyx_k_op_mode, sizeof(__pyx_k_op_mode), 0, 0, 1, 1},
  {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
  {&__pyx_n_s_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 0, 1, 1},
  {&__pyx_n_s_os_path, __pyx_k_os_path, sizeof(__pyx_k_os_path), 0, 0, 1, 1},
  {&__pyx_n_s_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
  {&__pyx_n_s_parents, __pyx_k_parents, sizeof(__pyx_k_parents), 0, 0, 1, 1},
  {&__pyx_n_s_path, __pyx_k_path, sizeof(__pyx_k_path), 0, 0, 1, 1},
  {&__pyx_n_s_pgfault, __pyx_k_pgfault, sizeof(__pyx_k_pgfault), 0, 0, 1, 1},
  {&__pyx_n_s_pgfree, __pyx_k_pgfree, sizeof(__pyx_k_pgfree), 0, 0, 1, 1},
  {&__pyx_n_s_pgmajfault, __pyx_k_pgmajfault, sizeof(__pyx_k_pgmajfault), 0, 0, 1, 1},
  {&__pyx_n_s_pgscan_direct, __pyx_k_pgscan_direct, sizeof(__pyx_k_pgscan_direct), 0, 0, 1, 1},
  {&__pyx_n_s_pgscan_kswapd, __pyx_k_pgscan_kswapd, sizeof(__pyx_k_pgscan_kswapd), 0, 0, 1, 1},
  {&__pyx_n_s_pgsteal, __pyx_k_pgsteal, sizeof(__pyx_k_pgsteal), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_pid, __pyx_k_pid, sizeof(__pyx_k_pid), 0, 0, 1, 1},
  {&__pyx_n_s_pids, __pyx_k_pids, sizeof(__pyx_k_pids), 0, 0, 1, 1},
  {&__pyx_n_s_pidstat_info, __pyx_k_pidstat_info, sizeof(__pyx_k_pidstat_info), 0, 0, 1, 1},
  {&__pyx_n_s_pmmr, __pyx_k_pmmr, sizeof(__pyx_k_pmmr), 0, 0, 1, 1},
  {&__pyx_n_s_policy, __pyx_k_policy, sizeof(__pyx_k_policy), 0, 0, 1, 1},
  {&__pyx_n_s_ppid, __pyx_k_ppid, sizeof(__pyx_k_ppid), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_priority, __pyx_k_priority, sizeof(__pyx_k_priority), 0, 0, 1, 1},
  {&__pyx_n_s_processes, __pyx_k_processes, sizeof(__pyx_k_processes), 0, 0, 1, 1},
  {&__pyx_n_s_processor, __pyx_k_processor, sizeof(__pyx_k_processor), 0, 0, 1, 1},
  {&__pyx_n_s_pswpin, __pyx_k_pswpin, sizeof(__pyx_k_pswpin), 0, 0, 1, 1},
  {&__pyx_n_s_pswpout, __pyx_k_pswpout, sizeof(__pyx_k_pswpout), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle___Pyx_EnumMeta, __pyx_k_pyx_unpickle___Pyx_EnumMeta, sizeof(__pyx_k_pyx_unpickle___Pyx_EnumMeta), 0, 0, 1, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_s_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_read_fan, __pyx_k_read_fan, sizeof(__pyx_k_read_fan), 0, 0, 1, 1},
  {&__pyx_n_s_read_temp, __pyx_k_read_temp, sizeof(__pyx_k_read_temp), 0, 0, 1, 1},
  {&__pyx_n_s_read_voltage, __pyx_k_read_voltage, sizeof(__pyx_k_read_voltage), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_regid, __pyx_k_regid, sizeof(__pyx_k_regid), 0, 0, 1, 1},
  {&__pyx_n_s_regname, __pyx_k_regname, sizeof(__pyx_k_regname), 0, 0, 1, 1},
  {&__pyx_n_s_regval, __pyx_k_regval, sizeof(__pyx_k_regval), 0, 0, 1, 1},
  {&__pyx_n_s_repr, __pyx_k_repr, sizeof(__pyx_k_repr), 0, 0, 1, 1},
  {&__pyx_n_s_res, __pyx_k_res, sizeof(__pyx_k_res), 0, 0, 1, 1},
  {&__pyx_n_s_rid, __pyx_k_rid, sizeof(__pyx_k_rid), 0, 0, 1, 1},
  {&__pyx_n_s_rss, __pyx_k_rss, sizeof(__pyx_k_rss), 0, 0, 1, 1},
  {&__pyx_n_s_rsslim, __pyx_k_rsslim, sizeof(__pyx_k_rsslim), 0, 0, 1, 1},
  {&__pyx_n_s_rstrip, __pyx_k_rstrip, sizeof(__pyx_k_rstrip), 0, 0, 1, 1},
  {&__pyx_n_s_rt_priority, __pyx_k_rt_priority, sizeof(__pyx_k_rt_priority), 0, 0, 1, 1},
  {&__pyx_n_s_runnable, __pyx_k_runnable, sizeof(__pyx_k_runnable), 0, 0, 1, 1},
  {&__pyx_n_s_running, __pyx_k_running, sizeof(__pyx_k_running), 0, 0, 1, 1},
  {&__pyx_n_s_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 1},
  {&__pyx_kp_s_s_s, __pyx_k_s_s, sizeof(__pyx_k_s_s), 0, 0, 1, 0},
  {&__pyx_kp_s_s_s_d, __pyx_k_s_s_d, sizeof(__pyx_k_s_s_d), 0, 0, 1, 0},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_si, __pyx_k_si, sizeof(__pyx_k_si), 0, 0, 1, 1},
  {&__pyx_n_s_socket, __pyx_k_socket, sizeof(__pyx_k_socket), 0, 0, 1, 1},
  {&__pyx_n_s_softirq, __pyx_k_softirq, sizeof(__pyx_k_softirq), 0, 0, 1, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_n_s_start_time, __pyx_k_start_time, sizeof(__pyx_k_start_time), 0, 0, 1, 1},
  {&__pyx_n_s_startcode, __pyx_k_startcode, sizeof(__pyx_k_startcode), 0, 0, 1, 1},
  {&__pyx_n_s_startstack, __pyx_k_startstack, sizeof(__pyx_k_startstack), 0, 0, 1, 1},
  {&__pyx_n_s_stat_info, __pyx_k_stat_info, sizeof(__pyx_k_stat_info), 0, 0, 1, 1},
  {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
  {&__pyx_n_s_status, __pyx_k_status, sizeof(__pyx_k_status), 0, 0, 1, 1},
  {&__pyx_n_s_steal, __pyx_k_steal, sizeof(__pyx_k_steal), 0, 0, 1, 1},
  {&__pyx_n_s_stepping, __pyx_k_stepping, sizeof(__pyx_k_stepping), 0, 0, 1, 1},
  {&__pyx_n_s_stime, __pyx_k_stime, sizeof(__pyx_k_stime), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_sysfs_path, __pyx_k_sysfs_path, sizeof(__pyx_k_sysfs_path), 0, 0, 1, 1},
  {&__pyx_n_s_t, __pyx_k_t, sizeof(__pyx_k_t), 0, 0, 1, 1},
  {&__pyx_n_s_task_id_all, __pyx_k_task_id_all, sizeof(__pyx_k_task_id_all), 0, 0, 1, 1},
  {&__pyx_n_s_temp_max, __pyx_k_temp_max, sizeof(__pyx_k_temp_max), 0, 0, 1, 1},
  {&__pyx_n_s_temp_min, __pyx_k_temp_min, sizeof(__pyx_k_temp_min), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_thread_per_core, __pyx_k_thread_per_core, sizeof(__pyx_k_thread_per_core), 0, 0, 1, 1},
  {&__pyx_n_s_time, __pyx_k_time, sizeof(__pyx_k_time), 0, 0, 1, 1},
  {&__pyx_n_s_total_node_count, __pyx_k_total_node_count, sizeof(__pyx_k_total_node_count), 0, 0, 1, 1},
  {&__pyx_n_s_total_proc, __pyx_k_total_proc, sizeof(__pyx_k_total_proc), 0, 0, 1, 1},
  {&__pyx_n_s_up, __pyx_k_up, sizeof(__pyx_k_up), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_uptime_info, __pyx_k_uptime_info, sizeof(__pyx_k_uptime_info), 0, 0, 1, 1},
  {&__pyx_n_s_user, __pyx_k_user, sizeof(__pyx_k_user), 0, 0, 1, 1},
  {&__pyx_n_s_utime, __pyx_k_utime, sizeof(__pyx_k_utime), 0, 0, 1, 1},
  {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
  {&__pyx_kp_s_ve_acct_failed, __pyx_k_ve_acct_failed, sizeof(__pyx_k_ve_acct_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_arch_info_failed, __pyx_k_ve_arch_info_failed, sizeof(__pyx_k_ve_arch_info_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_check_pid_d_failed_d, __pyx_k_ve_check_pid_d_failed_d, sizeof(__pyx_k_ve_check_pid_d_failed_d), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_core_info_failed, __pyx_k_ve_core_info_failed, sizeof(__pyx_k_ve_core_info_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_cpu_info_failed, __pyx_k_ve_cpu_info_failed, sizeof(__pyx_k_ve_cpu_info_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_cpufreq_info_failed, __pyx_k_ve_cpufreq_info_failed, sizeof(__pyx_k_ve_cpufreq_info_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_create_process_failed, __pyx_k_ve_create_process_failed, sizeof(__pyx_k_ve_create_process_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_get_regvals_failed, __pyx_k_ve_get_regvals_failed, sizeof(__pyx_k_ve_get_regvals_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_loadavg_info_failed, __pyx_k_ve_loadavg_info_failed, sizeof(__pyx_k_ve_loadavg_info_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_mem_info_failed, __pyx_k_ve_mem_info_failed, sizeof(__pyx_k_ve_mem_info_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_node_info_failed, __pyx_k_ve_node_info_failed, sizeof(__pyx_k_ve_node_info_failed), 0, 0, 1, 0},
  {&__pyx_n_s_ve_pid_perf, __pyx_k_ve_pid_perf, sizeof(__pyx_k_ve_pid_perf), 0, 0, 1, 1},
  {&__pyx_n_s_ve_pids, __pyx_k_ve_pids, sizeof(__pyx_k_ve_pids), 0, 0, 1, 1},
  {&__pyx_kp_s_ve_pidstat_info_failed, __pyx_k_ve_pidstat_info_failed, sizeof(__pyx_k_ve_pidstat_info_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_read_fan_failed, __pyx_k_ve_read_fan_failed, sizeof(__pyx_k_ve_read_fan_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_read_temp_failed, __pyx_k_ve_read_temp_failed, sizeof(__pyx_k_ve_read_temp_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_read_voltage_failed, __pyx_k_ve_read_voltage_failed, sizeof(__pyx_k_ve_read_voltage_failed), 0, 0, 1, 0},
  {&__pyx_n_s_ve_regid, __pyx_k_ve_regid, sizeof(__pyx_k_ve_regid), 0, 0, 1, 1},
  {&__pyx_n_s_ve_regval, __pyx_k_ve_regval, sizeof(__pyx_k_ve_regval), 0, 0, 1, 1},
  {&__pyx_kp_s_ve_stat_info_failed, __pyx_k_ve_stat_info_failed, sizeof(__pyx_k_ve_stat_info_failed), 0, 0, 1, 0},
  {&__pyx_n_s_ve_sysfs_path, __pyx_k_ve_sysfs_path, sizeof(__pyx_k_ve_sysfs_path), 0, 0, 1, 1},
  {&__pyx_kp_s_ve_sysfs_path_info_failed, __pyx_k_ve_sysfs_path_info_failed, sizeof(__pyx_k_ve_sysfs_path_info_failed), 0, 0, 1, 0},
  {&__pyx_n_s_ve_temp, __pyx_k_ve_temp, sizeof(__pyx_k_ve_temp), 0, 0, 1, 1},
  {&__pyx_kp_s_ve_uptime_info_failed, __pyx_k_ve_uptime_info_failed, sizeof(__pyx_k_ve_uptime_info_failed), 0, 0, 1, 0},
  {&__pyx_kp_s_ve_vmstat_info_failed, __pyx_k_ve_vmstat_info_failed, sizeof(__pyx_k_ve_vmstat_info_failed), 0, 0, 1, 0},
  {&__pyx_n_s_vendor, __pyx_k_vendor, sizeof(__pyx_k_vendor), 0, 0, 1, 1},
  {&__pyx_n_s_veosinfo, __pyx_k_veosinfo, sizeof(__pyx_k_veosinfo), 0, 0, 1, 1},
  {&__pyx_kp_s_veosinfo_pyx, __pyx_k_veosinfo_pyx, sizeof(__pyx_k_veosinfo_pyx), 0, 0, 1, 0},
  {&__pyx_n_s_vmstat_info, __pyx_k_vmstat_info, sizeof(__pyx_k_vmstat_info), 0, 0, 1, 1},
  {&__pyx_n_s_vni, __pyx_k_vni, sizeof(__pyx_k_vni), 0, 0, 1, 1},
  {&__pyx_n_s_volt_max, __pyx_k_volt_max, sizeof(__pyx_k_volt_max), 0, 0, 1, 1},
  {&__pyx_n_s_volt_min, __pyx_k_volt_min, sizeof(__pyx_k_volt_min), 0, 0, 1, 1},
  {&__pyx_n_s_vsize, __pyx_k_vsize, sizeof(__pyx_k_vsize), 0, 0, 1, 1},
  {&__pyx_n_s_wchan, __pyx_k_wchan, sizeof(__pyx_k_wchan), 0, 0, 1, 1},
  {&__pyx_n_s_whole, __pyx_k_whole, sizeof(__pyx_k_whole), 0, 0, 1, 1},
  {&__pyx_n_s_xrange, __pyx_k_xrange, sizeof(__pyx_k_xrange), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(0, 313, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 402, __pyx_L1_error)
  #if PY_MAJOR_VERSION >= 3
  __pyx_builtin_xrange = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_xrange) __PYX_ERR(0, 455, __pyx_L1_error)
  #else
  __pyx_builtin_xrange = __Pyx_GetBuiltinName(__pyx_n_s_xrange); if (!__pyx_builtin_xrange) __PYX_ERR(0, 455, __pyx_L1_error)
  #endif
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_n_s_open); if (!__pyx_builtin_open) __PYX_ERR(0, 475, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(1, 116, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "veosinfo.pyx":313
 * def acct(int nodeid, char *filename):
 *     if ve_acct(nodeid, filename):
 *         raise RuntimeError("ve_acct failed")             # <<<<<<<<<<<<<<
 * 
 * def arch_info(int nodeid):
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_s_ve_acct_failed); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "veosinfo.pyx":318
 *     cdef ve_archinfo ai
 *     if ve_arch_info(nodeid, &ai):
 *         raise RuntimeError("ve_arch_info failed")             # <<<<<<<<<<<<<<
 *     return ai
 * 
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_s_ve_arch_info_failed); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(0, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "veosinfo.pyx":334
 *     cdef int cores
 *     if ve_core_info(nodeid, &cores):
 *         raise RuntimeError("ve_core_info failed")             # <<<<<<<<<<<<<<
 *     return cores
 * 
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_s_ve_core_info_failed); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "veosinfo.pyx":340
 *     cdef ve_cpuinfo ci
 *     if ve_cpu_info(nodeid, &ci):
 *         raise RuntimeError("ve_cpu_info failed")             # <<<<<<<<<<<<<<
 *     return ci
 * 
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_s_ve_cpu_info_failed); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "veosinfo.pyx":346
 *     cdef unsigned long freq
 *     if ve_cpufreq_info(nodeid, &freq):
 *         raise RuntimeError("ve_cpufreq_info failed")             # <<<<<<<<<<<<<<
 *     return freq
 * 
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_s_ve_cpufreq_info_failed); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "veosinfo.pyx":351
 * def create_process(int nodeid, int pid, int flag):
 *     if ve_create_process(nodeid, pid, flag):
 *         raise RuntimeError("ve_create_process failed")             # <<<<<<<<<<<<<<
 *     return True
 * 
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_s_ve_create_process_failed); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "veosinfo.pyx":357
 *     cdef ve_loadavg la
 *     if ve_loadavg_info(nodeid, &la):
 *         raise RuntimeError("ve_loadavg_info failed")             # <<<<<<<<<<<<<<
 *     return la
 * 
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_s_ve_loadavg_info_failed); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "veosinfo.pyx":363
 *     cdef ve_meminfo mi
 *     if ve_mem_info(nodeid, &mi):
 *         raise RuntimeError("ve_mem_info failed")             # <<<<<<<<<<<<<<
 *     return mi
 * 
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_s_ve_mem_info_failed); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "veosinfo.pyx":369
 *     cdef ve_nodeinfo vni
 *     if ve_node_info(&vni):
 *         raise RuntimeError("ve_node_info failed")             # <<<<<<<<<<<<<<
 *     cdef object d = vni
 *     for key in ("nodeid", "status", "cores"):
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_s_ve_node_info_failed); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "veosinfo.pyx":371
 *         raise RuntimeError("ve_node_info failed")
 *     cdef object d = vni
 *     for key in ("nodeid", "status", "cores"):             # <<<<<<<<<<<<<<
 *         d[key] = d[key][:d["total_node_count"]]
 *     return d
 */
  __pyx_tuple__10 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_status, __pyx_n_s_cores); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "veosinfo.pyx":378
 *     cdef ve_pidstat p
 *     if ve_pidstat_info(nodeid, pid, &p):
 *         raise RuntimeError("ve_pidstat_info failed")             # <<<<<<<<<<<<<<
 *     return p
 * 
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_s_ve_pidstat_info_failed); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "veosinfo.pyx":384
 *     cdef ve_pwr_fan f
 *     if ve_read_fan(nodeid, &f):
 *         raise RuntimeError("ve_read_fan failed")             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_s_ve_read_fan_failed); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "veosinfo.pyx":390
 *     cdef ve_pwr_temp t
 *     if ve_read_temp(nodeid, &t):
 *         raise RuntimeError("ve_read_temp failed")             # <<<<<<<<<<<<<<
 *     return t
 * 
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_kp_s_ve_read_temp_failed); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "veosinfo.pyx":396
 *     cdef ve_pwr_voltage v
 *     if ve_read_voltage(nodeid, &v):
 *         raise RuntimeError("ve_read_voltage failed")             # <<<<<<<<<<<<<<
 *     return v
 * 
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_s_ve_read_voltage_failed); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "veosinfo.pyx":407
 *     cdef ve_statinfo si
 *     if ve_stat_info(nodeid, &si):
 *         raise RuntimeError("ve_stat_info failed")             # <<<<<<<<<<<<<<
 *     cdef object d = si
 *     for key in ("user", "nice", "idle", "iowait", "sys", "hardirq",
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_s_ve_stat_info_failed); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "veosinfo.pyx":409
 *         raise RuntimeError("ve_stat_info failed")
 *     cdef object d = si
 *     for key in ("user", "nice", "idle", "iowait", "sys", "hardirq",             # <<<<<<<<<<<<<<
 *                 "softirq", "steal", "guest", "guest_nice"):
 *         d[key] = d[key][:cores]
 */
  __pyx_tuple__16 = PyTuple_Pack(10, __pyx_n_s_user, __pyx_n_s_nice, __pyx_n_s_idle, __pyx_n_s_iowait, __pyx_n_s_sys, __pyx_n_s_hardirq, __pyx_n_s_softirq, __pyx_n_s_steal, __pyx_n_s_guest, __pyx_n_s_guest_nice); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "veosinfo.pyx":417
 *     cdef double up
 *     if ve_uptime_info(nodeid, &up):
 *         raise RuntimeError("ve_uptime_info failed")             # <<<<<<<<<<<<<<
 *     return up
 * 
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_s_ve_uptime_info_failed); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "veosinfo.pyx":423
 *     cdef ve_vmstat s
 *     if ve_vmstat_info(nodeid, &s):
 *         raise RuntimeError("ve_vmstat_info failed")             # <<<<<<<<<<<<<<
 *     return s
 * 
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_kp_s_ve_vmstat_info_failed); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "veosinfo.pyx":453
 *         i += 1
 *     if ve_get_regvals(nodeid, pid, len(regid), ve_regid, &ve_regval[0]):
 *         raise RuntimeError("ve_get_regvals failed")             # <<<<<<<<<<<<<<
 *     cdef list regval = list()
 *     for i in xrange(len(regid)):
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_kp_s_ve_get_regvals_failed); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "veosinfo.pyx":466
 *     memset(sysfs_path, 0, PATH_MAX)
 *     if ve_sysfs_path_info(nodeid, &sysfs_path[0]):
 *         raise RuntimeError("ve_sysfs_path_info failed")             # <<<<<<<<<<<<<<
 *     return sysfs_path
 * 
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_kp_s_ve_sysfs_path_info_failed); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "veosinfo.pyx":478
 *         for line in f:
 *             line = line.rstrip(os.linesep)
 *             for l in line.split(" "):             # <<<<<<<<<<<<<<
 *                 try:
 *                     pids.append(int(l))
 */
  __pyx_tuple__22 = PyTuple_Pack(1, __pyx_kp_s__21); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "veosinfo.pyx":475
 *     sysfs_path = ve_sysfs_path(nodeid)
 *     pids = list()
 *     with open(os.path.join(sysfs_path, "task_id_all"), "r") as f:             # <<<<<<<<<<<<<<
 *         for line in f:
 *             line = line.rstrip(os.linesep)
 */
  __pyx_tuple__23 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "veosinfo.pyx":311
 * 
 * 
 * def acct(int nodeid, char *filename):             # <<<<<<<<<<<<<<
 *     if ve_acct(nodeid, filename):
 *         raise RuntimeError("ve_acct failed")
 */
  __pyx_tuple__24 = PyTuple_Pack(2, __pyx_n_s_nodeid, __pyx_n_s_filename); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);
  __pyx_codeobj__25 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_acct, 311, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__25)) __PYX_ERR(0, 311, __pyx_L1_error)

  /* "veosinfo.pyx":315
 *         raise RuntimeError("ve_acct failed")
 * 
 * def arch_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_archinfo ai
 *     if ve_arch_info(nodeid, &ai):
 */
  __pyx_tuple__26 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_ai); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);
  __pyx_codeobj__27 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__26, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_arch_info, 315, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__27)) __PYX_ERR(0, 315, __pyx_L1_error)

  /* "veosinfo.pyx":331
 *     return res
 * 
 * def core_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef int cores
 *     if ve_core_info(nodeid, &cores):
 */
  __pyx_tuple__28 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_cores); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);
  __pyx_codeobj__29 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__28, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_core_info, 331, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__29)) __PYX_ERR(0, 331, __pyx_L1_error)

  /* "veosinfo.pyx":337
 *     return cores
 * 
 * def cpu_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_cpuinfo ci
 *     if ve_cpu_info(nodeid, &ci):
 */
  __pyx_tuple__30 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_ci); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);
  __pyx_codeobj__31 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__30, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_cpu_info, 337, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__31)) __PYX_ERR(0, 337, __pyx_L1_error)

  /* "veosinfo.pyx":343
 *     return ci
 * 
 * def cpufreq_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef unsigned long freq
 *     if ve_cpufreq_info(nodeid, &freq):
 */
  __pyx_tuple__32 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_freq); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);
  __pyx_codeobj__33 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__32, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_cpufreq_info, 343, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__33)) __PYX_ERR(0, 343, __pyx_L1_error)

  /* "veosinfo.pyx":349
 *     return freq
 * 
 * def create_process(int nodeid, int pid, int flag):             # <<<<<<<<<<<<<<
 *     if ve_create_process(nodeid, pid, flag):
 *         raise RuntimeError("ve_create_process failed")
 */
  __pyx_tuple__34 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_pid, __pyx_n_s_flag); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);
  __pyx_codeobj__35 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__34, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_create_process, 349, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__35)) __PYX_ERR(0, 349, __pyx_L1_error)

  /* "veosinfo.pyx":354
 *     return True
 * 
 * def loadavg_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_loadavg la
 *     if ve_loadavg_info(nodeid, &la):
 */
  __pyx_tuple__36 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_la); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);
  __pyx_codeobj__37 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__36, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_loadavg_info, 354, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__37)) __PYX_ERR(0, 354, __pyx_L1_error)

  /* "veosinfo.pyx":360
 *     return la
 * 
 * def mem_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_meminfo mi
 *     if ve_mem_info(nodeid, &mi):
 */
  __pyx_tuple__38 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_mi); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);
  __pyx_codeobj__39 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__38, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_mem_info, 360, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__39)) __PYX_ERR(0, 360, __pyx_L1_error)

  /* "veosinfo.pyx":366
 *     return mi
 * 
 * def node_info():             # <<<<<<<<<<<<<<
 *     cdef ve_nodeinfo vni
 *     if ve_node_info(&vni):
 */
  __pyx_tuple__40 = PyTuple_Pack(3, __pyx_n_s_vni, __pyx_n_s_d, __pyx_n_s_key); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);
  __pyx_codeobj__41 = (PyObject*)__Pyx_PyCode_New(0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__40, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_node_info, 366, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__41)) __PYX_ERR(0, 366, __pyx_L1_error)

  /* "veosinfo.pyx":375
 *     return d
 * 
 * def pidstat_info(int nodeid, pid_t pid):             # <<<<<<<<<<<<<<
 *     cdef ve_pidstat p
 *     if ve_pidstat_info(nodeid, pid, &p):
 */
  __pyx_tuple__42 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_pid, __pyx_n_s_p); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);
  __pyx_codeobj__43 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__42, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_pidstat_info, 375, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__43)) __PYX_ERR(0, 375, __pyx_L1_error)

  /* "veosinfo.pyx":381
 *     return p
 * 
 * def read_fan(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_fan f
 *     if ve_read_fan(nodeid, &f):
 */
  __pyx_tuple__44 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_f); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);
  __pyx_codeobj__45 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__44, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_read_fan, 381, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__45)) __PYX_ERR(0, 381, __pyx_L1_error)

  /* "veosinfo.pyx":387
 *     return f
 * 
 * def read_temp(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_temp t
 *     if ve_read_temp(nodeid, &t):
 */
  __pyx_tuple__46 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_t); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);
  __pyx_codeobj__47 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__46, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_read_temp, 387, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__47)) __PYX_ERR(0, 387, __pyx_L1_error)

  /* "veosinfo.pyx":393
 *     return t
 * 
 * def read_voltage(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_voltage v
 *     if ve_read_voltage(nodeid, &v):
 */
  __pyx_tuple__48 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_v); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);
  __pyx_codeobj__49 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__48, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_read_voltage, 393, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__49)) __PYX_ERR(0, 393, __pyx_L1_error)

  /* "veosinfo.pyx":399
 *     return v
 * 
 * def stat_info(int nodeid):             # <<<<<<<<<<<<<<
 *     ni = node_info()
 *     if nodeid >= ni["total_node_count"]:
 */
  __pyx_tuple__50 = PyTuple_Pack(7, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_ni, __pyx_n_s_cores, __pyx_n_s_si, __pyx_n_s_d, __pyx_n_s_key); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);
  __pyx_codeobj__51 = (PyObject*)__Pyx_PyCode_New(1, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__50, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_stat_info, 399, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__51)) __PYX_ERR(0, 399, __pyx_L1_error)

  /* "veosinfo.pyx":414
 *     return d
 * 
 * def uptime_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef double up
 *     if ve_uptime_info(nodeid, &up):
 */
  __pyx_tuple__52 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_up); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);
  __pyx_codeobj__53 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__52, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_uptime_info, 414, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__53)) __PYX_ERR(0, 414, __pyx_L1_error)

  /* "veosinfo.pyx":420
 *     return up
 * 
 * def vmstat_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_vmstat s
 *     if ve_vmstat_info(nodeid, &s):
 */
  __pyx_tuple__54 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_s); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);
  __pyx_codeobj__55 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__54, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_vmstat_info, 420, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__55)) __PYX_ERR(0, 420, __pyx_L1_error)

  /* "veosinfo.pyx":445
 *     SR56, SR57, SR58, SR59, SR60, SR61, SR62, SR63
 * 
 * def get_regvals(int nodeid, pid_t pid, list regid):             # <<<<<<<<<<<<<<
 *     cdef uint64_t ve_regval[VE_MAX_REGVALS]
 *     cdef int ve_regid[VE_MAX_REGVALS], i = 0
 */
  __pyx_tuple__56 = PyTuple_Pack(8, __pyx_n_s_nodeid, __pyx_n_s_pid, __pyx_n_s_regid, __pyx_n_s_ve_regval, __pyx_n_s_ve_regid, __pyx_n_s_i, __pyx_n_s_rid, __pyx_n_s_regval); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);
  __pyx_codeobj__57 = (PyObject*)__Pyx_PyCode_New(3, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__56, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_get_regvals, 445, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__57)) __PYX_ERR(0, 445, __pyx_L1_error)

  /* "veosinfo.pyx":462
 * # Return VE sysfs path corresponding to a certain nodeid
 * #
 * def ve_sysfs_path(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef char sysfs_path[PATH_MAX]
 *     memset(sysfs_path, 0, PATH_MAX)
 */
  __pyx_tuple__58 = PyTuple_Pack(3, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_sysfs_path); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);
  __pyx_codeobj__59 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__58, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_ve_sysfs_path, 462, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__59)) __PYX_ERR(0, 462, __pyx_L1_error)

  /* "veosinfo.pyx":472
 * # List of task IDs running on a certain VE node.
 * #
 * def ve_pids(int nodeid):             # <<<<<<<<<<<<<<
 *     sysfs_path = ve_sysfs_path(nodeid)
 *     pids = list()
 */
  __pyx_tuple__60 = PyTuple_Pack(7, __pyx_n_s_nodeid, __pyx_n_s_nodeid, __pyx_n_s_sysfs_path, __pyx_n_s_pids, __pyx_n_s_f, __pyx_n_s_line, __pyx_n_s_l); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);
  __pyx_codeobj__61 = (PyObject*)__Pyx_PyCode_New(1, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__60, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_ve_pids, 472, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__61)) __PYX_ERR(0, 472, __pyx_L1_error)

  /* "veosinfo.pyx":508
 * 
 * 
 * def ve_pid_perf(int nodeid, int pid):             # <<<<<<<<<<<<<<
 *     """
 *     Create a dict with performance counter values for
 */
  __pyx_tuple__62 = PyTuple_Pack(8, __pyx_n_s_nodeid, __pyx_n_s_pid, __pyx_n_s_res, __pyx_n_s_regval, __pyx_n_s_pmmr, __pyx_n_s_i, __pyx_n_s_mode, __pyx_n_s_regname); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(2, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__62, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_veosinfo_pyx, __pyx_n_s_ve_pid_perf, 508, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) __PYX_ERR(0, 508, __pyx_L1_error)

  /* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */
  __pyx_tuple__64 = PyTuple_Pack(5, __pyx_n_s_cls, __pyx_n_s_value, __pyx_n_s_name, __pyx_n_s_v, __pyx_n_s_res); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);
  __pyx_codeobj__65 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__64, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_new, 28, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__65)) __PYX_ERR(1, 28, __pyx_L1_error)
  __pyx_tuple__66 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__66)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */
  __pyx_tuple__67 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(1, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);
  __pyx_codeobj__68 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__67, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_repr, 39, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__68)) __PYX_ERR(1, 39, __pyx_L1_error)

  /* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */
  __pyx_tuple__69 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(1, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);
  __pyx_codeobj__70 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__69, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_str, 41, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__70)) __PYX_ERR(1, 41, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError
 */
  __pyx_tuple__71 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);
  __pyx_codeobj__72 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__71, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle___Pyx_EnumMeta, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__72)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_60 = PyInt_FromLong(60); if (unlikely(!__pyx_int_60)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_222419149 = PyInt_FromLong(222419149L); if (unlikely(!__pyx_int_222419149)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_modinit_global_init_code(void); /*proto*/
static int __Pyx_modinit_variable_export_code(void); /*proto*/
static int __Pyx_modinit_function_export_code(void); /*proto*/
static int __Pyx_modinit_type_init_code(void); /*proto*/
static int __Pyx_modinit_type_import_code(void); /*proto*/
static int __Pyx_modinit_variable_import_code(void); /*proto*/
static int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_OrderedDict = Py_None; Py_INCREF(Py_None);
  __Pyx_EnumBase = Py_None; Py_INCREF(Py_None);
  __Pyx_globals = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_EnumMeta.tp_base = (&PyType_Type);
  if (PyType_Ready(&__Pyx_EnumMeta) < 0) __PYX_ERR(1, 15, __pyx_L1_error)
  __Pyx_EnumMeta.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__Pyx_EnumMeta.tp_dictoffset && __Pyx_EnumMeta.tp_getattro == PyObject_GenericGetAttr)) {
    __Pyx_EnumMeta.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_setup_reduce((PyObject*)&__Pyx_EnumMeta) < 0) __PYX_ERR(1, 15, __pyx_L1_error)
  __pyx_ptype___Pyx_EnumMeta = &__Pyx_EnumMeta;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION < 3
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC void
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#else
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__)
    #define CYTHON_SMALL_CODE __attribute__((optimize("Os")))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initveosinfo(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initveosinfo(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_veosinfo(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_veosinfo(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        result = PyDict_SetItemString(moddict, to_name, value);
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__") < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static int __pyx_pymod_exec_veosinfo(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_t_20;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  PyObject *__pyx_t_31 = NULL;
  PyObject *__pyx_t_32 = NULL;
  PyObject *__pyx_t_33 = NULL;
  PyObject *__pyx_t_34 = NULL;
  PyObject *__pyx_t_35 = NULL;
  PyObject *__pyx_t_36 = NULL;
  PyObject *__pyx_t_37 = NULL;
  PyObject *__pyx_t_38 = NULL;
  PyObject *__pyx_t_39 = NULL;
  PyObject *__pyx_t_40 = NULL;
  PyObject *__pyx_t_41 = NULL;
  PyObject *__pyx_t_42 = NULL;
  PyObject *__pyx_t_43 = NULL;
  PyObject *__pyx_t_44 = NULL;
  PyObject *__pyx_t_45 = NULL;
  PyObject *__pyx_t_46 = NULL;
  PyObject *__pyx_t_47 = NULL;
  PyObject *__pyx_t_48 = NULL;
  PyObject *__pyx_t_49 = NULL;
  PyObject *__pyx_t_50 = NULL;
  PyObject *__pyx_t_51 = NULL;
  PyObject *__pyx_t_52 = NULL;
  PyObject *__pyx_t_53 = NULL;
  PyObject *__pyx_t_54 = NULL;
  PyObject *__pyx_t_55 = NULL;
  PyObject *__pyx_t_56 = NULL;
  PyObject *__pyx_t_57 = NULL;
  PyObject *__pyx_t_58 = NULL;
  PyObject *__pyx_t_59 = NULL;
  PyObject *__pyx_t_60 = NULL;
  PyObject *__pyx_t_61 = NULL;
  PyObject *__pyx_t_62 = NULL;
  PyObject *__pyx_t_63 = NULL;
  PyObject *__pyx_t_64 = NULL;
  PyObject *__pyx_t_65 = NULL;
  PyObject *__pyx_t_66 = NULL;
  PyObject *__pyx_t_67 = NULL;
  PyObject *__pyx_t_68 = NULL;
  PyObject *__pyx_t_69 = NULL;
  PyObject *__pyx_t_70 = NULL;
  PyObject *__pyx_t_71 = NULL;
  PyObject *__pyx_t_72 = NULL;
  PyObject *__pyx_t_73 = NULL;
  PyObject *__pyx_t_74 = NULL;
  PyObject *__pyx_t_75 = NULL;
  PyObject *__pyx_t_76 = NULL;
  PyObject *__pyx_t_77 = NULL;
  PyObject *__pyx_t_78 = NULL;
  PyObject *__pyx_t_79 = NULL;
  PyObject *__pyx_t_80 = NULL;
  PyObject *__pyx_t_81 = NULL;
  PyObject *__pyx_t_82 = NULL;
  PyObject *__pyx_t_83 = NULL;
  PyObject *__pyx_t_84 = NULL;
  PyObject *__pyx_t_85 = NULL;
  PyObject *__pyx_t_86 = NULL;
  PyObject *__pyx_t_87 = NULL;
  PyObject *__pyx_t_88 = NULL;
  PyObject *__pyx_t_89 = NULL;
  PyObject *__pyx_t_90 = NULL;
  PyObject *__pyx_t_91 = NULL;
  PyObject *__pyx_t_92 = NULL;
  PyObject *__pyx_t_93 = NULL;
  PyObject *__pyx_t_94 = NULL;
  PyObject *__pyx_t_95 = NULL;
  PyObject *__pyx_t_96 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m && __pyx_m == __pyx_pyinit_module) return 0;
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_veosinfo(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("veosinfo", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_veosinfo) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "veosinfo")) {
      if (unlikely(PyDict_SetItemString(modules, "veosinfo", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() != 0)) goto __pyx_L1_error;
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "veosinfo.pyx":36
 * from libc.stdint cimport uint64_t
 * from libc.string cimport memset
 * import os             # <<<<<<<<<<<<<<
 * import os.path
 * import time
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_os, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_1) < 0) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":37
 * from libc.string cimport memset
 * import os
 * import os.path             # <<<<<<<<<<<<<<
 * import time
 * 
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_os_path, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_1) < 0) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":38
 * import os
 * import os.path
 * import time             # <<<<<<<<<<<<<<
 * 
 * ctypedef int pid_t
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_time, 0, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_time, __pyx_t_1) < 0) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":311
 * 
 * 
 * def acct(int nodeid, char *filename):             # <<<<<<<<<<<<<<
 *     if ve_acct(nodeid, filename):
 *         raise RuntimeError("ve_acct failed")
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_1acct, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_acct, __pyx_t_1) < 0) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":315
 *         raise RuntimeError("ve_acct failed")
 * 
 * def arch_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_archinfo ai
 *     if ve_arch_info(nodeid, &ai):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_3arch_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_arch_info, __pyx_t_1) < 0) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":331
 *     return res
 * 
 * def core_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef int cores
 *     if ve_core_info(nodeid, &cores):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_7core_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_core_info, __pyx_t_1) < 0) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":337
 *     return cores
 * 
 * def cpu_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_cpuinfo ci
 *     if ve_cpu_info(nodeid, &ci):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_9cpu_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cpu_info, __pyx_t_1) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":343
 *     return ci
 * 
 * def cpufreq_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef unsigned long freq
 *     if ve_cpufreq_info(nodeid, &freq):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_11cpufreq_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cpufreq_info, __pyx_t_1) < 0) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":349
 *     return freq
 * 
 * def create_process(int nodeid, int pid, int flag):             # <<<<<<<<<<<<<<
 *     if ve_create_process(nodeid, pid, flag):
 *         raise RuntimeError("ve_create_process failed")
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_13create_process, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_create_process, __pyx_t_1) < 0) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":354
 *     return True
 * 
 * def loadavg_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_loadavg la
 *     if ve_loadavg_info(nodeid, &la):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_15loadavg_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_loadavg_info, __pyx_t_1) < 0) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":360
 *     return la
 * 
 * def mem_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_meminfo mi
 *     if ve_mem_info(nodeid, &mi):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_17mem_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mem_info, __pyx_t_1) < 0) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":366
 *     return mi
 * 
 * def node_info():             # <<<<<<<<<<<<<<
 *     cdef ve_nodeinfo vni
 *     if ve_node_info(&vni):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_19node_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_node_info, __pyx_t_1) < 0) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":375
 *     return d
 * 
 * def pidstat_info(int nodeid, pid_t pid):             # <<<<<<<<<<<<<<
 *     cdef ve_pidstat p
 *     if ve_pidstat_info(nodeid, pid, &p):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_21pidstat_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pidstat_info, __pyx_t_1) < 0) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":381
 *     return p
 * 
 * def read_fan(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_fan f
 *     if ve_read_fan(nodeid, &f):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_23read_fan, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_read_fan, __pyx_t_1) < 0) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":387
 *     return f
 * 
 * def read_temp(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_temp t
 *     if ve_read_temp(nodeid, &t):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_25read_temp, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_read_temp, __pyx_t_1) < 0) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":393
 *     return t
 * 
 * def read_voltage(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_pwr_voltage v
 *     if ve_read_voltage(nodeid, &v):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_27read_voltage, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_read_voltage, __pyx_t_1) < 0) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":399
 *     return v
 * 
 * def stat_info(int nodeid):             # <<<<<<<<<<<<<<
 *     ni = node_info()
 *     if nodeid >= ni["total_node_count"]:
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_29stat_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stat_info, __pyx_t_1) < 0) __PYX_ERR(0, 399, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":414
 *     return d
 * 
 * def uptime_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef double up
 *     if ve_uptime_info(nodeid, &up):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_31uptime_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_uptime_info, __pyx_t_1) < 0) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":420
 *     return up
 * 
 * def vmstat_info(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef ve_vmstat s
 *     if ve_vmstat_info(nodeid, &s):
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_33vmstat_info, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_vmstat_info, __pyx_t_1) < 0) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":445
 *     SR56, SR57, SR58, SR59, SR60, SR61, SR62, SR63
 * 
 * def get_regvals(int nodeid, pid_t pid, list regid):             # <<<<<<<<<<<<<<
 *     cdef uint64_t ve_regval[VE_MAX_REGVALS]
 *     cdef int ve_regid[VE_MAX_REGVALS], i = 0
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_35get_regvals, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_regvals, __pyx_t_1) < 0) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":462
 * # Return VE sysfs path corresponding to a certain nodeid
 * #
 * def ve_sysfs_path(int nodeid):             # <<<<<<<<<<<<<<
 *     cdef char sysfs_path[PATH_MAX]
 *     memset(sysfs_path, 0, PATH_MAX)
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_37ve_sysfs_path, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ve_sysfs_path, __pyx_t_1) < 0) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":472
 * # List of task IDs running on a certain VE node.
 * #
 * def ve_pids(int nodeid):             # <<<<<<<<<<<<<<
 *     sysfs_path = ve_sysfs_path(nodeid)
 *     pids = list()
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_39ve_pids, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ve_pids, __pyx_t_1) < 0) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "veosinfo.pyx":486
 * 
 * 
 * VEREGS = [USRCC, PMMR, PMC00, PMC01, PMC02, PMC03, PMC04, PMC05, PMC06,             # <<<<<<<<<<<<<<
 *           PMC07, PMC08, PMC09, PMC10, PMC11, PMC12, PMC13, PMC14, PMC15]
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_USRCC); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMMR); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC00); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC01); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC02); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC03); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC04); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC05); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC06); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "veosinfo.pyx":487
 * 
 * VEREGS = [USRCC, PMMR, PMC00, PMC01, PMC02, PMC03, PMC04, PMC05, PMC06,
 *           PMC07, PMC08, PMC09, PMC10, PMC11, PMC12, PMC13, PMC14, PMC15]             # <<<<<<<<<<<<<<
 * 
 * PMC_NAME = [ { 0:    "EX"},                                                # 00
 */
  __pyx_t_10 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC07); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_11 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC08); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC09); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_13 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC10); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_14 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC11); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_15 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC12); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_16 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC13); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_17 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC14); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_18 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC15); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);

  /* "veosinfo.pyx":486
 * 
 * 
 * VEREGS = [USRCC, PMMR, PMC00, PMC01, PMC02, PMC03, PMC04, PMC05, PMC06,             # <<<<<<<<<<<<<<
 *           PMC07, PMC08, PMC09, PMC10, PMC11, PMC12, PMC13, PMC14, PMC15]
 * 
 */
  __pyx_t_19 = PyList_New(18); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_19, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_19, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_19, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_19, 3, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_19, 4, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  PyList_SET_ITEM(__pyx_t_19, 5, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_19, 6, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_19, 7, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_19, 8, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_19, 9, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_11);
  PyList_SET_ITEM(__pyx_t_19, 10, __pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_12);
  PyList_SET_ITEM(__pyx_t_19, 11, __pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_13);
  PyList_SET_ITEM(__pyx_t_19, 12, __pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_14);
  PyList_SET_ITEM(__pyx_t_19, 13, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_15);
  PyList_SET_ITEM(__pyx_t_19, 14, __pyx_t_15);
  __Pyx_GIVEREF(__pyx_t_16);
  PyList_SET_ITEM(__pyx_t_19, 15, __pyx_t_16);
  __Pyx_GIVEREF(__pyx_t_17);
  PyList_SET_ITEM(__pyx_t_19, 16, __pyx_t_17);
  __Pyx_GIVEREF(__pyx_t_18);
  PyList_SET_ITEM(__pyx_t_19, 17, __pyx_t_18);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  __pyx_t_10 = 0;
  __pyx_t_11 = 0;
  __pyx_t_12 = 0;
  __pyx_t_13 = 0;
  __pyx_t_14 = 0;
  __pyx_t_15 = 0;
  __pyx_t_16 = 0;
  __pyx_t_17 = 0;
  __pyx_t_18 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_VEREGS, __pyx_t_19) < 0) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "veosinfo.pyx":489
 *           PMC07, PMC08, PMC09, PMC10, PMC11, PMC12, PMC13, PMC14, PMC15]
 * 
 * PMC_NAME = [ { 0:    "EX"},                                                # 00             # <<<<<<<<<<<<<<
 *              { 0:    "VX"},                                                # 01
 *              { 0:  "FPEC"},                                                # 02
 */
  __pyx_t_19 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_t_19, __pyx_int_0, __pyx_n_s_EX) < 0) __PYX_ERR(0, 489, __pyx_L1_error)

  /* "veosinfo.pyx":490
 * 
 * PMC_NAME = [ { 0:    "EX"},                                                # 00
 *              { 0:    "VX"},                                                # 01             # <<<<<<<<<<<<<<
 *              { 0:  "FPEC"},                                                # 02
 *              { 0:    "VE",              2: "L1IMC"},                       # 03
 */
  __pyx_t_18 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  if (PyDict_SetItem(__pyx_t_18, __pyx_int_0, __pyx_n_s_VX) < 0) __PYX_ERR(0, 490, __pyx_L1_error)

  /* "veosinfo.pyx":491
 * PMC_NAME = [ { 0:    "EX"},                                                # 00
 *              { 0:    "VX"},                                                # 01
 *              { 0:  "FPEC"},                                                # 02             # <<<<<<<<<<<<<<
 *              { 0:    "VE",              2: "L1IMC"},                       # 03
 *              { 0:  "VECC",              2: "L1IAC"},                       # 04
 */
  __pyx_t_17 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  if (PyDict_SetItem(__pyx_t_17, __pyx_int_0, __pyx_n_s_FPEC) < 0) __PYX_ERR(0, 491, __pyx_L1_error)

  /* "veosinfo.pyx":492
 *              { 0:    "VX"},                                                # 01
 *              { 0:  "FPEC"},                                                # 02
 *              { 0:    "VE",              2: "L1IMC"},                       # 03             # <<<<<<<<<<<<<<
 *              { 0:  "VECC",              2: "L1IAC"},                       # 04
 *              { 0: "L1MCC", 1:  "L2MCC", 2: "L1OMC",             8: "UXC"}, # 05
 */
  __pyx_t_16 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  if (PyDict_SetItem(__pyx_t_16, __pyx_int_0, __pyx_n_s_VE) < 0) __PYX_ERR(0, 492, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_16, __pyx_int_2, __pyx_n_s_L1IMC) < 0) __PYX_ERR(0, 492, __pyx_L1_error)

  /* "veosinfo.pyx":493
 *              { 0:  "FPEC"},                                                # 02
 *              { 0:    "VE",              2: "L1IMC"},                       # 03
 *              { 0:  "VECC",              2: "L1IAC"},                       # 04             # <<<<<<<<<<<<<<
 *              { 0: "L1MCC", 1:  "L2MCC", 2: "L1OMC",             8: "UXC"}, # 05
 *              { 0:   "VE2",              2: "L1OAC",             8: "UEC"}, # 06
 */
  __pyx_t_15 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  if (PyDict_SetItem(__pyx_t_15, __pyx_int_0, __pyx_n_s_VECC) < 0) __PYX_ERR(0, 493, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_15, __pyx_int_2, __pyx_n_s_L1IAC) < 0) __PYX_ERR(0, 493, __pyx_L1_error)

  /* "veosinfo.pyx":494
 *              { 0:    "VE",              2: "L1IMC"},                       # 03
 *              { 0:  "VECC",              2: "L1IAC"},                       # 04
 *              { 0: "L1MCC", 1:  "L2MCC", 2: "L1OMC",             8: "UXC"}, # 05             # <<<<<<<<<<<<<<
 *              { 0:   "VE2",              2: "L1OAC",             8: "UEC"}, # 06
 *              { 0: "VAREC", 1: "L1IMCC", 2:  "L2MC"},                       # 07
 */
  __pyx_t_14 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_t_14, __pyx_int_0, __pyx_n_s_L1MCC) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_int_1, __pyx_n_s_L2MCC) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_int_2, __pyx_n_s_L1OMC) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_int_8, __pyx_n_s_UXC) < 0) __PYX_ERR(0, 494, __pyx_L1_error)

  /* "veosinfo.pyx":495
 *              { 0:  "VECC",              2: "L1IAC"},                       # 04
 *              { 0: "L1MCC", 1:  "L2MCC", 2: "L1OMC",             8: "UXC"}, # 05
 *              { 0:   "VE2",              2: "L1OAC",             8: "UEC"}, # 06             # <<<<<<<<<<<<<<
 *              { 0: "VAREC", 1: "L1IMCC", 2:  "L2MC"},                       # 07
 *              { 0: "VLDEC", 1: "L1OMCC", 2:  "L2AC"},                       # 08
 */
  __pyx_t_13 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  if (PyDict_SetItem(__pyx_t_13, __pyx_int_0, __pyx_n_s_VE2) < 0) __PYX_ERR(0, 495, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_int_2, __pyx_n_s_L1OAC) < 0) __PYX_ERR(0, 495, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_13, __pyx_int_8, __pyx_n_s_UEC) < 0) __PYX_ERR(0, 495, __pyx_L1_error)

  /* "veosinfo.pyx":496
 *              { 0: "L1MCC", 1:  "L2MCC", 2: "L1OMC",             8: "UXC"}, # 05
 *              { 0:   "VE2",              2: "L1OAC",             8: "UEC"}, # 06
 *              { 0: "VAREC", 1: "L1IMCC", 2:  "L2MC"},                       # 07             # <<<<<<<<<<<<<<
 *              { 0: "VLDEC", 1: "L1OMCC", 2:  "L2AC"},                       # 08
 *              { 0:  "PCCC", 1:   "LTRC", 2:  "BREC", 3: "SARCC"},           # 09
 */
  __pyx_t_12 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  if (PyDict_SetItem(__pyx_t_12, __pyx_int_0, __pyx_n_s_VAREC) < 0) __PYX_ERR(0, 496, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_int_1, __pyx_n_s_L1IMCC) < 0) __PYX_ERR(0, 496, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_12, __pyx_int_2, __pyx_n_s_L2MC) < 0) __PYX_ERR(0, 496, __pyx_L1_error)

  /* "veosinfo.pyx":497
 *              { 0:   "VE2",              2: "L1OAC",             8: "UEC"}, # 06
 *              { 0: "VAREC", 1: "L1IMCC", 2:  "L2MC"},                       # 07
 *              { 0: "VLDEC", 1: "L1OMCC", 2:  "L2AC"},                       # 08             # <<<<<<<<<<<<<<
 *              { 0:  "PCCC", 1:   "LTRC", 2:  "BREC", 3: "SARCC"},           # 09
 *              { 0: "VLDCC", 1:   "STRC", 2:  "BPFC", 3: "IPHCC"},           # 10
 */
  __pyx_t_11 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  if (PyDict_SetItem(__pyx_t_11, __pyx_int_0, __pyx_n_s_VLDEC) < 0) __PYX_ERR(0, 497, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_int_1, __pyx_n_s_L1OMCC) < 0) __PYX_ERR(0, 497, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_11, __pyx_int_2, __pyx_n_s_L2AC) < 0) __PYX_ERR(0, 497, __pyx_L1_error)

  /* "veosinfo.pyx":498
 *              { 0: "VAREC", 1: "L1IMCC", 2:  "L2MC"},                       # 07
 *              { 0: "VLDEC", 1: "L1OMCC", 2:  "L2AC"},                       # 08
 *              { 0:  "PCCC", 1:   "LTRC", 2:  "BREC", 3: "SARCC"},           # 09             # <<<<<<<<<<<<<<
 *              { 0: "VLDCC", 1:   "STRC", 2:  "BPFC", 3: "IPHCC"},           # 10
 *              { 0:  "VLEC",              2:  "VLXC"},                       # 11
 */
  __pyx_t_10 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_t_10, __pyx_int_0, __pyx_n_s_PCCC) < 0) __PYX_ERR(0, 498, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_int_1, __pyx_n_s_LTRC) < 0) __PYX_ERR(0, 498, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_int_2, __pyx_n_s_BREC) < 0) __PYX_ERR(0, 498, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_int_3, __pyx_n_s_SARCC) < 0) __PYX_ERR(0, 498, __pyx_L1_error)

  /* "veosinfo.pyx":499
 *              { 0: "VLDEC", 1: "L1OMCC", 2:  "L2AC"},                       # 08
 *              { 0:  "PCCC", 1:   "LTRC", 2:  "BREC", 3: "SARCC"},           # 09
 *              { 0: "VLDCC", 1:   "STRC", 2:  "BPFC", 3: "IPHCC"},           # 10             # <<<<<<<<<<<<<<
 *              { 0:  "VLEC",              2:  "VLXC"},                       # 11
 *              { 0: "VLCME", 1: "VLCME2", 2: "VLCMX", 3: "VLCMX2"},          # 12
 */
  __pyx_t_9 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_int_0, __pyx_n_s_VLDCC) < 0) __PYX_ERR(0, 499, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_int_1, __pyx_n_s_STRC) < 0) __PYX_ERR(0, 499, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_int_2, __pyx_n_s_BPFC) < 0) __PYX_ERR(0, 499, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_int_3, __pyx_n_s_IPHCC) < 0) __PYX_ERR(0, 499, __pyx_L1_error)

  /* "veosinfo.pyx":500
 *              { 0:  "PCCC", 1:   "LTRC", 2:  "BREC", 3: "SARCC"},           # 09
 *              { 0: "VLDCC", 1:   "STRC", 2:  "BPFC", 3: "IPHCC"},           # 10
 *              { 0:  "VLEC",              2:  "VLXC"},                       # 11             # <<<<<<<<<<<<<<
 *              { 0: "VLCME", 1: "VLCME2", 2: "VLCMX", 3: "VLCMX2"},          # 12
 *              { 0: "FMAEC",              2: "FMAXC"},                       # 13
 */
  __pyx_t_8 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_int_0, __pyx_n_s_VLEC) < 0) __PYX_ERR(0, 500, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_int_2, __pyx_n_s_VLXC) < 0) __PYX_ERR(0, 500, __pyx_L1_error)

  /* "veosinfo.pyx":501
 *              { 0: "VLDCC", 1:   "STRC", 2:  "BPFC", 3: "IPHCC"},           # 10
 *              { 0:  "VLEC",              2:  "VLXC"},                       # 11
 *              { 0: "VLCME", 1: "VLCME2", 2: "VLCMX", 3: "VLCMX2"},          # 12             # <<<<<<<<<<<<<<
 *              { 0: "FMAEC",              2: "FMAXC"},                       # 13
 *              { 0: "PTCC"},                                                 # 14
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_int_0, __pyx_n_s_VLCME) < 0) __PYX_ERR(0, 501, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_int_1, __pyx_n_s_VLCME2) < 0) __PYX_ERR(0, 501, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_int_2, __pyx_n_s_VLCMX) < 0) __PYX_ERR(0, 501, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_int_3, __pyx_n_s_VLCMX2) < 0) __PYX_ERR(0, 501, __pyx_L1_error)

  /* "veosinfo.pyx":502
 *              { 0:  "VLEC",              2:  "VLXC"},                       # 11
 *              { 0: "VLCME", 1: "VLCME2", 2: "VLCMX", 3: "VLCMX2"},          # 12
 *              { 0: "FMAEC",              2: "FMAXC"},                       # 13             # <<<<<<<<<<<<<<
 *              { 0: "PTCC"},                                                 # 14
 *              { 0: "TTCC"}                                                  # 15
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_int_0, __pyx_n_s_FMAEC) < 0) __PYX_ERR(0, 502, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_int_2, __pyx_n_s_FMAXC) < 0) __PYX_ERR(0, 502, __pyx_L1_error)

  /* "veosinfo.pyx":503
 *              { 0: "VLCME", 1: "VLCME2", 2: "VLCMX", 3: "VLCMX2"},          # 12
 *              { 0: "FMAEC",              2: "FMAXC"},                       # 13
 *              { 0: "PTCC"},                                                 # 14             # <<<<<<<<<<<<<<
 *              { 0: "TTCC"}                                                  # 15
 * ]
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_int_0, __pyx_n_s_PTCC) < 0) __PYX_ERR(0, 503, __pyx_L1_error)

  /* "veosinfo.pyx":504
 *              { 0: "FMAEC",              2: "FMAXC"},                       # 13
 *              { 0: "PTCC"},                                                 # 14
 *              { 0: "TTCC"}                                                  # 15             # <<<<<<<<<<<<<<
 * ]
 * 
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_int_0, __pyx_n_s_TTCC) < 0) __PYX_ERR(0, 504, __pyx_L1_error)

  /* "veosinfo.pyx":489
 *           PMC07, PMC08, PMC09, PMC10, PMC11, PMC12, PMC13, PMC14, PMC15]
 * 
 * PMC_NAME = [ { 0:    "EX"},                                                # 00             # <<<<<<<<<<<<<<
 *              { 0:    "VX"},                                                # 01
 *              { 0:  "FPEC"},                                                # 02
 */
  __pyx_t_3 = PyList_New(16); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_19);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_18);
  PyList_SET_ITEM(__pyx_t_3, 1, __pyx_t_18);
  __Pyx_GIVEREF(__pyx_t_17);
  PyList_SET_ITEM(__pyx_t_3, 2, __pyx_t_17);
  __Pyx_GIVEREF(__pyx_t_16);
  PyList_SET_ITEM(__pyx_t_3, 3, __pyx_t_16);
  __Pyx_GIVEREF(__pyx_t_15);
  PyList_SET_ITEM(__pyx_t_3, 4, __pyx_t_15);
  __Pyx_GIVEREF(__pyx_t_14);
  PyList_SET_ITEM(__pyx_t_3, 5, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_13);
  PyList_SET_ITEM(__pyx_t_3, 6, __pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_12);
  PyList_SET_ITEM(__pyx_t_3, 7, __pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_11);
  PyList_SET_ITEM(__pyx_t_3, 8, __pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_3, 9, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_3, 10, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_3, 11, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_3, 12, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  PyList_SET_ITEM(__pyx_t_3, 13, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_3, 14, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_3, 15, __pyx_t_4);
  __pyx_t_19 = 0;
  __pyx_t_18 = 0;
  __pyx_t_17 = 0;
  __pyx_t_16 = 0;
  __pyx_t_15 = 0;
  __pyx_t_14 = 0;
  __pyx_t_13 = 0;
  __pyx_t_12 = 0;
  __pyx_t_11 = 0;
  __pyx_t_10 = 0;
  __pyx_t_9 = 0;
  __pyx_t_8 = 0;
  __pyx_t_7 = 0;
  __pyx_t_6 = 0;
  __pyx_t_5 = 0;
  __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PMC_NAME, __pyx_t_3) < 0) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "veosinfo.pyx":508
 * 
 * 
 * def ve_pid_perf(int nodeid, int pid):             # <<<<<<<<<<<<<<
 *     """
 *     Create a dict with performance counter values for
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_8veosinfo_41ve_pid_perf, NULL, __pyx_n_s_veosinfo); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ve_pid_perf, __pyx_t_3) < 0) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "veosinfo.pyx":1
 * ##########################################################################             # <<<<<<<<<<<<<<
 * #
 * # This program module is free software; you can redistribute it
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "EnumBase":9
 * 
 * cdef object __Pyx_OrderedDict
 * if PY_VERSION_HEX >= 0x02070000:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as __Pyx_OrderedDict
 * else:
 */
  __pyx_t_20 = ((PY_VERSION_HEX >= 0x02070000) != 0);
  if (__pyx_t_20) {

    /* "EnumBase":10
 * cdef object __Pyx_OrderedDict
 * if PY_VERSION_HEX >= 0x02070000:
 *     from collections import OrderedDict as __Pyx_OrderedDict             # <<<<<<<<<<<<<<
 * else:
 *     __Pyx_OrderedDict = dict
 */
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 10, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_OrderedDict);
    __Pyx_GIVEREF(__pyx_n_s_OrderedDict);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_OrderedDict);
    __pyx_t_4 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_3, -1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 10, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_4, __pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 10, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_XGOTREF(__Pyx_OrderedDict);
    __Pyx_DECREF_SET(__Pyx_OrderedDict, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "EnumBase":9
 * 
 * cdef object __Pyx_OrderedDict
 * if PY_VERSION_HEX >= 0x02070000:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as __Pyx_OrderedDict
 * else:
 */
    goto __pyx_L2;
  }

  /* "EnumBase":12
 *     from collections import OrderedDict as __Pyx_OrderedDict
 * else:
 *     __Pyx_OrderedDict = dict             # <<<<<<<<<<<<<<
 * 
 * @cython.internal
 */
  /*else*/ {
    __Pyx_INCREF(((PyObject *)(&PyDict_Type)));
    __Pyx_XGOTREF(__Pyx_OrderedDict);
    __Pyx_DECREF_SET(__Pyx_OrderedDict, ((PyObject *)(&PyDict_Type)));
    __Pyx_GIVEREF(((PyObject *)(&PyDict_Type)));
  }
  __pyx_L2:;

  /* "EnumBase":26
 * 
 * cdef object __Pyx_EnumBase
 * class __Pyx_EnumBase(int):             # <<<<<<<<<<<<<<
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)(&PyInt_Type)));
  __Pyx_GIVEREF(((PyObject *)(&PyInt_Type)));
  PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)(&PyInt_Type)));
  __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_4, __pyx_n_s_Pyx_EnumBase, __pyx_n_s_Pyx_EnumBase, (PyObject *) NULL, __pyx_n_s_EnumBase, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "EnumBase":27
 * cdef object __Pyx_EnumBase
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta             # <<<<<<<<<<<<<<
 *     def __new__(cls, value, name=None):
 *         for v in cls:
 */
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_n_s_metaclass, ((PyObject *)__pyx_ptype___Pyx_EnumMeta)) < 0) __PYX_ERR(1, 27, __pyx_L1_error)

  /* "EnumBase":28
 * class __Pyx_EnumBase(int):
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):             # <<<<<<<<<<<<<<
 *         for v in cls:
 *             if v == value:
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_8EnumBase_14__Pyx_EnumBase_1__new__, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_Pyx_EnumBase___new, NULL, __pyx_n_s_EnumBase, __pyx_d, ((PyObject *)__pyx_codeobj__65)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__66);
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_n_s_new, __pyx_t_6) < 0) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "EnumBase":39
 *         cls.__members__[name] = res
 *         return res
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_8EnumBase_14__Pyx_EnumBase_3__repr__, 0, __pyx_n_s_Pyx_EnumBase___repr, NULL, __pyx_n_s_EnumBase, __pyx_d, ((PyObject *)__pyx_codeobj__68)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_n_s_repr, __pyx_t_6) < 0) __PYX_ERR(1, 39, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "EnumBase":41
 *     def __repr__(self):
 *         return "<%s.%s: %d>" % (self.__class__.__name__, self.name, self)
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_8EnumBase_14__Pyx_EnumBase_5__str__, 0, __pyx_n_s_Pyx_EnumBase___str, NULL, __pyx_n_s_EnumBase, __pyx_d, ((PyObject *)__pyx_codeobj__70)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_n_s_str, __pyx_t_6) < 0) __PYX_ERR(1, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "EnumBase":26
 * 
 * cdef object __Pyx_EnumBase
 * class __Pyx_EnumBase(int):             # <<<<<<<<<<<<<<
 *     __metaclass__ = __Pyx_EnumMeta
 *     def __new__(cls, value, name=None):
 */
  __pyx_t_6 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_Pyx_EnumBase, __pyx_t_4, __pyx_t_5, NULL, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_XGOTREF(__Pyx_EnumBase);
  __Pyx_DECREF_SET(__Pyx_EnumBase, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "EnumBase":44
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 *     from enum import IntEnum as __Pyx_EnumBase
 * 
 */
  __pyx_t_20 = ((PY_VERSION_HEX >= 0x03040000) != 0);
  if (__pyx_t_20) {

    /* "EnumBase":45
 * 
 * if PY_VERSION_HEX >= 0x03040000:
 *     from enum import IntEnum as __Pyx_EnumBase             # <<<<<<<<<<<<<<
 * 
 */
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_n_s_IntEnum);
    __Pyx_GIVEREF(__pyx_n_s_IntEnum);
    PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_IntEnum);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_enum, __pyx_t_4, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_IntEnum); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_XGOTREF(__Pyx_EnumBase);
    __Pyx_DECREF_SET(__Pyx_EnumBase, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumBase":44
 *         return "%s.%s" % (self.__class__.__name__, self.name)
 * 
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 *     from enum import IntEnum as __Pyx_EnumBase
 * 
 */
  }

  /* "(tree fragment)":1
 * def __pyx_unpickle___Pyx_EnumMeta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_8EnumBase_1__pyx_unpickle___Pyx_EnumMeta, NULL, __pyx_n_s_EnumBase); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle___Pyx_EnumMeta, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "EnumType":50
 * 
 * 
 * cdef dict __Pyx_globals = globals()             # <<<<<<<<<<<<<<
 * if PY_VERSION_HEX >= 0x03040000:
 * 
 */
  __pyx_t_3 = __Pyx_Globals(); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(PyDict_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(1, 50, __pyx_L1_error)
  __Pyx_XGOTREF(__Pyx_globals);
  __Pyx_DECREF_SET(__Pyx_globals, ((PyObject*)__pyx_t_3));
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "EnumType":51
 * 
 * cdef dict __Pyx_globals = globals()
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 * 
 *     VERegIds = __Pyx_EnumBase('VERegIds', __Pyx_OrderedDict([
 */
  __pyx_t_20 = ((PY_VERSION_HEX >= 0x03040000) != 0);
  if (__pyx_t_20) {

    /* "EnumType":54
 * 
 *     VERegIds = __Pyx_EnumBase('VERegIds', __Pyx_OrderedDict([
 *         ('USRCC', USRCC),             # <<<<<<<<<<<<<<
 *         ('PMC00', PMC00),
 *         ('PMC01', PMC01),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_USRCC); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_n_s_USRCC);
    __Pyx_GIVEREF(__pyx_n_s_USRCC);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_USRCC);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":55
 *     VERegIds = __Pyx_EnumBase('VERegIds', __Pyx_OrderedDict([
 *         ('USRCC', USRCC),
 *         ('PMC00', PMC00),             # <<<<<<<<<<<<<<
 *         ('PMC01', PMC01),
 *         ('PMC02', PMC02),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC00); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_n_s_PMC00);
    __Pyx_GIVEREF(__pyx_n_s_PMC00);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_n_s_PMC00);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":56
 *         ('USRCC', USRCC),
 *         ('PMC00', PMC00),
 *         ('PMC01', PMC01),             # <<<<<<<<<<<<<<
 *         ('PMC02', PMC02),
 *         ('PMC03', PMC03),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC01); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_n_s_PMC01);
    __Pyx_GIVEREF(__pyx_n_s_PMC01);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_n_s_PMC01);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":57
 *         ('PMC00', PMC00),
 *         ('PMC01', PMC01),
 *         ('PMC02', PMC02),             # <<<<<<<<<<<<<<
 *         ('PMC03', PMC03),
 *         ('PMC04', PMC04),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC02); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_n_s_PMC02);
    __Pyx_GIVEREF(__pyx_n_s_PMC02);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_s_PMC02);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":58
 *         ('PMC01', PMC01),
 *         ('PMC02', PMC02),
 *         ('PMC03', PMC03),             # <<<<<<<<<<<<<<
 *         ('PMC04', PMC04),
 *         ('PMC05', PMC05),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC03); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_n_s_PMC03);
    __Pyx_GIVEREF(__pyx_n_s_PMC03);
    PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_n_s_PMC03);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":59
 *         ('PMC02', PMC02),
 *         ('PMC03', PMC03),
 *         ('PMC04', PMC04),             # <<<<<<<<<<<<<<
 *         ('PMC05', PMC05),
 *         ('PMC06', PMC06),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC04); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_n_s_PMC04);
    __Pyx_GIVEREF(__pyx_n_s_PMC04);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_n_s_PMC04);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":60
 *         ('PMC03', PMC03),
 *         ('PMC04', PMC04),
 *         ('PMC05', PMC05),             # <<<<<<<<<<<<<<
 *         ('PMC06', PMC06),
 *         ('PMC07', PMC07),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC05); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_INCREF(__pyx_n_s_PMC05);
    __Pyx_GIVEREF(__pyx_n_s_PMC05);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_n_s_PMC05);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":61
 *         ('PMC04', PMC04),
 *         ('PMC05', PMC05),
 *         ('PMC06', PMC06),             # <<<<<<<<<<<<<<
 *         ('PMC07', PMC07),
 *         ('PMC08', PMC08),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC06); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_INCREF(__pyx_n_s_PMC06);
    __Pyx_GIVEREF(__pyx_n_s_PMC06);
    PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_n_s_PMC06);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":62
 *         ('PMC05', PMC05),
 *         ('PMC06', PMC06),
 *         ('PMC07', PMC07),             # <<<<<<<<<<<<<<
 *         ('PMC08', PMC08),
 *         ('PMC09', PMC09),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC07); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_12 = PyTuple_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_INCREF(__pyx_n_s_PMC07);
    __Pyx_GIVEREF(__pyx_n_s_PMC07);
    PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_n_s_PMC07);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":63
 *         ('PMC06', PMC06),
 *         ('PMC07', PMC07),
 *         ('PMC08', PMC08),             # <<<<<<<<<<<<<<
 *         ('PMC09', PMC09),
 *         ('PMC10', PMC10),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC08); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_13 = PyTuple_New(2); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_INCREF(__pyx_n_s_PMC08);
    __Pyx_GIVEREF(__pyx_n_s_PMC08);
    PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_n_s_PMC08);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":64
 *         ('PMC07', PMC07),
 *         ('PMC08', PMC08),
 *         ('PMC09', PMC09),             # <<<<<<<<<<<<<<
 *         ('PMC10', PMC10),
 *         ('PMC11', PMC11),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC09); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_INCREF(__pyx_n_s_PMC09);
    __Pyx_GIVEREF(__pyx_n_s_PMC09);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_n_s_PMC09);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":65
 *         ('PMC08', PMC08),
 *         ('PMC09', PMC09),
 *         ('PMC10', PMC10),             # <<<<<<<<<<<<<<
 *         ('PMC11', PMC11),
 *         ('PMC12', PMC12),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC10); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_INCREF(__pyx_n_s_PMC10);
    __Pyx_GIVEREF(__pyx_n_s_PMC10);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_n_s_PMC10);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":66
 *         ('PMC09', PMC09),
 *         ('PMC10', PMC10),
 *         ('PMC11', PMC11),             # <<<<<<<<<<<<<<
 *         ('PMC12', PMC12),
 *         ('PMC13', PMC13),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC11); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_16 = PyTuple_New(2); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_INCREF(__pyx_n_s_PMC11);
    __Pyx_GIVEREF(__pyx_n_s_PMC11);
    PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_n_s_PMC11);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":67
 *         ('PMC10', PMC10),
 *         ('PMC11', PMC11),
 *         ('PMC12', PMC12),             # <<<<<<<<<<<<<<
 *         ('PMC13', PMC13),
 *         ('PMC14', PMC14),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC12); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_17 = PyTuple_New(2); if (unlikely(!__pyx_t_17)) __PYX_ERR(1, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_INCREF(__pyx_n_s_PMC12);
    __Pyx_GIVEREF(__pyx_n_s_PMC12);
    PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_n_s_PMC12);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_17, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":68
 *         ('PMC11', PMC11),
 *         ('PMC12', PMC12),
 *         ('PMC13', PMC13),             # <<<<<<<<<<<<<<
 *         ('PMC14', PMC14),
 *         ('PMC15', PMC15),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC13); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_18 = PyTuple_New(2); if (unlikely(!__pyx_t_18)) __PYX_ERR(1, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_18);
    __Pyx_INCREF(__pyx_n_s_PMC13);
    __Pyx_GIVEREF(__pyx_n_s_PMC13);
    PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_n_s_PMC13);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_18, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":69
 *         ('PMC12', PMC12),
 *         ('PMC13', PMC13),
 *         ('PMC14', PMC14),             # <<<<<<<<<<<<<<
 *         ('PMC15', PMC15),
 *         ('PSW', PSW),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC14); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_19 = PyTuple_New(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(1, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_INCREF(__pyx_n_s_PMC14);
    __Pyx_GIVEREF(__pyx_n_s_PMC14);
    PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_n_s_PMC14);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_19, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":70
 *         ('PMC13', PMC13),
 *         ('PMC14', PMC14),
 *         ('PMC15', PMC15),             # <<<<<<<<<<<<<<
 *         ('PSW', PSW),
 *         ('EXS', EXS),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC15); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PMC15);
    __Pyx_GIVEREF(__pyx_n_s_PMC15);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PMC15);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":71
 *         ('PMC14', PMC14),
 *         ('PMC15', PMC15),
 *         ('PSW', PSW),             # <<<<<<<<<<<<<<
 *         ('EXS', EXS),
 *         ('IC', IC),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PSW); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PSW);
    __Pyx_GIVEREF(__pyx_n_s_PSW);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PSW);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":72
 *         ('PMC15', PMC15),
 *         ('PSW', PSW),
 *         ('EXS', EXS),             # <<<<<<<<<<<<<<
 *         ('IC', IC),
 *         ('ICE', ICE),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_EXS); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_21 = PyTuple_New(2); if (unlikely(!__pyx_t_21)) __PYX_ERR(1, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_INCREF(__pyx_n_s_EXS);
    __Pyx_GIVEREF(__pyx_n_s_EXS);
    PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_n_s_EXS);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_21, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":73
 *         ('PSW', PSW),
 *         ('EXS', EXS),
 *         ('IC', IC),             # <<<<<<<<<<<<<<
 *         ('ICE', ICE),
 *         ('VIXR', VIXR),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_IC); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 73, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_22 = PyTuple_New(2); if (unlikely(!__pyx_t_22)) __PYX_ERR(1, 73, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_22);
    __Pyx_INCREF(__pyx_n_s_IC);
    __Pyx_GIVEREF(__pyx_n_s_IC);
    PyTuple_SET_ITEM(__pyx_t_22, 0, __pyx_n_s_IC);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_22, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":74
 *         ('EXS', EXS),
 *         ('IC', IC),
 *         ('ICE', ICE),             # <<<<<<<<<<<<<<
 *         ('VIXR', VIXR),
 *         ('VL', VL),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_ICE); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_23 = PyTuple_New(2); if (unlikely(!__pyx_t_23)) __PYX_ERR(1, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_23);
    __Pyx_INCREF(__pyx_n_s_ICE);
    __Pyx_GIVEREF(__pyx_n_s_ICE);
    PyTuple_SET_ITEM(__pyx_t_23, 0, __pyx_n_s_ICE);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_23, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":75
 *         ('IC', IC),
 *         ('ICE', ICE),
 *         ('VIXR', VIXR),             # <<<<<<<<<<<<<<
 *         ('VL', VL),
 *         ('SAR', SAR),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_VIXR); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_24 = PyTuple_New(2); if (unlikely(!__pyx_t_24)) __PYX_ERR(1, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_24);
    __Pyx_INCREF(__pyx_n_s_VIXR);
    __Pyx_GIVEREF(__pyx_n_s_VIXR);
    PyTuple_SET_ITEM(__pyx_t_24, 0, __pyx_n_s_VIXR);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_24, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":76
 *         ('ICE', ICE),
 *         ('VIXR', VIXR),
 *         ('VL', VL),             # <<<<<<<<<<<<<<
 *         ('SAR', SAR),
 *         ('PMMR', PMMR),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_VL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_25 = PyTuple_New(2); if (unlikely(!__pyx_t_25)) __PYX_ERR(1, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_25);
    __Pyx_INCREF(__pyx_n_s_VL);
    __Pyx_GIVEREF(__pyx_n_s_VL);
    PyTuple_SET_ITEM(__pyx_t_25, 0, __pyx_n_s_VL);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_25, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":77
 *         ('VIXR', VIXR),
 *         ('VL', VL),
 *         ('SAR', SAR),             # <<<<<<<<<<<<<<
 *         ('PMMR', PMMR),
 *         ('PMCR00', PMCR00),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SAR); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_26 = PyTuple_New(2); if (unlikely(!__pyx_t_26)) __PYX_ERR(1, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_26);
    __Pyx_INCREF(__pyx_n_s_SAR);
    __Pyx_GIVEREF(__pyx_n_s_SAR);
    PyTuple_SET_ITEM(__pyx_t_26, 0, __pyx_n_s_SAR);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_26, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":78
 *         ('VL', VL),
 *         ('SAR', SAR),
 *         ('PMMR', PMMR),             # <<<<<<<<<<<<<<
 *         ('PMCR00', PMCR00),
 *         ('PMCR01', PMCR01),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMMR); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_27 = PyTuple_New(2); if (unlikely(!__pyx_t_27)) __PYX_ERR(1, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_27);
    __Pyx_INCREF(__pyx_n_s_PMMR);
    __Pyx_GIVEREF(__pyx_n_s_PMMR);
    PyTuple_SET_ITEM(__pyx_t_27, 0, __pyx_n_s_PMMR);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_27, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":79
 *         ('SAR', SAR),
 *         ('PMMR', PMMR),
 *         ('PMCR00', PMCR00),             # <<<<<<<<<<<<<<
 *         ('PMCR01', PMCR01),
 *         ('PMCR02', PMCR02),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMCR00); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_28 = PyTuple_New(2); if (unlikely(!__pyx_t_28)) __PYX_ERR(1, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_28);
    __Pyx_INCREF(__pyx_n_s_PMCR00);
    __Pyx_GIVEREF(__pyx_n_s_PMCR00);
    PyTuple_SET_ITEM(__pyx_t_28, 0, __pyx_n_s_PMCR00);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_28, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":80
 *         ('PMMR', PMMR),
 *         ('PMCR00', PMCR00),
 *         ('PMCR01', PMCR01),             # <<<<<<<<<<<<<<
 *         ('PMCR02', PMCR02),
 *         ('PMCR03', PMCR03),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMCR01); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_29 = PyTuple_New(2); if (unlikely(!__pyx_t_29)) __PYX_ERR(1, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_29);
    __Pyx_INCREF(__pyx_n_s_PMCR01);
    __Pyx_GIVEREF(__pyx_n_s_PMCR01);
    PyTuple_SET_ITEM(__pyx_t_29, 0, __pyx_n_s_PMCR01);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_29, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":81
 *         ('PMCR00', PMCR00),
 *         ('PMCR01', PMCR01),
 *         ('PMCR02', PMCR02),             # <<<<<<<<<<<<<<
 *         ('PMCR03', PMCR03),
 *         ('PMCR04', PMCR04),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMCR02); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 81, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_30 = PyTuple_New(2); if (unlikely(!__pyx_t_30)) __PYX_ERR(1, 81, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_30);
    __Pyx_INCREF(__pyx_n_s_PMCR02);
    __Pyx_GIVEREF(__pyx_n_s_PMCR02);
    PyTuple_SET_ITEM(__pyx_t_30, 0, __pyx_n_s_PMCR02);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_30, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":82
 *         ('PMCR01', PMCR01),
 *         ('PMCR02', PMCR02),
 *         ('PMCR03', PMCR03),             # <<<<<<<<<<<<<<
 *         ('PMCR04', PMCR04),
 *         ('SR00', SR00),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMCR03); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_31 = PyTuple_New(2); if (unlikely(!__pyx_t_31)) __PYX_ERR(1, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_31);
    __Pyx_INCREF(__pyx_n_s_PMCR03);
    __Pyx_GIVEREF(__pyx_n_s_PMCR03);
    PyTuple_SET_ITEM(__pyx_t_31, 0, __pyx_n_s_PMCR03);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_31, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":83
 *         ('PMCR02', PMCR02),
 *         ('PMCR03', PMCR03),
 *         ('PMCR04', PMCR04),             # <<<<<<<<<<<<<<
 *         ('SR00', SR00),
 *         ('SR01', SR01),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMCR04); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_32 = PyTuple_New(2); if (unlikely(!__pyx_t_32)) __PYX_ERR(1, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_32);
    __Pyx_INCREF(__pyx_n_s_PMCR04);
    __Pyx_GIVEREF(__pyx_n_s_PMCR04);
    PyTuple_SET_ITEM(__pyx_t_32, 0, __pyx_n_s_PMCR04);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_32, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":84
 *         ('PMCR03', PMCR03),
 *         ('PMCR04', PMCR04),
 *         ('SR00', SR00),             # <<<<<<<<<<<<<<
 *         ('SR01', SR01),
 *         ('SR02', SR02),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR00); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_33 = PyTuple_New(2); if (unlikely(!__pyx_t_33)) __PYX_ERR(1, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_33);
    __Pyx_INCREF(__pyx_n_s_SR00);
    __Pyx_GIVEREF(__pyx_n_s_SR00);
    PyTuple_SET_ITEM(__pyx_t_33, 0, __pyx_n_s_SR00);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_33, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":85
 *         ('PMCR04', PMCR04),
 *         ('SR00', SR00),
 *         ('SR01', SR01),             # <<<<<<<<<<<<<<
 *         ('SR02', SR02),
 *         ('SR03', SR03),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR01); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_34 = PyTuple_New(2); if (unlikely(!__pyx_t_34)) __PYX_ERR(1, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_34);
    __Pyx_INCREF(__pyx_n_s_SR01);
    __Pyx_GIVEREF(__pyx_n_s_SR01);
    PyTuple_SET_ITEM(__pyx_t_34, 0, __pyx_n_s_SR01);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_34, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":86
 *         ('SR00', SR00),
 *         ('SR01', SR01),
 *         ('SR02', SR02),             # <<<<<<<<<<<<<<
 *         ('SR03', SR03),
 *         ('SR04', SR04),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR02); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_35 = PyTuple_New(2); if (unlikely(!__pyx_t_35)) __PYX_ERR(1, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_35);
    __Pyx_INCREF(__pyx_n_s_SR02);
    __Pyx_GIVEREF(__pyx_n_s_SR02);
    PyTuple_SET_ITEM(__pyx_t_35, 0, __pyx_n_s_SR02);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_35, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":87
 *         ('SR01', SR01),
 *         ('SR02', SR02),
 *         ('SR03', SR03),             # <<<<<<<<<<<<<<
 *         ('SR04', SR04),
 *         ('SR05', SR05),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR03); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_36 = PyTuple_New(2); if (unlikely(!__pyx_t_36)) __PYX_ERR(1, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_36);
    __Pyx_INCREF(__pyx_n_s_SR03);
    __Pyx_GIVEREF(__pyx_n_s_SR03);
    PyTuple_SET_ITEM(__pyx_t_36, 0, __pyx_n_s_SR03);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_36, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":88
 *         ('SR02', SR02),
 *         ('SR03', SR03),
 *         ('SR04', SR04),             # <<<<<<<<<<<<<<
 *         ('SR05', SR05),
 *         ('SR06', SR06),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR04); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_37 = PyTuple_New(2); if (unlikely(!__pyx_t_37)) __PYX_ERR(1, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_37);
    __Pyx_INCREF(__pyx_n_s_SR04);
    __Pyx_GIVEREF(__pyx_n_s_SR04);
    PyTuple_SET_ITEM(__pyx_t_37, 0, __pyx_n_s_SR04);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_37, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":89
 *         ('SR03', SR03),
 *         ('SR04', SR04),
 *         ('SR05', SR05),             # <<<<<<<<<<<<<<
 *         ('SR06', SR06),
 *         ('SR07', SR07),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR05); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_38 = PyTuple_New(2); if (unlikely(!__pyx_t_38)) __PYX_ERR(1, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_38);
    __Pyx_INCREF(__pyx_n_s_SR05);
    __Pyx_GIVEREF(__pyx_n_s_SR05);
    PyTuple_SET_ITEM(__pyx_t_38, 0, __pyx_n_s_SR05);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_38, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":90
 *         ('SR04', SR04),
 *         ('SR05', SR05),
 *         ('SR06', SR06),             # <<<<<<<<<<<<<<
 *         ('SR07', SR07),
 *         ('SR08', SR08),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR06); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 90, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_39 = PyTuple_New(2); if (unlikely(!__pyx_t_39)) __PYX_ERR(1, 90, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_39);
    __Pyx_INCREF(__pyx_n_s_SR06);
    __Pyx_GIVEREF(__pyx_n_s_SR06);
    PyTuple_SET_ITEM(__pyx_t_39, 0, __pyx_n_s_SR06);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_39, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":91
 *         ('SR05', SR05),
 *         ('SR06', SR06),
 *         ('SR07', SR07),             # <<<<<<<<<<<<<<
 *         ('SR08', SR08),
 *         ('SR09', SR09),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR07); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_40 = PyTuple_New(2); if (unlikely(!__pyx_t_40)) __PYX_ERR(1, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_40);
    __Pyx_INCREF(__pyx_n_s_SR07);
    __Pyx_GIVEREF(__pyx_n_s_SR07);
    PyTuple_SET_ITEM(__pyx_t_40, 0, __pyx_n_s_SR07);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_40, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":92
 *         ('SR06', SR06),
 *         ('SR07', SR07),
 *         ('SR08', SR08),             # <<<<<<<<<<<<<<
 *         ('SR09', SR09),
 *         ('SR10', SR10),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR08); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_41 = PyTuple_New(2); if (unlikely(!__pyx_t_41)) __PYX_ERR(1, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_41);
    __Pyx_INCREF(__pyx_n_s_SR08);
    __Pyx_GIVEREF(__pyx_n_s_SR08);
    PyTuple_SET_ITEM(__pyx_t_41, 0, __pyx_n_s_SR08);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_41, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":93
 *         ('SR07', SR07),
 *         ('SR08', SR08),
 *         ('SR09', SR09),             # <<<<<<<<<<<<<<
 *         ('SR10', SR10),
 *         ('SR11', SR11),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR09); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 93, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_42 = PyTuple_New(2); if (unlikely(!__pyx_t_42)) __PYX_ERR(1, 93, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_42);
    __Pyx_INCREF(__pyx_n_s_SR09);
    __Pyx_GIVEREF(__pyx_n_s_SR09);
    PyTuple_SET_ITEM(__pyx_t_42, 0, __pyx_n_s_SR09);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_42, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":94
 *         ('SR08', SR08),
 *         ('SR09', SR09),
 *         ('SR10', SR10),             # <<<<<<<<<<<<<<
 *         ('SR11', SR11),
 *         ('SR12', SR12),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR10); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 94, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_43 = PyTuple_New(2); if (unlikely(!__pyx_t_43)) __PYX_ERR(1, 94, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_43);
    __Pyx_INCREF(__pyx_n_s_SR10);
    __Pyx_GIVEREF(__pyx_n_s_SR10);
    PyTuple_SET_ITEM(__pyx_t_43, 0, __pyx_n_s_SR10);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_43, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":95
 *         ('SR09', SR09),
 *         ('SR10', SR10),
 *         ('SR11', SR11),             # <<<<<<<<<<<<<<
 *         ('SR12', SR12),
 *         ('SR13', SR13),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR11); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_44 = PyTuple_New(2); if (unlikely(!__pyx_t_44)) __PYX_ERR(1, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_44);
    __Pyx_INCREF(__pyx_n_s_SR11);
    __Pyx_GIVEREF(__pyx_n_s_SR11);
    PyTuple_SET_ITEM(__pyx_t_44, 0, __pyx_n_s_SR11);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_44, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":96
 *         ('SR10', SR10),
 *         ('SR11', SR11),
 *         ('SR12', SR12),             # <<<<<<<<<<<<<<
 *         ('SR13', SR13),
 *         ('SR14', SR14),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR12); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 96, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_45 = PyTuple_New(2); if (unlikely(!__pyx_t_45)) __PYX_ERR(1, 96, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_45);
    __Pyx_INCREF(__pyx_n_s_SR12);
    __Pyx_GIVEREF(__pyx_n_s_SR12);
    PyTuple_SET_ITEM(__pyx_t_45, 0, __pyx_n_s_SR12);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_45, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":97
 *         ('SR11', SR11),
 *         ('SR12', SR12),
 *         ('SR13', SR13),             # <<<<<<<<<<<<<<
 *         ('SR14', SR14),
 *         ('SR15', SR15),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR13); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 97, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_46 = PyTuple_New(2); if (unlikely(!__pyx_t_46)) __PYX_ERR(1, 97, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_46);
    __Pyx_INCREF(__pyx_n_s_SR13);
    __Pyx_GIVEREF(__pyx_n_s_SR13);
    PyTuple_SET_ITEM(__pyx_t_46, 0, __pyx_n_s_SR13);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_46, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":98
 *         ('SR12', SR12),
 *         ('SR13', SR13),
 *         ('SR14', SR14),             # <<<<<<<<<<<<<<
 *         ('SR15', SR15),
 *         ('SR16', SR16),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR14); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_47 = PyTuple_New(2); if (unlikely(!__pyx_t_47)) __PYX_ERR(1, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_47);
    __Pyx_INCREF(__pyx_n_s_SR14);
    __Pyx_GIVEREF(__pyx_n_s_SR14);
    PyTuple_SET_ITEM(__pyx_t_47, 0, __pyx_n_s_SR14);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_47, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":99
 *         ('SR13', SR13),
 *         ('SR14', SR14),
 *         ('SR15', SR15),             # <<<<<<<<<<<<<<
 *         ('SR16', SR16),
 *         ('SR17', SR17),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR15); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 99, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_48 = PyTuple_New(2); if (unlikely(!__pyx_t_48)) __PYX_ERR(1, 99, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_48);
    __Pyx_INCREF(__pyx_n_s_SR15);
    __Pyx_GIVEREF(__pyx_n_s_SR15);
    PyTuple_SET_ITEM(__pyx_t_48, 0, __pyx_n_s_SR15);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_48, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":100
 *         ('SR14', SR14),
 *         ('SR15', SR15),
 *         ('SR16', SR16),             # <<<<<<<<<<<<<<
 *         ('SR17', SR17),
 *         ('SR18', SR18),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR16); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_49 = PyTuple_New(2); if (unlikely(!__pyx_t_49)) __PYX_ERR(1, 100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_49);
    __Pyx_INCREF(__pyx_n_s_SR16);
    __Pyx_GIVEREF(__pyx_n_s_SR16);
    PyTuple_SET_ITEM(__pyx_t_49, 0, __pyx_n_s_SR16);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_49, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":101
 *         ('SR15', SR15),
 *         ('SR16', SR16),
 *         ('SR17', SR17),             # <<<<<<<<<<<<<<
 *         ('SR18', SR18),
 *         ('SR19', SR19),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR17); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_50 = PyTuple_New(2); if (unlikely(!__pyx_t_50)) __PYX_ERR(1, 101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_50);
    __Pyx_INCREF(__pyx_n_s_SR17);
    __Pyx_GIVEREF(__pyx_n_s_SR17);
    PyTuple_SET_ITEM(__pyx_t_50, 0, __pyx_n_s_SR17);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_50, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":102
 *         ('SR16', SR16),
 *         ('SR17', SR17),
 *         ('SR18', SR18),             # <<<<<<<<<<<<<<
 *         ('SR19', SR19),
 *         ('SR20', SR20),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR18); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 102, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_51 = PyTuple_New(2); if (unlikely(!__pyx_t_51)) __PYX_ERR(1, 102, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_51);
    __Pyx_INCREF(__pyx_n_s_SR18);
    __Pyx_GIVEREF(__pyx_n_s_SR18);
    PyTuple_SET_ITEM(__pyx_t_51, 0, __pyx_n_s_SR18);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_51, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":103
 *         ('SR17', SR17),
 *         ('SR18', SR18),
 *         ('SR19', SR19),             # <<<<<<<<<<<<<<
 *         ('SR20', SR20),
 *         ('SR21', SR21),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR19); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_52 = PyTuple_New(2); if (unlikely(!__pyx_t_52)) __PYX_ERR(1, 103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_52);
    __Pyx_INCREF(__pyx_n_s_SR19);
    __Pyx_GIVEREF(__pyx_n_s_SR19);
    PyTuple_SET_ITEM(__pyx_t_52, 0, __pyx_n_s_SR19);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_52, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":104
 *         ('SR18', SR18),
 *         ('SR19', SR19),
 *         ('SR20', SR20),             # <<<<<<<<<<<<<<
 *         ('SR21', SR21),
 *         ('SR22', SR22),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR20); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_53 = PyTuple_New(2); if (unlikely(!__pyx_t_53)) __PYX_ERR(1, 104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_53);
    __Pyx_INCREF(__pyx_n_s_SR20);
    __Pyx_GIVEREF(__pyx_n_s_SR20);
    PyTuple_SET_ITEM(__pyx_t_53, 0, __pyx_n_s_SR20);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_53, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":105
 *         ('SR19', SR19),
 *         ('SR20', SR20),
 *         ('SR21', SR21),             # <<<<<<<<<<<<<<
 *         ('SR22', SR22),
 *         ('SR23', SR23),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR21); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_54 = PyTuple_New(2); if (unlikely(!__pyx_t_54)) __PYX_ERR(1, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_54);
    __Pyx_INCREF(__pyx_n_s_SR21);
    __Pyx_GIVEREF(__pyx_n_s_SR21);
    PyTuple_SET_ITEM(__pyx_t_54, 0, __pyx_n_s_SR21);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_54, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":106
 *         ('SR20', SR20),
 *         ('SR21', SR21),
 *         ('SR22', SR22),             # <<<<<<<<<<<<<<
 *         ('SR23', SR23),
 *         ('SR24', SR24),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR22); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_55 = PyTuple_New(2); if (unlikely(!__pyx_t_55)) __PYX_ERR(1, 106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_55);
    __Pyx_INCREF(__pyx_n_s_SR22);
    __Pyx_GIVEREF(__pyx_n_s_SR22);
    PyTuple_SET_ITEM(__pyx_t_55, 0, __pyx_n_s_SR22);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_55, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":107
 *         ('SR21', SR21),
 *         ('SR22', SR22),
 *         ('SR23', SR23),             # <<<<<<<<<<<<<<
 *         ('SR24', SR24),
 *         ('SR25', SR25),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR23); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_56 = PyTuple_New(2); if (unlikely(!__pyx_t_56)) __PYX_ERR(1, 107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_56);
    __Pyx_INCREF(__pyx_n_s_SR23);
    __Pyx_GIVEREF(__pyx_n_s_SR23);
    PyTuple_SET_ITEM(__pyx_t_56, 0, __pyx_n_s_SR23);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_56, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":108
 *         ('SR22', SR22),
 *         ('SR23', SR23),
 *         ('SR24', SR24),             # <<<<<<<<<<<<<<
 *         ('SR25', SR25),
 *         ('SR26', SR26),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR24); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_57 = PyTuple_New(2); if (unlikely(!__pyx_t_57)) __PYX_ERR(1, 108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_57);
    __Pyx_INCREF(__pyx_n_s_SR24);
    __Pyx_GIVEREF(__pyx_n_s_SR24);
    PyTuple_SET_ITEM(__pyx_t_57, 0, __pyx_n_s_SR24);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_57, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":109
 *         ('SR23', SR23),
 *         ('SR24', SR24),
 *         ('SR25', SR25),             # <<<<<<<<<<<<<<
 *         ('SR26', SR26),
 *         ('SR27', SR27),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR25); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_58 = PyTuple_New(2); if (unlikely(!__pyx_t_58)) __PYX_ERR(1, 109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_58);
    __Pyx_INCREF(__pyx_n_s_SR25);
    __Pyx_GIVEREF(__pyx_n_s_SR25);
    PyTuple_SET_ITEM(__pyx_t_58, 0, __pyx_n_s_SR25);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_58, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":110
 *         ('SR24', SR24),
 *         ('SR25', SR25),
 *         ('SR26', SR26),             # <<<<<<<<<<<<<<
 *         ('SR27', SR27),
 *         ('SR28', SR28),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR26); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_59 = PyTuple_New(2); if (unlikely(!__pyx_t_59)) __PYX_ERR(1, 110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_59);
    __Pyx_INCREF(__pyx_n_s_SR26);
    __Pyx_GIVEREF(__pyx_n_s_SR26);
    PyTuple_SET_ITEM(__pyx_t_59, 0, __pyx_n_s_SR26);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_59, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":111
 *         ('SR25', SR25),
 *         ('SR26', SR26),
 *         ('SR27', SR27),             # <<<<<<<<<<<<<<
 *         ('SR28', SR28),
 *         ('SR29', SR29),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR27); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_60 = PyTuple_New(2); if (unlikely(!__pyx_t_60)) __PYX_ERR(1, 111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_60);
    __Pyx_INCREF(__pyx_n_s_SR27);
    __Pyx_GIVEREF(__pyx_n_s_SR27);
    PyTuple_SET_ITEM(__pyx_t_60, 0, __pyx_n_s_SR27);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_60, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":112
 *         ('SR26', SR26),
 *         ('SR27', SR27),
 *         ('SR28', SR28),             # <<<<<<<<<<<<<<
 *         ('SR29', SR29),
 *         ('SR30', SR30),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR28); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_61 = PyTuple_New(2); if (unlikely(!__pyx_t_61)) __PYX_ERR(1, 112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_61);
    __Pyx_INCREF(__pyx_n_s_SR28);
    __Pyx_GIVEREF(__pyx_n_s_SR28);
    PyTuple_SET_ITEM(__pyx_t_61, 0, __pyx_n_s_SR28);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_61, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":113
 *         ('SR27', SR27),
 *         ('SR28', SR28),
 *         ('SR29', SR29),             # <<<<<<<<<<<<<<
 *         ('SR30', SR30),
 *         ('SR31', SR31),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR29); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_62 = PyTuple_New(2); if (unlikely(!__pyx_t_62)) __PYX_ERR(1, 113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_62);
    __Pyx_INCREF(__pyx_n_s_SR29);
    __Pyx_GIVEREF(__pyx_n_s_SR29);
    PyTuple_SET_ITEM(__pyx_t_62, 0, __pyx_n_s_SR29);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_62, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":114
 *         ('SR28', SR28),
 *         ('SR29', SR29),
 *         ('SR30', SR30),             # <<<<<<<<<<<<<<
 *         ('SR31', SR31),
 *         ('SR32', SR32),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR30); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_63 = PyTuple_New(2); if (unlikely(!__pyx_t_63)) __PYX_ERR(1, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_63);
    __Pyx_INCREF(__pyx_n_s_SR30);
    __Pyx_GIVEREF(__pyx_n_s_SR30);
    PyTuple_SET_ITEM(__pyx_t_63, 0, __pyx_n_s_SR30);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_63, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":115
 *         ('SR29', SR29),
 *         ('SR30', SR30),
 *         ('SR31', SR31),             # <<<<<<<<<<<<<<
 *         ('SR32', SR32),
 *         ('SR33', SR33),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR31); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_64 = PyTuple_New(2); if (unlikely(!__pyx_t_64)) __PYX_ERR(1, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_64);
    __Pyx_INCREF(__pyx_n_s_SR31);
    __Pyx_GIVEREF(__pyx_n_s_SR31);
    PyTuple_SET_ITEM(__pyx_t_64, 0, __pyx_n_s_SR31);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_64, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":116
 *         ('SR30', SR30),
 *         ('SR31', SR31),
 *         ('SR32', SR32),             # <<<<<<<<<<<<<<
 *         ('SR33', SR33),
 *         ('SR34', SR34),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR32); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_65 = PyTuple_New(2); if (unlikely(!__pyx_t_65)) __PYX_ERR(1, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_65);
    __Pyx_INCREF(__pyx_n_s_SR32);
    __Pyx_GIVEREF(__pyx_n_s_SR32);
    PyTuple_SET_ITEM(__pyx_t_65, 0, __pyx_n_s_SR32);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_65, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":117
 *         ('SR31', SR31),
 *         ('SR32', SR32),
 *         ('SR33', SR33),             # <<<<<<<<<<<<<<
 *         ('SR34', SR34),
 *         ('SR35', SR35),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR33); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_66 = PyTuple_New(2); if (unlikely(!__pyx_t_66)) __PYX_ERR(1, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_66);
    __Pyx_INCREF(__pyx_n_s_SR33);
    __Pyx_GIVEREF(__pyx_n_s_SR33);
    PyTuple_SET_ITEM(__pyx_t_66, 0, __pyx_n_s_SR33);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_66, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":118
 *         ('SR32', SR32),
 *         ('SR33', SR33),
 *         ('SR34', SR34),             # <<<<<<<<<<<<<<
 *         ('SR35', SR35),
 *         ('SR36', SR36),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR34); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_67 = PyTuple_New(2); if (unlikely(!__pyx_t_67)) __PYX_ERR(1, 118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_67);
    __Pyx_INCREF(__pyx_n_s_SR34);
    __Pyx_GIVEREF(__pyx_n_s_SR34);
    PyTuple_SET_ITEM(__pyx_t_67, 0, __pyx_n_s_SR34);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_67, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":119
 *         ('SR33', SR33),
 *         ('SR34', SR34),
 *         ('SR35', SR35),             # <<<<<<<<<<<<<<
 *         ('SR36', SR36),
 *         ('SR37', SR37),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR35); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_68 = PyTuple_New(2); if (unlikely(!__pyx_t_68)) __PYX_ERR(1, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_68);
    __Pyx_INCREF(__pyx_n_s_SR35);
    __Pyx_GIVEREF(__pyx_n_s_SR35);
    PyTuple_SET_ITEM(__pyx_t_68, 0, __pyx_n_s_SR35);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_68, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":120
 *         ('SR34', SR34),
 *         ('SR35', SR35),
 *         ('SR36', SR36),             # <<<<<<<<<<<<<<
 *         ('SR37', SR37),
 *         ('SR38', SR38),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR36); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_69 = PyTuple_New(2); if (unlikely(!__pyx_t_69)) __PYX_ERR(1, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_69);
    __Pyx_INCREF(__pyx_n_s_SR36);
    __Pyx_GIVEREF(__pyx_n_s_SR36);
    PyTuple_SET_ITEM(__pyx_t_69, 0, __pyx_n_s_SR36);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_69, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":121
 *         ('SR35', SR35),
 *         ('SR36', SR36),
 *         ('SR37', SR37),             # <<<<<<<<<<<<<<
 *         ('SR38', SR38),
 *         ('SR39', SR39),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR37); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_70 = PyTuple_New(2); if (unlikely(!__pyx_t_70)) __PYX_ERR(1, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_70);
    __Pyx_INCREF(__pyx_n_s_SR37);
    __Pyx_GIVEREF(__pyx_n_s_SR37);
    PyTuple_SET_ITEM(__pyx_t_70, 0, __pyx_n_s_SR37);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_70, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":122
 *         ('SR36', SR36),
 *         ('SR37', SR37),
 *         ('SR38', SR38),             # <<<<<<<<<<<<<<
 *         ('SR39', SR39),
 *         ('SR40', SR40),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR38); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_71 = PyTuple_New(2); if (unlikely(!__pyx_t_71)) __PYX_ERR(1, 122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_71);
    __Pyx_INCREF(__pyx_n_s_SR38);
    __Pyx_GIVEREF(__pyx_n_s_SR38);
    PyTuple_SET_ITEM(__pyx_t_71, 0, __pyx_n_s_SR38);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_71, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":123
 *         ('SR37', SR37),
 *         ('SR38', SR38),
 *         ('SR39', SR39),             # <<<<<<<<<<<<<<
 *         ('SR40', SR40),
 *         ('SR41', SR41),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR39); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_72 = PyTuple_New(2); if (unlikely(!__pyx_t_72)) __PYX_ERR(1, 123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_72);
    __Pyx_INCREF(__pyx_n_s_SR39);
    __Pyx_GIVEREF(__pyx_n_s_SR39);
    PyTuple_SET_ITEM(__pyx_t_72, 0, __pyx_n_s_SR39);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_72, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":124
 *         ('SR38', SR38),
 *         ('SR39', SR39),
 *         ('SR40', SR40),             # <<<<<<<<<<<<<<
 *         ('SR41', SR41),
 *         ('SR42', SR42),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR40); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_73 = PyTuple_New(2); if (unlikely(!__pyx_t_73)) __PYX_ERR(1, 124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_73);
    __Pyx_INCREF(__pyx_n_s_SR40);
    __Pyx_GIVEREF(__pyx_n_s_SR40);
    PyTuple_SET_ITEM(__pyx_t_73, 0, __pyx_n_s_SR40);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_73, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":125
 *         ('SR39', SR39),
 *         ('SR40', SR40),
 *         ('SR41', SR41),             # <<<<<<<<<<<<<<
 *         ('SR42', SR42),
 *         ('SR43', SR43),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR41); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_74 = PyTuple_New(2); if (unlikely(!__pyx_t_74)) __PYX_ERR(1, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_74);
    __Pyx_INCREF(__pyx_n_s_SR41);
    __Pyx_GIVEREF(__pyx_n_s_SR41);
    PyTuple_SET_ITEM(__pyx_t_74, 0, __pyx_n_s_SR41);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_74, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":126
 *         ('SR40', SR40),
 *         ('SR41', SR41),
 *         ('SR42', SR42),             # <<<<<<<<<<<<<<
 *         ('SR43', SR43),
 *         ('SR44', SR44),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR42); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_75 = PyTuple_New(2); if (unlikely(!__pyx_t_75)) __PYX_ERR(1, 126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_75);
    __Pyx_INCREF(__pyx_n_s_SR42);
    __Pyx_GIVEREF(__pyx_n_s_SR42);
    PyTuple_SET_ITEM(__pyx_t_75, 0, __pyx_n_s_SR42);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_75, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":127
 *         ('SR41', SR41),
 *         ('SR42', SR42),
 *         ('SR43', SR43),             # <<<<<<<<<<<<<<
 *         ('SR44', SR44),
 *         ('SR45', SR45),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR43); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_76 = PyTuple_New(2); if (unlikely(!__pyx_t_76)) __PYX_ERR(1, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_76);
    __Pyx_INCREF(__pyx_n_s_SR43);
    __Pyx_GIVEREF(__pyx_n_s_SR43);
    PyTuple_SET_ITEM(__pyx_t_76, 0, __pyx_n_s_SR43);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_76, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":128
 *         ('SR42', SR42),
 *         ('SR43', SR43),
 *         ('SR44', SR44),             # <<<<<<<<<<<<<<
 *         ('SR45', SR45),
 *         ('SR46', SR46),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR44); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 128, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_77 = PyTuple_New(2); if (unlikely(!__pyx_t_77)) __PYX_ERR(1, 128, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_77);
    __Pyx_INCREF(__pyx_n_s_SR44);
    __Pyx_GIVEREF(__pyx_n_s_SR44);
    PyTuple_SET_ITEM(__pyx_t_77, 0, __pyx_n_s_SR44);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_77, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":129
 *         ('SR43', SR43),
 *         ('SR44', SR44),
 *         ('SR45', SR45),             # <<<<<<<<<<<<<<
 *         ('SR46', SR46),
 *         ('SR47', SR47),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR45); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_78 = PyTuple_New(2); if (unlikely(!__pyx_t_78)) __PYX_ERR(1, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_78);
    __Pyx_INCREF(__pyx_n_s_SR45);
    __Pyx_GIVEREF(__pyx_n_s_SR45);
    PyTuple_SET_ITEM(__pyx_t_78, 0, __pyx_n_s_SR45);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_78, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":130
 *         ('SR44', SR44),
 *         ('SR45', SR45),
 *         ('SR46', SR46),             # <<<<<<<<<<<<<<
 *         ('SR47', SR47),
 *         ('SR48', SR48),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR46); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_79 = PyTuple_New(2); if (unlikely(!__pyx_t_79)) __PYX_ERR(1, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_79);
    __Pyx_INCREF(__pyx_n_s_SR46);
    __Pyx_GIVEREF(__pyx_n_s_SR46);
    PyTuple_SET_ITEM(__pyx_t_79, 0, __pyx_n_s_SR46);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_79, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":131
 *         ('SR45', SR45),
 *         ('SR46', SR46),
 *         ('SR47', SR47),             # <<<<<<<<<<<<<<
 *         ('SR48', SR48),
 *         ('SR49', SR49),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR47); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_80 = PyTuple_New(2); if (unlikely(!__pyx_t_80)) __PYX_ERR(1, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_80);
    __Pyx_INCREF(__pyx_n_s_SR47);
    __Pyx_GIVEREF(__pyx_n_s_SR47);
    PyTuple_SET_ITEM(__pyx_t_80, 0, __pyx_n_s_SR47);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_80, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":132
 *         ('SR46', SR46),
 *         ('SR47', SR47),
 *         ('SR48', SR48),             # <<<<<<<<<<<<<<
 *         ('SR49', SR49),
 *         ('SR50', SR50),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR48); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_81 = PyTuple_New(2); if (unlikely(!__pyx_t_81)) __PYX_ERR(1, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_81);
    __Pyx_INCREF(__pyx_n_s_SR48);
    __Pyx_GIVEREF(__pyx_n_s_SR48);
    PyTuple_SET_ITEM(__pyx_t_81, 0, __pyx_n_s_SR48);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_81, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":133
 *         ('SR47', SR47),
 *         ('SR48', SR48),
 *         ('SR49', SR49),             # <<<<<<<<<<<<<<
 *         ('SR50', SR50),
 *         ('SR51', SR51),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR49); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_82 = PyTuple_New(2); if (unlikely(!__pyx_t_82)) __PYX_ERR(1, 133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_82);
    __Pyx_INCREF(__pyx_n_s_SR49);
    __Pyx_GIVEREF(__pyx_n_s_SR49);
    PyTuple_SET_ITEM(__pyx_t_82, 0, __pyx_n_s_SR49);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_82, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":134
 *         ('SR48', SR48),
 *         ('SR49', SR49),
 *         ('SR50', SR50),             # <<<<<<<<<<<<<<
 *         ('SR51', SR51),
 *         ('SR52', SR52),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR50); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_83 = PyTuple_New(2); if (unlikely(!__pyx_t_83)) __PYX_ERR(1, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_83);
    __Pyx_INCREF(__pyx_n_s_SR50);
    __Pyx_GIVEREF(__pyx_n_s_SR50);
    PyTuple_SET_ITEM(__pyx_t_83, 0, __pyx_n_s_SR50);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_83, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":135
 *         ('SR49', SR49),
 *         ('SR50', SR50),
 *         ('SR51', SR51),             # <<<<<<<<<<<<<<
 *         ('SR52', SR52),
 *         ('SR53', SR53),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR51); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_84 = PyTuple_New(2); if (unlikely(!__pyx_t_84)) __PYX_ERR(1, 135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_84);
    __Pyx_INCREF(__pyx_n_s_SR51);
    __Pyx_GIVEREF(__pyx_n_s_SR51);
    PyTuple_SET_ITEM(__pyx_t_84, 0, __pyx_n_s_SR51);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_84, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":136
 *         ('SR50', SR50),
 *         ('SR51', SR51),
 *         ('SR52', SR52),             # <<<<<<<<<<<<<<
 *         ('SR53', SR53),
 *         ('SR54', SR54),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR52); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_85 = PyTuple_New(2); if (unlikely(!__pyx_t_85)) __PYX_ERR(1, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_85);
    __Pyx_INCREF(__pyx_n_s_SR52);
    __Pyx_GIVEREF(__pyx_n_s_SR52);
    PyTuple_SET_ITEM(__pyx_t_85, 0, __pyx_n_s_SR52);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_85, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":137
 *         ('SR51', SR51),
 *         ('SR52', SR52),
 *         ('SR53', SR53),             # <<<<<<<<<<<<<<
 *         ('SR54', SR54),
 *         ('SR55', SR55),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR53); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_86 = PyTuple_New(2); if (unlikely(!__pyx_t_86)) __PYX_ERR(1, 137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_86);
    __Pyx_INCREF(__pyx_n_s_SR53);
    __Pyx_GIVEREF(__pyx_n_s_SR53);
    PyTuple_SET_ITEM(__pyx_t_86, 0, __pyx_n_s_SR53);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_86, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":138
 *         ('SR52', SR52),
 *         ('SR53', SR53),
 *         ('SR54', SR54),             # <<<<<<<<<<<<<<
 *         ('SR55', SR55),
 *         ('SR56', SR56),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR54); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_87 = PyTuple_New(2); if (unlikely(!__pyx_t_87)) __PYX_ERR(1, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_87);
    __Pyx_INCREF(__pyx_n_s_SR54);
    __Pyx_GIVEREF(__pyx_n_s_SR54);
    PyTuple_SET_ITEM(__pyx_t_87, 0, __pyx_n_s_SR54);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_87, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":139
 *         ('SR53', SR53),
 *         ('SR54', SR54),
 *         ('SR55', SR55),             # <<<<<<<<<<<<<<
 *         ('SR56', SR56),
 *         ('SR57', SR57),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR55); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_88 = PyTuple_New(2); if (unlikely(!__pyx_t_88)) __PYX_ERR(1, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_88);
    __Pyx_INCREF(__pyx_n_s_SR55);
    __Pyx_GIVEREF(__pyx_n_s_SR55);
    PyTuple_SET_ITEM(__pyx_t_88, 0, __pyx_n_s_SR55);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_88, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":140
 *         ('SR54', SR54),
 *         ('SR55', SR55),
 *         ('SR56', SR56),             # <<<<<<<<<<<<<<
 *         ('SR57', SR57),
 *         ('SR58', SR58),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR56); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_89 = PyTuple_New(2); if (unlikely(!__pyx_t_89)) __PYX_ERR(1, 140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_89);
    __Pyx_INCREF(__pyx_n_s_SR56);
    __Pyx_GIVEREF(__pyx_n_s_SR56);
    PyTuple_SET_ITEM(__pyx_t_89, 0, __pyx_n_s_SR56);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_89, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":141
 *         ('SR55', SR55),
 *         ('SR56', SR56),
 *         ('SR57', SR57),             # <<<<<<<<<<<<<<
 *         ('SR58', SR58),
 *         ('SR59', SR59),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR57); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_90 = PyTuple_New(2); if (unlikely(!__pyx_t_90)) __PYX_ERR(1, 141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_90);
    __Pyx_INCREF(__pyx_n_s_SR57);
    __Pyx_GIVEREF(__pyx_n_s_SR57);
    PyTuple_SET_ITEM(__pyx_t_90, 0, __pyx_n_s_SR57);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_90, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":142
 *         ('SR56', SR56),
 *         ('SR57', SR57),
 *         ('SR58', SR58),             # <<<<<<<<<<<<<<
 *         ('SR59', SR59),
 *         ('SR60', SR60),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR58); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_91 = PyTuple_New(2); if (unlikely(!__pyx_t_91)) __PYX_ERR(1, 142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_91);
    __Pyx_INCREF(__pyx_n_s_SR58);
    __Pyx_GIVEREF(__pyx_n_s_SR58);
    PyTuple_SET_ITEM(__pyx_t_91, 0, __pyx_n_s_SR58);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_91, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":143
 *         ('SR57', SR57),
 *         ('SR58', SR58),
 *         ('SR59', SR59),             # <<<<<<<<<<<<<<
 *         ('SR60', SR60),
 *         ('SR61', SR61),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR59); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 143, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_92 = PyTuple_New(2); if (unlikely(!__pyx_t_92)) __PYX_ERR(1, 143, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_92);
    __Pyx_INCREF(__pyx_n_s_SR59);
    __Pyx_GIVEREF(__pyx_n_s_SR59);
    PyTuple_SET_ITEM(__pyx_t_92, 0, __pyx_n_s_SR59);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_92, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":144
 *         ('SR58', SR58),
 *         ('SR59', SR59),
 *         ('SR60', SR60),             # <<<<<<<<<<<<<<
 *         ('SR61', SR61),
 *         ('SR62', SR62),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR60); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_93 = PyTuple_New(2); if (unlikely(!__pyx_t_93)) __PYX_ERR(1, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_93);
    __Pyx_INCREF(__pyx_n_s_SR60);
    __Pyx_GIVEREF(__pyx_n_s_SR60);
    PyTuple_SET_ITEM(__pyx_t_93, 0, __pyx_n_s_SR60);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_93, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":145
 *         ('SR59', SR59),
 *         ('SR60', SR60),
 *         ('SR61', SR61),             # <<<<<<<<<<<<<<
 *         ('SR62', SR62),
 *         ('SR63', SR63),
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR61); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 145, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_94 = PyTuple_New(2); if (unlikely(!__pyx_t_94)) __PYX_ERR(1, 145, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_94);
    __Pyx_INCREF(__pyx_n_s_SR61);
    __Pyx_GIVEREF(__pyx_n_s_SR61);
    PyTuple_SET_ITEM(__pyx_t_94, 0, __pyx_n_s_SR61);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_94, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":146
 *         ('SR60', SR60),
 *         ('SR61', SR61),
 *         ('SR62', SR62),             # <<<<<<<<<<<<<<
 *         ('SR63', SR63),
 *     ]))
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR62); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR62);
    __Pyx_GIVEREF(__pyx_n_s_SR62);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_n_s_SR62);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":147
 *         ('SR61', SR61),
 *         ('SR62', SR62),
 *         ('SR63', SR63),             # <<<<<<<<<<<<<<
 *     ]))
 *     __Pyx_globals['USRCC'] = VERegIds.USRCC
 */
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR63); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR63);
    __Pyx_GIVEREF(__pyx_n_s_SR63);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_n_s_SR63);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "EnumType":53
 * if PY_VERSION_HEX >= 0x03040000:
 * 
 *     VERegIds = __Pyx_EnumBase('VERegIds', __Pyx_OrderedDict([             # <<<<<<<<<<<<<<
 *         ('USRCC', USRCC),
 *         ('PMC00', PMC00),
 */
    __pyx_t_3 = PyList_New(94); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyList_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyList_SET_ITEM(__pyx_t_3, 2, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_7);
    PyList_SET_ITEM(__pyx_t_3, 3, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_8);
    PyList_SET_ITEM(__pyx_t_3, 4, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_9);
    PyList_SET_ITEM(__pyx_t_3, 5, __pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_10);
    PyList_SET_ITEM(__pyx_t_3, 6, __pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_11);
    PyList_SET_ITEM(__pyx_t_3, 7, __pyx_t_11);
    __Pyx_GIVEREF(__pyx_t_12);
    PyList_SET_ITEM(__pyx_t_3, 8, __pyx_t_12);
    __Pyx_GIVEREF(__pyx_t_13);
    PyList_SET_ITEM(__pyx_t_3, 9, __pyx_t_13);
    __Pyx_GIVEREF(__pyx_t_14);
    PyList_SET_ITEM(__pyx_t_3, 10, __pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyList_SET_ITEM(__pyx_t_3, 11, __pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_16);
    PyList_SET_ITEM(__pyx_t_3, 12, __pyx_t_16);
    __Pyx_GIVEREF(__pyx_t_17);
    PyList_SET_ITEM(__pyx_t_3, 13, __pyx_t_17);
    __Pyx_GIVEREF(__pyx_t_18);
    PyList_SET_ITEM(__pyx_t_3, 14, __pyx_t_18);
    __Pyx_GIVEREF(__pyx_t_19);
    PyList_SET_ITEM(__pyx_t_3, 15, __pyx_t_19);
    __Pyx_GIVEREF(__pyx_t_2);
    PyList_SET_ITEM(__pyx_t_3, 16, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_3, 17, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_21);
    PyList_SET_ITEM(__pyx_t_3, 18, __pyx_t_21);
    __Pyx_GIVEREF(__pyx_t_22);
    PyList_SET_ITEM(__pyx_t_3, 19, __pyx_t_22);
    __Pyx_GIVEREF(__pyx_t_23);
    PyList_SET_ITEM(__pyx_t_3, 20, __pyx_t_23);
    __Pyx_GIVEREF(__pyx_t_24);
    PyList_SET_ITEM(__pyx_t_3, 21, __pyx_t_24);
    __Pyx_GIVEREF(__pyx_t_25);
    PyList_SET_ITEM(__pyx_t_3, 22, __pyx_t_25);
    __Pyx_GIVEREF(__pyx_t_26);
    PyList_SET_ITEM(__pyx_t_3, 23, __pyx_t_26);
    __Pyx_GIVEREF(__pyx_t_27);
    PyList_SET_ITEM(__pyx_t_3, 24, __pyx_t_27);
    __Pyx_GIVEREF(__pyx_t_28);
    PyList_SET_ITEM(__pyx_t_3, 25, __pyx_t_28);
    __Pyx_GIVEREF(__pyx_t_29);
    PyList_SET_ITEM(__pyx_t_3, 26, __pyx_t_29);
    __Pyx_GIVEREF(__pyx_t_30);
    PyList_SET_ITEM(__pyx_t_3, 27, __pyx_t_30);
    __Pyx_GIVEREF(__pyx_t_31);
    PyList_SET_ITEM(__pyx_t_3, 28, __pyx_t_31);
    __Pyx_GIVEREF(__pyx_t_32);
    PyList_SET_ITEM(__pyx_t_3, 29, __pyx_t_32);
    __Pyx_GIVEREF(__pyx_t_33);
    PyList_SET_ITEM(__pyx_t_3, 30, __pyx_t_33);
    __Pyx_GIVEREF(__pyx_t_34);
    PyList_SET_ITEM(__pyx_t_3, 31, __pyx_t_34);
    __Pyx_GIVEREF(__pyx_t_35);
    PyList_SET_ITEM(__pyx_t_3, 32, __pyx_t_35);
    __Pyx_GIVEREF(__pyx_t_36);
    PyList_SET_ITEM(__pyx_t_3, 33, __pyx_t_36);
    __Pyx_GIVEREF(__pyx_t_37);
    PyList_SET_ITEM(__pyx_t_3, 34, __pyx_t_37);
    __Pyx_GIVEREF(__pyx_t_38);
    PyList_SET_ITEM(__pyx_t_3, 35, __pyx_t_38);
    __Pyx_GIVEREF(__pyx_t_39);
    PyList_SET_ITEM(__pyx_t_3, 36, __pyx_t_39);
    __Pyx_GIVEREF(__pyx_t_40);
    PyList_SET_ITEM(__pyx_t_3, 37, __pyx_t_40);
    __Pyx_GIVEREF(__pyx_t_41);
    PyList_SET_ITEM(__pyx_t_3, 38, __pyx_t_41);
    __Pyx_GIVEREF(__pyx_t_42);
    PyList_SET_ITEM(__pyx_t_3, 39, __pyx_t_42);
    __Pyx_GIVEREF(__pyx_t_43);
    PyList_SET_ITEM(__pyx_t_3, 40, __pyx_t_43);
    __Pyx_GIVEREF(__pyx_t_44);
    PyList_SET_ITEM(__pyx_t_3, 41, __pyx_t_44);
    __Pyx_GIVEREF(__pyx_t_45);
    PyList_SET_ITEM(__pyx_t_3, 42, __pyx_t_45);
    __Pyx_GIVEREF(__pyx_t_46);
    PyList_SET_ITEM(__pyx_t_3, 43, __pyx_t_46);
    __Pyx_GIVEREF(__pyx_t_47);
    PyList_SET_ITEM(__pyx_t_3, 44, __pyx_t_47);
    __Pyx_GIVEREF(__pyx_t_48);
    PyList_SET_ITEM(__pyx_t_3, 45, __pyx_t_48);
    __Pyx_GIVEREF(__pyx_t_49);
    PyList_SET_ITEM(__pyx_t_3, 46, __pyx_t_49);
    __Pyx_GIVEREF(__pyx_t_50);
    PyList_SET_ITEM(__pyx_t_3, 47, __pyx_t_50);
    __Pyx_GIVEREF(__pyx_t_51);
    PyList_SET_ITEM(__pyx_t_3, 48, __pyx_t_51);
    __Pyx_GIVEREF(__pyx_t_52);
    PyList_SET_ITEM(__pyx_t_3, 49, __pyx_t_52);
    __Pyx_GIVEREF(__pyx_t_53);
    PyList_SET_ITEM(__pyx_t_3, 50, __pyx_t_53);
    __Pyx_GIVEREF(__pyx_t_54);
    PyList_SET_ITEM(__pyx_t_3, 51, __pyx_t_54);
    __Pyx_GIVEREF(__pyx_t_55);
    PyList_SET_ITEM(__pyx_t_3, 52, __pyx_t_55);
    __Pyx_GIVEREF(__pyx_t_56);
    PyList_SET_ITEM(__pyx_t_3, 53, __pyx_t_56);
    __Pyx_GIVEREF(__pyx_t_57);
    PyList_SET_ITEM(__pyx_t_3, 54, __pyx_t_57);
    __Pyx_GIVEREF(__pyx_t_58);
    PyList_SET_ITEM(__pyx_t_3, 55, __pyx_t_58);
    __Pyx_GIVEREF(__pyx_t_59);
    PyList_SET_ITEM(__pyx_t_3, 56, __pyx_t_59);
    __Pyx_GIVEREF(__pyx_t_60);
    PyList_SET_ITEM(__pyx_t_3, 57, __pyx_t_60);
    __Pyx_GIVEREF(__pyx_t_61);
    PyList_SET_ITEM(__pyx_t_3, 58, __pyx_t_61);
    __Pyx_GIVEREF(__pyx_t_62);
    PyList_SET_ITEM(__pyx_t_3, 59, __pyx_t_62);
    __Pyx_GIVEREF(__pyx_t_63);
    PyList_SET_ITEM(__pyx_t_3, 60, __pyx_t_63);
    __Pyx_GIVEREF(__pyx_t_64);
    PyList_SET_ITEM(__pyx_t_3, 61, __pyx_t_64);
    __Pyx_GIVEREF(__pyx_t_65);
    PyList_SET_ITEM(__pyx_t_3, 62, __pyx_t_65);
    __Pyx_GIVEREF(__pyx_t_66);
    PyList_SET_ITEM(__pyx_t_3, 63, __pyx_t_66);
    __Pyx_GIVEREF(__pyx_t_67);
    PyList_SET_ITEM(__pyx_t_3, 64, __pyx_t_67);
    __Pyx_GIVEREF(__pyx_t_68);
    PyList_SET_ITEM(__pyx_t_3, 65, __pyx_t_68);
    __Pyx_GIVEREF(__pyx_t_69);
    PyList_SET_ITEM(__pyx_t_3, 66, __pyx_t_69);
    __Pyx_GIVEREF(__pyx_t_70);
    PyList_SET_ITEM(__pyx_t_3, 67, __pyx_t_70);
    __Pyx_GIVEREF(__pyx_t_71);
    PyList_SET_ITEM(__pyx_t_3, 68, __pyx_t_71);
    __Pyx_GIVEREF(__pyx_t_72);
    PyList_SET_ITEM(__pyx_t_3, 69, __pyx_t_72);
    __Pyx_GIVEREF(__pyx_t_73);
    PyList_SET_ITEM(__pyx_t_3, 70, __pyx_t_73);
    __Pyx_GIVEREF(__pyx_t_74);
    PyList_SET_ITEM(__pyx_t_3, 71, __pyx_t_74);
    __Pyx_GIVEREF(__pyx_t_75);
    PyList_SET_ITEM(__pyx_t_3, 72, __pyx_t_75);
    __Pyx_GIVEREF(__pyx_t_76);
    PyList_SET_ITEM(__pyx_t_3, 73, __pyx_t_76);
    __Pyx_GIVEREF(__pyx_t_77);
    PyList_SET_ITEM(__pyx_t_3, 74, __pyx_t_77);
    __Pyx_GIVEREF(__pyx_t_78);
    PyList_SET_ITEM(__pyx_t_3, 75, __pyx_t_78);
    __Pyx_GIVEREF(__pyx_t_79);
    PyList_SET_ITEM(__pyx_t_3, 76, __pyx_t_79);
    __Pyx_GIVEREF(__pyx_t_80);
    PyList_SET_ITEM(__pyx_t_3, 77, __pyx_t_80);
    __Pyx_GIVEREF(__pyx_t_81);
    PyList_SET_ITEM(__pyx_t_3, 78, __pyx_t_81);
    __Pyx_GIVEREF(__pyx_t_82);
    PyList_SET_ITEM(__pyx_t_3, 79, __pyx_t_82);
    __Pyx_GIVEREF(__pyx_t_83);
    PyList_SET_ITEM(__pyx_t_3, 80, __pyx_t_83);
    __Pyx_GIVEREF(__pyx_t_84);
    PyList_SET_ITEM(__pyx_t_3, 81, __pyx_t_84);
    __Pyx_GIVEREF(__pyx_t_85);
    PyList_SET_ITEM(__pyx_t_3, 82, __pyx_t_85);
    __Pyx_GIVEREF(__pyx_t_86);
    PyList_SET_ITEM(__pyx_t_3, 83, __pyx_t_86);
    __Pyx_GIVEREF(__pyx_t_87);
    PyList_SET_ITEM(__pyx_t_3, 84, __pyx_t_87);
    __Pyx_GIVEREF(__pyx_t_88);
    PyList_SET_ITEM(__pyx_t_3, 85, __pyx_t_88);
    __Pyx_GIVEREF(__pyx_t_89);
    PyList_SET_ITEM(__pyx_t_3, 86, __pyx_t_89);
    __Pyx_GIVEREF(__pyx_t_90);
    PyList_SET_ITEM(__pyx_t_3, 87, __pyx_t_90);
    __Pyx_GIVEREF(__pyx_t_91);
    PyList_SET_ITEM(__pyx_t_3, 88, __pyx_t_91);
    __Pyx_GIVEREF(__pyx_t_92);
    PyList_SET_ITEM(__pyx_t_3, 89, __pyx_t_92);
    __Pyx_GIVEREF(__pyx_t_93);
    PyList_SET_ITEM(__pyx_t_3, 90, __pyx_t_93);
    __Pyx_GIVEREF(__pyx_t_94);
    PyList_SET_ITEM(__pyx_t_3, 91, __pyx_t_94);
    __Pyx_GIVEREF(__pyx_t_95);
    PyList_SET_ITEM(__pyx_t_3, 92, __pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_96);
    PyList_SET_ITEM(__pyx_t_3, 93, __pyx_t_96);
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    __pyx_t_8 = 0;
    __pyx_t_9 = 0;
    __pyx_t_10 = 0;
    __pyx_t_11 = 0;
    __pyx_t_12 = 0;
    __pyx_t_13 = 0;
    __pyx_t_14 = 0;
    __pyx_t_15 = 0;
    __pyx_t_16 = 0;
    __pyx_t_17 = 0;
    __pyx_t_18 = 0;
    __pyx_t_19 = 0;
    __pyx_t_2 = 0;
    __pyx_t_1 = 0;
    __pyx_t_21 = 0;
    __pyx_t_22 = 0;
    __pyx_t_23 = 0;
    __pyx_t_24 = 0;
    __pyx_t_25 = 0;
    __pyx_t_26 = 0;
    __pyx_t_27 = 0;
    __pyx_t_28 = 0;
    __pyx_t_29 = 0;
    __pyx_t_30 = 0;
    __pyx_t_31 = 0;
    __pyx_t_32 = 0;
    __pyx_t_33 = 0;
    __pyx_t_34 = 0;
    __pyx_t_35 = 0;
    __pyx_t_36 = 0;
    __pyx_t_37 = 0;
    __pyx_t_38 = 0;
    __pyx_t_39 = 0;
    __pyx_t_40 = 0;
    __pyx_t_41 = 0;
    __pyx_t_42 = 0;
    __pyx_t_43 = 0;
    __pyx_t_44 = 0;
    __pyx_t_45 = 0;
    __pyx_t_46 = 0;
    __pyx_t_47 = 0;
    __pyx_t_48 = 0;
    __pyx_t_49 = 0;
    __pyx_t_50 = 0;
    __pyx_t_51 = 0;
    __pyx_t_52 = 0;
    __pyx_t_53 = 0;
    __pyx_t_54 = 0;
    __pyx_t_55 = 0;
    __pyx_t_56 = 0;
    __pyx_t_57 = 0;
    __pyx_t_58 = 0;
    __pyx_t_59 = 0;
    __pyx_t_60 = 0;
    __pyx_t_61 = 0;
    __pyx_t_62 = 0;
    __pyx_t_63 = 0;
    __pyx_t_64 = 0;
    __pyx_t_65 = 0;
    __pyx_t_66 = 0;
    __pyx_t_67 = 0;
    __pyx_t_68 = 0;
    __pyx_t_69 = 0;
    __pyx_t_70 = 0;
    __pyx_t_71 = 0;
    __pyx_t_72 = 0;
    __pyx_t_73 = 0;
    __pyx_t_74 = 0;
    __pyx_t_75 = 0;
    __pyx_t_76 = 0;
    __pyx_t_77 = 0;
    __pyx_t_78 = 0;
    __pyx_t_79 = 0;
    __pyx_t_80 = 0;
    __pyx_t_81 = 0;
    __pyx_t_82 = 0;
    __pyx_t_83 = 0;
    __pyx_t_84 = 0;
    __pyx_t_85 = 0;
    __pyx_t_86 = 0;
    __pyx_t_87 = 0;
    __pyx_t_88 = 0;
    __pyx_t_89 = 0;
    __pyx_t_90 = 0;
    __pyx_t_91 = 0;
    __pyx_t_92 = 0;
    __pyx_t_93 = 0;
    __pyx_t_94 = 0;
    __pyx_t_95 = 0;
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_CallOneArg(__Pyx_OrderedDict, __pyx_t_3); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_VERegIds);
    __Pyx_GIVEREF(__pyx_n_s_VERegIds);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_VERegIds);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_96);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__Pyx_EnumBase, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_VERegIds, __pyx_t_96) < 0) __PYX_ERR(1, 53, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":149
 *         ('SR63', SR63),
 *     ]))
 *     __Pyx_globals['USRCC'] = VERegIds.USRCC             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC00'] = VERegIds.PMC00
 *     __Pyx_globals['PMC01'] = VERegIds.PMC01
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_USRCC); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 149, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_USRCC, __pyx_t_3) < 0)) __PYX_ERR(1, 149, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":150
 *     ]))
 *     __Pyx_globals['USRCC'] = VERegIds.USRCC
 *     __Pyx_globals['PMC00'] = VERegIds.PMC00             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC01'] = VERegIds.PMC01
 *     __Pyx_globals['PMC02'] = VERegIds.PMC02
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMC00); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 150, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC00, __pyx_t_96) < 0)) __PYX_ERR(1, 150, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":151
 *     __Pyx_globals['USRCC'] = VERegIds.USRCC
 *     __Pyx_globals['PMC00'] = VERegIds.PMC00
 *     __Pyx_globals['PMC01'] = VERegIds.PMC01             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC02'] = VERegIds.PMC02
 *     __Pyx_globals['PMC03'] = VERegIds.PMC03
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMC01); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 151, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC01, __pyx_t_3) < 0)) __PYX_ERR(1, 151, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":152
 *     __Pyx_globals['PMC00'] = VERegIds.PMC00
 *     __Pyx_globals['PMC01'] = VERegIds.PMC01
 *     __Pyx_globals['PMC02'] = VERegIds.PMC02             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC03'] = VERegIds.PMC03
 *     __Pyx_globals['PMC04'] = VERegIds.PMC04
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMC02); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 152, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC02, __pyx_t_96) < 0)) __PYX_ERR(1, 152, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":153
 *     __Pyx_globals['PMC01'] = VERegIds.PMC01
 *     __Pyx_globals['PMC02'] = VERegIds.PMC02
 *     __Pyx_globals['PMC03'] = VERegIds.PMC03             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC04'] = VERegIds.PMC04
 *     __Pyx_globals['PMC05'] = VERegIds.PMC05
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMC03); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 153, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC03, __pyx_t_3) < 0)) __PYX_ERR(1, 153, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":154
 *     __Pyx_globals['PMC02'] = VERegIds.PMC02
 *     __Pyx_globals['PMC03'] = VERegIds.PMC03
 *     __Pyx_globals['PMC04'] = VERegIds.PMC04             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC05'] = VERegIds.PMC05
 *     __Pyx_globals['PMC06'] = VERegIds.PMC06
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMC04); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 154, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC04, __pyx_t_96) < 0)) __PYX_ERR(1, 154, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":155
 *     __Pyx_globals['PMC03'] = VERegIds.PMC03
 *     __Pyx_globals['PMC04'] = VERegIds.PMC04
 *     __Pyx_globals['PMC05'] = VERegIds.PMC05             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC06'] = VERegIds.PMC06
 *     __Pyx_globals['PMC07'] = VERegIds.PMC07
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMC05); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 155, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC05, __pyx_t_3) < 0)) __PYX_ERR(1, 155, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":156
 *     __Pyx_globals['PMC04'] = VERegIds.PMC04
 *     __Pyx_globals['PMC05'] = VERegIds.PMC05
 *     __Pyx_globals['PMC06'] = VERegIds.PMC06             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC07'] = VERegIds.PMC07
 *     __Pyx_globals['PMC08'] = VERegIds.PMC08
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMC06); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 156, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC06, __pyx_t_96) < 0)) __PYX_ERR(1, 156, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":157
 *     __Pyx_globals['PMC05'] = VERegIds.PMC05
 *     __Pyx_globals['PMC06'] = VERegIds.PMC06
 *     __Pyx_globals['PMC07'] = VERegIds.PMC07             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC08'] = VERegIds.PMC08
 *     __Pyx_globals['PMC09'] = VERegIds.PMC09
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 157, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMC07); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 157, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 157, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC07, __pyx_t_3) < 0)) __PYX_ERR(1, 157, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":158
 *     __Pyx_globals['PMC06'] = VERegIds.PMC06
 *     __Pyx_globals['PMC07'] = VERegIds.PMC07
 *     __Pyx_globals['PMC08'] = VERegIds.PMC08             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC09'] = VERegIds.PMC09
 *     __Pyx_globals['PMC10'] = VERegIds.PMC10
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMC08); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 158, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC08, __pyx_t_96) < 0)) __PYX_ERR(1, 158, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":159
 *     __Pyx_globals['PMC07'] = VERegIds.PMC07
 *     __Pyx_globals['PMC08'] = VERegIds.PMC08
 *     __Pyx_globals['PMC09'] = VERegIds.PMC09             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC10'] = VERegIds.PMC10
 *     __Pyx_globals['PMC11'] = VERegIds.PMC11
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMC09); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 159, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC09, __pyx_t_3) < 0)) __PYX_ERR(1, 159, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":160
 *     __Pyx_globals['PMC08'] = VERegIds.PMC08
 *     __Pyx_globals['PMC09'] = VERegIds.PMC09
 *     __Pyx_globals['PMC10'] = VERegIds.PMC10             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC11'] = VERegIds.PMC11
 *     __Pyx_globals['PMC12'] = VERegIds.PMC12
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMC10); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 160, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC10, __pyx_t_96) < 0)) __PYX_ERR(1, 160, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":161
 *     __Pyx_globals['PMC09'] = VERegIds.PMC09
 *     __Pyx_globals['PMC10'] = VERegIds.PMC10
 *     __Pyx_globals['PMC11'] = VERegIds.PMC11             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC12'] = VERegIds.PMC12
 *     __Pyx_globals['PMC13'] = VERegIds.PMC13
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMC11); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 161, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC11, __pyx_t_3) < 0)) __PYX_ERR(1, 161, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":162
 *     __Pyx_globals['PMC10'] = VERegIds.PMC10
 *     __Pyx_globals['PMC11'] = VERegIds.PMC11
 *     __Pyx_globals['PMC12'] = VERegIds.PMC12             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC13'] = VERegIds.PMC13
 *     __Pyx_globals['PMC14'] = VERegIds.PMC14
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMC12); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 162, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC12, __pyx_t_96) < 0)) __PYX_ERR(1, 162, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":163
 *     __Pyx_globals['PMC11'] = VERegIds.PMC11
 *     __Pyx_globals['PMC12'] = VERegIds.PMC12
 *     __Pyx_globals['PMC13'] = VERegIds.PMC13             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC14'] = VERegIds.PMC14
 *     __Pyx_globals['PMC15'] = VERegIds.PMC15
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMC13); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 163, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC13, __pyx_t_3) < 0)) __PYX_ERR(1, 163, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":164
 *     __Pyx_globals['PMC12'] = VERegIds.PMC12
 *     __Pyx_globals['PMC13'] = VERegIds.PMC13
 *     __Pyx_globals['PMC14'] = VERegIds.PMC14             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC15'] = VERegIds.PMC15
 *     __Pyx_globals['PSW'] = VERegIds.PSW
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMC14); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 164, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC14, __pyx_t_96) < 0)) __PYX_ERR(1, 164, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":165
 *     __Pyx_globals['PMC13'] = VERegIds.PMC13
 *     __Pyx_globals['PMC14'] = VERegIds.PMC14
 *     __Pyx_globals['PMC15'] = VERegIds.PMC15             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PSW'] = VERegIds.PSW
 *     __Pyx_globals['EXS'] = VERegIds.EXS
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMC15); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 165, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC15, __pyx_t_3) < 0)) __PYX_ERR(1, 165, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":166
 *     __Pyx_globals['PMC14'] = VERegIds.PMC14
 *     __Pyx_globals['PMC15'] = VERegIds.PMC15
 *     __Pyx_globals['PSW'] = VERegIds.PSW             # <<<<<<<<<<<<<<
 *     __Pyx_globals['EXS'] = VERegIds.EXS
 *     __Pyx_globals['IC'] = VERegIds.IC
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PSW); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 166, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PSW, __pyx_t_96) < 0)) __PYX_ERR(1, 166, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":167
 *     __Pyx_globals['PMC15'] = VERegIds.PMC15
 *     __Pyx_globals['PSW'] = VERegIds.PSW
 *     __Pyx_globals['EXS'] = VERegIds.EXS             # <<<<<<<<<<<<<<
 *     __Pyx_globals['IC'] = VERegIds.IC
 *     __Pyx_globals['ICE'] = VERegIds.ICE
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_EXS); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 167, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_EXS, __pyx_t_3) < 0)) __PYX_ERR(1, 167, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":168
 *     __Pyx_globals['PSW'] = VERegIds.PSW
 *     __Pyx_globals['EXS'] = VERegIds.EXS
 *     __Pyx_globals['IC'] = VERegIds.IC             # <<<<<<<<<<<<<<
 *     __Pyx_globals['ICE'] = VERegIds.ICE
 *     __Pyx_globals['VIXR'] = VERegIds.VIXR
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_IC); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 168, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_IC, __pyx_t_96) < 0)) __PYX_ERR(1, 168, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":169
 *     __Pyx_globals['EXS'] = VERegIds.EXS
 *     __Pyx_globals['IC'] = VERegIds.IC
 *     __Pyx_globals['ICE'] = VERegIds.ICE             # <<<<<<<<<<<<<<
 *     __Pyx_globals['VIXR'] = VERegIds.VIXR
 *     __Pyx_globals['VL'] = VERegIds.VL
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_ICE); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 169, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_ICE, __pyx_t_3) < 0)) __PYX_ERR(1, 169, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":170
 *     __Pyx_globals['IC'] = VERegIds.IC
 *     __Pyx_globals['ICE'] = VERegIds.ICE
 *     __Pyx_globals['VIXR'] = VERegIds.VIXR             # <<<<<<<<<<<<<<
 *     __Pyx_globals['VL'] = VERegIds.VL
 *     __Pyx_globals['SAR'] = VERegIds.SAR
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_VIXR); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 170, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_VIXR, __pyx_t_96) < 0)) __PYX_ERR(1, 170, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":171
 *     __Pyx_globals['ICE'] = VERegIds.ICE
 *     __Pyx_globals['VIXR'] = VERegIds.VIXR
 *     __Pyx_globals['VL'] = VERegIds.VL             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SAR'] = VERegIds.SAR
 *     __Pyx_globals['PMMR'] = VERegIds.PMMR
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_VL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 171, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_VL, __pyx_t_3) < 0)) __PYX_ERR(1, 171, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":172
 *     __Pyx_globals['VIXR'] = VERegIds.VIXR
 *     __Pyx_globals['VL'] = VERegIds.VL
 *     __Pyx_globals['SAR'] = VERegIds.SAR             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMMR'] = VERegIds.PMMR
 *     __Pyx_globals['PMCR00'] = VERegIds.PMCR00
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SAR); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 172, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SAR, __pyx_t_96) < 0)) __PYX_ERR(1, 172, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":173
 *     __Pyx_globals['VL'] = VERegIds.VL
 *     __Pyx_globals['SAR'] = VERegIds.SAR
 *     __Pyx_globals['PMMR'] = VERegIds.PMMR             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMCR00'] = VERegIds.PMCR00
 *     __Pyx_globals['PMCR01'] = VERegIds.PMCR01
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 173, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMMR); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 173, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 173, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMMR, __pyx_t_3) < 0)) __PYX_ERR(1, 173, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":174
 *     __Pyx_globals['SAR'] = VERegIds.SAR
 *     __Pyx_globals['PMMR'] = VERegIds.PMMR
 *     __Pyx_globals['PMCR00'] = VERegIds.PMCR00             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMCR01'] = VERegIds.PMCR01
 *     __Pyx_globals['PMCR02'] = VERegIds.PMCR02
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMCR00); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 174, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMCR00, __pyx_t_96) < 0)) __PYX_ERR(1, 174, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":175
 *     __Pyx_globals['PMMR'] = VERegIds.PMMR
 *     __Pyx_globals['PMCR00'] = VERegIds.PMCR00
 *     __Pyx_globals['PMCR01'] = VERegIds.PMCR01             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMCR02'] = VERegIds.PMCR02
 *     __Pyx_globals['PMCR03'] = VERegIds.PMCR03
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 175, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMCR01); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 175, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 175, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMCR01, __pyx_t_3) < 0)) __PYX_ERR(1, 175, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":176
 *     __Pyx_globals['PMCR00'] = VERegIds.PMCR00
 *     __Pyx_globals['PMCR01'] = VERegIds.PMCR01
 *     __Pyx_globals['PMCR02'] = VERegIds.PMCR02             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMCR03'] = VERegIds.PMCR03
 *     __Pyx_globals['PMCR04'] = VERegIds.PMCR04
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 176, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMCR02); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 176, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 176, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMCR02, __pyx_t_96) < 0)) __PYX_ERR(1, 176, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":177
 *     __Pyx_globals['PMCR01'] = VERegIds.PMCR01
 *     __Pyx_globals['PMCR02'] = VERegIds.PMCR02
 *     __Pyx_globals['PMCR03'] = VERegIds.PMCR03             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMCR04'] = VERegIds.PMCR04
 *     __Pyx_globals['SR00'] = VERegIds.SR00
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_PMCR03); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 177, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMCR03, __pyx_t_3) < 0)) __PYX_ERR(1, 177, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":178
 *     __Pyx_globals['PMCR02'] = VERegIds.PMCR02
 *     __Pyx_globals['PMCR03'] = VERegIds.PMCR03
 *     __Pyx_globals['PMCR04'] = VERegIds.PMCR04             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR00'] = VERegIds.SR00
 *     __Pyx_globals['SR01'] = VERegIds.SR01
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PMCR04); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 178, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMCR04, __pyx_t_96) < 0)) __PYX_ERR(1, 178, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":179
 *     __Pyx_globals['PMCR03'] = VERegIds.PMCR03
 *     __Pyx_globals['PMCR04'] = VERegIds.PMCR04
 *     __Pyx_globals['SR00'] = VERegIds.SR00             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR01'] = VERegIds.SR01
 *     __Pyx_globals['SR02'] = VERegIds.SR02
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR00); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 179, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR00, __pyx_t_3) < 0)) __PYX_ERR(1, 179, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":180
 *     __Pyx_globals['PMCR04'] = VERegIds.PMCR04
 *     __Pyx_globals['SR00'] = VERegIds.SR00
 *     __Pyx_globals['SR01'] = VERegIds.SR01             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR02'] = VERegIds.SR02
 *     __Pyx_globals['SR03'] = VERegIds.SR03
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR01); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 180, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR01, __pyx_t_96) < 0)) __PYX_ERR(1, 180, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":181
 *     __Pyx_globals['SR00'] = VERegIds.SR00
 *     __Pyx_globals['SR01'] = VERegIds.SR01
 *     __Pyx_globals['SR02'] = VERegIds.SR02             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR03'] = VERegIds.SR03
 *     __Pyx_globals['SR04'] = VERegIds.SR04
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR02); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 181, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR02, __pyx_t_3) < 0)) __PYX_ERR(1, 181, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":182
 *     __Pyx_globals['SR01'] = VERegIds.SR01
 *     __Pyx_globals['SR02'] = VERegIds.SR02
 *     __Pyx_globals['SR03'] = VERegIds.SR03             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR04'] = VERegIds.SR04
 *     __Pyx_globals['SR05'] = VERegIds.SR05
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 182, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR03); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 182, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 182, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR03, __pyx_t_96) < 0)) __PYX_ERR(1, 182, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":183
 *     __Pyx_globals['SR02'] = VERegIds.SR02
 *     __Pyx_globals['SR03'] = VERegIds.SR03
 *     __Pyx_globals['SR04'] = VERegIds.SR04             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR05'] = VERegIds.SR05
 *     __Pyx_globals['SR06'] = VERegIds.SR06
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR04); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 183, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR04, __pyx_t_3) < 0)) __PYX_ERR(1, 183, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":184
 *     __Pyx_globals['SR03'] = VERegIds.SR03
 *     __Pyx_globals['SR04'] = VERegIds.SR04
 *     __Pyx_globals['SR05'] = VERegIds.SR05             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR06'] = VERegIds.SR06
 *     __Pyx_globals['SR07'] = VERegIds.SR07
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR05); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 184, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR05, __pyx_t_96) < 0)) __PYX_ERR(1, 184, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":185
 *     __Pyx_globals['SR04'] = VERegIds.SR04
 *     __Pyx_globals['SR05'] = VERegIds.SR05
 *     __Pyx_globals['SR06'] = VERegIds.SR06             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR07'] = VERegIds.SR07
 *     __Pyx_globals['SR08'] = VERegIds.SR08
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR06); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 185, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR06, __pyx_t_3) < 0)) __PYX_ERR(1, 185, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":186
 *     __Pyx_globals['SR05'] = VERegIds.SR05
 *     __Pyx_globals['SR06'] = VERegIds.SR06
 *     __Pyx_globals['SR07'] = VERegIds.SR07             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR08'] = VERegIds.SR08
 *     __Pyx_globals['SR09'] = VERegIds.SR09
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR07); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 186, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR07, __pyx_t_96) < 0)) __PYX_ERR(1, 186, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":187
 *     __Pyx_globals['SR06'] = VERegIds.SR06
 *     __Pyx_globals['SR07'] = VERegIds.SR07
 *     __Pyx_globals['SR08'] = VERegIds.SR08             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR09'] = VERegIds.SR09
 *     __Pyx_globals['SR10'] = VERegIds.SR10
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR08); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 187, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR08, __pyx_t_3) < 0)) __PYX_ERR(1, 187, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":188
 *     __Pyx_globals['SR07'] = VERegIds.SR07
 *     __Pyx_globals['SR08'] = VERegIds.SR08
 *     __Pyx_globals['SR09'] = VERegIds.SR09             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR10'] = VERegIds.SR10
 *     __Pyx_globals['SR11'] = VERegIds.SR11
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR09); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 188, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR09, __pyx_t_96) < 0)) __PYX_ERR(1, 188, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":189
 *     __Pyx_globals['SR08'] = VERegIds.SR08
 *     __Pyx_globals['SR09'] = VERegIds.SR09
 *     __Pyx_globals['SR10'] = VERegIds.SR10             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR11'] = VERegIds.SR11
 *     __Pyx_globals['SR12'] = VERegIds.SR12
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR10); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 189, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR10, __pyx_t_3) < 0)) __PYX_ERR(1, 189, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":190
 *     __Pyx_globals['SR09'] = VERegIds.SR09
 *     __Pyx_globals['SR10'] = VERegIds.SR10
 *     __Pyx_globals['SR11'] = VERegIds.SR11             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR12'] = VERegIds.SR12
 *     __Pyx_globals['SR13'] = VERegIds.SR13
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR11); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 190, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR11, __pyx_t_96) < 0)) __PYX_ERR(1, 190, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":191
 *     __Pyx_globals['SR10'] = VERegIds.SR10
 *     __Pyx_globals['SR11'] = VERegIds.SR11
 *     __Pyx_globals['SR12'] = VERegIds.SR12             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR13'] = VERegIds.SR13
 *     __Pyx_globals['SR14'] = VERegIds.SR14
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR12); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 191, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR12, __pyx_t_3) < 0)) __PYX_ERR(1, 191, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":192
 *     __Pyx_globals['SR11'] = VERegIds.SR11
 *     __Pyx_globals['SR12'] = VERegIds.SR12
 *     __Pyx_globals['SR13'] = VERegIds.SR13             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR14'] = VERegIds.SR14
 *     __Pyx_globals['SR15'] = VERegIds.SR15
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR13); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 192, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR13, __pyx_t_96) < 0)) __PYX_ERR(1, 192, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":193
 *     __Pyx_globals['SR12'] = VERegIds.SR12
 *     __Pyx_globals['SR13'] = VERegIds.SR13
 *     __Pyx_globals['SR14'] = VERegIds.SR14             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR15'] = VERegIds.SR15
 *     __Pyx_globals['SR16'] = VERegIds.SR16
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR14); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 193, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR14, __pyx_t_3) < 0)) __PYX_ERR(1, 193, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":194
 *     __Pyx_globals['SR13'] = VERegIds.SR13
 *     __Pyx_globals['SR14'] = VERegIds.SR14
 *     __Pyx_globals['SR15'] = VERegIds.SR15             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR16'] = VERegIds.SR16
 *     __Pyx_globals['SR17'] = VERegIds.SR17
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR15); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 194, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR15, __pyx_t_96) < 0)) __PYX_ERR(1, 194, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":195
 *     __Pyx_globals['SR14'] = VERegIds.SR14
 *     __Pyx_globals['SR15'] = VERegIds.SR15
 *     __Pyx_globals['SR16'] = VERegIds.SR16             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR17'] = VERegIds.SR17
 *     __Pyx_globals['SR18'] = VERegIds.SR18
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR16); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 195, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR16, __pyx_t_3) < 0)) __PYX_ERR(1, 195, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":196
 *     __Pyx_globals['SR15'] = VERegIds.SR15
 *     __Pyx_globals['SR16'] = VERegIds.SR16
 *     __Pyx_globals['SR17'] = VERegIds.SR17             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR18'] = VERegIds.SR18
 *     __Pyx_globals['SR19'] = VERegIds.SR19
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR17); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 196, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR17, __pyx_t_96) < 0)) __PYX_ERR(1, 196, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":197
 *     __Pyx_globals['SR16'] = VERegIds.SR16
 *     __Pyx_globals['SR17'] = VERegIds.SR17
 *     __Pyx_globals['SR18'] = VERegIds.SR18             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR19'] = VERegIds.SR19
 *     __Pyx_globals['SR20'] = VERegIds.SR20
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR18); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 197, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR18, __pyx_t_3) < 0)) __PYX_ERR(1, 197, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":198
 *     __Pyx_globals['SR17'] = VERegIds.SR17
 *     __Pyx_globals['SR18'] = VERegIds.SR18
 *     __Pyx_globals['SR19'] = VERegIds.SR19             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR20'] = VERegIds.SR20
 *     __Pyx_globals['SR21'] = VERegIds.SR21
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR19); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 198, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR19, __pyx_t_96) < 0)) __PYX_ERR(1, 198, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":199
 *     __Pyx_globals['SR18'] = VERegIds.SR18
 *     __Pyx_globals['SR19'] = VERegIds.SR19
 *     __Pyx_globals['SR20'] = VERegIds.SR20             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR21'] = VERegIds.SR21
 *     __Pyx_globals['SR22'] = VERegIds.SR22
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR20); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 199, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR20, __pyx_t_3) < 0)) __PYX_ERR(1, 199, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":200
 *     __Pyx_globals['SR19'] = VERegIds.SR19
 *     __Pyx_globals['SR20'] = VERegIds.SR20
 *     __Pyx_globals['SR21'] = VERegIds.SR21             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR22'] = VERegIds.SR22
 *     __Pyx_globals['SR23'] = VERegIds.SR23
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR21); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 200, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR21, __pyx_t_96) < 0)) __PYX_ERR(1, 200, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":201
 *     __Pyx_globals['SR20'] = VERegIds.SR20
 *     __Pyx_globals['SR21'] = VERegIds.SR21
 *     __Pyx_globals['SR22'] = VERegIds.SR22             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR23'] = VERegIds.SR23
 *     __Pyx_globals['SR24'] = VERegIds.SR24
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR22); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 201, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR22, __pyx_t_3) < 0)) __PYX_ERR(1, 201, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":202
 *     __Pyx_globals['SR21'] = VERegIds.SR21
 *     __Pyx_globals['SR22'] = VERegIds.SR22
 *     __Pyx_globals['SR23'] = VERegIds.SR23             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR24'] = VERegIds.SR24
 *     __Pyx_globals['SR25'] = VERegIds.SR25
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR23); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 202, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR23, __pyx_t_96) < 0)) __PYX_ERR(1, 202, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":203
 *     __Pyx_globals['SR22'] = VERegIds.SR22
 *     __Pyx_globals['SR23'] = VERegIds.SR23
 *     __Pyx_globals['SR24'] = VERegIds.SR24             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR25'] = VERegIds.SR25
 *     __Pyx_globals['SR26'] = VERegIds.SR26
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR24); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 203, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR24, __pyx_t_3) < 0)) __PYX_ERR(1, 203, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":204
 *     __Pyx_globals['SR23'] = VERegIds.SR23
 *     __Pyx_globals['SR24'] = VERegIds.SR24
 *     __Pyx_globals['SR25'] = VERegIds.SR25             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR26'] = VERegIds.SR26
 *     __Pyx_globals['SR27'] = VERegIds.SR27
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR25); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 204, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR25, __pyx_t_96) < 0)) __PYX_ERR(1, 204, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":205
 *     __Pyx_globals['SR24'] = VERegIds.SR24
 *     __Pyx_globals['SR25'] = VERegIds.SR25
 *     __Pyx_globals['SR26'] = VERegIds.SR26             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR27'] = VERegIds.SR27
 *     __Pyx_globals['SR28'] = VERegIds.SR28
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR26); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 205, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR26, __pyx_t_3) < 0)) __PYX_ERR(1, 205, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":206
 *     __Pyx_globals['SR25'] = VERegIds.SR25
 *     __Pyx_globals['SR26'] = VERegIds.SR26
 *     __Pyx_globals['SR27'] = VERegIds.SR27             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR28'] = VERegIds.SR28
 *     __Pyx_globals['SR29'] = VERegIds.SR29
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR27); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 206, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR27, __pyx_t_96) < 0)) __PYX_ERR(1, 206, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":207
 *     __Pyx_globals['SR26'] = VERegIds.SR26
 *     __Pyx_globals['SR27'] = VERegIds.SR27
 *     __Pyx_globals['SR28'] = VERegIds.SR28             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR29'] = VERegIds.SR29
 *     __Pyx_globals['SR30'] = VERegIds.SR30
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR28); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 207, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR28, __pyx_t_3) < 0)) __PYX_ERR(1, 207, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":208
 *     __Pyx_globals['SR27'] = VERegIds.SR27
 *     __Pyx_globals['SR28'] = VERegIds.SR28
 *     __Pyx_globals['SR29'] = VERegIds.SR29             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR30'] = VERegIds.SR30
 *     __Pyx_globals['SR31'] = VERegIds.SR31
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR29); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 208, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR29, __pyx_t_96) < 0)) __PYX_ERR(1, 208, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":209
 *     __Pyx_globals['SR28'] = VERegIds.SR28
 *     __Pyx_globals['SR29'] = VERegIds.SR29
 *     __Pyx_globals['SR30'] = VERegIds.SR30             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR31'] = VERegIds.SR31
 *     __Pyx_globals['SR32'] = VERegIds.SR32
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR30); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 209, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR30, __pyx_t_3) < 0)) __PYX_ERR(1, 209, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":210
 *     __Pyx_globals['SR29'] = VERegIds.SR29
 *     __Pyx_globals['SR30'] = VERegIds.SR30
 *     __Pyx_globals['SR31'] = VERegIds.SR31             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR32'] = VERegIds.SR32
 *     __Pyx_globals['SR33'] = VERegIds.SR33
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 210, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR31); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 210, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 210, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR31, __pyx_t_96) < 0)) __PYX_ERR(1, 210, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":211
 *     __Pyx_globals['SR30'] = VERegIds.SR30
 *     __Pyx_globals['SR31'] = VERegIds.SR31
 *     __Pyx_globals['SR32'] = VERegIds.SR32             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR33'] = VERegIds.SR33
 *     __Pyx_globals['SR34'] = VERegIds.SR34
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR32); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 211, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR32, __pyx_t_3) < 0)) __PYX_ERR(1, 211, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":212
 *     __Pyx_globals['SR31'] = VERegIds.SR31
 *     __Pyx_globals['SR32'] = VERegIds.SR32
 *     __Pyx_globals['SR33'] = VERegIds.SR33             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR34'] = VERegIds.SR34
 *     __Pyx_globals['SR35'] = VERegIds.SR35
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR33); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 212, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR33, __pyx_t_96) < 0)) __PYX_ERR(1, 212, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":213
 *     __Pyx_globals['SR32'] = VERegIds.SR32
 *     __Pyx_globals['SR33'] = VERegIds.SR33
 *     __Pyx_globals['SR34'] = VERegIds.SR34             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR35'] = VERegIds.SR35
 *     __Pyx_globals['SR36'] = VERegIds.SR36
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR34); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 213, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR34, __pyx_t_3) < 0)) __PYX_ERR(1, 213, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":214
 *     __Pyx_globals['SR33'] = VERegIds.SR33
 *     __Pyx_globals['SR34'] = VERegIds.SR34
 *     __Pyx_globals['SR35'] = VERegIds.SR35             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR36'] = VERegIds.SR36
 *     __Pyx_globals['SR37'] = VERegIds.SR37
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR35); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 214, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR35, __pyx_t_96) < 0)) __PYX_ERR(1, 214, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":215
 *     __Pyx_globals['SR34'] = VERegIds.SR34
 *     __Pyx_globals['SR35'] = VERegIds.SR35
 *     __Pyx_globals['SR36'] = VERegIds.SR36             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR37'] = VERegIds.SR37
 *     __Pyx_globals['SR38'] = VERegIds.SR38
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR36); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 215, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR36, __pyx_t_3) < 0)) __PYX_ERR(1, 215, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":216
 *     __Pyx_globals['SR35'] = VERegIds.SR35
 *     __Pyx_globals['SR36'] = VERegIds.SR36
 *     __Pyx_globals['SR37'] = VERegIds.SR37             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR38'] = VERegIds.SR38
 *     __Pyx_globals['SR39'] = VERegIds.SR39
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR37); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 216, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR37, __pyx_t_96) < 0)) __PYX_ERR(1, 216, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":217
 *     __Pyx_globals['SR36'] = VERegIds.SR36
 *     __Pyx_globals['SR37'] = VERegIds.SR37
 *     __Pyx_globals['SR38'] = VERegIds.SR38             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR39'] = VERegIds.SR39
 *     __Pyx_globals['SR40'] = VERegIds.SR40
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR38); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 217, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR38, __pyx_t_3) < 0)) __PYX_ERR(1, 217, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":218
 *     __Pyx_globals['SR37'] = VERegIds.SR37
 *     __Pyx_globals['SR38'] = VERegIds.SR38
 *     __Pyx_globals['SR39'] = VERegIds.SR39             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR40'] = VERegIds.SR40
 *     __Pyx_globals['SR41'] = VERegIds.SR41
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR39); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 218, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR39, __pyx_t_96) < 0)) __PYX_ERR(1, 218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":219
 *     __Pyx_globals['SR38'] = VERegIds.SR38
 *     __Pyx_globals['SR39'] = VERegIds.SR39
 *     __Pyx_globals['SR40'] = VERegIds.SR40             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR41'] = VERegIds.SR41
 *     __Pyx_globals['SR42'] = VERegIds.SR42
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR40); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 219, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR40, __pyx_t_3) < 0)) __PYX_ERR(1, 219, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":220
 *     __Pyx_globals['SR39'] = VERegIds.SR39
 *     __Pyx_globals['SR40'] = VERegIds.SR40
 *     __Pyx_globals['SR41'] = VERegIds.SR41             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR42'] = VERegIds.SR42
 *     __Pyx_globals['SR43'] = VERegIds.SR43
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR41); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 220, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR41, __pyx_t_96) < 0)) __PYX_ERR(1, 220, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":221
 *     __Pyx_globals['SR40'] = VERegIds.SR40
 *     __Pyx_globals['SR41'] = VERegIds.SR41
 *     __Pyx_globals['SR42'] = VERegIds.SR42             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR43'] = VERegIds.SR43
 *     __Pyx_globals['SR44'] = VERegIds.SR44
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR42); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 221, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR42, __pyx_t_3) < 0)) __PYX_ERR(1, 221, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":222
 *     __Pyx_globals['SR41'] = VERegIds.SR41
 *     __Pyx_globals['SR42'] = VERegIds.SR42
 *     __Pyx_globals['SR43'] = VERegIds.SR43             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR44'] = VERegIds.SR44
 *     __Pyx_globals['SR45'] = VERegIds.SR45
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR43); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 222, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR43, __pyx_t_96) < 0)) __PYX_ERR(1, 222, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":223
 *     __Pyx_globals['SR42'] = VERegIds.SR42
 *     __Pyx_globals['SR43'] = VERegIds.SR43
 *     __Pyx_globals['SR44'] = VERegIds.SR44             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR45'] = VERegIds.SR45
 *     __Pyx_globals['SR46'] = VERegIds.SR46
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR44); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 223, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR44, __pyx_t_3) < 0)) __PYX_ERR(1, 223, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":224
 *     __Pyx_globals['SR43'] = VERegIds.SR43
 *     __Pyx_globals['SR44'] = VERegIds.SR44
 *     __Pyx_globals['SR45'] = VERegIds.SR45             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR46'] = VERegIds.SR46
 *     __Pyx_globals['SR47'] = VERegIds.SR47
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR45); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 224, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR45, __pyx_t_96) < 0)) __PYX_ERR(1, 224, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":225
 *     __Pyx_globals['SR44'] = VERegIds.SR44
 *     __Pyx_globals['SR45'] = VERegIds.SR45
 *     __Pyx_globals['SR46'] = VERegIds.SR46             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR47'] = VERegIds.SR47
 *     __Pyx_globals['SR48'] = VERegIds.SR48
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR46); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 225, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR46, __pyx_t_3) < 0)) __PYX_ERR(1, 225, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":226
 *     __Pyx_globals['SR45'] = VERegIds.SR45
 *     __Pyx_globals['SR46'] = VERegIds.SR46
 *     __Pyx_globals['SR47'] = VERegIds.SR47             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR48'] = VERegIds.SR48
 *     __Pyx_globals['SR49'] = VERegIds.SR49
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR47); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 226, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR47, __pyx_t_96) < 0)) __PYX_ERR(1, 226, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":227
 *     __Pyx_globals['SR46'] = VERegIds.SR46
 *     __Pyx_globals['SR47'] = VERegIds.SR47
 *     __Pyx_globals['SR48'] = VERegIds.SR48             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR49'] = VERegIds.SR49
 *     __Pyx_globals['SR50'] = VERegIds.SR50
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR48); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 227, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR48, __pyx_t_3) < 0)) __PYX_ERR(1, 227, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":228
 *     __Pyx_globals['SR47'] = VERegIds.SR47
 *     __Pyx_globals['SR48'] = VERegIds.SR48
 *     __Pyx_globals['SR49'] = VERegIds.SR49             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR50'] = VERegIds.SR50
 *     __Pyx_globals['SR51'] = VERegIds.SR51
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR49); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 228, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR49, __pyx_t_96) < 0)) __PYX_ERR(1, 228, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":229
 *     __Pyx_globals['SR48'] = VERegIds.SR48
 *     __Pyx_globals['SR49'] = VERegIds.SR49
 *     __Pyx_globals['SR50'] = VERegIds.SR50             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR51'] = VERegIds.SR51
 *     __Pyx_globals['SR52'] = VERegIds.SR52
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR50); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 229, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR50, __pyx_t_3) < 0)) __PYX_ERR(1, 229, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":230
 *     __Pyx_globals['SR49'] = VERegIds.SR49
 *     __Pyx_globals['SR50'] = VERegIds.SR50
 *     __Pyx_globals['SR51'] = VERegIds.SR51             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR52'] = VERegIds.SR52
 *     __Pyx_globals['SR53'] = VERegIds.SR53
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR51); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 230, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR51, __pyx_t_96) < 0)) __PYX_ERR(1, 230, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":231
 *     __Pyx_globals['SR50'] = VERegIds.SR50
 *     __Pyx_globals['SR51'] = VERegIds.SR51
 *     __Pyx_globals['SR52'] = VERegIds.SR52             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR53'] = VERegIds.SR53
 *     __Pyx_globals['SR54'] = VERegIds.SR54
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR52); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 231, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR52, __pyx_t_3) < 0)) __PYX_ERR(1, 231, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":232
 *     __Pyx_globals['SR51'] = VERegIds.SR51
 *     __Pyx_globals['SR52'] = VERegIds.SR52
 *     __Pyx_globals['SR53'] = VERegIds.SR53             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR54'] = VERegIds.SR54
 *     __Pyx_globals['SR55'] = VERegIds.SR55
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 232, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR53); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 232, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 232, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR53, __pyx_t_96) < 0)) __PYX_ERR(1, 232, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":233
 *     __Pyx_globals['SR52'] = VERegIds.SR52
 *     __Pyx_globals['SR53'] = VERegIds.SR53
 *     __Pyx_globals['SR54'] = VERegIds.SR54             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR55'] = VERegIds.SR55
 *     __Pyx_globals['SR56'] = VERegIds.SR56
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR54); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 233, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR54, __pyx_t_3) < 0)) __PYX_ERR(1, 233, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":234
 *     __Pyx_globals['SR53'] = VERegIds.SR53
 *     __Pyx_globals['SR54'] = VERegIds.SR54
 *     __Pyx_globals['SR55'] = VERegIds.SR55             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR56'] = VERegIds.SR56
 *     __Pyx_globals['SR57'] = VERegIds.SR57
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 234, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR55); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 234, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 234, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR55, __pyx_t_96) < 0)) __PYX_ERR(1, 234, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":235
 *     __Pyx_globals['SR54'] = VERegIds.SR54
 *     __Pyx_globals['SR55'] = VERegIds.SR55
 *     __Pyx_globals['SR56'] = VERegIds.SR56             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR57'] = VERegIds.SR57
 *     __Pyx_globals['SR58'] = VERegIds.SR58
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR56); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 235, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR56, __pyx_t_3) < 0)) __PYX_ERR(1, 235, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":236
 *     __Pyx_globals['SR55'] = VERegIds.SR55
 *     __Pyx_globals['SR56'] = VERegIds.SR56
 *     __Pyx_globals['SR57'] = VERegIds.SR57             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR58'] = VERegIds.SR58
 *     __Pyx_globals['SR59'] = VERegIds.SR59
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR57); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 236, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR57, __pyx_t_96) < 0)) __PYX_ERR(1, 236, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":237
 *     __Pyx_globals['SR56'] = VERegIds.SR56
 *     __Pyx_globals['SR57'] = VERegIds.SR57
 *     __Pyx_globals['SR58'] = VERegIds.SR58             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR59'] = VERegIds.SR59
 *     __Pyx_globals['SR60'] = VERegIds.SR60
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR58); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 237, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR58, __pyx_t_3) < 0)) __PYX_ERR(1, 237, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":238
 *     __Pyx_globals['SR57'] = VERegIds.SR57
 *     __Pyx_globals['SR58'] = VERegIds.SR58
 *     __Pyx_globals['SR59'] = VERegIds.SR59             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR60'] = VERegIds.SR60
 *     __Pyx_globals['SR61'] = VERegIds.SR61
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR59); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 238, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR59, __pyx_t_96) < 0)) __PYX_ERR(1, 238, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":239
 *     __Pyx_globals['SR58'] = VERegIds.SR58
 *     __Pyx_globals['SR59'] = VERegIds.SR59
 *     __Pyx_globals['SR60'] = VERegIds.SR60             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR61'] = VERegIds.SR61
 *     __Pyx_globals['SR62'] = VERegIds.SR62
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR60); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 239, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR60, __pyx_t_3) < 0)) __PYX_ERR(1, 239, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":240
 *     __Pyx_globals['SR59'] = VERegIds.SR59
 *     __Pyx_globals['SR60'] = VERegIds.SR60
 *     __Pyx_globals['SR61'] = VERegIds.SR61             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR62'] = VERegIds.SR62
 *     __Pyx_globals['SR63'] = VERegIds.SR63
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 240, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR61); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 240, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 240, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR61, __pyx_t_96) < 0)) __PYX_ERR(1, 240, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":241
 *     __Pyx_globals['SR60'] = VERegIds.SR60
 *     __Pyx_globals['SR61'] = VERegIds.SR61
 *     __Pyx_globals['SR62'] = VERegIds.SR62             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR63'] = VERegIds.SR63
 * else:
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_96, __pyx_n_s_SR62); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 241, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR62, __pyx_t_3) < 0)) __PYX_ERR(1, 241, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":242
 *     __Pyx_globals['SR61'] = VERegIds.SR61
 *     __Pyx_globals['SR62'] = VERegIds.SR62
 *     __Pyx_globals['SR63'] = VERegIds.SR63             # <<<<<<<<<<<<<<
 * else:
 *     class VERegIds(__Pyx_EnumBase):
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_96 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SR63); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 242, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR63, __pyx_t_96) < 0)) __PYX_ERR(1, 242, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":51
 * 
 * cdef dict __Pyx_globals = globals()
 * if PY_VERSION_HEX >= 0x03040000:             # <<<<<<<<<<<<<<
 * 
 *     VERegIds = __Pyx_EnumBase('VERegIds', __Pyx_OrderedDict([
 */
    goto __pyx_L4;
  }

  /* "EnumType":244
 *     __Pyx_globals['SR63'] = VERegIds.SR63
 * else:
 *     class VERegIds(__Pyx_EnumBase):             # <<<<<<<<<<<<<<
 *         pass
 *     __Pyx_globals['USRCC'] = VERegIds(USRCC, 'USRCC')
 */
  /*else*/ {
    __pyx_t_96 = PyTuple_New(1); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_INCREF(__Pyx_EnumBase);
    __Pyx_GIVEREF(__Pyx_EnumBase);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __Pyx_EnumBase);
    __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_96); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_96, __pyx_n_s_VERegIds, __pyx_n_s_VERegIds, (PyObject *) NULL, __pyx_n_s_EnumType, (PyObject *) NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_94 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_VERegIds, __pyx_t_96, __pyx_t_95, NULL, 0, 1); if (unlikely(!__pyx_t_94)) __PYX_ERR(1, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_94);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_VERegIds, __pyx_t_94) < 0) __PYX_ERR(1, 244, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_94); __pyx_t_94 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":246
 *     class VERegIds(__Pyx_EnumBase):
 *         pass
 *     __Pyx_globals['USRCC'] = VERegIds(USRCC, 'USRCC')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC00'] = VERegIds(PMC00, 'PMC00')
 *     __Pyx_globals['PMC01'] = VERegIds(PMC01, 'PMC01')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_USRCC); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_USRCC);
    __Pyx_GIVEREF(__pyx_n_s_USRCC);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_USRCC);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 246, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_USRCC, __pyx_t_3) < 0)) __PYX_ERR(1, 246, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":247
 *         pass
 *     __Pyx_globals['USRCC'] = VERegIds(USRCC, 'USRCC')
 *     __Pyx_globals['PMC00'] = VERegIds(PMC00, 'PMC00')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC01'] = VERegIds(PMC01, 'PMC01')
 *     __Pyx_globals['PMC02'] = VERegIds(PMC02, 'PMC02')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC00); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_PMC00);
    __Pyx_GIVEREF(__pyx_n_s_PMC00);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_PMC00);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 247, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC00, __pyx_t_95) < 0)) __PYX_ERR(1, 247, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":248
 *     __Pyx_globals['USRCC'] = VERegIds(USRCC, 'USRCC')
 *     __Pyx_globals['PMC00'] = VERegIds(PMC00, 'PMC00')
 *     __Pyx_globals['PMC01'] = VERegIds(PMC01, 'PMC01')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC02'] = VERegIds(PMC02, 'PMC02')
 *     __Pyx_globals['PMC03'] = VERegIds(PMC03, 'PMC03')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC01); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_PMC01);
    __Pyx_GIVEREF(__pyx_n_s_PMC01);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_PMC01);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 248, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC01, __pyx_t_96) < 0)) __PYX_ERR(1, 248, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":249
 *     __Pyx_globals['PMC00'] = VERegIds(PMC00, 'PMC00')
 *     __Pyx_globals['PMC01'] = VERegIds(PMC01, 'PMC01')
 *     __Pyx_globals['PMC02'] = VERegIds(PMC02, 'PMC02')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC03'] = VERegIds(PMC03, 'PMC03')
 *     __Pyx_globals['PMC04'] = VERegIds(PMC04, 'PMC04')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC02); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_PMC02);
    __Pyx_GIVEREF(__pyx_n_s_PMC02);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_PMC02);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 249, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC02, __pyx_t_3) < 0)) __PYX_ERR(1, 249, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":250
 *     __Pyx_globals['PMC01'] = VERegIds(PMC01, 'PMC01')
 *     __Pyx_globals['PMC02'] = VERegIds(PMC02, 'PMC02')
 *     __Pyx_globals['PMC03'] = VERegIds(PMC03, 'PMC03')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC04'] = VERegIds(PMC04, 'PMC04')
 *     __Pyx_globals['PMC05'] = VERegIds(PMC05, 'PMC05')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC03); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_PMC03);
    __Pyx_GIVEREF(__pyx_n_s_PMC03);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_PMC03);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 250, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC03, __pyx_t_95) < 0)) __PYX_ERR(1, 250, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":251
 *     __Pyx_globals['PMC02'] = VERegIds(PMC02, 'PMC02')
 *     __Pyx_globals['PMC03'] = VERegIds(PMC03, 'PMC03')
 *     __Pyx_globals['PMC04'] = VERegIds(PMC04, 'PMC04')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC05'] = VERegIds(PMC05, 'PMC05')
 *     __Pyx_globals['PMC06'] = VERegIds(PMC06, 'PMC06')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC04); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_PMC04);
    __Pyx_GIVEREF(__pyx_n_s_PMC04);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_PMC04);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 251, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC04, __pyx_t_96) < 0)) __PYX_ERR(1, 251, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":252
 *     __Pyx_globals['PMC03'] = VERegIds(PMC03, 'PMC03')
 *     __Pyx_globals['PMC04'] = VERegIds(PMC04, 'PMC04')
 *     __Pyx_globals['PMC05'] = VERegIds(PMC05, 'PMC05')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC06'] = VERegIds(PMC06, 'PMC06')
 *     __Pyx_globals['PMC07'] = VERegIds(PMC07, 'PMC07')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC05); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_PMC05);
    __Pyx_GIVEREF(__pyx_n_s_PMC05);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_PMC05);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 252, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC05, __pyx_t_3) < 0)) __PYX_ERR(1, 252, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":253
 *     __Pyx_globals['PMC04'] = VERegIds(PMC04, 'PMC04')
 *     __Pyx_globals['PMC05'] = VERegIds(PMC05, 'PMC05')
 *     __Pyx_globals['PMC06'] = VERegIds(PMC06, 'PMC06')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC07'] = VERegIds(PMC07, 'PMC07')
 *     __Pyx_globals['PMC08'] = VERegIds(PMC08, 'PMC08')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC06); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_PMC06);
    __Pyx_GIVEREF(__pyx_n_s_PMC06);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_PMC06);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 253, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC06, __pyx_t_95) < 0)) __PYX_ERR(1, 253, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":254
 *     __Pyx_globals['PMC05'] = VERegIds(PMC05, 'PMC05')
 *     __Pyx_globals['PMC06'] = VERegIds(PMC06, 'PMC06')
 *     __Pyx_globals['PMC07'] = VERegIds(PMC07, 'PMC07')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC08'] = VERegIds(PMC08, 'PMC08')
 *     __Pyx_globals['PMC09'] = VERegIds(PMC09, 'PMC09')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC07); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_PMC07);
    __Pyx_GIVEREF(__pyx_n_s_PMC07);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_PMC07);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 254, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC07, __pyx_t_96) < 0)) __PYX_ERR(1, 254, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":255
 *     __Pyx_globals['PMC06'] = VERegIds(PMC06, 'PMC06')
 *     __Pyx_globals['PMC07'] = VERegIds(PMC07, 'PMC07')
 *     __Pyx_globals['PMC08'] = VERegIds(PMC08, 'PMC08')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC09'] = VERegIds(PMC09, 'PMC09')
 *     __Pyx_globals['PMC10'] = VERegIds(PMC10, 'PMC10')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC08); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_PMC08);
    __Pyx_GIVEREF(__pyx_n_s_PMC08);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_PMC08);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 255, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC08, __pyx_t_3) < 0)) __PYX_ERR(1, 255, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":256
 *     __Pyx_globals['PMC07'] = VERegIds(PMC07, 'PMC07')
 *     __Pyx_globals['PMC08'] = VERegIds(PMC08, 'PMC08')
 *     __Pyx_globals['PMC09'] = VERegIds(PMC09, 'PMC09')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC10'] = VERegIds(PMC10, 'PMC10')
 *     __Pyx_globals['PMC11'] = VERegIds(PMC11, 'PMC11')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC09); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_PMC09);
    __Pyx_GIVEREF(__pyx_n_s_PMC09);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_PMC09);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 256, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC09, __pyx_t_95) < 0)) __PYX_ERR(1, 256, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":257
 *     __Pyx_globals['PMC08'] = VERegIds(PMC08, 'PMC08')
 *     __Pyx_globals['PMC09'] = VERegIds(PMC09, 'PMC09')
 *     __Pyx_globals['PMC10'] = VERegIds(PMC10, 'PMC10')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC11'] = VERegIds(PMC11, 'PMC11')
 *     __Pyx_globals['PMC12'] = VERegIds(PMC12, 'PMC12')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC10); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_PMC10);
    __Pyx_GIVEREF(__pyx_n_s_PMC10);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_PMC10);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 257, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC10, __pyx_t_96) < 0)) __PYX_ERR(1, 257, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":258
 *     __Pyx_globals['PMC09'] = VERegIds(PMC09, 'PMC09')
 *     __Pyx_globals['PMC10'] = VERegIds(PMC10, 'PMC10')
 *     __Pyx_globals['PMC11'] = VERegIds(PMC11, 'PMC11')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC12'] = VERegIds(PMC12, 'PMC12')
 *     __Pyx_globals['PMC13'] = VERegIds(PMC13, 'PMC13')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 258, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC11); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 258, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 258, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_PMC11);
    __Pyx_GIVEREF(__pyx_n_s_PMC11);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_PMC11);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 258, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 258, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC11, __pyx_t_3) < 0)) __PYX_ERR(1, 258, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":259
 *     __Pyx_globals['PMC10'] = VERegIds(PMC10, 'PMC10')
 *     __Pyx_globals['PMC11'] = VERegIds(PMC11, 'PMC11')
 *     __Pyx_globals['PMC12'] = VERegIds(PMC12, 'PMC12')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC13'] = VERegIds(PMC13, 'PMC13')
 *     __Pyx_globals['PMC14'] = VERegIds(PMC14, 'PMC14')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC12); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_PMC12);
    __Pyx_GIVEREF(__pyx_n_s_PMC12);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_PMC12);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 259, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC12, __pyx_t_95) < 0)) __PYX_ERR(1, 259, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":260
 *     __Pyx_globals['PMC11'] = VERegIds(PMC11, 'PMC11')
 *     __Pyx_globals['PMC12'] = VERegIds(PMC12, 'PMC12')
 *     __Pyx_globals['PMC13'] = VERegIds(PMC13, 'PMC13')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC14'] = VERegIds(PMC14, 'PMC14')
 *     __Pyx_globals['PMC15'] = VERegIds(PMC15, 'PMC15')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC13); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_PMC13);
    __Pyx_GIVEREF(__pyx_n_s_PMC13);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_PMC13);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 260, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC13, __pyx_t_96) < 0)) __PYX_ERR(1, 260, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":261
 *     __Pyx_globals['PMC12'] = VERegIds(PMC12, 'PMC12')
 *     __Pyx_globals['PMC13'] = VERegIds(PMC13, 'PMC13')
 *     __Pyx_globals['PMC14'] = VERegIds(PMC14, 'PMC14')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMC15'] = VERegIds(PMC15, 'PMC15')
 *     __Pyx_globals['PSW'] = VERegIds(PSW, 'PSW')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC14); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_PMC14);
    __Pyx_GIVEREF(__pyx_n_s_PMC14);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_PMC14);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 261, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC14, __pyx_t_3) < 0)) __PYX_ERR(1, 261, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":262
 *     __Pyx_globals['PMC13'] = VERegIds(PMC13, 'PMC13')
 *     __Pyx_globals['PMC14'] = VERegIds(PMC14, 'PMC14')
 *     __Pyx_globals['PMC15'] = VERegIds(PMC15, 'PMC15')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PSW'] = VERegIds(PSW, 'PSW')
 *     __Pyx_globals['EXS'] = VERegIds(EXS, 'EXS')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMC15); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_PMC15);
    __Pyx_GIVEREF(__pyx_n_s_PMC15);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_PMC15);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 262, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMC15, __pyx_t_95) < 0)) __PYX_ERR(1, 262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":263
 *     __Pyx_globals['PMC14'] = VERegIds(PMC14, 'PMC14')
 *     __Pyx_globals['PMC15'] = VERegIds(PMC15, 'PMC15')
 *     __Pyx_globals['PSW'] = VERegIds(PSW, 'PSW')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['EXS'] = VERegIds(EXS, 'EXS')
 *     __Pyx_globals['IC'] = VERegIds(IC, 'IC')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PSW); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_PSW);
    __Pyx_GIVEREF(__pyx_n_s_PSW);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_PSW);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 263, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PSW, __pyx_t_96) < 0)) __PYX_ERR(1, 263, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":264
 *     __Pyx_globals['PMC15'] = VERegIds(PMC15, 'PMC15')
 *     __Pyx_globals['PSW'] = VERegIds(PSW, 'PSW')
 *     __Pyx_globals['EXS'] = VERegIds(EXS, 'EXS')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['IC'] = VERegIds(IC, 'IC')
 *     __Pyx_globals['ICE'] = VERegIds(ICE, 'ICE')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_EXS); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_EXS);
    __Pyx_GIVEREF(__pyx_n_s_EXS);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_EXS);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 264, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_EXS, __pyx_t_3) < 0)) __PYX_ERR(1, 264, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":265
 *     __Pyx_globals['PSW'] = VERegIds(PSW, 'PSW')
 *     __Pyx_globals['EXS'] = VERegIds(EXS, 'EXS')
 *     __Pyx_globals['IC'] = VERegIds(IC, 'IC')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['ICE'] = VERegIds(ICE, 'ICE')
 *     __Pyx_globals['VIXR'] = VERegIds(VIXR, 'VIXR')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_IC); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_IC);
    __Pyx_GIVEREF(__pyx_n_s_IC);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_IC);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 265, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_IC, __pyx_t_95) < 0)) __PYX_ERR(1, 265, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":266
 *     __Pyx_globals['EXS'] = VERegIds(EXS, 'EXS')
 *     __Pyx_globals['IC'] = VERegIds(IC, 'IC')
 *     __Pyx_globals['ICE'] = VERegIds(ICE, 'ICE')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['VIXR'] = VERegIds(VIXR, 'VIXR')
 *     __Pyx_globals['VL'] = VERegIds(VL, 'VL')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_ICE); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_ICE);
    __Pyx_GIVEREF(__pyx_n_s_ICE);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_ICE);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 266, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_ICE, __pyx_t_96) < 0)) __PYX_ERR(1, 266, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":267
 *     __Pyx_globals['IC'] = VERegIds(IC, 'IC')
 *     __Pyx_globals['ICE'] = VERegIds(ICE, 'ICE')
 *     __Pyx_globals['VIXR'] = VERegIds(VIXR, 'VIXR')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['VL'] = VERegIds(VL, 'VL')
 *     __Pyx_globals['SAR'] = VERegIds(SAR, 'SAR')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 267, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_VIXR); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 267, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 267, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_VIXR);
    __Pyx_GIVEREF(__pyx_n_s_VIXR);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_VIXR);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 267, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 267, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_VIXR, __pyx_t_3) < 0)) __PYX_ERR(1, 267, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":268
 *     __Pyx_globals['ICE'] = VERegIds(ICE, 'ICE')
 *     __Pyx_globals['VIXR'] = VERegIds(VIXR, 'VIXR')
 *     __Pyx_globals['VL'] = VERegIds(VL, 'VL')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SAR'] = VERegIds(SAR, 'SAR')
 *     __Pyx_globals['PMMR'] = VERegIds(PMMR, 'PMMR')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_VL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_VL);
    __Pyx_GIVEREF(__pyx_n_s_VL);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_VL);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 268, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_VL, __pyx_t_95) < 0)) __PYX_ERR(1, 268, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":269
 *     __Pyx_globals['VIXR'] = VERegIds(VIXR, 'VIXR')
 *     __Pyx_globals['VL'] = VERegIds(VL, 'VL')
 *     __Pyx_globals['SAR'] = VERegIds(SAR, 'SAR')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMMR'] = VERegIds(PMMR, 'PMMR')
 *     __Pyx_globals['PMCR00'] = VERegIds(PMCR00, 'PMCR00')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SAR); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SAR);
    __Pyx_GIVEREF(__pyx_n_s_SAR);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SAR);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 269, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SAR, __pyx_t_96) < 0)) __PYX_ERR(1, 269, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":270
 *     __Pyx_globals['VL'] = VERegIds(VL, 'VL')
 *     __Pyx_globals['SAR'] = VERegIds(SAR, 'SAR')
 *     __Pyx_globals['PMMR'] = VERegIds(PMMR, 'PMMR')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMCR00'] = VERegIds(PMCR00, 'PMCR00')
 *     __Pyx_globals['PMCR01'] = VERegIds(PMCR01, 'PMCR01')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 270, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMMR); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 270, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 270, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_PMMR);
    __Pyx_GIVEREF(__pyx_n_s_PMMR);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_PMMR);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 270, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 270, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMMR, __pyx_t_3) < 0)) __PYX_ERR(1, 270, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":271
 *     __Pyx_globals['SAR'] = VERegIds(SAR, 'SAR')
 *     __Pyx_globals['PMMR'] = VERegIds(PMMR, 'PMMR')
 *     __Pyx_globals['PMCR00'] = VERegIds(PMCR00, 'PMCR00')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMCR01'] = VERegIds(PMCR01, 'PMCR01')
 *     __Pyx_globals['PMCR02'] = VERegIds(PMCR02, 'PMCR02')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMCR00); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_PMCR00);
    __Pyx_GIVEREF(__pyx_n_s_PMCR00);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_PMCR00);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 271, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMCR00, __pyx_t_95) < 0)) __PYX_ERR(1, 271, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":272
 *     __Pyx_globals['PMMR'] = VERegIds(PMMR, 'PMMR')
 *     __Pyx_globals['PMCR00'] = VERegIds(PMCR00, 'PMCR00')
 *     __Pyx_globals['PMCR01'] = VERegIds(PMCR01, 'PMCR01')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMCR02'] = VERegIds(PMCR02, 'PMCR02')
 *     __Pyx_globals['PMCR03'] = VERegIds(PMCR03, 'PMCR03')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMCR01); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_PMCR01);
    __Pyx_GIVEREF(__pyx_n_s_PMCR01);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_PMCR01);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 272, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMCR01, __pyx_t_96) < 0)) __PYX_ERR(1, 272, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":273
 *     __Pyx_globals['PMCR00'] = VERegIds(PMCR00, 'PMCR00')
 *     __Pyx_globals['PMCR01'] = VERegIds(PMCR01, 'PMCR01')
 *     __Pyx_globals['PMCR02'] = VERegIds(PMCR02, 'PMCR02')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMCR03'] = VERegIds(PMCR03, 'PMCR03')
 *     __Pyx_globals['PMCR04'] = VERegIds(PMCR04, 'PMCR04')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMCR02); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_PMCR02);
    __Pyx_GIVEREF(__pyx_n_s_PMCR02);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_PMCR02);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 273, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMCR02, __pyx_t_3) < 0)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":274
 *     __Pyx_globals['PMCR01'] = VERegIds(PMCR01, 'PMCR01')
 *     __Pyx_globals['PMCR02'] = VERegIds(PMCR02, 'PMCR02')
 *     __Pyx_globals['PMCR03'] = VERegIds(PMCR03, 'PMCR03')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['PMCR04'] = VERegIds(PMCR04, 'PMCR04')
 *     __Pyx_globals['SR00'] = VERegIds(SR00, 'SR00')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMCR03); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_PMCR03);
    __Pyx_GIVEREF(__pyx_n_s_PMCR03);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_PMCR03);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 274, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMCR03, __pyx_t_95) < 0)) __PYX_ERR(1, 274, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":275
 *     __Pyx_globals['PMCR02'] = VERegIds(PMCR02, 'PMCR02')
 *     __Pyx_globals['PMCR03'] = VERegIds(PMCR03, 'PMCR03')
 *     __Pyx_globals['PMCR04'] = VERegIds(PMCR04, 'PMCR04')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR00'] = VERegIds(SR00, 'SR00')
 *     __Pyx_globals['SR01'] = VERegIds(SR01, 'SR01')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_PMCR04); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_PMCR04);
    __Pyx_GIVEREF(__pyx_n_s_PMCR04);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_PMCR04);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 275, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_PMCR04, __pyx_t_96) < 0)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":276
 *     __Pyx_globals['PMCR03'] = VERegIds(PMCR03, 'PMCR03')
 *     __Pyx_globals['PMCR04'] = VERegIds(PMCR04, 'PMCR04')
 *     __Pyx_globals['SR00'] = VERegIds(SR00, 'SR00')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR01'] = VERegIds(SR01, 'SR01')
 *     __Pyx_globals['SR02'] = VERegIds(SR02, 'SR02')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR00); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR00);
    __Pyx_GIVEREF(__pyx_n_s_SR00);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR00);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 276, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR00, __pyx_t_3) < 0)) __PYX_ERR(1, 276, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":277
 *     __Pyx_globals['PMCR04'] = VERegIds(PMCR04, 'PMCR04')
 *     __Pyx_globals['SR00'] = VERegIds(SR00, 'SR00')
 *     __Pyx_globals['SR01'] = VERegIds(SR01, 'SR01')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR02'] = VERegIds(SR02, 'SR02')
 *     __Pyx_globals['SR03'] = VERegIds(SR03, 'SR03')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR01); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR01);
    __Pyx_GIVEREF(__pyx_n_s_SR01);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR01);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 277, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR01, __pyx_t_95) < 0)) __PYX_ERR(1, 277, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":278
 *     __Pyx_globals['SR00'] = VERegIds(SR00, 'SR00')
 *     __Pyx_globals['SR01'] = VERegIds(SR01, 'SR01')
 *     __Pyx_globals['SR02'] = VERegIds(SR02, 'SR02')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR03'] = VERegIds(SR03, 'SR03')
 *     __Pyx_globals['SR04'] = VERegIds(SR04, 'SR04')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR02); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR02);
    __Pyx_GIVEREF(__pyx_n_s_SR02);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR02);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 278, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR02, __pyx_t_96) < 0)) __PYX_ERR(1, 278, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":279
 *     __Pyx_globals['SR01'] = VERegIds(SR01, 'SR01')
 *     __Pyx_globals['SR02'] = VERegIds(SR02, 'SR02')
 *     __Pyx_globals['SR03'] = VERegIds(SR03, 'SR03')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR04'] = VERegIds(SR04, 'SR04')
 *     __Pyx_globals['SR05'] = VERegIds(SR05, 'SR05')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 279, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR03); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 279, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 279, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR03);
    __Pyx_GIVEREF(__pyx_n_s_SR03);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR03);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 279, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 279, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR03, __pyx_t_3) < 0)) __PYX_ERR(1, 279, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":280
 *     __Pyx_globals['SR02'] = VERegIds(SR02, 'SR02')
 *     __Pyx_globals['SR03'] = VERegIds(SR03, 'SR03')
 *     __Pyx_globals['SR04'] = VERegIds(SR04, 'SR04')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR05'] = VERegIds(SR05, 'SR05')
 *     __Pyx_globals['SR06'] = VERegIds(SR06, 'SR06')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR04); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR04);
    __Pyx_GIVEREF(__pyx_n_s_SR04);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR04);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 280, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR04, __pyx_t_95) < 0)) __PYX_ERR(1, 280, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":281
 *     __Pyx_globals['SR03'] = VERegIds(SR03, 'SR03')
 *     __Pyx_globals['SR04'] = VERegIds(SR04, 'SR04')
 *     __Pyx_globals['SR05'] = VERegIds(SR05, 'SR05')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR06'] = VERegIds(SR06, 'SR06')
 *     __Pyx_globals['SR07'] = VERegIds(SR07, 'SR07')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR05); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR05);
    __Pyx_GIVEREF(__pyx_n_s_SR05);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR05);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 281, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR05, __pyx_t_96) < 0)) __PYX_ERR(1, 281, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":282
 *     __Pyx_globals['SR04'] = VERegIds(SR04, 'SR04')
 *     __Pyx_globals['SR05'] = VERegIds(SR05, 'SR05')
 *     __Pyx_globals['SR06'] = VERegIds(SR06, 'SR06')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR07'] = VERegIds(SR07, 'SR07')
 *     __Pyx_globals['SR08'] = VERegIds(SR08, 'SR08')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR06); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR06);
    __Pyx_GIVEREF(__pyx_n_s_SR06);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR06);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 282, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR06, __pyx_t_3) < 0)) __PYX_ERR(1, 282, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":283
 *     __Pyx_globals['SR05'] = VERegIds(SR05, 'SR05')
 *     __Pyx_globals['SR06'] = VERegIds(SR06, 'SR06')
 *     __Pyx_globals['SR07'] = VERegIds(SR07, 'SR07')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR08'] = VERegIds(SR08, 'SR08')
 *     __Pyx_globals['SR09'] = VERegIds(SR09, 'SR09')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 283, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR07); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 283, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 283, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR07);
    __Pyx_GIVEREF(__pyx_n_s_SR07);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR07);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 283, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 283, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR07, __pyx_t_95) < 0)) __PYX_ERR(1, 283, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":284
 *     __Pyx_globals['SR06'] = VERegIds(SR06, 'SR06')
 *     __Pyx_globals['SR07'] = VERegIds(SR07, 'SR07')
 *     __Pyx_globals['SR08'] = VERegIds(SR08, 'SR08')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR09'] = VERegIds(SR09, 'SR09')
 *     __Pyx_globals['SR10'] = VERegIds(SR10, 'SR10')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR08); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR08);
    __Pyx_GIVEREF(__pyx_n_s_SR08);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR08);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 284, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR08, __pyx_t_96) < 0)) __PYX_ERR(1, 284, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":285
 *     __Pyx_globals['SR07'] = VERegIds(SR07, 'SR07')
 *     __Pyx_globals['SR08'] = VERegIds(SR08, 'SR08')
 *     __Pyx_globals['SR09'] = VERegIds(SR09, 'SR09')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR10'] = VERegIds(SR10, 'SR10')
 *     __Pyx_globals['SR11'] = VERegIds(SR11, 'SR11')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR09); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR09);
    __Pyx_GIVEREF(__pyx_n_s_SR09);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR09);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 285, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR09, __pyx_t_3) < 0)) __PYX_ERR(1, 285, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":286
 *     __Pyx_globals['SR08'] = VERegIds(SR08, 'SR08')
 *     __Pyx_globals['SR09'] = VERegIds(SR09, 'SR09')
 *     __Pyx_globals['SR10'] = VERegIds(SR10, 'SR10')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR11'] = VERegIds(SR11, 'SR11')
 *     __Pyx_globals['SR12'] = VERegIds(SR12, 'SR12')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR10); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR10);
    __Pyx_GIVEREF(__pyx_n_s_SR10);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR10);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 286, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR10, __pyx_t_95) < 0)) __PYX_ERR(1, 286, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":287
 *     __Pyx_globals['SR09'] = VERegIds(SR09, 'SR09')
 *     __Pyx_globals['SR10'] = VERegIds(SR10, 'SR10')
 *     __Pyx_globals['SR11'] = VERegIds(SR11, 'SR11')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR12'] = VERegIds(SR12, 'SR12')
 *     __Pyx_globals['SR13'] = VERegIds(SR13, 'SR13')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR11); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR11);
    __Pyx_GIVEREF(__pyx_n_s_SR11);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR11);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 287, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR11, __pyx_t_96) < 0)) __PYX_ERR(1, 287, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":288
 *     __Pyx_globals['SR10'] = VERegIds(SR10, 'SR10')
 *     __Pyx_globals['SR11'] = VERegIds(SR11, 'SR11')
 *     __Pyx_globals['SR12'] = VERegIds(SR12, 'SR12')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR13'] = VERegIds(SR13, 'SR13')
 *     __Pyx_globals['SR14'] = VERegIds(SR14, 'SR14')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR12); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR12);
    __Pyx_GIVEREF(__pyx_n_s_SR12);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR12);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 288, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR12, __pyx_t_3) < 0)) __PYX_ERR(1, 288, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":289
 *     __Pyx_globals['SR11'] = VERegIds(SR11, 'SR11')
 *     __Pyx_globals['SR12'] = VERegIds(SR12, 'SR12')
 *     __Pyx_globals['SR13'] = VERegIds(SR13, 'SR13')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR14'] = VERegIds(SR14, 'SR14')
 *     __Pyx_globals['SR15'] = VERegIds(SR15, 'SR15')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR13); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR13);
    __Pyx_GIVEREF(__pyx_n_s_SR13);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR13);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 289, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR13, __pyx_t_95) < 0)) __PYX_ERR(1, 289, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":290
 *     __Pyx_globals['SR12'] = VERegIds(SR12, 'SR12')
 *     __Pyx_globals['SR13'] = VERegIds(SR13, 'SR13')
 *     __Pyx_globals['SR14'] = VERegIds(SR14, 'SR14')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR15'] = VERegIds(SR15, 'SR15')
 *     __Pyx_globals['SR16'] = VERegIds(SR16, 'SR16')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR14); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR14);
    __Pyx_GIVEREF(__pyx_n_s_SR14);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR14);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 290, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR14, __pyx_t_96) < 0)) __PYX_ERR(1, 290, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":291
 *     __Pyx_globals['SR13'] = VERegIds(SR13, 'SR13')
 *     __Pyx_globals['SR14'] = VERegIds(SR14, 'SR14')
 *     __Pyx_globals['SR15'] = VERegIds(SR15, 'SR15')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR16'] = VERegIds(SR16, 'SR16')
 *     __Pyx_globals['SR17'] = VERegIds(SR17, 'SR17')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR15); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR15);
    __Pyx_GIVEREF(__pyx_n_s_SR15);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR15);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 291, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR15, __pyx_t_3) < 0)) __PYX_ERR(1, 291, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":292
 *     __Pyx_globals['SR14'] = VERegIds(SR14, 'SR14')
 *     __Pyx_globals['SR15'] = VERegIds(SR15, 'SR15')
 *     __Pyx_globals['SR16'] = VERegIds(SR16, 'SR16')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR17'] = VERegIds(SR17, 'SR17')
 *     __Pyx_globals['SR18'] = VERegIds(SR18, 'SR18')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR16); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR16);
    __Pyx_GIVEREF(__pyx_n_s_SR16);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR16);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 292, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR16, __pyx_t_95) < 0)) __PYX_ERR(1, 292, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":293
 *     __Pyx_globals['SR15'] = VERegIds(SR15, 'SR15')
 *     __Pyx_globals['SR16'] = VERegIds(SR16, 'SR16')
 *     __Pyx_globals['SR17'] = VERegIds(SR17, 'SR17')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR18'] = VERegIds(SR18, 'SR18')
 *     __Pyx_globals['SR19'] = VERegIds(SR19, 'SR19')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR17); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR17);
    __Pyx_GIVEREF(__pyx_n_s_SR17);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR17);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 293, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR17, __pyx_t_96) < 0)) __PYX_ERR(1, 293, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":294
 *     __Pyx_globals['SR16'] = VERegIds(SR16, 'SR16')
 *     __Pyx_globals['SR17'] = VERegIds(SR17, 'SR17')
 *     __Pyx_globals['SR18'] = VERegIds(SR18, 'SR18')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR19'] = VERegIds(SR19, 'SR19')
 *     __Pyx_globals['SR20'] = VERegIds(SR20, 'SR20')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR18); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR18);
    __Pyx_GIVEREF(__pyx_n_s_SR18);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR18);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 294, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR18, __pyx_t_3) < 0)) __PYX_ERR(1, 294, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":295
 *     __Pyx_globals['SR17'] = VERegIds(SR17, 'SR17')
 *     __Pyx_globals['SR18'] = VERegIds(SR18, 'SR18')
 *     __Pyx_globals['SR19'] = VERegIds(SR19, 'SR19')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR20'] = VERegIds(SR20, 'SR20')
 *     __Pyx_globals['SR21'] = VERegIds(SR21, 'SR21')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 295, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR19); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 295, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 295, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR19);
    __Pyx_GIVEREF(__pyx_n_s_SR19);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR19);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 295, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 295, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR19, __pyx_t_95) < 0)) __PYX_ERR(1, 295, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":296
 *     __Pyx_globals['SR18'] = VERegIds(SR18, 'SR18')
 *     __Pyx_globals['SR19'] = VERegIds(SR19, 'SR19')
 *     __Pyx_globals['SR20'] = VERegIds(SR20, 'SR20')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR21'] = VERegIds(SR21, 'SR21')
 *     __Pyx_globals['SR22'] = VERegIds(SR22, 'SR22')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 296, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR20); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 296, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 296, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR20);
    __Pyx_GIVEREF(__pyx_n_s_SR20);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR20);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 296, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 296, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR20, __pyx_t_96) < 0)) __PYX_ERR(1, 296, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":297
 *     __Pyx_globals['SR19'] = VERegIds(SR19, 'SR19')
 *     __Pyx_globals['SR20'] = VERegIds(SR20, 'SR20')
 *     __Pyx_globals['SR21'] = VERegIds(SR21, 'SR21')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR22'] = VERegIds(SR22, 'SR22')
 *     __Pyx_globals['SR23'] = VERegIds(SR23, 'SR23')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR21); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR21);
    __Pyx_GIVEREF(__pyx_n_s_SR21);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR21);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 297, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR21, __pyx_t_3) < 0)) __PYX_ERR(1, 297, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":298
 *     __Pyx_globals['SR20'] = VERegIds(SR20, 'SR20')
 *     __Pyx_globals['SR21'] = VERegIds(SR21, 'SR21')
 *     __Pyx_globals['SR22'] = VERegIds(SR22, 'SR22')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR23'] = VERegIds(SR23, 'SR23')
 *     __Pyx_globals['SR24'] = VERegIds(SR24, 'SR24')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR22); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR22);
    __Pyx_GIVEREF(__pyx_n_s_SR22);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR22);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 298, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR22, __pyx_t_95) < 0)) __PYX_ERR(1, 298, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":299
 *     __Pyx_globals['SR21'] = VERegIds(SR21, 'SR21')
 *     __Pyx_globals['SR22'] = VERegIds(SR22, 'SR22')
 *     __Pyx_globals['SR23'] = VERegIds(SR23, 'SR23')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR24'] = VERegIds(SR24, 'SR24')
 *     __Pyx_globals['SR25'] = VERegIds(SR25, 'SR25')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR23); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR23);
    __Pyx_GIVEREF(__pyx_n_s_SR23);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR23);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 299, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR23, __pyx_t_96) < 0)) __PYX_ERR(1, 299, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":300
 *     __Pyx_globals['SR22'] = VERegIds(SR22, 'SR22')
 *     __Pyx_globals['SR23'] = VERegIds(SR23, 'SR23')
 *     __Pyx_globals['SR24'] = VERegIds(SR24, 'SR24')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR25'] = VERegIds(SR25, 'SR25')
 *     __Pyx_globals['SR26'] = VERegIds(SR26, 'SR26')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR24); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR24);
    __Pyx_GIVEREF(__pyx_n_s_SR24);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR24);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 300, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR24, __pyx_t_3) < 0)) __PYX_ERR(1, 300, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":301
 *     __Pyx_globals['SR23'] = VERegIds(SR23, 'SR23')
 *     __Pyx_globals['SR24'] = VERegIds(SR24, 'SR24')
 *     __Pyx_globals['SR25'] = VERegIds(SR25, 'SR25')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR26'] = VERegIds(SR26, 'SR26')
 *     __Pyx_globals['SR27'] = VERegIds(SR27, 'SR27')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR25); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR25);
    __Pyx_GIVEREF(__pyx_n_s_SR25);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR25);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 301, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR25, __pyx_t_95) < 0)) __PYX_ERR(1, 301, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":302
 *     __Pyx_globals['SR24'] = VERegIds(SR24, 'SR24')
 *     __Pyx_globals['SR25'] = VERegIds(SR25, 'SR25')
 *     __Pyx_globals['SR26'] = VERegIds(SR26, 'SR26')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR27'] = VERegIds(SR27, 'SR27')
 *     __Pyx_globals['SR28'] = VERegIds(SR28, 'SR28')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR26); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR26);
    __Pyx_GIVEREF(__pyx_n_s_SR26);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR26);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 302, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR26, __pyx_t_96) < 0)) __PYX_ERR(1, 302, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":303
 *     __Pyx_globals['SR25'] = VERegIds(SR25, 'SR25')
 *     __Pyx_globals['SR26'] = VERegIds(SR26, 'SR26')
 *     __Pyx_globals['SR27'] = VERegIds(SR27, 'SR27')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR28'] = VERegIds(SR28, 'SR28')
 *     __Pyx_globals['SR29'] = VERegIds(SR29, 'SR29')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR27); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR27);
    __Pyx_GIVEREF(__pyx_n_s_SR27);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR27);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 303, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR27, __pyx_t_3) < 0)) __PYX_ERR(1, 303, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":304
 *     __Pyx_globals['SR26'] = VERegIds(SR26, 'SR26')
 *     __Pyx_globals['SR27'] = VERegIds(SR27, 'SR27')
 *     __Pyx_globals['SR28'] = VERegIds(SR28, 'SR28')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR29'] = VERegIds(SR29, 'SR29')
 *     __Pyx_globals['SR30'] = VERegIds(SR30, 'SR30')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR28); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR28);
    __Pyx_GIVEREF(__pyx_n_s_SR28);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR28);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 304, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR28, __pyx_t_95) < 0)) __PYX_ERR(1, 304, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":305
 *     __Pyx_globals['SR27'] = VERegIds(SR27, 'SR27')
 *     __Pyx_globals['SR28'] = VERegIds(SR28, 'SR28')
 *     __Pyx_globals['SR29'] = VERegIds(SR29, 'SR29')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR30'] = VERegIds(SR30, 'SR30')
 *     __Pyx_globals['SR31'] = VERegIds(SR31, 'SR31')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR29); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR29);
    __Pyx_GIVEREF(__pyx_n_s_SR29);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR29);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 305, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR29, __pyx_t_96) < 0)) __PYX_ERR(1, 305, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":306
 *     __Pyx_globals['SR28'] = VERegIds(SR28, 'SR28')
 *     __Pyx_globals['SR29'] = VERegIds(SR29, 'SR29')
 *     __Pyx_globals['SR30'] = VERegIds(SR30, 'SR30')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR31'] = VERegIds(SR31, 'SR31')
 *     __Pyx_globals['SR32'] = VERegIds(SR32, 'SR32')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR30); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR30);
    __Pyx_GIVEREF(__pyx_n_s_SR30);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR30);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 306, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR30, __pyx_t_3) < 0)) __PYX_ERR(1, 306, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":307
 *     __Pyx_globals['SR29'] = VERegIds(SR29, 'SR29')
 *     __Pyx_globals['SR30'] = VERegIds(SR30, 'SR30')
 *     __Pyx_globals['SR31'] = VERegIds(SR31, 'SR31')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR32'] = VERegIds(SR32, 'SR32')
 *     __Pyx_globals['SR33'] = VERegIds(SR33, 'SR33')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR31); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR31);
    __Pyx_GIVEREF(__pyx_n_s_SR31);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR31);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 307, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR31, __pyx_t_95) < 0)) __PYX_ERR(1, 307, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":308
 *     __Pyx_globals['SR30'] = VERegIds(SR30, 'SR30')
 *     __Pyx_globals['SR31'] = VERegIds(SR31, 'SR31')
 *     __Pyx_globals['SR32'] = VERegIds(SR32, 'SR32')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR33'] = VERegIds(SR33, 'SR33')
 *     __Pyx_globals['SR34'] = VERegIds(SR34, 'SR34')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR32); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR32);
    __Pyx_GIVEREF(__pyx_n_s_SR32);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR32);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 308, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR32, __pyx_t_96) < 0)) __PYX_ERR(1, 308, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":309
 *     __Pyx_globals['SR31'] = VERegIds(SR31, 'SR31')
 *     __Pyx_globals['SR32'] = VERegIds(SR32, 'SR32')
 *     __Pyx_globals['SR33'] = VERegIds(SR33, 'SR33')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR34'] = VERegIds(SR34, 'SR34')
 *     __Pyx_globals['SR35'] = VERegIds(SR35, 'SR35')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR33); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR33);
    __Pyx_GIVEREF(__pyx_n_s_SR33);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR33);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 309, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR33, __pyx_t_3) < 0)) __PYX_ERR(1, 309, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":310
 *     __Pyx_globals['SR32'] = VERegIds(SR32, 'SR32')
 *     __Pyx_globals['SR33'] = VERegIds(SR33, 'SR33')
 *     __Pyx_globals['SR34'] = VERegIds(SR34, 'SR34')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR35'] = VERegIds(SR35, 'SR35')
 *     __Pyx_globals['SR36'] = VERegIds(SR36, 'SR36')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR34); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR34);
    __Pyx_GIVEREF(__pyx_n_s_SR34);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR34);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 310, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR34, __pyx_t_95) < 0)) __PYX_ERR(1, 310, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":311
 *     __Pyx_globals['SR33'] = VERegIds(SR33, 'SR33')
 *     __Pyx_globals['SR34'] = VERegIds(SR34, 'SR34')
 *     __Pyx_globals['SR35'] = VERegIds(SR35, 'SR35')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR36'] = VERegIds(SR36, 'SR36')
 *     __Pyx_globals['SR37'] = VERegIds(SR37, 'SR37')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR35); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR35);
    __Pyx_GIVEREF(__pyx_n_s_SR35);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR35);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 311, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR35, __pyx_t_96) < 0)) __PYX_ERR(1, 311, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":312
 *     __Pyx_globals['SR34'] = VERegIds(SR34, 'SR34')
 *     __Pyx_globals['SR35'] = VERegIds(SR35, 'SR35')
 *     __Pyx_globals['SR36'] = VERegIds(SR36, 'SR36')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR37'] = VERegIds(SR37, 'SR37')
 *     __Pyx_globals['SR38'] = VERegIds(SR38, 'SR38')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR36); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR36);
    __Pyx_GIVEREF(__pyx_n_s_SR36);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR36);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 312, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR36, __pyx_t_3) < 0)) __PYX_ERR(1, 312, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":313
 *     __Pyx_globals['SR35'] = VERegIds(SR35, 'SR35')
 *     __Pyx_globals['SR36'] = VERegIds(SR36, 'SR36')
 *     __Pyx_globals['SR37'] = VERegIds(SR37, 'SR37')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR38'] = VERegIds(SR38, 'SR38')
 *     __Pyx_globals['SR39'] = VERegIds(SR39, 'SR39')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR37); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR37);
    __Pyx_GIVEREF(__pyx_n_s_SR37);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR37);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 313, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR37, __pyx_t_95) < 0)) __PYX_ERR(1, 313, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":314
 *     __Pyx_globals['SR36'] = VERegIds(SR36, 'SR36')
 *     __Pyx_globals['SR37'] = VERegIds(SR37, 'SR37')
 *     __Pyx_globals['SR38'] = VERegIds(SR38, 'SR38')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR39'] = VERegIds(SR39, 'SR39')
 *     __Pyx_globals['SR40'] = VERegIds(SR40, 'SR40')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR38); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR38);
    __Pyx_GIVEREF(__pyx_n_s_SR38);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR38);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 314, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR38, __pyx_t_96) < 0)) __PYX_ERR(1, 314, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":315
 *     __Pyx_globals['SR37'] = VERegIds(SR37, 'SR37')
 *     __Pyx_globals['SR38'] = VERegIds(SR38, 'SR38')
 *     __Pyx_globals['SR39'] = VERegIds(SR39, 'SR39')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR40'] = VERegIds(SR40, 'SR40')
 *     __Pyx_globals['SR41'] = VERegIds(SR41, 'SR41')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR39); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR39);
    __Pyx_GIVEREF(__pyx_n_s_SR39);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR39);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 315, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR39, __pyx_t_3) < 0)) __PYX_ERR(1, 315, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":316
 *     __Pyx_globals['SR38'] = VERegIds(SR38, 'SR38')
 *     __Pyx_globals['SR39'] = VERegIds(SR39, 'SR39')
 *     __Pyx_globals['SR40'] = VERegIds(SR40, 'SR40')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR41'] = VERegIds(SR41, 'SR41')
 *     __Pyx_globals['SR42'] = VERegIds(SR42, 'SR42')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 316, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR40); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 316, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 316, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR40);
    __Pyx_GIVEREF(__pyx_n_s_SR40);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR40);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 316, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 316, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR40, __pyx_t_95) < 0)) __PYX_ERR(1, 316, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":317
 *     __Pyx_globals['SR39'] = VERegIds(SR39, 'SR39')
 *     __Pyx_globals['SR40'] = VERegIds(SR40, 'SR40')
 *     __Pyx_globals['SR41'] = VERegIds(SR41, 'SR41')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR42'] = VERegIds(SR42, 'SR42')
 *     __Pyx_globals['SR43'] = VERegIds(SR43, 'SR43')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR41); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR41);
    __Pyx_GIVEREF(__pyx_n_s_SR41);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR41);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 317, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR41, __pyx_t_96) < 0)) __PYX_ERR(1, 317, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":318
 *     __Pyx_globals['SR40'] = VERegIds(SR40, 'SR40')
 *     __Pyx_globals['SR41'] = VERegIds(SR41, 'SR41')
 *     __Pyx_globals['SR42'] = VERegIds(SR42, 'SR42')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR43'] = VERegIds(SR43, 'SR43')
 *     __Pyx_globals['SR44'] = VERegIds(SR44, 'SR44')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR42); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR42);
    __Pyx_GIVEREF(__pyx_n_s_SR42);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR42);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 318, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR42, __pyx_t_3) < 0)) __PYX_ERR(1, 318, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":319
 *     __Pyx_globals['SR41'] = VERegIds(SR41, 'SR41')
 *     __Pyx_globals['SR42'] = VERegIds(SR42, 'SR42')
 *     __Pyx_globals['SR43'] = VERegIds(SR43, 'SR43')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR44'] = VERegIds(SR44, 'SR44')
 *     __Pyx_globals['SR45'] = VERegIds(SR45, 'SR45')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR43); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR43);
    __Pyx_GIVEREF(__pyx_n_s_SR43);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR43);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 319, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR43, __pyx_t_95) < 0)) __PYX_ERR(1, 319, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":320
 *     __Pyx_globals['SR42'] = VERegIds(SR42, 'SR42')
 *     __Pyx_globals['SR43'] = VERegIds(SR43, 'SR43')
 *     __Pyx_globals['SR44'] = VERegIds(SR44, 'SR44')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR45'] = VERegIds(SR45, 'SR45')
 *     __Pyx_globals['SR46'] = VERegIds(SR46, 'SR46')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 320, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR44); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 320, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 320, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR44);
    __Pyx_GIVEREF(__pyx_n_s_SR44);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR44);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 320, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 320, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR44, __pyx_t_96) < 0)) __PYX_ERR(1, 320, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":321
 *     __Pyx_globals['SR43'] = VERegIds(SR43, 'SR43')
 *     __Pyx_globals['SR44'] = VERegIds(SR44, 'SR44')
 *     __Pyx_globals['SR45'] = VERegIds(SR45, 'SR45')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR46'] = VERegIds(SR46, 'SR46')
 *     __Pyx_globals['SR47'] = VERegIds(SR47, 'SR47')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR45); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR45);
    __Pyx_GIVEREF(__pyx_n_s_SR45);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR45);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 321, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR45, __pyx_t_3) < 0)) __PYX_ERR(1, 321, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":322
 *     __Pyx_globals['SR44'] = VERegIds(SR44, 'SR44')
 *     __Pyx_globals['SR45'] = VERegIds(SR45, 'SR45')
 *     __Pyx_globals['SR46'] = VERegIds(SR46, 'SR46')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR47'] = VERegIds(SR47, 'SR47')
 *     __Pyx_globals['SR48'] = VERegIds(SR48, 'SR48')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR46); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR46);
    __Pyx_GIVEREF(__pyx_n_s_SR46);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR46);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 322, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR46, __pyx_t_95) < 0)) __PYX_ERR(1, 322, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":323
 *     __Pyx_globals['SR45'] = VERegIds(SR45, 'SR45')
 *     __Pyx_globals['SR46'] = VERegIds(SR46, 'SR46')
 *     __Pyx_globals['SR47'] = VERegIds(SR47, 'SR47')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR48'] = VERegIds(SR48, 'SR48')
 *     __Pyx_globals['SR49'] = VERegIds(SR49, 'SR49')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR47); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR47);
    __Pyx_GIVEREF(__pyx_n_s_SR47);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR47);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 323, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR47, __pyx_t_96) < 0)) __PYX_ERR(1, 323, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":324
 *     __Pyx_globals['SR46'] = VERegIds(SR46, 'SR46')
 *     __Pyx_globals['SR47'] = VERegIds(SR47, 'SR47')
 *     __Pyx_globals['SR48'] = VERegIds(SR48, 'SR48')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR49'] = VERegIds(SR49, 'SR49')
 *     __Pyx_globals['SR50'] = VERegIds(SR50, 'SR50')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR48); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR48);
    __Pyx_GIVEREF(__pyx_n_s_SR48);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR48);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 324, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR48, __pyx_t_3) < 0)) __PYX_ERR(1, 324, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":325
 *     __Pyx_globals['SR47'] = VERegIds(SR47, 'SR47')
 *     __Pyx_globals['SR48'] = VERegIds(SR48, 'SR48')
 *     __Pyx_globals['SR49'] = VERegIds(SR49, 'SR49')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR50'] = VERegIds(SR50, 'SR50')
 *     __Pyx_globals['SR51'] = VERegIds(SR51, 'SR51')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR49); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR49);
    __Pyx_GIVEREF(__pyx_n_s_SR49);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR49);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 325, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR49, __pyx_t_95) < 0)) __PYX_ERR(1, 325, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":326
 *     __Pyx_globals['SR48'] = VERegIds(SR48, 'SR48')
 *     __Pyx_globals['SR49'] = VERegIds(SR49, 'SR49')
 *     __Pyx_globals['SR50'] = VERegIds(SR50, 'SR50')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR51'] = VERegIds(SR51, 'SR51')
 *     __Pyx_globals['SR52'] = VERegIds(SR52, 'SR52')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR50); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR50);
    __Pyx_GIVEREF(__pyx_n_s_SR50);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR50);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 326, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR50, __pyx_t_96) < 0)) __PYX_ERR(1, 326, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":327
 *     __Pyx_globals['SR49'] = VERegIds(SR49, 'SR49')
 *     __Pyx_globals['SR50'] = VERegIds(SR50, 'SR50')
 *     __Pyx_globals['SR51'] = VERegIds(SR51, 'SR51')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR52'] = VERegIds(SR52, 'SR52')
 *     __Pyx_globals['SR53'] = VERegIds(SR53, 'SR53')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR51); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR51);
    __Pyx_GIVEREF(__pyx_n_s_SR51);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR51);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 327, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR51, __pyx_t_3) < 0)) __PYX_ERR(1, 327, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":328
 *     __Pyx_globals['SR50'] = VERegIds(SR50, 'SR50')
 *     __Pyx_globals['SR51'] = VERegIds(SR51, 'SR51')
 *     __Pyx_globals['SR52'] = VERegIds(SR52, 'SR52')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR53'] = VERegIds(SR53, 'SR53')
 *     __Pyx_globals['SR54'] = VERegIds(SR54, 'SR54')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR52); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR52);
    __Pyx_GIVEREF(__pyx_n_s_SR52);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR52);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 328, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR52, __pyx_t_95) < 0)) __PYX_ERR(1, 328, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":329
 *     __Pyx_globals['SR51'] = VERegIds(SR51, 'SR51')
 *     __Pyx_globals['SR52'] = VERegIds(SR52, 'SR52')
 *     __Pyx_globals['SR53'] = VERegIds(SR53, 'SR53')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR54'] = VERegIds(SR54, 'SR54')
 *     __Pyx_globals['SR55'] = VERegIds(SR55, 'SR55')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR53); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR53);
    __Pyx_GIVEREF(__pyx_n_s_SR53);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR53);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 329, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR53, __pyx_t_96) < 0)) __PYX_ERR(1, 329, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":330
 *     __Pyx_globals['SR52'] = VERegIds(SR52, 'SR52')
 *     __Pyx_globals['SR53'] = VERegIds(SR53, 'SR53')
 *     __Pyx_globals['SR54'] = VERegIds(SR54, 'SR54')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR55'] = VERegIds(SR55, 'SR55')
 *     __Pyx_globals['SR56'] = VERegIds(SR56, 'SR56')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR54); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR54);
    __Pyx_GIVEREF(__pyx_n_s_SR54);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR54);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 330, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR54, __pyx_t_3) < 0)) __PYX_ERR(1, 330, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":331
 *     __Pyx_globals['SR53'] = VERegIds(SR53, 'SR53')
 *     __Pyx_globals['SR54'] = VERegIds(SR54, 'SR54')
 *     __Pyx_globals['SR55'] = VERegIds(SR55, 'SR55')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR56'] = VERegIds(SR56, 'SR56')
 *     __Pyx_globals['SR57'] = VERegIds(SR57, 'SR57')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 331, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR55); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 331, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 331, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR55);
    __Pyx_GIVEREF(__pyx_n_s_SR55);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR55);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 331, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 331, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR55, __pyx_t_95) < 0)) __PYX_ERR(1, 331, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":332
 *     __Pyx_globals['SR54'] = VERegIds(SR54, 'SR54')
 *     __Pyx_globals['SR55'] = VERegIds(SR55, 'SR55')
 *     __Pyx_globals['SR56'] = VERegIds(SR56, 'SR56')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR57'] = VERegIds(SR57, 'SR57')
 *     __Pyx_globals['SR58'] = VERegIds(SR58, 'SR58')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 332, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR56); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 332, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 332, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR56);
    __Pyx_GIVEREF(__pyx_n_s_SR56);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR56);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 332, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 332, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR56, __pyx_t_96) < 0)) __PYX_ERR(1, 332, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":333
 *     __Pyx_globals['SR55'] = VERegIds(SR55, 'SR55')
 *     __Pyx_globals['SR56'] = VERegIds(SR56, 'SR56')
 *     __Pyx_globals['SR57'] = VERegIds(SR57, 'SR57')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR58'] = VERegIds(SR58, 'SR58')
 *     __Pyx_globals['SR59'] = VERegIds(SR59, 'SR59')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR57); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR57);
    __Pyx_GIVEREF(__pyx_n_s_SR57);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR57);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 333, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR57, __pyx_t_3) < 0)) __PYX_ERR(1, 333, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":334
 *     __Pyx_globals['SR56'] = VERegIds(SR56, 'SR56')
 *     __Pyx_globals['SR57'] = VERegIds(SR57, 'SR57')
 *     __Pyx_globals['SR58'] = VERegIds(SR58, 'SR58')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR59'] = VERegIds(SR59, 'SR59')
 *     __Pyx_globals['SR60'] = VERegIds(SR60, 'SR60')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR58); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR58);
    __Pyx_GIVEREF(__pyx_n_s_SR58);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR58);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 334, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR58, __pyx_t_95) < 0)) __PYX_ERR(1, 334, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":335
 *     __Pyx_globals['SR57'] = VERegIds(SR57, 'SR57')
 *     __Pyx_globals['SR58'] = VERegIds(SR58, 'SR58')
 *     __Pyx_globals['SR59'] = VERegIds(SR59, 'SR59')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR60'] = VERegIds(SR60, 'SR60')
 *     __Pyx_globals['SR61'] = VERegIds(SR61, 'SR61')
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR59); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR59);
    __Pyx_GIVEREF(__pyx_n_s_SR59);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR59);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 335, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR59, __pyx_t_96) < 0)) __PYX_ERR(1, 335, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":336
 *     __Pyx_globals['SR58'] = VERegIds(SR58, 'SR58')
 *     __Pyx_globals['SR59'] = VERegIds(SR59, 'SR59')
 *     __Pyx_globals['SR60'] = VERegIds(SR60, 'SR60')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR61'] = VERegIds(SR61, 'SR61')
 *     __Pyx_globals['SR62'] = VERegIds(SR62, 'SR62')
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR60); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR60);
    __Pyx_GIVEREF(__pyx_n_s_SR60);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR60);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 336, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR60, __pyx_t_3) < 0)) __PYX_ERR(1, 336, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "EnumType":337
 *     __Pyx_globals['SR59'] = VERegIds(SR59, 'SR59')
 *     __Pyx_globals['SR60'] = VERegIds(SR60, 'SR60')
 *     __Pyx_globals['SR61'] = VERegIds(SR61, 'SR61')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR62'] = VERegIds(SR62, 'SR62')
 *     __Pyx_globals['SR63'] = VERegIds(SR63, 'SR63')
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR61); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = PyTuple_New(2); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_GIVEREF(__pyx_t_95);
    PyTuple_SET_ITEM(__pyx_t_96, 0, __pyx_t_95);
    __Pyx_INCREF(__pyx_n_s_SR61);
    __Pyx_GIVEREF(__pyx_n_s_SR61);
    PyTuple_SET_ITEM(__pyx_t_96, 1, __pyx_n_s_SR61);
    __pyx_t_95 = 0;
    __pyx_t_95 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_96, NULL); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 337, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR61, __pyx_t_95) < 0)) __PYX_ERR(1, 337, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;

    /* "EnumType":338
 *     __Pyx_globals['SR60'] = VERegIds(SR60, 'SR60')
 *     __Pyx_globals['SR61'] = VERegIds(SR61, 'SR61')
 *     __Pyx_globals['SR62'] = VERegIds(SR62, 'SR62')             # <<<<<<<<<<<<<<
 *     __Pyx_globals['SR63'] = VERegIds(SR63, 'SR63')
 * 
 */
    __pyx_t_95 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 338, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __pyx_t_96 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR62); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 338, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 338, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_96);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_96);
    __Pyx_INCREF(__pyx_n_s_SR62);
    __Pyx_GIVEREF(__pyx_n_s_SR62);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_SR62);
    __pyx_t_96 = 0;
    __pyx_t_96 = __Pyx_PyObject_Call(__pyx_t_95, __pyx_t_3, NULL); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 338, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 338, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR62, __pyx_t_96) < 0)) __PYX_ERR(1, 338, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;

    /* "EnumType":339
 *     __Pyx_globals['SR61'] = VERegIds(SR61, 'SR61')
 *     __Pyx_globals['SR62'] = VERegIds(SR62, 'SR62')
 *     __Pyx_globals['SR63'] = VERegIds(SR63, 'SR63')             # <<<<<<<<<<<<<<
 * 
 */
    __pyx_t_96 = __Pyx_GetModuleGlobalName(__pyx_n_s_VERegIds); if (unlikely(!__pyx_t_96)) __PYX_ERR(1, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_96);
    __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(__pyx_e_8veosinfo_SR63); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_95 = PyTuple_New(2); if (unlikely(!__pyx_t_95)) __PYX_ERR(1, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_95);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_95, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_n_s_SR63);
    __Pyx_GIVEREF(__pyx_n_s_SR63);
    PyTuple_SET_ITEM(__pyx_t_95, 1, __pyx_n_s_SR63);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_96, __pyx_t_95, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_96); __pyx_t_96 = 0;
    __Pyx_DECREF(__pyx_t_95); __pyx_t_95 = 0;
    if (unlikely(__Pyx_globals == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 339, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__Pyx_globals, __pyx_n_s_SR63, __pyx_t_3) < 0)) __PYX_ERR(1, 339, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_XDECREF(__pyx_t_28);
  __Pyx_XDECREF(__pyx_t_29);
  __Pyx_XDECREF(__pyx_t_30);
  __Pyx_XDECREF(__pyx_t_31);
  __Pyx_XDECREF(__pyx_t_32);
  __Pyx_XDECREF(__pyx_t_33);
  __Pyx_XDECREF(__pyx_t_34);
  __Pyx_XDECREF(__pyx_t_35);
  __Pyx_XDECREF(__pyx_t_36);
  __Pyx_XDECREF(__pyx_t_37);
  __Pyx_XDECREF(__pyx_t_38);
  __Pyx_XDECREF(__pyx_t_39);
  __Pyx_XDECREF(__pyx_t_40);
  __Pyx_XDECREF(__pyx_t_41);
  __Pyx_XDECREF(__pyx_t_42);
  __Pyx_XDECREF(__pyx_t_43);
  __Pyx_XDECREF(__pyx_t_44);
  __Pyx_XDECREF(__pyx_t_45);
  __Pyx_XDECREF(__pyx_t_46);
  __Pyx_XDECREF(__pyx_t_47);
  __Pyx_XDECREF(__pyx_t_48);
  __Pyx_XDECREF(__pyx_t_49);
  __Pyx_XDECREF(__pyx_t_50);
  __Pyx_XDECREF(__pyx_t_51);
  __Pyx_XDECREF(__pyx_t_52);
  __Pyx_XDECREF(__pyx_t_53);
  __Pyx_XDECREF(__pyx_t_54);
  __Pyx_XDECREF(__pyx_t_55);
  __Pyx_XDECREF(__pyx_t_56);
  __Pyx_XDECREF(__pyx_t_57);
  __Pyx_XDECREF(__pyx_t_58);
  __Pyx_XDECREF(__pyx_t_59);
  __Pyx_XDECREF(__pyx_t_60);
  __Pyx_XDECREF(__pyx_t_61);
  __Pyx_XDECREF(__pyx_t_62);
  __Pyx_XDECREF(__pyx_t_63);
  __Pyx_XDECREF(__pyx_t_64);
  __Pyx_XDECREF(__pyx_t_65);
  __Pyx_XDECREF(__pyx_t_66);
  __Pyx_XDECREF(__pyx_t_67);
  __Pyx_XDECREF(__pyx_t_68);
  __Pyx_XDECREF(__pyx_t_69);
  __Pyx_XDECREF(__pyx_t_70);
  __Pyx_XDECREF(__pyx_t_71);
  __Pyx_XDECREF(__pyx_t_72);
  __Pyx_XDECREF(__pyx_t_73);
  __Pyx_XDECREF(__pyx_t_74);
  __Pyx_XDECREF(__pyx_t_75);
  __Pyx_XDECREF(__pyx_t_76);
  __Pyx_XDECREF(__pyx_t_77);
  __Pyx_XDECREF(__pyx_t_78);
  __Pyx_XDECREF(__pyx_t_79);
  __Pyx_XDECREF(__pyx_t_80);
  __Pyx_XDECREF(__pyx_t_81);
  __Pyx_XDECREF(__pyx_t_82);
  __Pyx_XDECREF(__pyx_t_83);
  __Pyx_XDECREF(__pyx_t_84);
  __Pyx_XDECREF(__pyx_t_85);
  __Pyx_XDECREF(__pyx_t_86);
  __Pyx_XDECREF(__pyx_t_87);
  __Pyx_XDECREF(__pyx_t_88);
  __Pyx_XDECREF(__pyx_t_89);
  __Pyx_XDECREF(__pyx_t_90);
  __Pyx_XDECREF(__pyx_t_91);
  __Pyx_XDECREF(__pyx_t_92);
  __Pyx_XDECREF(__pyx_t_93);
  __Pyx_XDECREF(__pyx_t_94);
  __Pyx_XDECREF(__pyx_t_95);
  __Pyx_XDECREF(__pyx_t_96);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init veosinfo", 0, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init veosinfo");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
#include "frameobject.h"
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = f->f_localsplus;
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely((0 <= wrapped_i) & (wrapped_i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely((0 <= wrapped_i) & (wrapped_i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely((n >= 0) & (n < PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* GetModuleGlobalName */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    if (likely(result)) {
        Py_INCREF(result);
    } else if (unlikely(PyErr_Occurred())) {
        result = NULL;
    } else {
#else
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

/* PyObjectCallNoArg */
    #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* ArgTypeTest */
      static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* SliceTupleAndList */
      #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject** CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject* dest;
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (unlikely(length <= 0))
        return PyList_New(0);
    dest = PyList_New(length);
    if (unlikely(!dest))
        return NULL;
    __Pyx_copy_object_array(
        ((PyListObject*)src)->ob_item + start,
        ((PyListObject*)dest)->ob_item,
        length);
    return dest;
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject* dest;
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (unlikely(length <= 0))
        return PyTuple_New(0);
    dest = PyTuple_New(length);
    if (unlikely(!dest))
        return NULL;
    __Pyx_copy_object_array(
        ((PyTupleObject*)src)->ob_item + start,
        ((PyTupleObject*)dest)->ob_item,
        length);
    return dest;
}
#endif

/* SaveResetException */
      #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if PY_VERSION_HEX >= 0x030700A2
    *type = tstate->exc_state.exc_type;
    *value = tstate->exc_state.exc_value;
    *tb = tstate->exc_state.exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if PY_VERSION_HEX >= 0x030700A2
    tmp_type = tstate->exc_state.exc_type;
    tmp_value = tstate->exc_state.exc_value;
    tmp_tb = tstate->exc_state.exc_traceback;
    tstate->exc_state.exc_type = type;
    tstate->exc_state.exc_value = value;
    tstate->exc_state.exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* GetException */
      #if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
#endif
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if PY_VERSION_HEX >= 0x030700A2
    tmp_type = tstate->exc_state.exc_type;
    tmp_value = tstate->exc_state.exc_value;
    tmp_tb = tstate->exc_state.exc_traceback;
    tstate->exc_state.exc_type = local_type;
    tstate->exc_state.exc_value = local_value;
    tstate->exc_state.exc_traceback = local_tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyIntBinop */
        #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AndObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
            return PyInt_FromLong(a & b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_and(op1, op2);
            }
        }
                x = a & b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla & llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    return (inplace ? PyNumber_InPlaceAnd : PyNumber_And)(op1, op2);
}
#endif

/* PyIntBinop */
        #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractCObj(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op2))) {
        const long a = intval;
        long x;
        long b = PyInt_AS_LONG(op2);
            x = (long)((unsigned long)a - b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op2))) {
        const long a = intval;
        long b, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG lla = intval;
        PY_LONG_LONG llb, llx;
#endif
        const digit* digits = ((PyLongObject*)op2)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op2);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            b = likely(size) ? digits[0] : 0;
            if (size == -1) b = -b;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        b = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        b = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        b = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        b = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        b = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        b = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op2)) {
        const long a = intval;
        double b = PyFloat_AS_DOUBLE(op2);
            double result;
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* PyIntBinop */
        #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddCObj(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op2))) {
        const long a = intval;
        long x;
        long b = PyInt_AS_LONG(op2);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op2))) {
        const long a = intval;
        long b, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG lla = intval;
        PY_LONG_LONG llb, llx;
#endif
        const digit* digits = ((PyLongObject*)op2)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op2);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            b = likely(size) ? digits[0] : 0;
            if (size == -1) b = -b;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        b = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        b = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        b = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        b = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        b = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        b = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op2)) {
        const long a = intval;
        double b = PyFloat_AS_DOUBLE(op2);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyObjectSetAttrStr */
        #if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyErrExceptionMatches */
        #if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetAttr */
        static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
        static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* Import */
        static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
        static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* HasAttr */
        static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* PyObject_GenericGetAttrNoDict */
        #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
        #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetupReduce */
        static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_cython); if (unlikely(!reduce_cython)) goto BAD;
            ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto BAD;
            ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto BAD;
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate_cython); if (unlikely(!setstate_cython)) goto BAD;
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto BAD;
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto GOOD;
BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* CalculateMetaclass */
        static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* FetchCommonType */
        static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunction */
        #include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* Py3ClassCreate */
            static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

/* Globals */
            static PyObject* __Pyx_Globals(void) {
    Py_ssize_t i;
    PyObject *names;
    PyObject *globals = __pyx_d;
    Py_INCREF(globals);
    names = PyObject_Dir(__pyx_m);
    if (!names)
        goto bad;
    for (i = PyList_GET_SIZE(names)-1; i >= 0; i--) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject* name = PySequence_ITEM(names, i);
        if (!name)
            goto bad;
#else
        PyObject* name = PyList_GET_ITEM(names, i);
#endif
        if (!PyDict_Contains(globals, name)) {
            PyObject* value = __Pyx_GetAttr(__pyx_m, name);
            if (!value) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                goto bad;
            }
            if (PyDict_SetItem(globals, name, value) < 0) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                Py_DECREF(value);
                goto bad;
            }
        }
#if CYTHON_COMPILING_IN_PYPY
        Py_DECREF(name);
#endif
    }
    Py_DECREF(names);
    return globals;
bad:
    Py_XDECREF(names);
    Py_XDECREF(globals);
    return NULL;
}

/* CLineInTraceback */
            #ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
      use_cline = __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback);
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (PyObject_Not(use_cline) != 0) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
            static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
            #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
            #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum____pyx_t_8veosinfo_VERegIds(enum __pyx_t_8veosinfo_VERegIds value) {
    const enum __pyx_t_8veosinfo_VERegIds neg_one = (enum __pyx_t_8veosinfo_VERegIds) -1, const_zero = (enum __pyx_t_8veosinfo_VERegIds) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum __pyx_t_8veosinfo_VERegIds) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum __pyx_t_8veosinfo_VERegIds) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum __pyx_t_8veosinfo_VERegIds) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum __pyx_t_8veosinfo_VERegIds) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum __pyx_t_8veosinfo_VERegIds) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum __pyx_t_8veosinfo_VERegIds),
                                     little, !is_unsigned);
    }
}

static PyObject* __pyx_convert__to_py_struct__ve_archinfo(struct ve_archinfo s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(3); if (unlikely(!res)) return NULL;
              member = __Pyx_PyObject_FromString(s.machine); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_machine, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.processor); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_processor, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.hw_platform); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_hw_platform, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            /* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

static PyObject* __pyx_convert__to_py_struct__ve_cpuinfo(struct ve_cpuinfo s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(15); if (unlikely(!res)) return NULL;
              member = __Pyx_PyInt_From_int(s.cores); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cores, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.thread_per_core); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_thread_per_core, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.core_per_socket); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_core_per_socket, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.socket); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_socket, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.vendor); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_vendor, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.family); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_family, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.model); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_model, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.modelname); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_modelname, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.mhz); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_mhz, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.stepping); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_stepping, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.bogomips); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_bogomips, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.nnodes); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_nnodes, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.op_mode); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_op_mode, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_char___5b_VE_BUF_LEN_5d_(s.cache_name, VE_MAX_CACHE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cache_name, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_int(s.cache_size, VE_MAX_CACHE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cache_size, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            /* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_long(unsigned long value) {
    const unsigned long neg_one = (unsigned long) -1, const_zero = (unsigned long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(unsigned long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(unsigned long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(unsigned long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(unsigned long),
                                     little, !is_unsigned);
    }
}

static PyObject* __pyx_convert__to_py_struct__ve_loadavg(struct ve_loadavg s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(5); if (unlikely(!res)) return NULL;
              member = PyFloat_FromDouble(s.av_1); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_av_1, member) < 0)) goto bad;
              Py_DECREF(member);
              member = PyFloat_FromDouble(s.av_5); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_av_5, member) < 0)) goto bad;
              Py_DECREF(member);
              member = PyFloat_FromDouble(s.av_15); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_av_15, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.runnable); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_runnable, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.total_proc); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_total_proc, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            static PyObject* __pyx_convert__to_py_struct__ve_meminfo(struct ve_meminfo s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(20); if (unlikely(!res)) return NULL;
              member = __Pyx_PyInt_From_unsigned_long(s.kb_main_total); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_main_total, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_main_used); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_main_used, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_main_free); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_main_free, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_main_shared); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_main_shared, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_main_buffers); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_main_buffers, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_main_cached); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_main_cached, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_swap_cached); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_swap_cached, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_low_total); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_low_total, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_low_free); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_low_free, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_high_total); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_high_total, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_high_free); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_high_free, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_swap_total); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_swap_total, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_swap_free); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_swap_free, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_active); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_active, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_inactive); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_inactive, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_dirty); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_dirty, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_committed_as); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_committed_as, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.hugepage_total); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_hugepage_total, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.hugepage_free); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_hugepage_free, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kb_hugepage_used); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kb_hugepage_used, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            static PyObject* __pyx_convert__to_py_struct__ve_nodeinfo(struct ve_nodeinfo s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(4); if (unlikely(!res)) return NULL;
              member = __Pyx_carray_to_py_int(s.nodeid, VE_MAX_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_nodeid, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_int(s.status, VE_MAX_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_status, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_int(s.cores, VE_MAX_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cores, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.total_node_count); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_total_node_count, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            /* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_char(char value) {
    const char neg_one = (char) -1, const_zero = (char) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(char) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(char) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(char) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(char) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(char) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(char),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_int(unsigned int value) {
    const unsigned int neg_one = (unsigned int) -1, const_zero = (unsigned int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(unsigned int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(unsigned int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(unsigned int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(unsigned int),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_PY_LONG_LONG(unsigned PY_LONG_LONG value) {
    const unsigned PY_LONG_LONG neg_one = (unsigned PY_LONG_LONG) -1, const_zero = (unsigned PY_LONG_LONG) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(unsigned PY_LONG_LONG) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(unsigned PY_LONG_LONG) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned PY_LONG_LONG) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(unsigned PY_LONG_LONG) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned PY_LONG_LONG) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(unsigned PY_LONG_LONG),
                                     little, !is_unsigned);
    }
}

static PyObject* __pyx_convert__to_py_struct__ve_pidstat(struct ve_pidstat s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(36); if (unlikely(!res)) return NULL;
              member = __Pyx_PyInt_From_char(s.state); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_state, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.ppid); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_ppid, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.processor); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_processor, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_long(s.priority); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_priority, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_long(s.nice); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_nice, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_int(s.policy); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_policy, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_int(s.rt_priority); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_rt_priority, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_PY_LONG_LONG(s.utime); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_utime, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_long(s.cguest_time); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cguest_time, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_long(s.guest_time); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_guest_time, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_PY_LONG_LONG(s.cutime); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cutime, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_PY_LONG_LONG(s.stime); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_stime, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_PY_LONG_LONG(s.cstime); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cstime, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_PY_LONG_LONG(s.wchan); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_wchan, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.flags); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_flags, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.vsize); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_vsize, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.rsslim); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_rsslim, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.startcode); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_startcode, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.endcode); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_endcode, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.startstack); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_startstack, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.kstesp); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_kstesp, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.ksteip); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_ksteip, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_long(s.rss); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_rss, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.min_flt); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_min_flt, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.maj_flt); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_maj_flt, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.cmin_flt); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cmin_flt, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.cmaj_flt); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cmaj_flt, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.maj_delta); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_maj_delta, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.min_delta); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_min_delta, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_PY_LONG_LONG(s.blkio); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_blkio, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_PY_LONG_LONG(s.nswap); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_nswap, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_PY_LONG_LONG(s.cnswap); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cnswap, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_PY_LONG_LONG(s.itrealvalue); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_itrealvalue, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyObject_FromString(s.cmd); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cmd, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.start_time); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_start_time, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyBool_FromLong(s.whole); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_whole, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            static PyObject* __pyx_convert__to_py_struct__ve_pwr_fan(struct ve_pwr_fan s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(5); if (unlikely(!res)) return NULL;
              member = __Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_(s.device_name, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_device_name, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.count); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_count, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_double(s.fan_min, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_fan_min, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_double(s.fan_max, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_fan_max, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_double(s.fan_speed, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_fan_speed, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            static PyObject* __pyx_convert__to_py_struct__ve_pwr_temp(struct ve_pwr_temp s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(5); if (unlikely(!res)) return NULL;
              member = __Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_(s.device_name, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_device_name, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.count); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_count, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_double(s.temp_min, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_temp_min, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_double(s.temp_max, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_temp_max, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_double(s.ve_temp, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_ve_temp, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            static PyObject* __pyx_convert__to_py_struct__ve_pwr_voltage(struct ve_pwr_voltage s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(5); if (unlikely(!res)) return NULL;
              member = __Pyx_carray_to_py_char___5b_MAX_DEVICE_LEN_5d_(s.device_name, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_device_name, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_int(s.count); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_count, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_double(s.volt_min, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_volt_min, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_double(s.volt_max, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_volt_max, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_double(s.cpu_volt, MAX_POWER_DEV); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_cpu_volt, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            static PyObject* __pyx_convert__to_py_struct__ve_statinfo(struct ve_statinfo s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(16); if (unlikely(!res)) return NULL;
              member = __Pyx_carray_to_py_unsigned_PY_LONG_LONG(s.user, VE_MAX_CORE_PER_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_user, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_unsigned_PY_LONG_LONG(s.nice, VE_MAX_CORE_PER_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_nice, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_unsigned_PY_LONG_LONG(s.idle, VE_MAX_CORE_PER_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_idle, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_unsigned_PY_LONG_LONG(s.iowait, VE_MAX_CORE_PER_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_iowait, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_unsigned_PY_LONG_LONG(s.sys, VE_MAX_CORE_PER_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_sys, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_unsigned_PY_LONG_LONG(s.hardirq, VE_MAX_CORE_PER_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_hardirq, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_unsigned_PY_LONG_LONG(s.softirq, VE_MAX_CORE_PER_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_softirq, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_unsigned_long(s.steal, VE_MAX_CORE_PER_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_steal, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_unsigned_long(s.guest, VE_MAX_CORE_PER_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_guest, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_carray_to_py_unsigned_long(s.guest_nice, VE_MAX_CORE_PER_NODE); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_guest_nice, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_int(s.intr); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_intr, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_int(s.ctxt); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_ctxt, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_int(s.running); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_running, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_int(s.blocked); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_blocked, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.btime); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_btime, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_int(s.processes); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_processes, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            static PyObject* __pyx_convert__to_py_struct__ve_vmstat(struct ve_vmstat s) {
              PyObject* res;
              PyObject* member;
              res = __Pyx_PyDict_NewPresized(8); if (unlikely(!res)) return NULL;
              member = __Pyx_PyInt_From_unsigned_long(s.pgfree); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_pgfree, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.pgscan_direct); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_pgscan_direct, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.pgsteal); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_pgsteal, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.pswpin); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_pswpin, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.pswpout); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_pswpout, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.pgfault); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_pgfault, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.pgmajfault); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_pgmajfault, member) < 0)) goto bad;
              Py_DECREF(member);
              member = __Pyx_PyInt_From_unsigned_long(s.pgscan_kswapd); if (unlikely(!member)) goto bad;
              if (unlikely(PyDict_SetItem(res, __pyx_n_s_pgscan_kswapd, member) < 0)) goto bad;
              Py_DECREF(member);
              return res;
              bad:
              Py_XDECREF(member);
              Py_DECREF(res);
              return NULL;
            }
            /* CIntToPy */
            static CYTHON_INLINE PyObject* __Pyx_PyInt_From_uint64_t(uint64_t value) {
    const uint64_t neg_one = (uint64_t) -1, const_zero = (uint64_t) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(uint64_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(uint64_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(uint64_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(uint64_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(uint64_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(uint64_t),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
            static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
            static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *x) {
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(size_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(size_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (size_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(size_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 2 * PyLong_SHIFT) {
                            return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 3 * PyLong_SHIFT) {
                            return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 4 * PyLong_SHIFT) {
                            return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (size_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(size_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(size_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(size_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(size_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            size_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (size_t) -1;
        }
    } else {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyInt_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* CIntFromPy */
            static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* FastTypeChecks */
            #if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
            static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
            static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(x);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
